#!/usr/bin/perl

use strict;
use warnings;

use Getopt::Long;

use F5::ASMConfig::Client;
use F5::ASMReady;
use F5::Logger;

my $use_daemon = 1;
my $check_asm_ready = 1;
GetOptions('check-asm-ready!' => \$check_asm_ready,
          );

my $retval = 0;
my $logger = F5::Logger->get_logger(logger_name => 'clustering');

eval {
    if ($check_asm_ready && ! F5::ASMReady::is_asm_ready()) {
        $logger->info("Applying request log sync files skipped while ASM is not ready");
        exit;
    }

    my $client = F5::ASMConfig::Client->new(username => 'apply_request_log_sync.pl');
    my $session = $client->{session};
    my $call_flags = F5::ASMConfig::CallFlags->new({});

    $retval = $client->apply_request_log_sync($session, $call_flags);

};
if ($@) {
    my $error_msg = $@;
    if (ref($@)) {
        if ($@->{error_message}) {
            $error_msg = $@->{error_message};
        }
        elsif ($@->{message}) {
            $error_msg = $@->{message};
        }
    }

    $logger->error("Request log sync file could not be applied - $error_msg");
    die "Could not apply sync - $error_msg\n";
}

exit;
