#!/usr/bin/perl

use strict;
use warnings;

use F5::ASMConfig::EasyClient;
use F5::ASMReady;
use F5::Logger;
use F5::DbUtils;
use F5::Cluster::Sync;

use Getopt::Long;

my $use_daemon = 1;
my $check_asm_ready = 1;
GetOptions('use-daemon!' => \$use_daemon,
           'check-asm-ready!' => \$check_asm_ready,
          );

my $retval = 0;
my $logger = F5::Logger->get_logger(logger_name => 'clustering');

my $trigger_filename = $ARGV[0] || '';
$logger->debug("Apply sync file startup (trigger file = $trigger_filename)") if $logger;
eval {
    if ($check_asm_ready && ! F5::ASMReady::is_asm_ready()) {
        $logger->info("Applying sync files skipped while ASM is not ready");
        exit;
    }

    if ($use_daemon) {
        my $client = F5::ASMConfig::EasyClient->new(username => 'apply_sync.pl');
        my $session = $client->{session};
        my $call_flags = F5::ASMConfig::CallFlags->new();

        $logger->debug("Calling send_apply_cluster_sync_event via ASM-config") if $logger;
        $client->send_apply_cluster_sync_event($session, $call_flags);
        $retval = 1;
    }
    else {
        my $cluster_sync = F5::Cluster::Sync->new(dbh => F5::DbUtils::get_dbh(),
                                                  logger => $logger);

        $cluster_sync->apply_sync(check_asm_ready => $check_asm_ready);
        # Always return successfully - apply_sync fails are already logged elsewhere
        $retval = 1;
    }

};
if ($@ || ! $retval) {
    my $error_msg = $@;
    if (ref($@)) {
        if ($@->{error_message}) {
            $error_msg = $@->{error_message};
        }
        elsif ($@->{message}) {
            $error_msg = $@->{message};
        }
    }

    $logger->error("Sync file could not be applied - $error_msg");
    die "Could not apply sync - $error_msg\n";
}

$logger->debug("Apply sync file complete (trigger file = $trigger_filename)") if $logger;

exit;
