#!/usr/bin/perl
use strict; 
use warnings;

use YAML::XS;
use F5::Deploy;
use F5::ASM::COAPI;

F5::ASM::COAPI::Login("%asm_php_ini_munge");
if ($@) {
    print("cannot login to MCP: $F5::COAPI::error");
}

local $/;
my $mode = shift || 'on';
my $php_ini = "/etc/php.ini.d/asm.php.extensions.ini";
my $security_header_conf_file = "/etc/httpd/conf.d/asm_security_headers_fix.conf";
my $data = <DATA>;
my $num_actions_finished = 0;

if ( $mode eq 'off' ) {
    
    if ( -f $php_ini ) {
        unlink $php_ini or die "unlink($php_ini): $!\n";
        $num_actions_finished++;
    }
    
    if ( -f $security_header_conf_file ) {
        unlink $security_header_conf_file or die "unlink($security_header_conf_file): $!\n";
        $num_actions_finished++;
    }
}
else {
    if ( not -f $php_ini ) {
        open( my $fh_a, '>', $php_ini ) or die "open($php_ini): $!\n";
        print $fh_a $data;
        close $fh_a;
        $num_actions_finished++;
    }

    my $SCANNERS_CONFIG_FILENAME = F5::Deploy::map_path('/usr/share/ts/config/scanners_config.yaml');
    my $scanners_config = YAML::XS::LoadFile($SCANNERS_CONFIG_FILENAME);
    
    my $service_urls = [];
    extract_urls($scanners_config, $service_urls);
    cloud_services_urls($service_urls);
    my $fixed_headers = 'SetEnv ALLOWED_SECURITY_SOURCES "' . join(' ', @$service_urls) . '"';
    
    open( my $fh_b, '>', $security_header_conf_file ) or die "open($security_header_conf_file): $!\n";
    print $fh_b $fixed_headers;
    close $fh_b;
    $num_actions_finished++;
}

if($num_actions_finished > 0) {
    exit(12);
}
 
sub extract_urls {
    my ($elemVal, $service_urls) = @_; 

    my $type = ref $elemVal;
    
    if ($type eq 'HASH') {
        for my $key (keys %$elemVal) {
            extract_urls($elemVal->{$key}, $service_urls);
        }
    }
    if ($type eq 'ARRAY') {
        for my $arrVal (@$elemVal) {
            extract_urls($arrVal, $service_urls);
        }
    }
    if (!$type) {
        if ($elemVal =~ m|^https?://|) {
            push @$service_urls, $elemVal;
        }
    }
}

sub cloud_services_urls {
    my ($service_urls) = @_; 

    # Do not add URLs if Cloud Services is not enabled
    my ($obj) = @{F5::ASM::COAPI::Query->new("db_variable", {name => "security.cloud_services.allow"})};
    if (!$obj || $obj->{value} ne "enable") {
        return;
    }

    # Add the URL from the DB variable
    ($obj) = @{F5::ASM::COAPI::Query->new("db_variable", {name => "security.cloud_services.default_url"})};
    if ($obj && $obj->{value}) {
        my $url = $obj->{value};
        $url =~ s|^([^/]*//[^/]*).*$|$1|; #strip path from url
        push @$service_urls, $url;
    }

    # Add the URL from each connector object
    my $objs = F5::ASM::COAPI::Query->new("cloud_services_connector");
    for $obj (@$objs) {
        my $url = $obj->{control_url};
        if ($url) {
            $url =~ s|^([^/]*//[^/]*).*$|$1|; #strip path from url
            push @$service_urls, $url;
        }
    }
}

__DATA__
extension=hsl.so
; mcp.so and php_bridge.so are now loaded in php.ini directly
;extension=mcp.so
;extension=php_bridge.so
