#!/usr/bin/perl

use strict;
use warnings;


use F5::DbUtils;
use Getopt::Long;
use Cwd;
use File::Basename;
use F5::XML::Twig;
use F5::XML::WSDL::Convert;

local $" = ',';

my $xml_profile_name;
my $schema_document;
my %schema_composition_mappings;

GetOptions('p|xml_profile_name=s' => \$xml_profile_name);

my $dbh = F5::DbUtils::get_dbh();

my($profile_id) = $dbh->selectrow_array(<<EndQuery, undef, $xml_profile_name);
SELECT id 
  FROM PLC.PL_CONTENT_PROFILES 
 WHERE profile_name = ?
   AND flg_is_temporary = 0
EndQuery

my $temp_schema_dir = getcwd();
mkdir $temp_schema_dir unless -d $temp_schema_dir;

my @validation_file_fields = qw(id validation_file_name validation_file_type validation_file_contents import_url flg_is_primary_enforced);

my $validation_files_sth = $dbh->prepare(<<EndQuery);
SELECT @validation_file_fields
  FROM PLC.PL_XML_PROFILE_VALIDATION_FILES
 WHERE profile_id = ?
EndQuery

$validation_files_sth->execute($profile_id);
my $file_count = 0;
my %wsdl_composition_mappings;
my $primary_validation_file;
while (my $validation_file = $validation_files_sth->fetchrow_hashref) {
  $file_count++;
  $validation_file->{local_filename} = "$temp_schema_dir/" . basename($validation_file->{validation_file_name});
  open(my $outf, '>', $validation_file->{local_filename});
  print $outf $validation_file->{validation_file_contents};
  close $outf;

  $validation_file->{is_wsdl} = is_wsdl($validation_file->{validation_file_contents});

  # Save memory by releasing the file contents before storing the row
  delete $validation_file->{validation_file_contents};
  if ($validation_file->{flg_is_primary_enforced}) {
    $primary_validation_file = $validation_file;
  }
  else {
    if ($validation_file->{is_wsdl}) {
      $wsdl_composition_mappings{$validation_file->{import_url}} = $validation_file->{local_filename};
    } 
    else {
      $schema_composition_mappings{$validation_file->{import_url}} = $validation_file->{local_filename};
    }
  }
}

if ($primary_validation_file->{is_wsdl}) {
  my $wsdl_attribs = F5::XML::WSDL::Convert::convert_wsdl(wsdl_filename => $primary_validation_file->{local_filename},
                                                          wsdl_composition_mappings => \%wsdl_composition_mappings,
                                                          schema_dir => $temp_schema_dir);
  unless ($wsdl_attribs->{completed_successfully}) {
    die "$wsdl_attribs->{error_msg}\n";
  }

  $primary_validation_file->{local_filename} = $wsdl_attribs->{schema_document};
  %schema_composition_mappings = (%schema_composition_mappings,
                                  %{$wsdl_attribs->{schema_composition_mappings}});
}

#----------------------------------------------------------------------

sub is_wsdl {
  my($file_contents) = @_;

  my $twig = F5::XML::Twig->new( start_tag_handlers => {
                                                    'wsdl:definition'=> sub { 
                                                      my($twig, $elm) = @_;
                                                      $twig->finish;
                                                    }
                                                   },
                             map_xmlns => {
                                           "http://schemas.xmlsoap.org/wsdl/" => 'wsdl',
                                           'http://schemas.xmlsoap.org/wsdl/soap/' => 'soap',
                                          },
                             keep_original_prefix => 1,
                           );

  $twig->safe_parse($file_contents);
  if ($twig && $twig->root && $twig->root->name eq 'wsdl:definitions') {
    return 1;
  }
  return;
}

