#!/usr/bin/perl
use warnings;
use strict;
my $params=handle_commandline_arguments();
binmode STDIN;
my %pointers;
while(my $line=<>) {
	next unless $line=~/^\s*(free|malloc|calloc)\s*:\s+(\S+)/;
	my ($operator,$address) = ($1,$2);
	if (exists $pointers{$address}) {
		if ($params->{verbose}) {
			if ($operator=~/free/) {
				# its ok, we had some allocation before
				# and now we are freeing that allocation
			} else {
				print "Expected a /free/ but operator was /$operator/ on $address\n";
			}
		}
		delete($pointers{$address});
	} else {
		push @{$pointers{$address}},$line;
		if ($params->{verbose}) {
			if ($operator=~/free/) {
				print "Expected some allocation operator but /free/ was used\n";
			}
		}
	}
}
while (my ($k,$v) = each %pointers) {
	print "LEAK: $k:";
	map {chomp $_ ; print " |$_| "} @$v;
	print "\n";
}
sub handle_commandline_arguments {
	while (my $argument = shift @ARGV) {
		if ($argument=~/-h|--help/) {
			usage();
			exit 0;
		}
		if ($argument=~/-v|--verbose/) {
			return {verbose=>1};
		}
	}
	return {};
}

sub usage {
	print qq{
USAGE:
	cat bd.log | $0 [--help|--verbose]



You'll need to get a bd.log containing debug printouts for every memory
allocation and release.
	\n};
}
