#!/usr/bin/perl

use strict;
use warnings;

use Getopt::Long;
use F5::NegativeSignatures;
use F5::NegativeSignatures::Collection;
use F5::DbUtils;

my $output_filename;
my $apply_to;
GetOptions('O|output=s' => \$output_filename,
           'apply_to=s' => \$apply_to,
          );

die "Output file must be specified!\n" unless $output_filename;

my %filter;
if ($apply_to) {
  $filter{apply_to} = $apply_to;
}

my $dbh = F5::DbUtils::get_dbh() or die "Could not connect to database";
my $negative_signatures = F5::NegativeSignatures->new($dbh);
my $signatures = $negative_signatures->get_signatures({filter => \%filter});

my $sig_ids = [ map { $_->{sig_id} } @{$signatures->{results}} ];

my $collection = F5::NegativeSignatures::Collection->new(dbh => $dbh,
                                                         sig_ids => $sig_ids);

my $output_fh;
if ($output_filename eq '-') {
  open($output_fh, ">&=STDOUT");
} 
else {
  open($output_fh, ">$output_filename");
}

print $output_fh $collection->get_compiled_collection;
close $output_fh;


