#!/usr/bin/perl

use strict;
use warnings;

use JSON;
use F5::NegativeSignatures;
use F5::DbUtils;


my $request = from_json(<>);

die "Input is not a valid JSON hash" unless ($request && ref($request) eq 'HASH');

my $dbh = F5::DbUtils::get_dbh() or die "Could not connect to database";

my $negative_signatures = F5::NegativeSignatures->new($dbh);
my $result;

if (exists $request->{get_policies} && $request->{get_policies}) {
  if (exists $request->{sig_id}) {
    $result = { policies => [ $negative_signatures->get_policies_using_signatures($request->{sig_id}) ] };
  }
  elsif (exists $request->{set_id}) {
    $result = { policies => [ $negative_signatures->get_policies_using_sets($request->{set_id}) ] };
  }
}
else {
  if (exists $request->{sig_id}) {
    $result = { sets => [ $negative_signatures->get_sets_for_signature($request->{sig_id}) ] };
  } else {
    $result = $negative_signatures->get_signatures($request);
  }
}

print to_json($result) . "\n";

