#!/usr/bin/perl

use strict;
use warnings;

use F5::ASMConfig::EasyClient;
use F5::ASMReady;
use F5::Logger;

my $logger = F5::Logger->get_logger(logger_name => 'clustering');
my $trigger_filename = $ARGV[0] || '';
$logger->debug("Handle sync status file startup (trigger file = $trigger_filename)") if $logger;

my $retval = 0;
eval {
    if (! F5::ASMReady::is_asm_ready()) {
        $logger->info("Updating sync status files skipped while ASM is not ready");
        exit;
    }

    my $client = F5::ASMConfig::EasyClient->new(username => 'get_sync_status_file.pl');
    my $session = $client->{session};
    my $call_flags = F5::ASMConfig::CallFlags->new({});

    $retval = $client->get_sync_status_file($session, $call_flags);
};
if ($@ || ! $retval) {
    $logger->error("Sync status file could not be saved - $@");

    die "Could not update sync status - $@\n";
}

$logger->debug("Handle sync status file complete (trigger file = $trigger_filename)") if $logger;

exit;
