#!/usr/bin/perl

#####################################################################################
# Tool name: handle_certificate
# Description: verify a certificate OR upload a certificate
# Usage: - for verification: ./handle_certificate -m verify -f /pem/file/path/file.pem
#        - for upload: ./handle_certificate -m upload -id XX
#                                                 (XX= ssl_cert_id)
######################################################################################

use strict;
use warnings;

use JSON;
use Getopt::Long;
use F5::Logger;
use F5::Certificates;


 my $logger = F5::Logger->new('/ts/log/handle_certificate.log');
 $logger->log_level('info');

 my $mode = 'verify';  # mode = verify/upload
 my $pem_file;
 my $pem_file_content = '';
 my $ssl_cert_id;
 my $res;
 my $help;

    GetOptions(
                 'f|file=s'          => \$pem_file,
                 'm|mode=s'          => \$mode,
                 'id|ssl_cert_id=i'  => \$ssl_cert_id,
                 'h|help'            => \$help,
               );


 exit usage() if ($help || (($mode ne 'verify')&&($mode ne 'upload')));


 if($mode eq 'upload'){ 
    $res = F5::Certificates::upload_certificate(ssl_cert_id => $ssl_cert_id, logger => $logger);
  }
 elsif($mode eq 'verify'){
     if(not defined $pem_file){
        exit usage();
     }

   my $fh;
   if(!  open($fh, "<", $pem_file) ) {
          $res = {
                     completed_successfully => 0,
                     error_message => "Could not open '$pem_file': $!\n",
                 };
          $logger->error("Could not open '$pem_file': $!");
          print to_json($res) . "\n"; 
          exit;

    }

    $pem_file_content = join('', <$fh>);
    close $fh;

    $res = F5::Certificates::verify_certificate(pem_file_content => $pem_file_content, logger => $logger);
  }

 if($res->{completed_successfully}){
   $logger->debug("$mode : completed_successfully");
 }
 else
 {
    $logger->error("$mode : failed, $res->{error_message}");
 }

 print to_json($res) . "\n";

#----------------------------------------------------------------------------
# Sub: usage
#----------------------------------------------------------------------------
sub usage {
   print "Usage:
$0 <mode> <options>
Options are:
-h|--help
-m|--mode mode can be verify or upload
-id|--ss_cert_id in case of upload, you must give the ssl_cert_id
-f|--file in case of 'verify', you must give a  pem file for verification
";

}

