#!/usr/bin/perl

use strict;
use warnings;

use JSON;
use F5::XML::Twig;
use F5::DbUtils;
use F5::NegativeSignatures::SigFile::Update;
use F5::Logger;

use F5::Syslog;
use F5::ASMConfig::EasyClient;
use Cwd;

my $version;
my $license_text;

my $twig = F5::XML::Twig->new(
    twig_handlers => {
        '/asmAttackSignatureImage/version' => sub { $version = $_->text },
        '/asmAttackSignatureImage/entitlement/license' => sub { $license_text = $_->text },
    }
);

$twig->safe_parsefile("metadata.xml");


my $logger = F5::Logger->new('/ts/log/im.log');

my $client = F5::ASMConfig::EasyClient->new( username => 'im', logger => $logger);
my $session = $client->{session};
my $call_flags = F5::ASMConfig::CallFlags->new({});

my $retval = $client->update_sigfile(
    $session,
    $call_flags,
    F5::ASMConfig::Sigfile->new({ filename => getcwd() . "/" . $ARGV[0],}),
    F5::ASMConfig::SigfileUpdateSettings->new({license_text => $license_text}));


if ($retval->{completed_successfully}) {
    if ($license_text) {
        F5::Syslog::ts_syslog( 'info', "Device was updated with a new signature file $version by Enterprise Manager" );
    } else {
        F5::Syslog::ts_syslog( 'info', "Device was updated with a new signature file $version" );
    }
} 
else {
    print $retval->{error_msg};
    exit 1;
}
