#!/usr/bin/perl

#******************************************************************************
#copyright 2000-2003 Magnifire Networks Ltd. All Right Reserved.
#
#FILE: is_ip_exist.pl  
#
#USES: Logger.pm
#
#CREATED: 02 Mar 2004 By Leonid Klebanov
#
#MODIFIED:
#
#COMMENTS: checking if ip unique

#*******************************************************************************


#$Header$

use strict;
use Cwd;
use File::Basename;
use Getopt::Long;

# tsdev includes
use F5::Logger qw(:LEGACY_ERROR_CONSTANTS);

use F5::Iface;

use constant IFACE_0 => 0;
use constant IFACE_1 => 1;

use vars qw{$TS_ROOT
	    $DEBUG
	    $PRINT_TARGET
	    $LOG_FILE
  	};


# defaults

$DEBUG = 1;
$PRINT_TARGET = 1;
$LOG_FILE = 'is_ip_exist.log';

use constant  FALSE       => 0;
use constant  TRUE        => 1;

# script return values

use constant  RET_EXIST       => 0;
use constant  RET_NOT_EXIST   => 1;
use constant  RET_FAILURE     => -1;
use constant  IFACE_ALL       => -1;


my $CHECK_PACKETS = 3;
my $RESULT_LOCATION = 0;
my $MAC_LOCATION = 4;
my $UNICAST = 'Unicast';
my $INTERFACE = IFACE_ALL;
my $IFACE_0_NAME = "eth0.11";
my $IFACE_1_NAME = "eth0.12";


$TS_ROOT = '/ts'; 
my $LOGGER = F5::Logger->new($TS_ROOT.'/log/'.$LOG_FILE, $PRINT_TARGET);

my $TS_VER = '27.4.1';

#*****************************  MAIN  start  *****************************

my $ret = 0;


# check script arguments

if ( $#ARGV < 0)
{
   iie_logprint($ERR, undef, "Usage: is_ip_exist <ip> [-c arping_packets] [-i interface_ind]"); 
   print RET_FAILURE;
   exit(RET_FAILURE);
}

 
my $ip_addr = $ARGV[0];

GetOptions(
# value
    'c=s'       => \$CHECK_PACKETS,
    'i=s'       => \$INTERFACE,
);
my $value = F5::Iface::iface_get_iface(IFACE_0);
$IFACE_0_NAME =  $value if defined $value;
$value = F5::Iface::iface_get_iface(IFACE_1);
$IFACE_1_NAME =  $value if defined $value;

# check if address is unique


if(($INTERFACE == IFACE_0) || ($INTERFACE == IFACE_ALL))
{
   my $cmd_res = (qx/arping -I $IFACE_0_NAME -D $ip_addr -c $CHECK_PACKETS/)[1];
   handle_arping_result($cmd_res);
}

if(($INTERFACE == IFACE_1) || ($INTERFACE == IFACE_ALL))
{
   my $cmd_res = (qx/arping -I $IFACE_1_NAME -D $ip_addr -c $CHECK_PACKETS/)[1];
   handle_arping_result($cmd_res);
}
# duplicate addr not found on the local network
    
print RET_NOT_EXIST;
exit(RET_NOT_EXIST);


#*****************************  MAIN  end  *****************************
#--------------------------------------------------------------------------------
sub handle_arping_result   
{
   my ($cmd_res) =  @_;
   my @arr = split(" ", $cmd_res);

   if( $arr[$RESULT_LOCATION] eq $UNICAST)
   {
      # duplicate addr found
   
      # extact the mac addr
  
      $arr[$MAC_LOCATION] =~ /\[(.+)\]/;

      # checking if found address not from local interfaces
  
      if ( ($1 ne F5::Iface::get_mac_addr('eth0')) && ($1 ne F5::Iface::get_mac_addr('eth1'))) 
      {
         # duplicate ip address belong to intrface $1 

         print $1;
         exit(RET_EXIST); 
      }
   
   }

}
#--------------------------------------------------------------------------------
sub iie_logprint
{     
    my $level = shift;
    return 0 if(($level eq $DBG) and ($DEBUG == 0));
    $LOGGER->log_print($level, shift, shift);
}


#--------------------------------------------------------------------------------
