#!/usr/bin/perl -w

# mpidump_all.pl

use strict;
use Getopt::Std;
use File::Basename;

use F5::NwdUtils;

sub usage {
  my($mess) = @_;

  die "${\($mess ? qq/Error: $mess\n/ : '')}
Usage: ${\(basename $0)} [flags] [-- <args>]
  -H     use HSL
  -a     don't run, just print calculated args
  -h     print help

  This program calculates the correct channel parameters and runs mpidump on a BIGIP.
  To pass real mpidump arguments, you must insert --

";
}

use vars qw($opt_H $opt_a $opt_h);
getopts("Hah") or usage;
usage if $opt_h;

my $num_threads = F5::NwdUtils::get_relevant_cpu_count(consider_wa => 1);

my ($major_version) = `cat /VERSION` =~ /Version: (\d+)/;
my $pre = $major_version >= 10 ? 'mem://' : '';
my $post = $opt_H ? '_hslhttp' : '';
my $channel_arg = "";
foreach (my $i=0; $i < $num_threads; $i++) {
  $channel_arg .= " -c ${pre}bd${post}$i";
}

if ($opt_a) {
  print "$channel_arg\n";
  exit 0;
}

system "mpidump $channel_arg @ARGV";
