#!/usr/bin/perl

use strict;
use warnings;

use F5::Cfg;
use F5::Provisioning;

use F5::Syslog;
use F5::Logger;
use F5::BigipVersionUtils;
use F5::DbUtils;
use F5::UI;
use File::Copy;
use POSIX qw(strftime);
use POSIX qw(tmpnam);
use IO::File;
use constant TRUE => 1;
use constant FALSE => 0;
use constant LOG_FILE => '/ts/log/optimize_db.log';
use constant UI_OPTIMIZE_WARNING_MSG => 'The MySQL optimize operation can take a while, and it will lock the ASM tables during its running.';
use constant UI_CONTINUE_MSG => 'Would you like to continue?';
use constant OPTIMIZE_START_MSG => "Optimize process started. Please wait...";
use constant OPERATION_CANCELED_MSG => "Operation cancelled, exiting.";
use constant OPTIMIZE_SUMMARY_MSG => 'Tool optimize_db was activated, and has finished successfully';
my @DB_NAMES = (qw/DCC PLC PRX/);


#--------------------------------------------------------------------------
main();
#--------------------------------------------------------------------------
# Functions section
#--------------------------------------------------------------------------
sub main{
    my $rv = 0;
    my $logger = get_logger();

    check_provisioning_state();
    check_mysql();
    $rv = F5::UI::ui({general_msg => UI_OPTIMIZE_WARNING_MSG, continue_msg => UI_CONTINUE_MSG, defaultno => 0});
    exit_on_cancel() if $rv;
    optimize_asm_db($logger);
    F5::Syslog::ts_syslog('info', OPTIMIZE_SUMMARY_MSG);
    exit(0);
}
#--------------------------------------------------------------------------
sub optimize_asm_db{
    my ($logger) = @_;
    my $dbh = F5::DbUtils::get_dbh();

    $logger->info("Started...");
    print OPTIMIZE_START_MSG."\n";
    sleep(2);
    foreach my $db_name (@DB_NAMES){
          my $tables = $dbh->selectcol_arrayref("SHOW TABLES FROM $db_name");
          foreach my $table (@$tables){
             print "Table name: $table\n";
             my $sql = <<EndQuery;
OPTIMIZE TABLE $db_name.$table 
EndQuery
             if ( !$dbh->do($sql)){
                 $logger->error("failed to execute query $sql ".DBI::errstr());
            }
         }
    }
    $logger->info("Finished sucessfully");
    print "OK\n";
}
#--------------------------------------------------------------------------
sub exit_on_cancel {
    print OPERATION_CANCELED_MSG . "\n";
    exit;
}
#--------------------------------------------------------------------------
sub check_mysql{

    if (!F5::DbUtils::is_mysql_up()){
       print "The database is not running. Program terminated.\n";
       exit 0;
    }
}
#--------------------------------------------------------------------------
sub get_logger{
    return F5::Logger->new(LOG_FILE);
}
#--------------------------------------------------------------------------
sub check_provisioning_state{
    if(!F5::Provisioning::is_asm_on()) {
        print "ASM is not provisioned, The program will be terminated... \n";
        exit 0;
    }
}
