#!/usr/bin/perl

use strict;
use warnings;

use Getopt::Long;
use F5::ASMConfig::EasyClient;
use F5::ASMConfig::ASMConfig;
use F5::Logger;

my %params = (
    grace_signing_interval => 30,
    grace_accepting_interval => 2880,
    username => "regen_cookie_security_key.pl",
    set_main_cookie_hash => '',
    set_other_cookie_hash => '',
    regen_key             => 1,
);

my $logger = F5::Logger->new('/ts/log/regen_cookie_security_key.log');

GetOptions(
           'grace_signing_interval=s' => \$params{grace_signing_interval},
           'grace_accepting_interval=s' => \$params{grace_accepting_interval},
           'username=s' => \$params{username},
           'set_main_cookie_hash=s' => \$params{set_main_cookie_hash},
           'set_other_cookie_hash=s' => \$params{set_other_cookie_hash},
           'regen_key!' => \$params{regen_key},
          );

my $client = F5::ASMConfig::EasyClient->new( username => $params{username}, logger => $logger);
my $session = F5::ASMConfig::Session->new({user_name => $params{username}, session_id => $$});
my $call_flags = F5::ASMConfig::CallFlags->new({});

my $exit_code = -1;

eval {
    my $data_protection = F5::ASMConfig::DataProtection->new();
    if ($params{set_main_cookie_hash} || $params{set_other_cookie_hash}) {
        $data_protection = $client->get_data_protection($session, $call_flags, $data_protection);
        my @data_protection_cookie_configurations;
        for my $cookie_configuration (@{$data_protection->{data_protection_cookie_configurations}}) {       
            if ($params{set_main_cookie_hash} 
                && $cookie_configuration->{cookie_type} == F5::ASMConfig::DataProtectionCookieType::DATA_PROTECTION_COOKIE_TYPE_MAIN()) {
                $cookie_configuration->{hash_algorithm} = $params{set_main_cookie_hash};
            }
            elsif ($params{set_other_cookie_hash}
                && $cookie_configuration->{cookie_type} == F5::ASMConfig::DataProtectionCookieType::DATA_PROTECTION_COOKIE_TYPE_FRAME()) {
                $cookie_configuration->{hash_algorithm} = $params{set_other_cookie_hash};
            }
            push (@data_protection_cookie_configurations, $cookie_configuration);
        }
        $data_protection->{data_protection_cookie_configurations} = \@data_protection_cookie_configurations;
    }
    $data_protection->{regen_key} = $params{regen_key};
    $data_protection->{grace_signing_interval} = $params{grace_signing_interval};
    $data_protection->{grace_accepting_interval} = $params{grace_accepting_interval};    

    my $retval = $client->update_data_protection($session, $call_flags, $data_protection);
    $exit_code = 0;
};

if (my $err = $@) {
    if (ref $err) {
        $err = $err->{error_msg} || $err->{msg};
    }
    $logger->info("Regenerating Cookie Security Key error: $err");
}

exit($exit_code);



