#!/usr/bin/perl

use strict;
use warnings;

use File::Copy;

my $CORE_DIR = '/shared/core';
my $MAX_KEEP_COUNT = 9;

my $core_process_name = shift;
if (! $core_process_name) {
    die "Core prefix must be specified!\n";
}

my @all_cores = glob("$CORE_DIR/$core_process_name.*");

if (my($new_core_file) = grep { /\.core\.gz$/ } @all_cores) {
    # New core file exists

    my %cores_by_saved_suffix;
    for my $core (@all_cores) {
        if ($core =~ /\.core\.(\d+)\.gz$/) {
            $cores_by_saved_suffix{$1} = $core;
        }
    }

    # Re-number sequentially
    my $new_suffix = 1;
    my $reload_needed = 0;
    for my $suffix (sort { $a <=> $b } keys %cores_by_saved_suffix) {
        my $core = $cores_by_saved_suffix{$suffix};
        my $new_filename = $core;
        $new_filename =~ s/(\.core\.)(\d+)(\.gz)$/$1$new_suffix$3/;
        if ($core ne $new_filename) {
            move($core, $new_filename);
            $reload_needed = 1;
        }
        $new_suffix++;
    }

    if ($reload_needed) {
        @all_cores = glob("$CORE_DIR/$core_process_name.*");
        for my $core (@all_cores) {
            if ($core =~ /\.core\.(\d+)\.gz$/) {
                $cores_by_saved_suffix{$1} = $core;
            }
        }
    }

    # Delete excess
    my @suffixes_descending = sort { $b <=> $a } keys %cores_by_saved_suffix;
    if (scalar @suffixes_descending + 1 > $MAX_KEEP_COUNT) {
        for my $i (0..(scalar @suffixes_descending - $MAX_KEEP_COUNT)) {
            unlink $cores_by_saved_suffix{$suffixes_descending[0]};
            delete $cores_by_saved_suffix{$suffixes_descending[0]};
            shift @suffixes_descending;
        }
    }

    # Renumber to new numbering
    for my $suffix (@suffixes_descending) {
        my $core = $cores_by_saved_suffix{$suffix};
        my $new_filename = $core;
        $new_filename =~ s/(\.core\.)(\d+)(\.gz)$/$1 . ($2 + 1) . $3/e;
        move($core, $new_filename);
    }

    my $renamed_new_core_file = $new_core_file;
    $renamed_new_core_file =~ s/(\.core\.)(gz)$/$1 . "1." . $2/e;
    move($new_core_file, $renamed_new_core_file);
}
