#!/usr/bin/perl

use strict;
use warnings;

my ($devfs, $libdir);

BEGIN
{
   my ($client_arch) = `uname -p`;
   if($client_arch =~ /x86_64/) {
      $devfs = "devfs_x86_64";
      $libdir = "lib64";
   }
   else {
      $devfs = "devfs";
      $libdir = "lib64";
   }
}

use FindBin;
use Config;
use lib "$FindBin::Bin/../../../../$devfs$Config{'vendorlib'}";
use lib "$FindBin::Bin/../../../../$devfs$Config{'vendorarch'}";
use lib $FindBin::Bin;

use F5::XML::Schema::Processor;

my $xsp = F5::XML::Schema::Processor->new(
	allow_external_references => 1,
	schema_document => $ARGV[0],
	debug => $ARGV[1], # if --nobin used
);

eval {
	$xsp->xparse;
};

if (not $xsp->OK) {
	my $error_message = "\n\nProblems parsing XML Schema document: ".$ARGV[0]."\n";
	$error_message .= join("\n",$xsp->errors);
	$error_message .= "\n\nMissing files: ".join(', ',$xsp->missing_files)."\n"
		if $xsp->missing_files;
	die $error_message;
}

die "\n\nException caught by schema processor:\n$@\n" if $@;

$xsp->print_binary;
