#!/usr/bin/perl

#$Header$#


use strict;

my $TS_ROOT='/ts';


use F5::Logger qw(:LEGACY_ERROR_CONSTANTS); 

use F5::Cfg;

my $DEF_UMASK = umask();
my $CUSTOM_UMASK = "0000";
my $RET_OK = 0; 
my $RET_NOT_OK = -1;
my $LOG_FILE = 'secopy.log';
my $CFG_FILE = '/etc/ts/tools/secopy.cfg';
my $PRINT_TARGET = 1;
my $DEBUG = 1;

my $LOGGER = F5::Logger->new($TS_ROOT.'/log/'.$LOG_FILE, $PRINT_TARGET);

# try to ensure we'll find cp in PATH
$ENV{PATH} .= ":/bin:/usr/bin:/usr/local/bin";

secopy();

sub secopy
{
    get_config();
    my $args = join ' ', @ARGV;
    my ($action, $src, $dest, $opts) = parse_args($args);

    local $" = " ";

    sc_logprint($INF,undef,"started\n");
    sc_logprint($DBG,undef,"parameters got: $action, $src, $dest, opts=(@$opts)\n");
    
	if ( $src eq $dest )
	{
		sc_logprint($INF,undef,"source and destination are the same file - we're done");
		exit($RET_OK);
	}

    my $command = 'cp';
    my @parameters = @$opts;
    if($action eq 'get')
    {
	push @parameters, $dest, $src;
    }
    else
    {
	push @parameters, $src, $dest;
    }

	sc_logprint($DBG,undef,"cmd to execute: $command @parameters");
    
    my $ret = system($command, @parameters);
    $ret >>= 8;
    if($ret == 0)
    {
       sc_logprint($INF, undef, "cp succeeded");
    }
    else
    {
       sc_logprint($ERR, undef, "cp failed, return value was $ret");
    }
    sc_logprint($INF,undef,"ended\n");
    exit($ret); 
}

#--------------------------------------------------------------------------------
sub parse_args
{
    my $args = shift;

    my @opts = ();

    if($args =~ /\s*-help/)
    {
	&usage;
	exit($RET_NOT_OK);
    }
    
    if($args =~ /-h:\s*(\S+)/)
    {    
		my $host = $1;
		if ( $host ne '127.0.0.1' && $host ne 'localhost' )
		{
			sc_logprint($F_ERR, undef, "Error: invalid host '$host', only 127.0.0.1 is allowed\n");  
			exit($RET_NOT_OK);	
		}
    }
  
    if($args !~ /-a:\s*(\S+)/)
    {    
	sc_logprint($F_ERR,undef," ParseError: Must have an action argument!\n");  
	&usage;
	exit($RET_NOT_OK);	
    }
    my $action = $1;
    
    if (($action ne 'get') and ($action ne 'put'))
    {
	sc_logprint($F_ERR,undef,"Parse Error: action argument must be \'get\' or \'put\'!\n");  
	&usage;
	exit($RET_NOT_OK);	
    }

    if($args !~ /-r:\s*(\S+)/)
    {    
      	sc_logprint($F_ERR,undef,"\nParse Error: Must have remote file argument!\n");  
	&usage;
	exit($RET_NOT_OK);	
    }
    my $remote = $1;

    if($args !~ /-l:\s*(\S+)/)
    {    
	sc_logprint($F_ERR,undef,"\nError: Must have local file argument!\n");  
	&usage;
	exit($RET_NOT_OK);	
    }
    my $local = $1;

    if($args =~ /-o:r/)
    {    
        # recursive option
        push @opts, "-r";
    }

    return ($action, $local, $remote, \@opts);
}

#--------------------------------------------------------------------------------
sub get_config
{
   my $config_full_path = "$CFG_FILE";
   my $value;
   $value = F5::Cfg::cfg_get_config_item($config_full_path, 'Debug', 'Debug');
   $DEBUG = $value if defined $value;
   $value = F5::Cfg::cfg_get_config_item($config_full_path, 'Debug', 'PrintTarget');
   $PRINT_TARGET = $value if defined $value;
   $value = F5::Cfg::cfg_get_config_item($config_full_path, 'Debug', 'LogFile');
   $LOG_FILE = $value if defined $value;
}
#--------------------------------------------------------------------------------
sub usage
{
	print <<EOF;

cp wrapper (no longer supports scp)  Usage:
    -h:<host>;
      Not used.  Will generate error if it's other than 127.0.0.1
    -u:<user>
      Ignored.
    -p:<password>
      Ignored.
    -a:<get/put>
      The action - get or put.  get just reverses source/destination files
    -l:<file>
      The source file name
    -r:<file>
      The destination file name
    [-o:r]
      Recursive (cp -r)
    [-t:<timeout>]
      Ignored.
    -help
      Show this info.
EOF
}

#--------------------------------------------------------------------------------
# print to log/console
# umask is changed to set write permissions to nobody for the log files
# changing it right back to avoid security hazards

sub sc_logprint
{     
    my $level = shift;
    return 0 if(($level eq $DBG) and ($DEBUG == 0));
    umask($CUSTOM_UMASK);
    $LOGGER->log_print($level, shift, shift);
    umask($DEF_UMASK);
}
