#!/usr/bin/perl

use strict;
use warnings;


use F5::Syslog;
use F5::Cfg;
use F5::DbUtils;

open(my $mycnf, "<", "/etc/my.cnf") || die $!;
my @mycnf_lines = <$mycnf>;
close $mycnf;

my $db_connection_retries = 12;
my $sleep_between_retries = 5;

my ($bind_address_line) = grep {/^bind-address/} @mycnf_lines;
exit unless $bind_address_line;
my ($bind_address) = $bind_address_line =~ /=\s*([\d\.]*)\s*$/;

my $dbh=get_db_handle($db_connection_retries, $sleep_between_retries);
exit unless $dbh;
F5::Cfg::cfg_set_config_item ("/etc/ts/common/users.cfg", "MYSQL", "IpAddress", $bind_address);

my $sql_delete = "DELETE FROM 
    mysql.user 
    where Host != '127.0.0.1' 
        AND Host != 'localhost'
        AND Host != '127.3.0.%'
        AND User = 'root'
";

$dbh->do($sql_delete);

if ($bind_address ne "127.0.0.1" && $bind_address ne "0.0.0.0") {
    my $query = "SELECT * from mysql.user where Host = 'localhost'";
    my $user_localhost = $dbh->selectrow_hashref($query);
    $user_localhost->{Host} = $bind_address;

    my @placeholders = ('?') x scalar keys %$user_localhost;
    my @fields = keys %$user_localhost;
    local $" = ',';
    $dbh->do("INSERT INTO mysql.user (@fields) VALUES (@placeholders)",
           undef,
           @{$user_localhost}{@fields}
    );
}

my $sql_flush = "FLUSH PRIVILEGES";
$dbh->do($sql_flush);

sub get_db_handle {
    my ($db_connection_retries, $sleep_between_retries) = @_;

    # re-read mysql password each connect operation.
    my $dbh = F5::DbUtils::get_dbh(database_name => "mysql",
                                   database_username => "root",
                                   connect_attempt_limit => $db_connection_retries,
                                   connect_attempt_delay => $sleep_between_retries,
                                   db_opts => {PrintError => 0},
                                  );
    return $dbh if ($dbh);
    F5::Syslog::ts_syslog( 'err', "%s", "failed to connect  to database after $db_connection_retries retries, aborting" );
    return;
}
