#!/usr/bin/python

import f5.tmstat as tmstat
import sys


def main():
    initialize_policy_changes()
    initialize_enforced_entities()
    initialize_learning_suggestions()


def initialize_policy_changes():
    columns = []
    columns.append(("policy_name", 256, 0, tmstat.TEXT, tmstat.KEY))
    columns.append(("user_name", 256, 256, tmstat.TEXT, tmstat.KEY))
    columns.append(("policy_changes_cnt", 8, 512, tmstat.UNSIGNED, tmstat.SUM))
    initialize_table('asm_policy_changes_stats', columns)



def initialize_enforced_entities():
    columns = []
    columns.append(("policy_name", 256, 0, tmstat.TEXT, tmstat.KEY))
    columns.append(("enforced_entities_cnt", 8, 256, tmstat.UNSIGNED, tmstat.SUM))
    columns.append(("not_enforced_entities_cnt", 8, 264, tmstat.UNSIGNED, tmstat.SUM))
    initialize_table('asm_enforced_entities_stats', columns)


def initialize_learning_suggestions():
    columns = []
    columns.append(("policy_name", 256, 0, tmstat.TEXT, tmstat.KEY))
    columns.append(("accepted_cnt", 8, 256, tmstat.UNSIGNED, tmstat.SUM))
    columns.append(("pending_lowscore_cnt", 8, 264, tmstat.UNSIGNED, tmstat.SUM))
    columns.append(("pending_highscore_cnt", 8, 272, tmstat.UNSIGNED, tmstat.SUM))
    columns.append(("ignored_cnt", 8, 280, tmstat.UNSIGNED, tmstat.SUM))
    initialize_table('asm_learning_suggestions_stats', columns)



def initialize_table(table_name, columns):
    stat = tmstat.create(table_name)
    tbl = stat.table_register(table_name, columns)
    stat.publish(tmstat.DIR_PUBLISH)



if __name__ == '__main__':
    r = main()
    sys.exit(r)


