#!/usr/bin/perl 

use strict;
use warnings;

use Getopt::Long;
use F5::ConfigSync;

my $action;
my $bigip_version;
my $bigip_build;
my $ucs_version;
my $ucs_build;
my $force_upgrade;
my $base_dir;
my $cleanup_temporary_files;
my $check_asm_ready;
my $provisioned;
my $policy_history;
my $update_mcp_timestamp = 1;
my $originator;

GetOptions(
    'action|a=s' => \$action,
    'originator|o=s' => \$originator,
    'bigip_version=s' => \$bigip_version,
    'bigip_build=s' => \$bigip_build,
    'ucs_version=s' => \$ucs_version,
    'ucs_build=s' => \$ucs_build,
    'force_upgrade!' => \$force_upgrade,
    'dir=s' => \$base_dir,
    'cleanup!' => \$cleanup_temporary_files,
    'check_asm_ready!' => \$check_asm_ready,
    'provisioned' => \$provisioned,
    'policy_history!' => \$policy_history,
    'update_mcp_timestamp!' => \$update_mcp_timestamp,
);


my $no_private_keys = $ENV{'NO_PRIVATE_KEYS'};
my $ucs_post_install = ($action eq 'delayed_load') ? 1 : 0;
my $configsync = F5::ConfigSync->new(
    bigip_version => $bigip_version,
    bigip_build => $bigip_build,
    ucs_version => $ucs_version,
    ucs_build => $ucs_build,
    ucs_post_install => $ucs_post_install,
    force_upgrade => $force_upgrade,
    base_dir => $base_dir,
    cleanup => $cleanup_temporary_files,
    no_private_keys => $no_private_keys,
    policy_history => $policy_history,
    originator => $originator,
);

exit 0 unless $configsync;

if ($action eq 'load') {
    $configsync->load(update_mcp_timestamp => $update_mcp_timestamp);
}
elsif($action eq 'delayed_load') {
    if(F5::ConfigSync::is_ucs_post_install_waiting()) {
        $configsync->load_with_account_data(check_asm_ready => $check_asm_ready);
    }
} else {
    $configsync->save(provisioned => $provisioned,
                      check_asm_ready => defined $check_asm_ready ? $check_asm_ready : 0,
                      db_opts => {PrintError => 0},
                     );
}




