#!/usr/bin/perl
use strict;
use warnings;

use Getopt::Long;
#use SOAP::Lite +trace => qw(debug);
use F5::FPS::Signatures::Update;
use F5::Logger;
use F5::BigipUtils;
use F5::Provisioning;

exit unless F5::BigipUtils::is_device_bigip();
exit unless F5::Provisioning::is_module_enabled("fps");

my %params = (
    automatic_mode => 0,
    user_name => "",
    check_interval => 0,
    check_for_updates => 0,
);

my $logger = F5::Logger->new('/ts/log/update_fps_signatures.log');

GetOptions(
           'a|automatic!' => \$params{automatic_mode},
           'f|file=s' => \$params{filename},
           'username=s' => \$params{user_name},
           'check-interval!' => \$params{check_interval},
           'check-for-updates!' => \$params{check_for_updates},
          );


my $fps_signatures_update = F5::FPS::Signatures::Update->new(logger => $logger, 
                                                          %params);
my $exit_code = -1;
my $rv;
eval {
    $rv = $fps_signatures_update->update(%params);
    if ($rv->{completed_successfully}) {
        $exit_code = 0;
    }
};

if (my $err = $@) {
    if (ref $err) {
        $err = $err->{error_msg} || $err->{msg};
    }
    $logger->info("FPS Signatures update error: $err");
}

exit($exit_code);
