#!/usr/bin/perl
use strict;
use warnings;

use Getopt::Long;
#use SOAP::Lite +trace => qw(debug);
use F5::PEM::Tacdb::Update;
use F5::Logger;
use F5::BigipUtils;

exit unless F5::BigipUtils::is_device_bigip();

my %params = (
    automatic_mode => 0,
    user_name => "",
    check_interval => 0,
);

GetOptions(
           'a|automatic!' => \$params{automatic_mode},
           'f|file=s' => \$params{filename},
           'username=s' => \$params{user_name},
           'check-interval!' => \$params{check_interval},
           'partition=s'
          );

my $logger = F5::Logger->new("/var/log/hitless_upgrade_tacdb.log");

sub report_and_exit {
    my($msg, %params) = @_;
    print STDERR $msg;
    $logger->info($msg);
    exit(1);
}

# Disallow upgrades on secondaries, as config operations on them is prohibited.
if (`/usr/bin/getdb clustered.environment` =~ /true/ &&
        `/usr/bin/getdb platform.chassis.slot` != `/usr/bin/getdb cluster.primary.slot`) {
    report_and_exit("Hitless upgrade must be done on a primary slot, aborting upgrade.");
}

my $pem_tacdb_update = F5::PEM::Tacdb::Update->new(logger => $logger,
                                                       %params);
my $exit_code = -1;
my $rv;
eval {
    $rv = $pem_tacdb_update->update(%params);
    if ($rv->{completed_successfully}) {
        $exit_code = 0;
    }
    else {
        # Most of the code quits by returning $rv, and we still need to print
        # the error message to let the user know.
        die $rv;
    }
};

if (my $err = $@) {
    if (ref $err) {
        $err = $err->{error_msg} || $err->{msg};
    }
    $logger->info("Tacdb Hitless upgrade error: $err");
    print STDERR "$err\n";
    print STDERR "See $logger->{filename} for additional info.\n";
}

exit($exit_code);
