#!/usr/bin/perl

use strict;
use warnings;

use Getopt::Long;
#use SOAP::Lite +trace => qw(debug);
use SOAP::Lite;
use F5::NegativeSignatures::SigFile::Update;
use F5::Logger;
use F5::ASMConfig::GuaranteedClient;
use F5::BigipUtils;
use F5::Provisioning;
use F5::License;
use JSON;

exit unless F5::BigipUtils::is_device_bigip();
exit unless F5::Provisioning::is_asm_on() || F5::Provisioning::is_module_enabled('dos');

my %params = (
    automatic_mode => 0,
    flg_is_user_defined => 0,
    force => 0,
    user_name => "",
    check_interval =>0,
    silent =>0,
);

my $logger = F5::Logger->new('/ts/log/update_sigfile.log');

if (F5::License->new->is_aws_icm_platform()) {
    $logger->info("Updates are disallowed on an IC platform") if $logger;
    exit;
}

warn "update_sigfile.pl has been deprecated. ASM Security Updates should be installed using Live Update instead.\n"; 

GetOptions(
           'a|automatic!' => \$params{automatic_mode},
           'f|file=s' => \$params{filename},
           'u|user!' => \$params{flg_is_user_defined},
           'force!' => \$params{force},
           'username=s' => \$params{user_name},
           'check-interval!' => \$params{check_interval},
           'silent!' => \$params{silent},
          );

my $client = F5::ASMConfig::GuaranteedClient::get_client((username => $params{user_name} || 'update_sigfile.pl'),
                                                          gui_user_name => $params{user_name},
                                                          logger => $logger,
                                                        );
my $session = F5::ASMConfig::Session->new({user_name => 'update_sigfile.pl', session_id => $$});
my $call_flags = F5::ASMConfig::CallFlags->new({});

my %additional_params;
if ($params{force}) {
    $additional_params{allow_older_timestamp} = 1;
}
my $retval = $client->update_sigfile(
    $session, 
    $call_flags,  
    F5::ASMConfig::Sigfile->new({ filename => $params{filename}}),
    F5::ASMConfig::SigfileUpdateSettings->new({
                                               check_interval => $params{check_interval},
                                               %additional_params,
                                              }));


$retval->{error_msg} = [ $retval->{error_msg} ];
$retval = { %{$retval} };
if (!$params{silent}) {
    print JSON::to_json($retval, { allow_blessed => 1, convert_blessed => 1 });
}
