#!/usr/bin/perl

use strict;
use warnings;

use Getopt::Long;
#use SOAP::Lite +trace => qw(debug);
use SOAP::Lite;
use F5::Logger;
use F5::ASMConfig::EasyClient;
use F5::BigipUtils;
use F5::Provisioning;
use F5::License;
use JSON;

exit unless F5::BigipUtils::is_device_bigip();
exit unless F5::Provisioning::is_asm_on() && F5::License::is_threat_campaigns_licensed();

my %params = (
    automatic_mode => 0,
    force => 0,
    user_name => "",
    check_interval =>0,
    silent =>0,
);

my $logger = F5::Logger->new('/ts/log/update_threat_campaign_file.log');

if (F5::License->new->is_aws_icm_platform()) {
    $logger->info("Updates are disallowed on an IC platform") if $logger;
    exit;
}

GetOptions(
           'a|automatic!' => \$params{automatic_mode},
           'f|file=s' => \$params{filename},
           'force!' => \$params{force},
           'username=s' => \$params{user_name},
           'check-interval!' => \$params{check_interval},
           'silent!' => \$params{silent},
          );

my $client = F5::ASMConfig::EasyClient->new( username => 'update_threat_campaign_file.pl', logger => $logger);
my $session = F5::ASMConfig::Session->new({user_name => 'update_threat_campaign_file.pl', session_id => $$});
my $call_flags = F5::ASMConfig::CallFlags->new({});

my %additional_params;
if ($params{force}) {
    $additional_params{allow_older_timestamp} = 1;
}
my $retval = $client->update_threat_campaign_file(
    $session, 
    $call_flags,  
    F5::ASMConfig::ThreatCampaignFile->new({ filename => $params{filename}}),
    F5::ASMConfig::ThreatCampaignFileUpdateSettings->new({
                                                          check_interval => $params{check_interval},
                                                          %additional_params,
                                                         }));


$retval->{error_msg} = [ $retval->{error_msg} ];
$retval = { %{$retval} };
if (!$params{silent}) {
    print JSON::to_json($retval, { allow_blessed => 1, convert_blessed => 1 });
}
