#!/usr/bin/perl

use strict;
use warnings;

use lib '/ts/packages/';

use FindBin;
#use lib "$FindBin::Bin/../../../../devfs/usr/lib/perl5/vendor_perl/5.8.0";
#use lib "$FindBin::Bin/../../../../devfs/usr/lib/perl5/vendor_perl/5.8.0/i386-linux-thread-multi";
use lib $FindBin::Bin;

use Getopt::Std;
use File::Basename;
use Data::Dumper;

use F5::XML::Xpath::xpathprocessor;

sub usage {
  my($mess) = @_;

  die "${\($mess ? qq/Error: $mess\n/ : '')}

Usage: ${\(basename $0)} -c -d -x <xpath-query-file> -n <namespace-mapping-file> [ -t <timeout-in-seconds ]
  
  This program compiles a list of xpath queries and prefix-namespace mappings and generates a binary representation for them.
  -x                          specify queries file.
  -n                          specify prefix-namespace mappings file.
  -t                          specify timeout in seconds.
  -d                          generate wss request queries
  -c                          generate wss request queries
  -b                          output using base64 encoding

  The format of this binary file follows:

----------------------------------------
  uint num_states
  uint num_trans
  uint string_store_size
  uint ns_store_size
  uint queries_store_size
  
  xpath_state[num_states] (see xpath_info.h)
  xpath_trans[num_trans]  (see xpath_info.h)

  list of ordered null-terminated element and attribute names
  list of ordered null-terminated namespaces
  list of ordered null-terminated queries
----------------------------------------

  all hash values and lists are calculated during runtime load (see load_xpath.c)

";
}

use vars qw($opt_x $opt_n $opt_h $opt_c $opt_d $opt_b $opt_t);
getopts("x:n:t:hcdb") or usage;
usage if $opt_h;
usage "-x is mandatory" unless $opt_x;

if($opt_t) {
    $SIG{ALRM} = sub {
                     print "Compilation timed out after $opt_t seconds\n";
                     exit -1;
                 };
    alarm $opt_t;
}

my $xpc = F5::XML::Xpath::xpathprocessor->new(
	xpath_queries_list => read_xpath_queries_from_file($opt_x),
	xpath_namespaces_hash => read_namespace_mappings_from_file($opt_n),
	wss_request_queries  => $opt_d, #temporary
	wss_response_queries => $opt_c, #temporary
);

### test for list and hash parameter
#my @q_list = ('a', 'b', 'c');
#my $ns_hash = {'d' => "asdfgh",
#              'e' => "zxcvbn",};
#my $xpc2 = F5::XML::Xpath::xpathprocessor->new(
#    xpath_queries_list    => \@q_list,
#    xpath_namespaces_hash => $ns_hash,
#);
#$xpc2->xparse;

$xpc->xparse;
if (not $xpc->OK) {
  my $error_message = "\n\nProblems compiling queries from file: ".$opt_x."\n";
  $error_message .= join("\n",$xpc->errors);
  $xpc->reset_errors;
  die $error_message;
}

$xpc->print_blob("/tmp/aaatest.bin") unless ($xpc->OK);

if (not $xpc->OK) {
  my $error_message = "\n\nProblems compiling queries from file: ".$opt_x."\n";
  $error_message .= join("\n",$xpc->errors);
  $xpc->reset_errors;
  die $error_message;
}

$xpc->print_blob_to_stdout($opt_b);


#$xsp->print_binary;

sub read_xpath_queries_from_file {
	my ($f)=@_;
	open my $in, "<",$f or die "cannot open $f for reading: $!\n";
	my $q=[];
	while(<$in>){
		next if /^\s*$/; # skip empty lines
		next if /^\s*#/; # skip lines with comments only
		s/^\s*//; # remove leading white space characters
		s/\s*$//; # remove trailing white space characters
		push @$q,$_;
	}
	close $in;
	return $q;
}

sub read_namespace_mappings_from_file {
	my ($f)=@_;
	my $h = { '' => ''};
	return $h unless defined $f;
	return $h unless -f $f;
	open my $in, "<",$f or die "cannot open $f for reading: $!\n";
	while(<$in>){
		next if /^\s*$/; # skip empty lines
		next if /^\s*#/; # skip lines with comments only
		s/^\s*//; # remove leading white space characters
		s/\s*$//; # remove trailing white space characters
		my ($p,$n)=split /\s+/,$_,2;
		$h->{$p}=$n;
	}
	close $in;
	return $h;
}

