<?php

include_once $GLOBALS['THRIFT_ROOT'].'/Thrift.php';

class f5_thrift_object implements IteratorAggregate {
  const THRIFT_STRICT_MODE = 0;

    
  public static  $thrift_types = array(
                               "string" => array(
                                                  "ttype" => TType::STRING,
                                                  "write_func" => 'writeString',
                                                  "read_func" => 'readString',
                                                  ),
                                "i32" => array(
                                               "ttype" => TType::I32,
                                               "write_func" => 'writeI32',
                                               "read_func" => 'readI32',
                                               ),
                                "i64" => array(
                                               "ttype" => TType::I64,
                                               "write_func" => 'writeI64',
                                               "read_func" => 'readI64',
                                               ),
                                "bool" => array(
                                                "ttype" => TType::BOOL,
                                                "write_func" => 'writeBool',
                                                "read_func" => 'readBool',
                                                ),
                                "double" => array(
                                                  "ttype" => TType::DOUBLE,
                                                  "write_func" => 'writeDouble',
                                                  "read_func" => 'readDouble',
                                                  ),
                                );
  private $data = array();
  public $short_class;
  public $struct_config;

  public function __construct($vals = null, $short_class = null, $struct_config = null) {
    if (is_array($vals)) {
      $this->data = $vals;
    }
    $this->short_class = $short_class;
    $this->struct_config = $struct_config;
    $iter_struct_config = $this->get_struct_config();
    foreach ( $iter_struct_config as $field_name => $field) {
      if (! isset($this->data[$field["name"]]) && isset($field["default"])) {
        $this->data[$field["name"]] = $field["default"];
      }
    }
  }

  //----------------------------------------------------------------------

  public function getName() {
    return $this->get_short_class();
  }

  //----------------------------------------------------------------------

  public function get_short_class() {
    if (! isset($this->short_class)) {
      $short_class = get_class($this);
      $short_class = preg_replace('/^[^_]+_/', '', $short_class);
      $this->short_class = $short_class;
    }
    return $this->short_class;
  }

  //----------------------------------------------------------------------

  public function read($input) {
    $xfer  = 0;
    $fname = null;
    $ftype = 0;
    $fid   = 0;
    $ktype = 0;
    $vtype = 0;
    $map_key = null;

    $struct_config = $this->get_struct_config();
    if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
      $xfer += $input->readStructBegin($fname);
    while (1) {
      $xfer += $input->readFieldBegin($fname, $ftype, $fid);
      if ($ftype == TType::STOP) {
        break;
      }

      $field = $struct_config[$fid];
      if (! isset($field)) {
        $xfer += $input->skip($ftype);
        if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE) {
          $xfer += $input->readFieldEnd();
        }
        continue;
      }     
      $field_type = $field["type"];
      $list_count = 0;
      $iteration_count = 1;
      if (isset($field["list"]) && $field["list"]) {
        $xfer += $input->readListBegin($ftype, $list_count);
        $iteration_count = $list_count;
        $this->data[$field["name"]] = array();
      }

      if (isset($field["map"]) && $field["map"]) {
        $xfer += $input->readMapBegin($ktype, $vtype, $list_count);
        $iteration_count = $list_count * 2;
        $this->data[$field["name"]] = array();
      }

      $type_category = $field["type_category"];
      for ($i = 1; $i <= $iteration_count; $i++) {
        if (isset($field["map"]) && $field["map"]) {
          $ftype = ($i % 2 ? $ktype : $vtype);
          $type_category = ($i % 2 ? $field["type_category"] : $field["map_value_type_category"]);
        }

        if ($type_category == 'enum') {
          $field_type = 'i32';
        }
        if (isset(self::$thrift_types[$field_type]["ttype"])) {
          if (self::$thrift_types[$field_type]["ttype"] == $ftype) {
            $read_func = self::$thrift_types[$field_type]["read_func"];
            $xfer += $input->$read_func($read_value);
          }
          else {
            $xfer += $input->skip($ftype);
          }
        }
        elseif ($type_category == 'struct') {
          if ($ftype == TType::STRUCT) {
            $class = $this->get_prefix() . '_' . $field_type;
            $read_value = new $class();
            $xfer += $read_value->read($input);
          }
          else {
            $xfer += $input->skip($ftype);
          }
        }

        if (isset($field["list"])) {
          if (! isset($this->data[$field["name"]])) {
            $this->data[$field["name"]] = array();
          }
          $this->data[$field["name"]][] = $read_value;
        }
        elseif (isset($field["map"])) {
          if (! isset($this->data[$field["name"]])) {
            $this->data[$field["name"]] = array();
          }
          if ($i % 2) {
            $map_key = $read_value;
          }
          else {
            $this->data[$field["name"]][$map_key] = $read_value;
          }
        }
        else {
          $this->data[$field["name"]] = $read_value;
        }
      }

      if (isset($field["list"])) {
        if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
          $xfer += $input->readListEnd();
      }

      if (isset($field["map"])) {
        if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
          $xfer += $input->readMapEnd();
      }

      if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
        $xfer += $input->readFieldEnd();
    }
    if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
      $xfer += $input->readStructEnd();
    return $xfer;
  }

  //----------------------------------------------------------------------

  public function write($output) {
    $xfer   = 0;
    $map_keys_as_list = null;

    if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
      $xfer += $output->writeStructBegin($this->get_short_class());

    $struct_config = array_values($this->get_struct_config());
    usort($struct_config, function ($func_a, $func_b) {
        if ($func_a["index"] == $func_b["index"]) return 0;
        return ($func_a["index"] < $func_b["index"]) ? -1 : 1;
      });
    foreach ($struct_config as $field) {
      if (isset($this->data[$field["name"]])) {
        $field_type = $field["type"];
        $list_count = 0;
        if (isset($field["list"])) {
          $list_count = count($this->data[$field["name"]]);
          $renumbered_list = array_values($this->data[$field["name"]]);
        }

        if ($field["type_category"] == 'enum') {
          $field_type = 'i32';
        }

        $ttype = NULL;

        if (isset(self::$thrift_types[$field_type]["ttype"])) {
          $ttype = self::$thrift_types[$field_type]["ttype"];
        }
        elseif ($field["type_category"] == 'struct') {
          $ttype = TType::STRUCT;
        }
 
        if (isset($field["map"])) {
            $map_value_field_type = $field["map_value_type"];
            $map_keys_as_list = array_keys($this->data[$field["name"]]);
            $list_count = count($map_keys_as_list) * 2;

            if ($field["map_value_type_category"] == 'enum') {
                $map_value_field_type = 'i32';
            }
            if (isset(self::$thrift_types[$map_value_field_type]["ttype"])) {
                $map_value_ttype = self::$thrift_types[$field_type]["ttype"];
            }
            elseif ($field["map_value_type_category"] == 'struct') {
                $map_value_ttype = TType::STRUCT;
            }
            $map_key_ttype = $ttype;
            $map_key_field_type = $field_type;
        }

        $iteration_count = 1;
        if (isset($field["list"])) {
          $xfer += $output->writeFieldBegin($field["name"], TType::LST, $field["index"]);
          $output->writeListBegin($ttype, $list_count);
          $iteration_count = $list_count;
        }
        elseif (isset($field["map"])) {
          $xfer += $output->writeFieldBegin($field["name"], TType::MAP, $field["index"]);
          $output->writeMapBegin($map_key_ttype, $map_value_ttype, $list_count / 2);
          $iteration_count = $list_count;
        }
        else {
          if (isset($ttype)) {
            $xfer += $output->writeFieldBegin($field["name"], $ttype, $field["index"]);
          }
        }

        for ($i = 1; $i <= $iteration_count; $i++) {
          $write_value = $this->data[$field["name"]];
          if (isset($field["list"])) {
            $write_value = $renumbered_list[$i - 1];
          }
          elseif (isset($field["map"])) {
              if ($i % 2) {
                $write_value = $map_keys_as_list[($i - 1) / 2];
              }
              else {
                $write_value = $this->data[$field["name"]][$map_keys_as_list[($i - 2) / 2]];
              }
              $field_type = ($i % 2 ? $map_key_field_type : $map_value_field_type);
              $ttype = ($i % 2 ? $map_key_ttype : $map_value_ttype);
          }

          if (isset(self::$thrift_types[$field_type]["ttype"])) {
            $write_func = self::$thrift_types[$field_type]["write_func"];
            $xfer += $output->$write_func($write_value);
          }
          elseif ($field["type_category"] == 'struct') {
            $xfer += $write_value->write($output);
          }
        }
        if (isset($field["list"])) {
          if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
            $output->writeListEnd();
        }
        elseif (isset($field["map"])) {
          if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
            $output->writeMapEnd();
        }
        if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
          $xfer += $output->writeFieldEnd();
      }
    }

    $xfer += $output->writeFieldStop();
    if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
      $xfer += $output->writeStructEnd();
    return $xfer;
  }

  //----------------------------------------------------------------------

  public function &__get($field) {
    return $this->data[$field];
  }

  public function __set($field, $new_val) {
    $this->data[$field] = $new_val;
  }

  public function __isset($field) {
    return isset($this->data[$field]);
  }

  //----------------------------------------------------------------------

  public function get_struct_config() {
    if (! isset($this->struct_config)) {
      $this->struct_config = $this->get_thrift_config('structs', $this->get_short_class());

    }
    return $this->struct_config;
  }

  //----------------------------------------------------------------------

  public function get_thrift_config($type, $item) {
    echo "Abstract method -- must be implemented by subclass";
  }

  //----------------------------------------------------------------------

  public function get_prefix() {
    echo "Abstract method -- mustst be implemented by subclass";
  }

  //----------------------------------------------------------------------

  public function getIterator() {

    // Populate $this->data array with nulls for all struct fields.
    // This is only needed for GUI iterating over known fields based on Thrift definitions
    $iter_struct_config = $this->get_struct_config();
    foreach ( $iter_struct_config as $field_name => $field) {
      if (! array_key_exists($field["name"], $this->data)) {
        $this->data[$field["name"]] = null;
      }
    }
    return new ArrayIterator($this->data);
  }
}

//======================================================================

// TException adds 8k overhead per object, and is only needed for one specific struct.
// Thus, this was duplicated from f5_thrift_object above, since PHP doesn't allow multiple inheritance.

class f5_thrift_exception extends TException implements IteratorAggregate {
  const THRIFT_STRICT_MODE = 0;

    
  public static  $thrift_types = array(
                               "string" => array(
                                                  "ttype" => TType::STRING,
                                                  "write_func" => 'writeString',
                                                  "read_func" => 'readString',
                                                  ),
                                "i32" => array(
                                               "ttype" => TType::I32,
                                               "write_func" => 'writeI32',
                                               "read_func" => 'readI32',
                                               ),
                                "i64" => array(
                                               "ttype" => TType::I64,
                                               "write_func" => 'writeI64',
                                               "read_func" => 'readI64',
                                               ),
                                "bool" => array(
                                                "ttype" => TType::BOOL,
                                                "write_func" => 'writeBool',
                                                "read_func" => 'readBool',
                                                ),
                                "double" => array(
                                                  "ttype" => TType::DOUBLE,
                                                  "write_func" => 'writeDouble',
                                                  "read_func" => 'readDouble',
                                                  ),
                                );
  private $data = array();
  public $short_class;
  public $struct_config;

  public function __construct($vals = null, $short_class = null, $struct_config = null) {
    if (is_array($vals)) {
      $this->data = $vals;
    }
    $this->short_class = $short_class;
    $this->struct_config = $struct_config;
    $iter_struct_config = $this->get_struct_config();
    foreach ( $iter_struct_config as $field_name => $field) {
      if (! isset($this->data[$field["name"]]) && isset($field["default"])) {
        $this->data[$field["name"]] = $field["default"];
      }
    }
  }

  //----------------------------------------------------------------------

  public function getName() {
    return $this->get_short_class();
  }

  //----------------------------------------------------------------------

  public function get_short_class() {
    if (! isset($this->short_class)) {
      $short_class = get_class($this);
      $short_class = preg_replace('/^[^_]+_/', '', $short_class);
      $this->short_class = $short_class;
    }
    return $this->short_class;
  }

  //----------------------------------------------------------------------

  public function read($input) {
    $xfer  = 0;
    $fname = null;
    $ftype = 0;
    $fid   = 0;

    $struct_config = $this->get_struct_config();
    if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
      $xfer += $input->readStructBegin($fname);
    while (1) {
      $xfer += $input->readFieldBegin($fname, $ftype, $fid);
      if ($ftype == TType::STOP) {
        break;
      }

      $field = $struct_config[$fid];
      $field_type = $field["type"];
      $list_count = 0;
      $iteration_count = 1;
      if (isset($field["list"]) && $field["list"]) {
        $xfer += $input->readListBegin($ftype, $list_count);
        $iteration_count = $list_count;
        $this->data[$field["name"]] = array();
      }

      for ($i = 1; $i <= $iteration_count; $i++) {
        if (isset($field["type_category"]) && ($field["type_category"] == 'enum')) {
          $field_type = 'i32';
        }
        if (isset(self::$thrift_types[$field_type]["ttype"])) {
          if (self::$thrift_types[$field_type]["ttype"] == $ftype) {
            $read_func = self::$thrift_types[$field_type]["read_func"];
            $xfer += $input->$read_func($read_value);
          }
          else {
            $xfer += $input->skip($ftype);
          }
        }
        elseif ($field["type_category"] == 'struct') {
          if ($ftype == TType::STRUCT) {
            $class = $this->get_prefix() . '_' . $field_type;
            $read_value = new $class();
            $xfer += $read_value->read($input);
          }
          else {
            $xfer += $input->skip($ftype);
          }
        }

        if (isset($field["list"])) {
          if (! isset($this->data[$field["name"]])) {
            $this->data[$field["name"]] = array();
          }
          $this->data[$field["name"]][] = $read_value;
        }
        else {
          $this->data[$field["name"]] = $read_value;
        }
      }

      if (isset($field["list"])) {
        if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
          $xfer += $input->readListEnd();
      }

      if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
        $xfer += $input->readFieldEnd();
    }
    if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
      $xfer += $input->readStructEnd();
    return $xfer;
  }

  //----------------------------------------------------------------------

  public function write($output) {
    $xfer   = 0;
    if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
      $xfer += $output->writeStructBegin($this->get_short_class());

    $struct_config = array_values($this->get_struct_config());
    usort($struct_config, function ($func_a, $func_b) {
        if ($func_a["index"] == $func_b["index"]) return 0;
        return ($func_a["index"] < $func_b["index"]) ? -1 : 1;
      });
    foreach ($struct_config as $field) {
      if (isset($this->data[$field["name"]])) {
        $field_type = $field["type"];
        $list_count = 0;
        if (isset($field["list"])) {
          $list_count = count($this->data[$field["name"]]);
          $renumbered_list = array_values($this->data[$field["name"]]);
        }

        if (isset($field["type_category"]) && ($field["type_category"] == 'enum')) {
          $field_type = 'i32';
        }

        $ttype = NULL;

        if (isset(self::$thrift_types[$field_type]["ttype"])) {
          $ttype = self::$thrift_types[$field_type]["ttype"];
        }
        elseif (isset($field["type_category"]) && ($field["type_category"] == 'struct')) {
          $ttype = TType::STRUCT;
        }
 
        $iteration_count = 1;
        if (isset($field["list"])) {
          $xfer += $output->writeFieldBegin($field["name"], TType::LST, $field["index"]);
          $output->writeListBegin($ttype, $list_count);
          $iteration_count = $list_count;
        }
        else {
          if (isset($ttype)) {
            $xfer += $output->writeFieldBegin($field["name"], $ttype, $field["index"]);
          }
        }

        for ($i = 1; $i <= $iteration_count; $i++) {
          $write_value = $this->data[$field["name"]];
          if (isset($field["list"])) {
            $write_value = $renumbered_list[$i - 1];
          }

          if (isset(self::$thrift_types[$field_type]["ttype"])) {
            $write_func = self::$thrift_types[$field_type]["write_func"];
            $xfer += $output->$write_func($write_value);
          }
          elseif ($field["type_category"] == 'struct') {
            $xfer += $write_value->write($output);
          }
        }
        if (isset($field["list"])) {
          if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
            $output->writeListEnd();
        }
        if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
          $xfer += $output->writeFieldEnd();
      }
    }

    $xfer += $output->writeFieldStop();
    if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
      $xfer += $output->writeStructEnd();
    return $xfer;
  }

  //----------------------------------------------------------------------

  public function &__get($field) {
    return $this->data[$field];
  }

  public function __set($field, $new_val) {
    $this->data[$field] = $new_val;
  }

  public function __isset($field) {
    return isset($this->data[$field]);
  }

  //----------------------------------------------------------------------

  public function get_struct_config() {
    if (! isset($this->struct_config)) {
      $this->struct_config = $this->get_thrift_config('structs', $this->get_short_class());

    }
    return $this->struct_config;
  }

  //----------------------------------------------------------------------

  public function get_thrift_config($type, $item) {
    echo "Abstract method -- must be implemented by subclass";
  }

  //----------------------------------------------------------------------

  public function get_prefix() {
    echo "Abstract method -- mustst be implemented by subclass";
  }

  //----------------------------------------------------------------------

  public function getIterator() {

    // Populate $this->data array with nulls for all struct fields.
    // This is only needed for GUI iterating over known fields based on Thrift definitions
    $iter_struct_config = $this->get_struct_config();
    foreach ( $iter_struct_config as $field_name => $field) {
      if (! array_key_exists($field["name"], $this->data)) {
        $this->data[$field["name"]] = null;
      }
    }
    return new ArrayIterator($this->data);
  }
}

//======================================================================

class f5_thrift_client {
  const THRIFT_STRICT_MODE = 0;

  protected $input = null;
  protected $output = null;

  protected $seqid = 0;

  public function __construct($input, $output=null) {
    $this->input = $input;
    $this->output = $output ? $output : $input;
  }


  public function __call($method_call, $params) {
    $this_config = $this->get_thrift_config('rpc', $method_call);
    $method_prefix = $this->get_prefix();

    // Send request
    $args = array();
    $call_struct_config = array();
    for ($i = 0; $i <= count($this_config["arguments"]); $i++) {
      if (isset($this_config["arguments"][$i]["name"])) {
        $args[$this_config["arguments"][$i]["name"]] = isset($params[$i]) ? $params[$i] : null;
        $call_struct_config[$this_config["arguments"][$i]["index"]] = $this_config["arguments"][$i];
      }
    }

    $generic_object_class = $this->get_generic_object_class();
    $args_obj = new $generic_object_class($args, "${method_prefix}_${method_call}_args", $call_struct_config);

    $this->output->writeMessageBegin($method_call, TMessageType::CALL, $this->seqid);
    $args_obj->write($this->output);
    if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
      $this->output->writeMessageEnd();
    $this->output->getTransport()->flush();

    // Receive result
    $rseqid = 0;
    $fname;
    $mtype = 0;

    $this->input->readMessageBegin($fname, $mtype, $rseqid);
    if ($mtype == TMessageType::EXCEPTION) {
      $x = new TApplicationException();
      $x->read($this->input);
      if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
        $this->input->readMessageEnd();
      throw $x;
    }

    $return_struct_config = array();
    for ($i = 0; $i <= count($this_config["return_value"]); $i++) {
      if (isset($this_config["return_value"][$i]["index"])) {
        $return_struct_config[$this_config["return_value"][$i]["index"]] = isset($this_config["return_value"][$i]) ? $this_config["return_value"][$i] : null;
      }
    }
    $result = new $generic_object_class(null, "${method_prefix}_${method_call}_result", $return_struct_config);
    $result->read($this->input);
    if (defined ('THRIFT_STRICT_MODE') && THRIFT_STRICT_MODE)
      $this->input->readMessageEnd();

    $success = $result->success;
    if ($this_config["return_value"][0]["type"] == "void") {
      return 1;
    }
    if (isset($success)) {
      return $result->success;
    }
    $ex = $result->ex;
    if (isset($ex)) {
      throw $ex;
    }
    throw new Exception("$method_call failed: unknown result");
  }

  public function  get_thrift_config($type, $item) {
    echo "Abstract method -- must be implemented by subclass";
  }

  //----------------------------------------------------------------------

  public function get_prefix() {
    echo "Abstract method -- must be implemented by subclass";
  }

}

//======================================================================

?>
