-- CONFIG_SYNC: DCC.ACCOUNTS
CREATE TABLE ACCOUNTS (
  account_id int(10) unsigned NOT NULL,
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  policy_name varchar(128) BINARY NOT NULL default '',
  policy_apply_date int unsigned NOT NULL default 0,
  lang_set_id int(10) NOT NULL default '3',
  flg_encoding_selected int(2) NOT NULL default '0',
  flg_use_dynamic_session_in_url int(2) NOT NULL default '0',
  dynamic_session_pattern varchar(255) NOT NULL default '',
  flg_use_violation_asm_irule int(2) NOT NULL default '0',
  dynamic_session_description blob,
  policy_changed_time int(10) NOT NULL default 0,
  http_protocol_checks_mask bigint(20) unsigned NOT NULL default '0',  -- will be removed after BD change
  http_protocol_checks_learn_mask bigint(20) unsigned NOT NULL default '0',
  http_protocol_checks_alarm_mask bigint(20) unsigned NOT NULL default '0',
  http_protocol_checks_reject_mask bigint(20) unsigned NOT NULL default '0',
  max_headers int(10) unsigned NOT NULL default '0',   
  mandatory_headers_mask bigint(20) unsigned NOT NULL default '0',
  negsig_excluded_headers_mask bigint(20) unsigned NOT NULL default '0',
  wss_sub_violations_mask int(4) NOT NULL default '0',
  flg_is_whitehat int(2) NOT NULL default '0',
  whitehat_attacks_bitmap int NOT NULL default '0',
  policy_template_system_id int(4) NOT NULL default '0',
  flg_virus_check_file_upload int(2) NOT NULL default '0',
  max_params int(10) unsigned NOT NULL default '0',   
  flg_is_protocol_free int(2) NOT NULL default '0',
  path_parameter_handling int(2) NOT NULL default '1',
  flg_mask_sensitive int(2) NOT NULL default '1',
  redirect_action int(2) NOT NULL default '0',
  obj_methods_templ_id int(10) NOT NULL DEFAULT '0',
  flg_enable_correlation tinyint(2) NOT NULL default '1',
  flg_passive_mode int(2) NOT NULL default '0',
  PRIMARY KEY  (policy_name_crc),
  UNIQUE KEY policy_name (policy_name)
) ENGINE=InnoDB COMMENT='Website domain and other per website information';


-- ACTIVE_POLICY: DCC.ACCOUNT_XFF
CREATE TABLE ACCOUNT_XFF (
  flg_is_trust_xff int(2) NOT NULL default '0',
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  PRIMARY KEY (policy_name_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_WILDCARD_OBJECT_PARAMETERS
CREATE TABLE ACCOUNT_WILDCARD_OBJECT_PARAMETERS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  app_id int(10) NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  key_input_type int(10) NOT NULL default '0',
  max_user_input_len int(10) NOT NULL default '0',
  ui_type int(10) NOT NULL default '0',
  flg_disallow_upload_of_exe int(2) NOT NULL default '1',
  regexp_crc bigint(20) unsigned NOT NULL default '0',
  flg_null_value_allow int(2) NOT NULL default '0',
  flg_mandatory int(2) NOT NULL default '0',
  param_value_charset_templ_id int(10) NOT NULL default 0,
  pattern blob NOT NULL default '',
  negative_check_bitmap int NOT NULL default '0',
  flg_tightening int(2) not NULL default '0',
  pattern_order int(10) NOT NULL default '0',
  param_name_charset_templ_id int(10) NOT NULL default 0,
  key_crc bigint(20) unsigned NOT NULL default '0',
  profile_templ_id int(10) NOT NULL default 0,
  flg_is_staging int(2) NOT NULL default '0',
  flg_is_sensitive int(2) NOT NULL default '0',
  flg_allow_repeated_parameter_name int(2) NOT NULL default '0',
  flg_in_classification int(2) NOT NULL default '0',
  flg_is_base64 int(2) NOT NULL DEFAULT '0',
  flg_is_ip_address int(2) NOT NULL DEFAULT '0',
  parameter_location tinyint(1) unsigned NOT NULL default '1',
  flags_array_type_bitmask int(10) unsigned NOT NULL default '0',
  min_values_items_in_array int(10) unsigned NOT NULL default '0',
  max_values_items_in_array int(10) unsigned NOT NULL default '0',
  array_serialization_format tinyint(1) unsigned NOT NULL default '1',
  flg_check_enum_values tinyint(1) unsigned NOT NULL default 0,
  min_user_input_len int(8) unsigned default 0,
  flg_conviction tinyint(1) unsigned NOT NULL default 0,
  object_serialization_style tinyint(2) unsigned NOT NULL default 1,
  flg_object_serialization_explode tinyint(2) unsigned NOT NULL default 0,
  flg_detect_base64 int(2) NOT NULL DEFAULT '0',
  PRIMARY KEY (policy_name_crc,object_crc, pattern_order),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='enforcer policy configuration for object wildcard parameters';


-- ACTIVE_POLICY: DCC.ACCOUNT_WILDCARD_HEADERS
CREATE TABLE ACCOUNT_WILDCARD_HEADERS (
    policy_name_crc bigint(20) unsigned NOT NULL default '0',
    header_name_crc bigint(20) unsigned NOT NULL default '0',
    header_code bigint(20) unsigned NOT NULL default '0',
    header_name varchar(255) NOT NULL default '',
    flg_check_signatures int(2) NOT NULL default 1,
    flg_enable_normalization_violation int(2) NOT NULL default 0, 
    flg_is_base64 int(2) NOT NULL default 0,
    flg_detect_base64 int(2) NOT NULL default 0,
    pattern_order int(10) NOT NULL default '0' ,
    normalization_mask int(1) NOT NULL default '0',
    excluded_signatures_exist tinyint(1) NOT NULL default 0,
    flg_mask_value int(2) NOT NULL default 0,
    flg_allow_repeated int(2) NOT NULL default 1,
    UNIQUE KEY ( policy_name_crc, header_name_crc),
    FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_WILDCARD_GLOBAL_PARAMETERS
CREATE TABLE ACCOUNT_WILDCARD_GLOBAL_PARAMETERS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  app_id int(10) NOT NULL default '0',
  key_input_type int(10) NOT NULL default '0',
  max_user_input_len int(10) NOT NULL default '0',
  ui_type int(10) NOT NULL default '0',
  flg_disallow_upload_of_exe int(2) NOT NULL default '1',
  regexp_crc bigint(20) unsigned NOT NULL default '0',
  flg_null_value_allow int(2) NOT NULL default '0',
  flg_mandatory int(2) NOT NULL default '0',
  param_value_charset_templ_id int(10) NOT NULL default 0,
  pattern blob NOT NULL default '',
  negative_check_bitmap int NOT NULL default '0',
  flg_tightening int(2) not NULL default '0',
  pattern_order int(10) NOT NULL default '0',
  param_name_charset_templ_id int(10) NOT NULL default 0,
  key_crc bigint(20) unsigned NOT NULL default '0',
  profile_templ_id int(10) NOT NULL default 0,
  flg_is_staging int(2) NOT NULL default '0',
  flg_is_sensitive  int(2) NOT NULL default '0',
  flg_allow_repeated_parameter_name int(2) NOT NULL default '0',
  flg_in_classification int(2) NOT NULL default '0',
  flg_is_base64 int(2) NOT NULL DEFAULT '0',
  flg_is_ip_address int(2) NOT NULL DEFAULT '0',
  parameter_location tinyint(1) unsigned NOT NULL default '1',
  flags_array_type_bitmask int(10) unsigned NOT NULL default '0',
  min_values_items_in_array int(10) unsigned NOT NULL default '0',
  max_values_items_in_array int(10) unsigned NOT NULL default '0',
  array_serialization_format tinyint(1) unsigned NOT NULL default '1',
  flg_check_enum_values tinyint(1) unsigned NOT NULL default 0,
  min_user_input_len int(8) unsigned default 0,
  flg_conviction tinyint(1) unsigned NOT NULL default 0,
  object_serialization_style tinyint(2) unsigned NOT NULL default 1,
  flg_object_serialization_explode tinyint(2) unsigned NOT NULL default 0,
  flg_detect_base64 int(2) NOT NULL DEFAULT '0',
  PRIMARY KEY (policy_name_crc,pattern_order),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='enforcer policy configuration for wildcard global parameters';


-- ACTIVE_POLICY: DCC.ACCOUNT_WILDCARD_FLOW_PARAMETERS
CREATE TABLE ACCOUNT_WILDCARD_FLOW_PARAMETERS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  app_id int(10) NOT NULL default '0',
  flow_crc bigint(20) unsigned NOT NULL default '0',
  key_input_type int(10) NOT NULL default '0',
  max_user_input_len int(10) NOT NULL default '0',
  ui_type int(10) NOT NULL default '0',
  flg_disallow_upload_of_exe int(2) NOT NULL default '1',
  regexp_crc bigint(20) unsigned NOT NULL default '0',
  flg_null_value_allow int(2) NOT NULL default '0',
  flg_mandatory int(2) NOT NULL default '0',
  param_value_charset_templ_id int(10) NOT NULL default 0,
  pattern blob NOT NULL default '',
  negative_check_bitmap int NOT NULL default '0',
  flg_tightening int(2) not NULL default '0',
  pattern_order int(10) NOT NULL default '0',
  param_name_charset_templ_id int(10) NOT NULL default 0,
  key_crc bigint(20) unsigned NOT NULL default '0',
  profile_templ_id int(10) NOT NULL default 0,
  flg_is_staging int(2) NOT NULL default '0',
  flg_is_sensitive int(2) NOT NULL default '0',
  flg_allow_repeated_parameter_name int(2) NOT NULL default '0',
  flg_in_classification int(2) NOT NULL default '0',
  flg_is_base64 int(2) NOT NULL DEFAULT '0',
  flg_is_ip_address int(2) NOT NULL DEFAULT '0',
  parameter_location tinyint(1) unsigned NOT NULL default '1',
  flags_array_type_bitmask int(10) unsigned NOT NULL default '0',
  min_values_items_in_array int(10) unsigned NOT NULL default '0',
  max_values_items_in_array int(10) unsigned NOT NULL default '0',
  array_serialization_format tinyint(1) unsigned NOT NULL default '1',
  flg_check_enum_values tinyint(1) unsigned NOT NULL default 0,
  min_user_input_len int(8) unsigned default 0,
  flg_conviction tinyint(1) unsigned NOT NULL default 0,
  object_serialization_style tinyint(2) unsigned NOT NULL default 1,
  flg_object_serialization_explode tinyint(2) unsigned NOT NULL default 0,
  flg_detect_base64 int(2) NOT NULL DEFAULT '0',
  PRIMARY KEY (policy_name_crc,flow_crc,pattern_order),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='enforcer policy configuration for flow wildcard parameters';



-- ACTIVE_POLICY: DCC.ACCOUNT_WILDCARD_ALLOWED_COOKIES
CREATE TABLE ACCOUNT_WILDCARD_ALLOWED_COOKIES (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  pattern_order int(10) NOT NULL,
  cookie_name_crc bigint(20) unsigned NOT NULL default '0',
  pattern blob NOT NULL default '',
  cookie_enforcement_mode int(2) NOT NULL default 0,
  flg_tightening int(2) NOT NULL default '0',
  flg_is_staging int(2) NOT NULL default 0,
  is_http_only int(2) NOT NULL default 0,
  is_secure int(2) NOT NULL default 0,
  flg_is_base64 int(2) NOT NULL DEFAULT '0',
  cookie_same_site_attribute int(2) NOT NULL default 1,
  flg_check_signatures int(2) NOT NULL default 1,
  flg_mask_value int(2) NOT NULL default 0,
  flg_detect_base64 int(2) NOT NULL DEFAULT '0',
  PRIMARY KEY (policy_name_crc, pattern_order),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Contains all cookies not to be checked by core enforcer(fnmatch patterns)';


-- ACTIVE_POLICY: DCC.ACCOUNT_WEBSOCKET_URL_WILDCARD
CREATE TABLE ACCOUNT_WEBSOCKET_URL_WILDCARD (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  protocol int(2) NOT NULL default 0,
  websocket_url_crc bigint(20) unsigned NOT NULL default 0,
  flg_is_disallowed tinyint(2) NOT NULL default 0,
  flg_is_staging tinyint(2) NOT NULL default 1,
  message_max_binary_size int(10) unsigned NOT NULL default 10000,
  message_max_frame_size int(10) unsigned NOT NULL default 10000,
  message_max_frames int(10) unsigned NOT NULL default 100,
  websocket_text_profile_id bigint(20) unsigned NOT NULL default 0,
  websocket_json_profile_id bigint(20) unsigned NOT NULL default 0,
  websocket_extension int(2) NOT NULL default 0,
  flg_in_classification tinyint(2) NOT NULL default 0,
  flg_websocket_message_format_text tinyint(2) NOT NULL default 0,
  flg_websocket_message_format_json tinyint(2) NOT NULL default 0,
  flg_websocket_message_format_binary tinyint(2) NOT NULL default 0,
  flg_enable_cors_enforcement tinyint(2) NOT NULL default 0,
  flg_check_payload tinyint(2) NOT NULL default 1,
  flg_allow_cors tinyint(2) NOT NULL default 0,
  flg_tightening tinyint(2) NOT NULL default 0,
  pattern blob NOT NULL default '',
  pattern_order int(10) NOT NULL default 0,
  flg_wildcard_includes_slash tinyint(2) NOT NULL default 1,
  websocket_url_charset_templ_id int(10) NOT NULL default 0,
  flg_check_websocket_url_metachar tinyint(2) NOT NULL default 1,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  PRIMARY KEY  (policy_name_crc,websocket_url_crc)
) ENGINE=InnoDB COMMENT='policy attributes for WebSocket wildcard URLs';


-- ACTIVE_POLICY: DCC.ACCOUNT_WEBSOCKET_URL_CORS_ALLOWED_ORIGINS
CREATE TABLE ACCOUNT_WEBSOCKET_URL_CORS_ALLOWED_ORIGINS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  websocket_url_crc bigint(20) unsigned NOT NULL default 0,
  origin_name varchar(1024) NOT NULL default '',
  origin_port int(8),
  origin_protocol int(2) not NULL default 3,
  flg_include_sub_domains tinyint(2) NOT NULL default 0,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_WEBSOCKET_URL
CREATE TABLE ACCOUNT_WEBSOCKET_URL (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  protocol int(2) NOT NULL default 0,
  websocket_url_crc bigint(20) unsigned NOT NULL default 0,
  flg_is_disallowed tinyint(2) NOT NULL default 0,
  flg_is_staging tinyint(2) NOT NULL default 1,
  message_max_binary_size int(10) unsigned NOT NULL default 10000,
  message_max_frame_size int(10) unsigned NOT NULL default 10000,
  message_max_frames int(10) unsigned NOT NULL default 100,
  websocket_text_profile_id bigint(20) unsigned NOT NULL default 0,
  websocket_json_profile_id bigint(20) unsigned NOT NULL default 0,
  websocket_extension int(2) NOT NULL default 0,
  flg_in_classification tinyint(2) NOT NULL default 0,
  flg_websocket_message_format_text tinyint(2) NOT NULL default 0,
  flg_websocket_message_format_json tinyint(2) NOT NULL default 0,
  flg_websocket_message_format_binary tinyint(2) NOT NULL default 0,
  flg_enable_cors_enforcement tinyint(2) NOT NULL default 0,
  flg_check_payload tinyint(2) NOT NULL default 1,
  flg_allow_cors tinyint(2) NOT NULL default 0,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  PRIMARY KEY  (policy_name_crc,protocol,websocket_url_crc)
) ENGINE=InnoDB COMMENT='policy attributes for WebSocket URLs';


-- ACTIVE_POLICY: DCC.ACCOUNT_VALID_HOST_NAMES_REGEXES
CREATE TABLE ACCOUNT_VALID_HOST_NAMES_REGEXES (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  regexes_filename char(255) NOT NULL default '',
  UNIQUE (policy_name_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Contains file location with host names regexes which should also be considered safe for CSRF checking';


-- ACTIVE_POLICY: DCC.ACCOUNT_VALID_HOST_NAME_DOMAINS
CREATE TABLE ACCOUNT_VALID_HOST_NAME_DOMAINS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  domain_name varchar(255)  NOT NULL default '',
  flg_include_sub_domains int(2) NOT NULL default '0',
  UNIQUE (policy_name_crc, domain_name),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE  
) ENGINE=InnoDB COMMENT='Contains domains for which the enforcer should set cookies that will traverse subdomains';


-- ACTIVE_POLICY: DCC.ACCOUNT_THREAT_RATING_SETTINGS
CREATE TABLE ACCOUNT_THREAT_RATING_SETTINGS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  aggregation_strategy int(4) NOT NULL default '1',
  flg_machine_learning_enabled tinyint(1) NOT NULL default '0',
  machine_learning_weight double NOT NULL default 0,
FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_SSRF_DISALLOWED_HOSTS
CREATE TABLE ACCOUNT_SSRF_DISALLOWED_HOSTS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  domain_name varchar(255)  NOT NULL default '',
  flg_include_sub_domains boolean NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Contains hosts which the enforcer should block for SSRF';


-- ACTIVE_POLICY: DCC.ACCOUNT_SIGNATURE_RESPONSES
CREATE TABLE ACCOUNT_SIGNATURE_RESPONSES(
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  sig_id bigint(20) unsigned NOT NULL,
  deception_response_id bigint(20) unsigned NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  PRIMARY KEY (policy_name_crc, sig_id)
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_SESSION_AWARENESS_SETTINGS
CREATE TABLE ACCOUNT_SESSION_AWARENESS_SETTINGS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  flg_session_awareness_on tinyint(1) NOT NULL default '0',
  flg_use_apm_username tinyint(1) NOT NULL default '0',
  violations_mask varchar(255) NOT NULL default '0',
  sliding_window_lifetime int(4)  NOT NULL default '0',
  sid_track_all_threshold int(4)  NOT NULL default '0',
  sid_block_illegal_threshold int(4)  NOT NULL default '0',
  sid_block_all_threshold int(4)  NOT NULL default '0',
  ip_track_all_threshold int(4)  NOT NULL default '0',
  ip_block_illegal_threshold int(4)  NOT NULL default '0',
  ip_block_all_threshold int(4)  NOT NULL default '0',
  user_track_all_threshold int(4)  NOT NULL default '0',
  user_block_illegal_threshold int(4)  NOT NULL default '0',
  user_block_all_threshold int(4)  NOT NULL default '0',
  device_track_all_threshold int(4)  NOT NULL default '0',
  device_block_illegal_threshold int(4)  NOT NULL default '0',
  device_block_all_threshold int(4)  NOT NULL default '0',
  track_all_period int(4)  NOT NULL default '0',
  block_illegal_period int(4)  NOT NULL default '0',
  flg_violations_actions_enabled tinyint(1)  NOT NULL default '0',
  block_all_period int(4)  NOT NULL default '600',
  flg_check_block_all_period tinyint(1)  NOT NULL default '1',
  flg_block_only_authenticated tinyint(1)  NOT NULL default '0',
  flg_session_hijacking tinyint(1) NOT NULL default '0',
  viol_set varbinary(16) NOT NULL default '',
  PRIMARY KEY  (policy_name_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_SERVER_TECHNOLOGY_RESPONSES
CREATE TABLE ACCOUNT_SERVER_TECHNOLOGY_RESPONSES(
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  deception_response_id bigint(20) unsigned NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_SENSITIVE_PARAMS
CREATE TABLE ACCOUNT_SENSITIVE_PARAMS (
  id int(8) NOT NULL auto_increment,
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  param_name varchar(255) BINARY NOT NULL default '',
  from_params_tables int(2) NOT NULL default 0,
  PRIMARY KEY  (id),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT=' Contain data about sensitive params';


-- ACTIVE_POLICY: DCC.ACCOUNT_RESPONSE_SCRUBBING_URLS
CREATE TABLE ACCOUNT_RESPONSE_SCRUBBING_URLS (
  account_response_scrubbing_url_id bigint(20) unsigned NOT NULL auto_increment,
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  target_pattern blob NOT NULL default '',
  PRIMARY KEY (account_response_scrubbing_url_id),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_RESPONSE_SCRUBBING_FORMATS
CREATE TABLE ACCOUNT_RESPONSE_SCRUBBING_FORMATS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  format_id int(8) unsigned NOT NULL,
  format_name varchar(255) NOT NULL,
  PRIMARY KEY  (policy_name_crc,format_id),
  FOREIGN KEY (policy_name_crc) references ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;



-- ACTIVE_POLICY: DCC.ACCOUNT_RESPONSE_SCRUBBING
CREATE TABLE ACCOUNT_RESPONSE_SCRUBBING (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  flg_check_for_ccn tinyint(1) NOT NULL default '0',
  ccn_exposed_len int(2) NOT NULL default '4',
  flg_check_for_ssn tinyint(1) NOT NULL default '0',
  ssn_exposed_len int(2) NOT NULL default '4',
  all_patterns blob NOT NULL default '',
  all_exceptions blob NOT NULL default '',
  flg_mask_data tinyint(1) NOT NULL default '0',
  flg_check_file_content tinyint(1) NOT NULL default '0',
  flg_enforcement_mode tinyint(1) NOT NULL default '0',
  PRIMARY KEY  (policy_name_crc),
  FOREIGN KEY (policy_name_crc) references ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_REGEXP_DYNAMIC_FLOWS
CREATE TABLE ACCOUNT_REGEXP_DYNAMIC_FLOWS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  from_object_crc bigint(20) unsigned NOT NULL default '0',
  reg_exp mediumtext NOT NULL default '',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='List of regular expressions used by bd to extract dynamic fl';


-- ACTIVE_POLICY: DCC.ACCOUNT_REDIRECT_DOMAINS
CREATE TABLE ACCOUNT_REDIRECT_DOMAINS (
    policy_name_crc bigint(20) unsigned NOT NULL default '0',
    domain_name varchar(255) NOT NULL default '',
    flg_include_subdomains int(2) NOT NULL default 0,
    FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_PREREQUISITE_VALID_CRITERIA
CREATE TABLE ACCOUNT_PREREQUISITE_VALID_CRITERIA (
    policy_name_crc bigint(20) unsigned NOT NULL default '0',
    object_crc bigint(20) unsigned NOT NULL default '0',
    criterium_type int(2) NOT NULL default '0',
    criterium_match blob NOT NULL default '',
    FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
    PRIMARY KEY (object_crc, criterium_type)
) ENGINE=InnoDB COMMENT='Pre-requisite objects criteria';


-- ACTIVE_POLICY: DCC.ACCOUNT_PREREQUISITE_OBJECT_TARGETS
CREATE TABLE ACCOUNT_PREREQUISITE_OBJECT_TARGETS (
    policy_name_crc bigint(20) unsigned NOT NULL default '0',
    restricted_target_pattern text NOT NULL,
    FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Pre-requisite object targets';


-- ACTIVE_POLICY: DCC.ACCOUNT_PREREQUISITE_ATTRIBUTES 
CREATE TABLE ACCOUNT_PREREQUISITE_ATTRIBUTES (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  expiration_period int(2) NOT NULL default '0',
  PRIMARY KEY (policy_name_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_PB_SETTINGS
CREATE TABLE ACCOUNT_PB_SETTINGS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  pb_learn_from_response int(2) NOT NULL default 0,
  pb_learn_login_forms int(2) NOT NULL DEFAULT '0',
  pb_learning_mode int(2) NOT NULL DEFAULT 0,
  pb_learning_progress int(3) NOT NULL DEFAULT 0,
  pb_server_technologies int(2) NOT NULL DEFAULT 0,
  pb_cookie_learning int(2) NOT NULL DEFAULT 0,
  UNIQUE (policy_name_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_PARAMETER_NAMES
CREATE TABLE ACCOUNT_PARAMETER_NAMES (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  param_name varbinary(255) NOT NULL default '',
  param_name_crc bigint(20) unsigned NOT NULL default '0',
  PRIMARY KEY (policy_name_crc,param_name_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_PARAM_VALUE_RANGES
CREATE TABLE ACCOUNT_PARAM_VALUE_RANGES (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  app_id int(10) NOT NULL default '0',
  key_crc bigint(20) unsigned NOT NULL default '0',
  flag_check_min int(2) NOT NULL default '0',
  min_value double NOT NULL default '0',
  flag_check_max int(2) NOT NULL default '0',
  max_value double NOT NULL default '0',
  flg_exclusive_min tinyint(2) unsigned NOT NULL default 0,
  flg_exclusive_max tinyint(2) unsigned NOT NULL default 0,
  flg_check_multiple_of_value tinyint(2) NOT NULL default 0,
  multiple_of_value double NOT NULL default 5,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  PRIMARY KEY  (policy_name_crc,key_crc)
) ENGINE=InnoDB COMMENT='numeric parameter value ranges';


-- ACTIVE_POLICY: DCC.ACCOUNT_PARAM_REG_EXPS
CREATE TABLE ACCOUNT_PARAM_REG_EXPS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  app_id int(10) NOT NULL default '0',
  reg_exp_crc bigint(20) unsigned NOT NULL default '0',
  reg_exp mediumtext NOT NULL default '',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  PRIMARY KEY  (policy_name_crc,reg_exp_crc)
) ENGINE=InnoDB COMMENT='regular expressions for allowed values of parameters';


-- ACTIVE_POLICY: DCC.ACCOUNT_OBJECT_POSITIONAL_PARAMETERS
CREATE TABLE ACCOUNT_OBJECT_POSITIONAL_PARAMETERS (
  positional_parameter_id bigint(20) unsigned NOT NULL auto_increment,
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  param_name_crc bigint(20) unsigned NOT NULL default '0',
  url_segment_index int(10) NOT NULL default '0',
  PRIMARY KEY  (positional_parameter_id),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_OBJECT_PARAMETERS
CREATE TABLE ACCOUNT_OBJECT_PARAMETERS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  app_id int(10) NOT NULL default '0',
  key_crc bigint(20) unsigned NOT NULL default '0',
  key_input_type int(10) NOT NULL default '0',
  max_user_input_len int(10) NOT NULL default '0',
  ui_type int(10) NOT NULL default '0',
  flg_disallow_upload_of_exe int(2) NOT NULL default '1',
  regexp_crc bigint(20) unsigned NOT NULL default '0',
  flg_null_value_allow int(2) NOT NULL default '0',
  flg_mandatory int(2) NOT NULL default '0',
  param_value_charset_templ_id int(10) NOT NULL default 0,
  profile_templ_id int(10) NOT NULL default 0,
  flg_is_staging int(2) NOT NULL default '0',
  flg_is_sensitive int(2) NOT NULL default '0',
  negative_check_bitmap int NOT NULL default '0',
  flg_allow_repeated_parameter_name int(2) NOT NULL default '0',
  flg_in_classification int(2) NOT NULL default '0',
  flg_is_base64 int(2) NOT NULL DEFAULT '0',
  flg_is_ip_address int(2) NOT NULL DEFAULT '0',
  parameter_location tinyint(1) unsigned NOT NULL default '1',
  flags_array_type_bitmask int(10) unsigned NOT NULL default '0',
  min_values_items_in_array int(10) unsigned NOT NULL default '0',
  max_values_items_in_array int(10) unsigned NOT NULL default '0',
  array_serialization_format tinyint(1) unsigned NOT NULL default '1',
  flg_check_enum_values tinyint(1) unsigned NOT NULL default 0,
  min_user_input_len int(8) unsigned default 0,
  flg_conviction tinyint(1) unsigned NOT NULL default 0,
  object_serialization_style tinyint(2) unsigned NOT NULL default 1,
  flg_object_serialization_explode tinyint(2) unsigned NOT NULL default 0,
  flg_detect_base64 int(2) NOT NULL DEFAULT '0',
  PRIMARY KEY  (policy_name_crc,key_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='enforcer policy configuration for parameters';


-- ACTIVE_POLICY: DCC.ACCOUNT_OBJECT_QUERY_AS_VALUE_PARAMETERS
CREATE TABLE ACCOUNT_OBJECT_QUERY_AS_VALUE_PARAMETERS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  obj_crc bigint(20) unsigned NOT NULL default '0',
  object_param_key_crc bigint(20) unsigned NOT NULL default '0',
  parameter_name varbinary(255) NOT NULL default '',
  PRIMARY KEY (policy_name_crc, obj_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  FOREIGN KEY (policy_name_crc,object_param_key_crc) REFERENCES ACCOUNT_OBJECT_PARAMETERS(policy_name_crc,key_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_OBJECT_MANDATORY_PARAMETERS
CREATE TABLE ACCOUNT_OBJECT_MANDATORY_PARAMETERS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  obj_crc bigint(20) unsigned NOT NULL default '0',
  object_param_key_crc bigint(20) unsigned NOT NULL default '0',
  parameter_name varbinary(255) NOT NULL default '',
  PRIMARY KEY (policy_name_crc, obj_crc, object_param_key_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  FOREIGN KEY (policy_name_crc,object_param_key_crc) REFERENCES ACCOUNT_OBJECT_PARAMETERS(policy_name_crc,key_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_OBJECT_EXTRACT_XPATH
CREATE TABLE ACCOUNT_OBJECT_EXTRACT_XPATH (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  param_name tinyblob NOT NULL,
  xpath blob NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Object extractions using xpath';


-- ACTIVE_POLICY: DCC.ACCOUNT_OBJECT_EXTRACT_REGEXP
CREATE TABLE ACCOUNT_OBJECT_EXTRACT_REGEXP (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  reg_exp mediumtext NOT NULL default '',
  regexp_num_occurrences int(10) NOT NULL default '0',
  param_name tinyblob NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Object extractions using regexp';


-- ACTIVE_POLICY: DCC.ACCOUNT_OBJECT_EXTRACT_HREF
CREATE TABLE ACCOUNT_OBJECT_EXTRACT_HREF (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  target_uri varchar(255) NOT NULL default '',
  param_name tinyblob NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Object extractions using href';


-- ACTIVE_POLICY: DCC.ACCOUNT_OBJECT_EXTRACT_FORM_PARAM_NAME
CREATE TABLE ACCOUNT_OBJECT_EXTRACT_FORM_PARAM_NAME (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  param_name_crc bigint(20) unsigned NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Object extractions using form param name';


-- ACTIVE_POLICY: DCC.ACCOUNT_OBJECT_EXTRACT_FORM_PARAM_INDEX
CREATE TABLE ACCOUNT_OBJECT_EXTRACT_FORM_PARAM_INDEX (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  param_name_crc bigint(20) unsigned NOT NULL default '0',
  form_idx int(10) NOT NULL default '0',
  param_idx int(10) NOT NULL default '0',
  unused_legacy_flag int(1) unsigned NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Object extractions using form param index';


-- ACTIVE_POLICY: DCC.ACCOUNT_OBJECT_EXTRACT_DYNAMIC_PARAM_NAME
CREATE TABLE ACCOUNT_OBJECT_EXTRACT_DYNAMIC_PARAM_NAME (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  reg_exp mediumtext NOT NULL default '',
  flg_check_dynamic_value int(2) NOT NULL default '1',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Object extractions using dynamic param name';


-- ACTIVE_POLICY: DCC.ACCOUNT_OBJECT_CORS_HEADERS
CREATE TABLE ACCOUNT_OBJECT_CORS_HEADERS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  header_type int(2) NOT NULL,
  header_name varchar(255)NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_OBJECT_CORS_ALLOWED_ORIGINS
CREATE TABLE ACCOUNT_OBJECT_CORS_ALLOWED_ORIGINS  (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  origin_name varchar(1024) NOT NULL default '',
  origin_port int(8),
  origin_protocol int(2) not NULL default 3,
  flg_include_sub_domains int(2) NOT NULL default 0,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_OBJECT_CORS_ALLOWED_METHODS
CREATE TABLE ACCOUNT_OBJECT_CORS_ALLOWED_METHODS  (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  method_name varchar(255) NOT NULL default '',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB ;


-- ACTIVE_POLICY: DCC.ACCOUNT_NORMALIZATION_PROFILE
CREATE TABLE ACCOUNT_NORMALIZATION_PROFILE (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  user_mask_bitmap int(4) NOT NULL,
  reject_bitmap int(10) NOT NULL,
  alarm_bitmap int(10) NOT NULL,
  learn_bitmap int(10) NOT NULL,
  max_decoding_passes int(8) NOT NULL,
  PRIMARY KEY (policy_name_crc),  
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_NEGSIG_XML_EXCLUSIONS
CREATE TABLE ACCOUNT_NEGSIG_XML_EXCLUSIONS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  xml_sig_crc bigint(20) unsigned NOT NULL,
  blocking_mask int(10) NOT NULL,
  flg_is_enabled tinyint(1),
  profile_templ_id int(10) unsigned NOT NULL,
  sig_id bigint(20) unsigned NOT NULL,
  PRIMARY KEY (xml_sig_crc),  
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_NEGSIG_URL_EXCLUSIONS
CREATE TABLE ACCOUNT_NEGSIG_URL_EXCLUSIONS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  url_sig_crc bigint(20) unsigned NOT NULL,
  blocking_mask int(10) NOT NULL,
  flg_is_enabled tinyint(1) NOT NULL default '0',
  objcrc bigint(20) unsigned NOT NULL,
  sig_id bigint(20) unsigned NOT NULL,
  PRIMARY KEY (url_sig_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_NEGSIG_SIGNATURE_PROPERTIES
CREATE TABLE ACCOUNT_NEGSIG_SIGNATURE_PROPERTIES (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  sig_id bigint(20) unsigned NOT NULL,
  sig_id_orig bigint(20) unsigned NOT NULL,
  negsig_set_names_id int(10) unsigned NOT NULL DEFAULT 0,
  sig_crc bigint(20) unsigned NOT NULL,
  blocking_mask int(10) NOT NULL,
  threshold int(10) NOT NULL DEFAULT 0,
  flg_quarantined tinyint(1) NOT NULL,
  last_enforcement_change int(10) NOT NULL DEFAULT 0,
  threat_campaign_id bigint(20) unsigned NOT NULL DEFAULT 0,
  bot_sig_id bigint(20) unsigned NOT NULL DEFAULT 0,
  sig_type int(8) NOT NULL,
  PRIMARY KEY (sig_crc),
  UNIQUE (policy_name_crc, sig_id),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_NEGSIG_SET_NAMES_TEMPLATES
CREATE TABLE ACCOUNT_NEGSIG_SET_NAMES_TEMPLATES (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  negsig_set_names_id int(10) unsigned NOT NULL default '0',
  negsig_set_names_text varchar(1023) NOT NULL default '',
  modify_time timestamp NOT NULL default CURRENT_TIMESTAMP,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  PRIMARY KEY  (policy_name_crc,negsig_set_names_id)
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_NEGSIG_PARAM_EXCLUSIONS
CREATE TABLE ACCOUNT_NEGSIG_PARAM_EXCLUSIONS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  param_sig_crc bigint(20) unsigned NOT NULL,
  blocking_mask int(10) NOT NULL,
  flg_is_enabled tinyint(1),
  keycrc bigint(20) unsigned NOT NULL,
  sig_id bigint(20) unsigned NOT NULL,
  PRIMARY KEY (param_sig_crc),  
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_NEGSIG_HEADER_EXCLUSIONS
CREATE TABLE ACCOUNT_NEGSIG_HEADER_EXCLUSIONS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  header_sig_crc bigint(20) unsigned NOT NULL,
  blocking_mask int(10) NOT NULL,
  flg_is_enabled tinyint(1) NOT NULL default '0',
  header_name_crc bigint(20) unsigned NOT NULL,
  sig_id bigint(20) unsigned NOT NULL,
  PRIMARY KEY (header_sig_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_NEGSIG_COOKIE_EXCLUSIONS
CREATE TABLE ACCOUNT_NEGSIG_COOKIE_EXCLUSIONS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  cookie_sig_crc bigint(20) unsigned NOT NULL,
  blocking_mask int(10) NOT NULL,
  flg_is_enabled tinyint(1),
  cookie_name blob NOT NULL default '',
  sig_id bigint(20) unsigned NOT NULL,
  PRIMARY KEY (cookie_sig_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_NEGSIG_COLLECTIONS
CREATE TABLE ACCOUNT_NEGSIG_COLLECTIONS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  request_collection_id int(10),
  response_collection_id int(10),
  request_buffer_type_mask int(10) NOT NULL,
  response_buffer_type_mask int(10) NOT NULL,
  sets_json blob DEFAULT '',
  sets_json_md5 varchar(32) NOT NULL,
  always_disabled_sigs blob DEFAULT '',
  max_last_enforcement_change int(10),
  KEY(sets_json_md5),
  PRIMARY KEY (policy_name_crc),  
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_NEGSIG_ATTRIBUTES
CREATE TABLE ACCOUNT_NEGSIG_ATTRIBUTES (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  attack_signature_false_positive_mode int(10) unsigned NOT NULL default '1',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  PRIMARY KEY  (policy_name_crc)
) ENGINE=InnoDB COMMENT='settings for attack signature enforcements';


-- ACTIVE_POLICY: DCC.ACCOUNT_NAVIGATION_PARAMS
CREATE TABLE ACCOUNT_NAVIGATION_PARAMS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_path_crc bigint(20) unsigned NOT NULL default '0',
  param_name tinyblob NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  KEY object_path_crc (policy_name_crc,object_path_crc)
) ENGINE=InnoDB COMMENT='parameters that are logicaly part of the web objects';


-- ACTIVE_POLICY: DCC.ACCOUNT_MICROSERVICES
CREATE TABLE ACCOUNT_MICROSERVICES (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  pattern_order int(10) NOT NULL default '0',
  object_pattern blob NOT NULL,
  flg_is_pattern_object int(2) NOT NULL default 1,
  flg_wildcard_includes_slash int(2) NOT NULL default '1',
  host_pattern blob NOT NULL,
  flg_is_pattern_host int(2) NOT NULL default 1,
  is_transparent tinyint(1) NOT NULL default 1,
  http_protocol_checks_learn_mask int NOT NULL default '0',
  http_protocol_checks_alarm_mask int NOT NULL default '0',
  http_protocol_checks_reject_mask int NOT NULL default '0',
  evasion_reject_mask int NOT NULL default '0',
  evasion_alarm_mask int NOT NULL default '0',
  evasion_learn_mask int NOT NULL default '0',
  evasion_max_decoding_passes int(8) NOT NULL,
  viol_set_learn varbinary(16) NOT NULL default '',
  viol_set_alarm varbinary(16) NOT NULL default '',
  viol_set_block varbinary(16) NOT NULL default '',
  max_params int(10) unsigned NOT NULL default '0',
  max_headers int(10) unsigned NOT NULL default '0',
  PRIMARY KEY (policy_name_crc,object_pattern(500),host_pattern(500)),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_LOGOUT_OBJECT_VALID_CRITERIA
CREATE TABLE ACCOUNT_LOGOUT_OBJECT_VALID_CRITERIA (
    policy_name_crc bigint(20) unsigned NOT NULL default '0',
    object_crc bigint(20) unsigned NOT NULL default '0',
    criterium_type int(2) NOT NULL default '0',
    criterium_match blob NOT NULL default '',
    FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
    PRIMARY KEY (object_crc, criterium_type)
) ENGINE=InnoDB COMMENT='Logout objects criteria';



-- ACTIVE_POLICY: DCC.ACCOUNT_LOGOUT_OBJECT_ATTRIBUTES
CREATE TABLE ACCOUNT_LOGOUT_OBJECT_ATTRIBUTES (
    policy_name_crc bigint(20) unsigned NOT NULL default '0',
    object_crc bigint(20) unsigned NOT NULL default '0',
    criteria_bitmap int(2) NOT NULL default '0',
    FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
    PRIMARY KEY (object_crc)
) ENGINE=InnoDB COMMENT='Logout objects';



-- ACTIVE_POLICY: DCC.ACCOUNT_LOGIN_OBJECT_ATTRIBUTES
CREATE TABLE ACCOUNT_LOGIN_OBJECT_ATTRIBUTES (
    policy_name_crc bigint(20) unsigned NOT NULL default '0',
    object_crc bigint(20) unsigned NOT NULL default '0',
    criteria_bitmap int(2) NOT NULL default '0',
    username_param_crc bigint(20) unsigned NOT NULL default '0',
    password_param_crc bigint(20) unsigned NOT NULL default '0',
    auth_type int(8) NOT NULL default '0',
    FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
    PRIMARY KEY (object_crc)
) ENGINE=InnoDB COMMENT='Login objects';


-- ACTIVE_POLICY: DCC.ACCOUNT_LOGIN_IGNORE_URLS
CREATE TABLE ACCOUNT_LOGIN_IGNORE_URLS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB ;


-- ACTIVE_POLICY: DCC.ACCOUNT_LOGIN_BRUTE_FORCE_OBJECT_ATTRIBUTES
CREATE TABLE ACCOUNT_LOGIN_BRUTE_FORCE_OBJECT_ATTRIBUTES (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  obj_crc bigint(20) unsigned NOT NULL default '0',
  obj blob NOT NULL default '',
  protocol int(2) NOT NULL default '0',
  login_object_rest_uuid char(22) NOT NULL default '',
  max_login_attempts int(8) NOT NULL default '20',
  session_expiration_period int(8) NOT NULL default '3600',
  measurement_period int(8) NOT NULL default '900',
  detection_threshold_abs int(8) NOT NULL default '100',
  max_prevention_time int(8) NOT NULL default '3600',
  flg_force_blocking int(2) NOT NULL default '0',
  flg_alarm int(2) NOT NULL default '1',
  flg_block int(2) NOT NULL default '1',
  flg_identify_device int(2) NOT NULL default '0',
  is_inherited int(2) NOT NULL default '0',
  last_updated int(10) NOT NULL default '0',
  flg_detect_credentials_stuffing_attack tinyint(1) NOT NULL DEFAULT '1',
  detection_threshold_credentials_stuffing_matches_reached int(8) NOT NULL DEFAULT '100',
  detection_threshold_action int(2) NOT NULL DEFAULT '3',
  flg_detect_distributed_brute_force_attack tinyint(1) NOT NULL DEFAULT '1',
  flg_detect_login_attempts_from_the_same_user tinyint(1) NOT NULL DEFAULT '1',
  login_attempts_from_the_same_user_threshold int(8) NOT NULL DEFAULT '3',
  login_attempts_from_the_same_user_action int(2) NOT NULL DEFAULT '3',
  login_attempts_from_the_same_device_id_threshold int(8) NOT NULL DEFAULT '3',
  login_attempts_from_the_same_device_id_action int(2) NOT NULL DEFAULT '3',
  flg_detect_login_attempts_from_the_same_ip int(2) NOT NULL DEFAULT '1',
  login_attempts_from_the_same_ip_action int(2) NOT NULL DEFAULT '3',
  flg_captcha_bypass tinyint(1) NOT NULL DEFAULT '1',
  captcha_bypass_threshold int(8) NOT NULL DEFAULT '5',
  captcha_bypass_threshold_action int(2) NOT NULL DEFAULT '6',
  flg_client_side_integrity_bypass tinyint(1) NOT NULL DEFAULT '1',
  client_side_integrity_bypass_threshold int(8) NOT NULL DEFAULT '3',
  client_side_integrity_bypass_threshold_action int(2) NOT NULL DEFAULT '3',
  source_based_protection_detection_period int(8) NOT NULL DEFAULT '3600',
  flg_leaked_credentials_detection tinyint(1) NOT NULL DEFAULT '0',
  leaked_credentials_action int(2) NOT NULL DEFAULT '2',
  PRIMARY KEY  (policy_name_crc, obj_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_LOG_PROFILE
CREATE TABLE ACCOUNT_LOG_PROFILE (
    policy_name_crc       bigint(20) unsigned NOT NULL default '0',
    log_profile_name_crc  bigint(20) unsigned NOT NULL default '0',
    PRIMARY KEY (log_profile_name_crc, policy_name_crc),
    FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_IP_WHITELIST
CREATE TABLE ACCOUNT_IP_WHITELIST (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  ip_address varchar(128) NOT NULL,
  route_domain int(2) NOT NULL default '0',
  ip_mask varchar(128) NOT NULL,
  ip_address_int varbinary(16) NOT NULL default '',
  ip_mask_int varbinary(16) NOT NULL default '',
  ignore_flags_mask  int(1) NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_IP_REPUTATION
CREATE TABLE ACCOUNT_IP_REPUTATION (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  categories_alarm_mask  int(1) NOT NULL default '0',
  categories_block_mask  int(1) NOT NULL default '0',
  categories_learn_mask  int(1) NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_HEADERS
CREATE TABLE ACCOUNT_HEADERS (
    policy_name_crc bigint(20) unsigned NOT NULL default '0',
    header_name_crc bigint(20) unsigned NOT NULL default '0',
    header_code bigint(20) unsigned NOT NULL default '0',
    header_name varchar(255) NOT NULL default '',
    flg_is_mandatory int(2) NOT NULL default 0,
    flg_check_signatures int(2) NOT NULL default 1,
    flg_enable_normalization_violation int(2) NOT NULL default 0,
    flg_is_base64 int(2) NOT NULL default 0,
    flg_detect_base64 int(2) NOT NULL default 0,
    normalization_mask int(1) NOT NULL default '0',
    excluded_signatures_exist tinyint(1) NOT NULL default 0,
    flg_mask_value int(2) NOT NULL default 0,
    flg_allow_repeated int(2) NOT NULL default 1,
    flg_enforced_as_param tinyint(1) unsigned NOT NULL default 0,
    flg_conviction tinyint(1) unsigned NOT NULL default 0,
    UNIQUE KEY ( policy_name_crc, header_name_crc),
    FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_PARAMETERS
CREATE TABLE ACCOUNT_GLOBAL_PARAMETERS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  key_crc bigint(20) unsigned NOT NULL default '0',
  key_input_type int(10) NOT NULL default '0',
  max_user_input_len int(10) NOT NULL default '0',
  ui_type int(10) NOT NULL default '0',
  flg_disallow_upload_of_exe int(2) NOT NULL default '1',
  regexp_crc bigint(20) unsigned NOT NULL default '0',
  flg_null_value_allow int(2) NOT NULL default '0',
  flg_mandatory int(2) NOT NULL default '0',
  param_value_charset_templ_id int(10) NOT NULL default 0,
  profile_templ_id int(10) NOT NULL default 0,
  flg_is_staging int(2) NOT NULL default '0',
  flg_is_sensitive int(2) NOT NULL default '0',
  negative_check_bitmap int NOT NULL default '0',
  flg_allow_repeated_parameter_name int(2) NOT NULL default '0',
  flg_in_classification int(2) NOT NULL default '0',
  flg_is_base64 int(2) NOT NULL DEFAULT '0',
  flg_is_ip_address int(2) NOT NULL DEFAULT '0',
  parameter_location tinyint(1) unsigned NOT NULL default '1',
  flags_array_type_bitmask int(10) unsigned NOT NULL default '0',
  min_values_items_in_array int(10) unsigned NOT NULL default '0',
  max_values_items_in_array int(10) unsigned NOT NULL default '0',
  array_serialization_format tinyint(1) unsigned NOT NULL default '1',
  flg_check_enum_values tinyint(1) unsigned NOT NULL default 0,
  min_user_input_len int(8) unsigned default 0,
  flg_conviction tinyint(1) unsigned NOT NULL default 0,
  object_serialization_style tinyint(2) unsigned NOT NULL default 1,
  flg_object_serialization_explode tinyint(2) unsigned NOT NULL default 0,
  flg_detect_base64 int(2) NOT NULL DEFAULT '0',
  PRIMARY KEY  (policy_name_crc,key_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='enforcer policy configuration for parameters';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_MANDATORY_PARAMETERS
CREATE TABLE ACCOUNT_GLOBAL_MANDATORY_PARAMETERS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  global_param_key_crc bigint(20) unsigned NOT NULL default '0',
  parameter_name varbinary(255) NOT NULL default '',
  PRIMARY KEY (policy_name_crc, global_param_key_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  FOREIGN KEY (policy_name_crc, global_param_key_crc) REFERENCES ACCOUNT_GLOBAL_PARAMETERS(policy_name_crc,key_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_LENGTHS
CREATE TABLE ACCOUNT_GLOBAL_LENGTHS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  max_header_len int(8) NOT NULL default '0',
  max_cookie_len int(8) NOT NULL default '0',
  PRIMARY KEY  (policy_name_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';



-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_EXTRACT_XPATH
CREATE TABLE ACCOUNT_GLOBAL_EXTRACT_XPATH (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  param_name tinyblob NOT NULL,
  xpath blob NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions using xpath';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_EXTRACT_REGEXP
CREATE TABLE ACCOUNT_GLOBAL_EXTRACT_REGEXP (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  reg_exp mediumtext NOT NULL default '',
  regexp_num_occurrences int(10) NOT NULL default '0',
  param_name tinyblob NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions using regexp';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_EXTRACT_HREF
CREATE TABLE ACCOUNT_GLOBAL_EXTRACT_HREF (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  param_name tinyblob NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions using href';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_EXTRACT_FORM_PARAM_NAME
CREATE TABLE ACCOUNT_GLOBAL_EXTRACT_FORM_PARAM_NAME (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  param_name_crc bigint(20) unsigned NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions using form param name';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_EXTRACT_FORM_PARAM_INDEX
CREATE TABLE ACCOUNT_GLOBAL_EXTRACT_FORM_PARAM_INDEX (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  param_name_crc bigint(20) unsigned NOT NULL default '0',
  form_idx int(10) NOT NULL default '0',
  param_idx int(10) NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions using form param index';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_EXTRACT_DYNAMIC_PARAM_NAME
CREATE TABLE ACCOUNT_GLOBAL_EXTRACT_DYNAMIC_PARAM_NAME (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  reg_exp mediumtext NOT NULL default '',
  flg_check_dynamic_value int(2) NOT NULL default '1',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions using dynamic param name';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_BYREGEXP_EXTRACT_XPATH
CREATE TABLE ACCOUNT_GLOBAL_BYREGEXP_EXTRACT_XPATH (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_regexp blob NOT NULL default '',
  param_name tinyblob NOT NULL,
  xpath blob NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions (by regexp) using xpath';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_BYREGEXP_EXTRACT_REGEXP
CREATE TABLE ACCOUNT_GLOBAL_BYREGEXP_EXTRACT_REGEXP (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_regexp blob NOT NULL default '',
  reg_exp mediumtext NOT NULL default '',
  regexp_num_occurrences int(10) NOT NULL default '0',
  param_name tinyblob NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions (by regexp) using regexp';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_BYREGEXP_EXTRACT_HREF
CREATE TABLE ACCOUNT_GLOBAL_BYREGEXP_EXTRACT_HREF (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_regexp blob NOT NULL default '',
  param_name tinyblob NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions (by regexp) using href';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_BYREGEXP_EXTRACT_FORM_PARAM_NAME
CREATE TABLE ACCOUNT_GLOBAL_BYREGEXP_EXTRACT_FORM_PARAM_NAME (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_regexp blob NOT NULL default '',
  param_name_crc bigint(20) unsigned NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions (by regexp) using form param name';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_BYREGEXP_EXTRACT_FORM_PARAM_INDEX
CREATE TABLE ACCOUNT_GLOBAL_BYREGEXP_EXTRACT_FORM_PARAM_INDEX (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_regexp blob NOT NULL default '',
  param_name_crc bigint(20) unsigned NOT NULL default '0',
  form_idx int(10) NOT NULL default '0',
  param_idx int(10) NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions (by regexp) using form param index';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_BYREGEXP_EXTRACT_DYNAMIC_PARAM_NAME
CREATE TABLE ACCOUNT_GLOBAL_BYREGEXP_EXTRACT_DYNAMIC_PARAM_NAME (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_regexp blob NOT NULL default '',
  reg_exp mediumtext NOT NULL default '',
  flg_check_dynamic_value int(2) NOT NULL default '1',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions (by regexp) using dynamic param name';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_BYOBJECT_EXTRACT_XPATH
CREATE TABLE ACCOUNT_GLOBAL_BYOBJECT_EXTRACT_XPATH (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  param_name tinyblob NOT NULL,
  xpath blob NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions (by object) using xpath';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_BYOBJECT_EXTRACT_REGEXP
CREATE TABLE ACCOUNT_GLOBAL_BYOBJECT_EXTRACT_REGEXP (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  reg_exp mediumtext NOT NULL default '',
  regexp_num_occurrences int(10) NOT NULL default '0',
  param_name tinyblob NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions (by object) using regexp';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_BYOBJECT_EXTRACT_HREF
CREATE TABLE ACCOUNT_GLOBAL_BYOBJECT_EXTRACT_HREF (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  param_name tinyblob NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions (by object) using href';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_BYOBJECT_EXTRACT_FORM_PARAM_NAME
CREATE TABLE ACCOUNT_GLOBAL_BYOBJECT_EXTRACT_FORM_PARAM_NAME (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  param_name_crc bigint(20) unsigned NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions (by object) using form param name';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_BYOBJECT_EXTRACT_FORM_PARAM_INDEX
CREATE TABLE ACCOUNT_GLOBAL_BYOBJECT_EXTRACT_FORM_PARAM_INDEX (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  param_name_crc bigint(20) unsigned NOT NULL default '0',
  form_idx int(10) NOT NULL default '0',
  param_idx int(10) NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions (by object) using form param index';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_BYOBJECT_EXTRACT_DYNAMIC_PARAM_NAME
CREATE TABLE ACCOUNT_GLOBAL_BYOBJECT_EXTRACT_DYNAMIC_PARAM_NAME (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  reg_exp mediumtext NOT NULL default '',
  flg_check_dynamic_value int(2) NOT NULL default '1',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions (by object) using dynamic param name';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_BYFILETYPE_EXTRACT_XPATH
CREATE TABLE ACCOUNT_GLOBAL_BYFILETYPE_EXTRACT_XPATH (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  filetype_crc bigint(20) unsigned NOT NULL default '0',
  param_name tinyblob NOT NULL,
  xpath blob NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions (by filetype) using xpath';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_BYFILETYPE_EXTRACT_REGEXP
CREATE TABLE ACCOUNT_GLOBAL_BYFILETYPE_EXTRACT_REGEXP (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  filetype_crc bigint(20) unsigned NOT NULL default '0',
  reg_exp mediumtext NOT NULL default '',
  regexp_num_occurrences int(10) NOT NULL default '0',
  param_name tinyblob NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions (by filetype) using regexp';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_BYFILETYPE_EXTRACT_HREF
CREATE TABLE ACCOUNT_GLOBAL_BYFILETYPE_EXTRACT_HREF (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  filetype_crc bigint(20) unsigned NOT NULL default '0',
  param_name tinyblob NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions (by filetype) using href';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_BYFILETYPE_EXTRACT_FORM_PARAM_NAME
CREATE TABLE ACCOUNT_GLOBAL_BYFILETYPE_EXTRACT_FORM_PARAM_NAME (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  filetype_crc bigint(20) unsigned NOT NULL default '0',
  param_name_crc bigint(20) unsigned NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions (by filetype) using form param name';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_BYFILETYPE_EXTRACT_FORM_PARAM_INDEX
CREATE TABLE ACCOUNT_GLOBAL_BYFILETYPE_EXTRACT_FORM_PARAM_INDEX (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  filetype_crc bigint(20) unsigned NOT NULL default '0',
  param_name_crc bigint(20) unsigned NOT NULL default '0',
  form_idx int(10) NOT NULL default '0',
  param_idx int(10) NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions (by filetype) using form param index';


-- ACTIVE_POLICY: DCC.ACCOUNT_GLOBAL_BYFILETYPE_EXTRACT_DYNAMIC_PARAM_NAME
CREATE TABLE ACCOUNT_GLOBAL_BYFILETYPE_EXTRACT_DYNAMIC_PARAM_NAME (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  filetype_crc bigint(20) unsigned NOT NULL default '0',
  reg_exp mediumtext NOT NULL default '',
  flg_check_dynamic_value int(2) NOT NULL default '1',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Global extractions (by filetype) using dynamic param name';


-- ACTIVE_POLICY: DCC.ACCOUNT_GEOLOCATION_ENFORCEMENT
CREATE TABLE ACCOUNT_GEOLOCATION_ENFORCEMENT (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  country_code varchar(3) NOT NULL DEFAULT '',  
  UNIQUE KEY `policy_name_crc` (`policy_name_crc`,`country_code`),
  FOREIGN KEY (`policy_name_crc`) REFERENCES `ACCOUNTS` (`policy_name_crc`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COMMENT='Contains a list of countries to allow/disallow (based on flag in ACCOUNTS)';



-- ACTIVE_POLICY: DCC.ACCOUNT_FLOW_PARAMETERS
CREATE TABLE ACCOUNT_FLOW_PARAMETERS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  app_id int(10) NOT NULL default '0',
  key_crc bigint(20) unsigned NOT NULL default '0',
  key_input_type int(10) NOT NULL default '0',
  max_user_input_len int(10) NOT NULL default '0',
  ui_type int(10) NOT NULL default '0',
  flg_disallow_upload_of_exe int(2) NOT NULL default '1',
  regexp_crc bigint(20) unsigned NOT NULL default '0',
  flg_null_value_allow int(2) NOT NULL default '0',
  flg_mandatory int(2) NOT NULL default '0',
  param_value_charset_templ_id int(10) NOT NULL default 0,
  profile_templ_id int(10) NOT NULL default 0,
  flg_is_staging int(2) NOT NULL default '0',
  flg_is_sensitive int(2) NOT NULL default '0',
  negative_check_bitmap int NOT NULL default '0',
  flg_allow_repeated_parameter_name int(2) NOT NULL default '0',
  flg_in_classification int(2) NOT NULL default '0',
  flg_is_base64 int(2) NOT NULL DEFAULT '0',
  flg_is_ip_address int(2) NOT NULL DEFAULT '0',
  parameter_location tinyint(1) unsigned NOT NULL default '1',
  flags_array_type_bitmask int(10) unsigned NOT NULL default '0',
  min_values_items_in_array int(10) unsigned NOT NULL default '0',
  max_values_items_in_array int(10) unsigned NOT NULL default '0',
  array_serialization_format tinyint(1) unsigned NOT NULL default '1',
  flg_check_enum_values tinyint(1) unsigned NOT NULL default 0,
  min_user_input_len int(8) unsigned default 0,
  flg_conviction tinyint(1) unsigned NOT NULL default 0,
  object_serialization_style tinyint(2) unsigned NOT NULL default 1,
  flg_object_serialization_explode tinyint(2) unsigned NOT NULL default 0,
  flg_detect_base64 int(2) NOT NULL DEFAULT '0',
  PRIMARY KEY  (policy_name_crc,key_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='enforcer policy configuration for parameters';


-- ACTIVE POLICY: DCC.ACCOUNT_FACTORY_BROWSER_PROPERTIES
CREATE TABLE ACCOUNT_FACTORY_BROWSER_PROPERTIES (
    policy_name_crc bigint(20) unsigned NOT NULL default '0',
    factory_browser_id int(10) unsigned NOT NULL default '0',
    min_version int(10) unsigned,
    max_version int(10) unsigned,
    action_mask int(10) unsigned NOT NULL default '0',
    UNIQUE KEY ( policy_name_crc, factory_browser_id),
    FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_ENFORCER_SETTINGS
CREATE TABLE ACCOUNT_ENFORCER_SETTINGS (
    policy_name_crc bigint(20) unsigned NOT NULL default '0',
    state_cookie_http_only_attribute int(2) NOT NULL default 1,
    state_cookie_secure_attribute int(2) NOT NULL default 1,
    state_cookie_same_site_attribute int(2) NOT NULL default 2,
    UNIQUE KEY (policy_name_crc),
    FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


CREATE TABLE ACCOUNT_EM_TRANSACTIONS (
  em_transaction_id int(8) NOT NULL auto_increment,
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  PRIMARY KEY (em_transaction_id),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_DECEPTION_TRAPS
CREATE TABLE ACCOUNT_DECEPTION_TRAPS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  injection_type tinyint (3) NOT NULL default '1',
  deception_trap_id bigint(20) unsigned NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_DATABASE_PROTECTION
CREATE TABLE ACCOUNT_DATABASE_PROTECTION (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  flg_is_enabled int(2) unsigned NOT NULL DEFAULT '0',
  user_source int(2) NOT NULL DEFAULT 1,
  UNIQUE (policy_name_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE  
) ENGINE=InnoDB;



-- ACTIVE_POLICY: DCC.ACCOUNT_CUSTOM_RESPONSES
CREATE TABLE ACCOUNT_CUSTOM_RESPONSES (
  custom_response_id bigint(20) unsigned NOT NULL auto_increment,
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  response_code varchar(3) NOT NULL default '200',
  response_body blob,
  PRIMARY KEY (custom_response_id),
  UNIQUE (policy_name_crc, response_code),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_CUSTOM_RESPONSE_HEADERS
CREATE TABLE ACCOUNT_CUSTOM_RESPONSE_HEADERS (
  custom_response_id bigint(20) unsigned NOT NULL default '0',
  header_name blob NOT NULL,
  header_value blob NOT NULL,
  FOREIGN KEY (custom_response_id) REFERENCES ACCOUNT_CUSTOM_RESPONSES(custom_response_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_CUSTOM_HEADERS_POOL
CREATE TABLE ACCOUNT_CUSTOM_HEADERS_POOL (
    policy_name_crc bigint(20) unsigned NOT NULL default '0',
    header_code bigint(20) unsigned NOT NULL default '0',
    header_name varchar(255) NOT NULL default '',
    FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_CSRF_URLS_PARAMETERS
CREATE TABLE ACCOUNT_CSRF_URLS_PARAMETERS (
  account_csrf_url_parameter_id bigint(20) unsigned NOT NULL auto_increment,
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  csrf_url_crc bigint(20) unsigned NOT NULL,
  param_name varbinary(255) NOT NULL,
  PRIMARY KEY (account_csrf_url_parameter_id),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;



-- ACTIVE_POLICY: DCC.ACCOUNT_CSRF_URLS
CREATE TABLE ACCOUNT_CSRF_URLS (
  account_csrf_url_id bigint(20) unsigned NOT NULL auto_increment,
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  csrf_url_crc bigint(20) unsigned NOT NULL,
  pattern blob NOT NULL default '',
  pattern_order int(10) NOT NULL default '0',
  method int(8)unsigned NOT NULL,
  csrf_url_enforcement_action int(10) unsigned NOT NULL,
  required_parameters int(10) unsigned NOT NULL default '1',
  url_regexp blob NOT NULL default '',
  PRIMARY KEY (account_csrf_url_id),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_CSRF
CREATE TABLE ACCOUNT_CSRF (
  account_csrf_id bigint(20) unsigned NOT NULL auto_increment,
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  flg_is_enabled int(2) NOT NULL default '0',
  flg_is_ssl_only int(2) NOT NULL default '0',
  expiration_time_in_seconds int(8) NOT NULL default '0',
  PRIMARY KEY (account_csrf_id),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_CHARSETS
CREATE TABLE ACCOUNT_CHARSETS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  charset_type int(10) NOT NULL default '0',
  charset_templ_id int(10) NOT NULL default 0,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  PRIMARY KEY  (policy_name_crc,charset_type)
) ENGINE=InnoDB COMMENT='Table contains data about account charsets';


-- ACTIVE_POLICY: DCC.ACCOUNT_CHARSET_TEMPLATES
CREATE TABLE ACCOUNT_CHARSET_TEMPLATES (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  charset_templ_id int(10) NOT NULL default '0',
  charset mediumtext NOT NULL default '',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  PRIMARY KEY  (policy_name_crc,charset_templ_id)
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_CASE_INSENSITIVE
CREATE TABLE ACCOUNT_CASE_INSENSITIVE (
  policy_name_crc bigint(20) unsigned NOT NULL default '0', 
  flg_is_case_insensitive int(2) NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_BOT_DEFENSE_CLASS
CREATE TABLE ACCOUNT_BOT_DEFENSE_CLASS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  bot_class int(10) NOT NULL default 0,
  action int(10) NOT NULL default 0,
  UNIQUE KEY (policy_name_crc, bot_class),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_BOT_ANOMALIES
CREATE TABLE ACCOUNT_BOT_ANOMALIES (
    policy_name_crc bigint(20) unsigned NOT NULL default '0',
    bot_anomaly_id int(10) unsigned NOT NULL default '0',
    blocking_mask int NOT NULL default '0',
    score_threshold int NOT NULL default '0',
    PRIMARY KEY (policy_name_crc, bot_anomaly_id),
    FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;



-- ACTIVE_POLICY: DCC.ACCOUNT_BLOCKING
CREATE TABLE ACCOUNT_BLOCKING (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  viol_set_learn varbinary(16) NOT NULL default '',
  viol_set_alarm varbinary(16) NOT NULL default '',
  viol_set_block varbinary(16) NOT NULL default '',
  is_policy_transparent tinyint(1) NOT NULL default '0',
  flg_behavioral_enforcement tinyint(1) NOT NULL default '0',
  viol_set_behavioral varbinary(16) NOT NULL DEFAULT '',
  flg_block_cve_signatures tinyint(1) NOT NULL DEFAULT '0',
  flg_block_suspicious_transactions tinyint(1) NOT NULL DEFAULT '0',
  flg_block_likely_malicious_transactions tinyint(1) NOT NULL DEFAULT '0',
  flg_block_high_accuracy_signatures tinyint(1) NOT NULL DEFAULT '0',
  flg_use_custom_deception_pages tinyint(1) unsigned NOT NULL default '0',
  server_technology_id bigint(20) unsigned NOT NULL default '0',
  flg_response_by_attack_type tinyint(1) NOT NULL default '0',
  flg_managed_by_bewaf tinyint(1) NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  PRIMARY KEY  (policy_name_crc)
) ENGINE=InnoDB COMMENT='actions taken by enforcer when a violation is encountered';


-- CONFIG_SYNC: DCC.ACCOUNT_APPLICATIONS
CREATE TABLE ACCOUNT_APPLICATIONS (
  idx int(10) unsigned NOT NULL auto_increment,
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  app_id int(10) NOT NULL default '0',
  max_sessions int(10) NOT NULL default '0',
  strict_mode int(10) NOT NULL default '0',
  verification_object varchar(255) NOT NULL default '',
  KEY idx (idx),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='application (http/ssl) specific configuration sent to core';


-- ACTIVE_POLICY: DCC.ACCOUNT_APPLICATION_WILDCARD_OBJECT_ATTRIBUTES
CREATE TABLE ACCOUNT_APPLICATION_WILDCARD_OBJECT_ATTRIBUTES (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  app_id int(11) NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  pattern blob NOT NULL default '',
  negative_check_bitmap int NOT NULL default '0',
  flg_has_positional_params int(2) NOT NULL default '0',
  flg_tightening int(2) NOT NULL default '0',
  pattern_order int(10) NOT NULL default '0' ,
  obj_charset_templ_id int(10) NOT NULL default 0,
  object_settings_bitmap  int NOT NULL default '0',
  flg_is_staging int(2) NOT NULL default '0',
  clickjacking_type int(2) default 0,
  clickjacking_from varchar(267),
  content_profile_id int(8) unsigned NOT NULL default '0',
  type_id  int(8) unsigned NOT NULL default '0',
  flg_in_classification int(2) NOT NULL default '0',
  flg_wildcard_includes_slash  int(2) NOT NULL default '1',
  maximum_age int(10) NOT NULL default '1800',
  obj_methods_templ_id int(10) NOT NULL DEFAULT '0',
  allowed_origins_enforcement_mode int(2) NOT NULL default '1',
  flg_check_signatures tinyint(1) NOT NULL default 0,
  excluded_signatures_exist tinyint(1) NOT NULL default 0,
  default_xml_profile_id int(8) unsigned NOT NULL default '0',
  default_json_profile_id int(8) unsigned NOT NULL default '0',
  method_code int(10) unsigned NOT NULL default '0',
  operation_id varchar(255),
  positional_param_last_segment int(10) unsigned NOT NULL default '0',
  PRIMARY KEY (policy_name_crc,object_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_APPLICATION_WILDCARD_FILE_TYPE_ATTRIBUTES
CREATE TABLE ACCOUNT_APPLICATION_WILDCARD_FILE_TYPE_ATTRIBUTES (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  validity int(2) NOT NULL default '0',
  max_request_len int(10) NOT NULL default '0',
  max_object_name_len int(10) NOT NULL default '0',
  max_user_input_len int(10) NOT NULL default '0',
  max_post_data_len int(10) NOT NULL default '0',
  max_url_len int(10) NOT NULL default '0',
  flg_filter_app_error int(2) NOT NULL default '0',
  pattern blob NOT NULL default '',
  flg_tightening int(2) NOT NULL default '0',
  pattern_order int(10) NOT NULL default '0',
  flg_is_staging int(2) NOT NULL default '0',
  flg_check_uri_len int(2) NOT NULL default 1,
  flg_check_req_len int(2) NOT NULL default 1,
  flg_check_qs_len int(2) NOT NULL default 1,
  flg_check_pd_len int(2) NOT NULL default 1,
  PRIMARY KEY (policy_name_crc,pattern_order),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Contains wildcard file type(extension) configuration sent to core';


-- ACTIVE_POLICY: DCC.ACCOUNT_APPLICATION_STATIC_PARAMS
CREATE TABLE ACCOUNT_APPLICATION_STATIC_PARAMS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  app_id int(10) NOT NULL default '0',
  key_value_crc bigint(20) unsigned NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  PRIMARY KEY  (policy_name_crc,key_value_crc)
) ENGINE=InnoDB COMMENT='value list of parameters of type static';


-- ACTIVE_POLICY: DCC.ACCOUNT_APPLICATION_OBJECT_ATTRIBUTES
CREATE TABLE ACCOUNT_APPLICATION_OBJECT_ATTRIBUTES (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  app_id int(11) NOT NULL default '0',
  object_crc bigint(20) unsigned NOT NULL default '0',
  object_settings_bitmap int NOT NULL default '0',
  flg_parse_dynamic_params int(2) NOT NULL default '0',
  flg_is_staging int(2) NOT NULL default '1',
  clickjacking_type int(2) default 0,
  clickjacking_from varchar(267),
  content_profile_id int(8) unsigned NOT NULL default '0',
  type_id  int(8) unsigned NOT NULL default '0',
  flg_in_classification int(2) NOT NULL default '0',
  maximum_age int(10) NOT NULL default '1800',
  obj_methods_templ_id int(10) NOT NULL DEFAULT '0',
  allowed_origins_enforcement_mode int(2) NOT NULL default '1',
  flg_check_signatures tinyint(1) NOT NULL default 0,
  excluded_signatures_exist tinyint(1) NOT NULL default 0,
  default_xml_profile_id int(8) unsigned NOT NULL default '0',
  default_json_profile_id int(8) unsigned NOT NULL default '0',
  flg_conviction tinyint(1) unsigned NOT NULL default 0,
  operation_id varchar(255),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  PRIMARY KEY  (policy_name_crc,app_id,object_crc)
) ENGINE=InnoDB COMMENT='policy attributes for objects (urls)';


-- ACTIVE_POLICY: DCC.ACCOUNT_APPLICATION_FLOW
CREATE TABLE ACCOUNT_APPLICATION_FLOW (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  app_id int(10) NOT NULL default '0',
  arch_crc bigint(20) unsigned NOT NULL default '0',
  input_attributes int(10) NOT NULL default '0',
  encoding int(10) NOT NULL default '0',
  num_mandatory_params int(10) NOT NULL default '0',
  frame_index int(10) NOT NULL default '0',
  flg_has_dynamic_param_name tinyint(1) NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  PRIMARY KEY  (policy_name_crc,app_id,arch_crc)
) ENGINE=InnoDB COMMENT='policy flows sent to core enforcer';


-- ACTIVE_POLICY: DCC.ACCOUNT_APPLICATION_FILE_TYPE_ATTRIBUTES
CREATE TABLE ACCOUNT_APPLICATION_FILE_TYPE_ATTRIBUTES (
  filetype_crc bigint(20) unsigned NOT NULL default '0',
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  validity int(2) NOT NULL default '0',
  max_request_len int(10) NOT NULL default '0',
  max_object_name_len int(10) NOT NULL default '0',
  max_user_input_len int(10) NOT NULL default '0',
  max_post_data_len int(10) NOT NULL default '0',
  max_url_len int(10) NOT NULL default '0',
  flg_filter_app_error int(2) NOT NULL default '0',
  flg_is_staging int(2) NOT NULL default '0',
  flg_check_uri_len int(2) NOT NULL default 1,
  flg_check_req_len int(2) NOT NULL default 1,
  flg_check_qs_len int(2) NOT NULL default 1,
  flg_check_pd_len int(2) NOT NULL default 1,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Contains file type (extension) configuration sent to core';


-- ACTIVE_POLICY: DCC.ACCOUNT_APPLICATION_DISALLOWED_FILE_TYPES
CREATE TABLE ACCOUNT_APPLICATION_DISALLOWED_FILE_TYPES (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  filetype_crc bigint(20) unsigned NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.ACCOUNT_ALTERNATE_RESPONSE_SETTINGS
CREATE TABLE ACCOUNT_ALTERNATE_RESPONSE_SETTINGS(
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  flg_ajax_enabled int(2) unsigned NOT NULL default '0',
  PRIMARY KEY (policy_name_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;



-- ACTIVE_POLICY: DCC.ACCOUNT_ALTERNATE_RESPONSE_FILE_HEADERS
CREATE TABLE ACCOUNT_ALTERNATE_RESPONSE_FILE_HEADERS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  cause int(2) NOT NULL,
  header_name text NOT NULL,
  header_value text NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='response files sent by enforcer in case of web server error';


-- ACTIVE_POLICY: DCC.ACCOUNT_ALTERNATE_RESPONSE_FILE
CREATE TABLE ACCOUNT_ALTERNATE_RESPONSE_FILE (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  cause int(2) NOT NULL,
  alternate_response_content text NOT NULL,
  response_code int(10) NOT NULL default 200,
  offset_to_image int(10) NOT NULL default 0,
  offset_to_support_id int(10) NOT NULL default 0,
  offset_to_audio int(10) NOT NULL default 0,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  PRIMARY KEY  (policy_name_crc, cause)
) ENGINE=InnoDB COMMENT='response files sent by enforcer in case of web server error';


-- ACTIVE_POLICY: DCC.ACCOUNT_ALLOWED_RESPONSE_CODES
CREATE TABLE ACCOUNT_ALLOWED_RESPONSE_CODES (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  allowed_response_code int(10) NOT NULL default '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;



-- ACTIVE_POLICY: DCC.ACCOUNT_ALLOWED_METHODS
CREATE TABLE ACCOUNT_ALLOWED_METHODS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  method_code int(10) NOT NULL default '0',
  act_as_method_code int(10) NOT NULL default '0',
  obj_methods_templ_id int(10) NOT NULL DEFAULT '0',
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='HTTP methods accepted by enforcer';


-- ACTIVE_POLICY: DCC.ACCOUNT_ALLOWED_COOKIES
CREATE TABLE ACCOUNT_ALLOWED_COOKIES (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  cookie_name_crc bigint(20) unsigned NOT NULL default '0',
  cookie_enforcement_mode int(2) NOT NULL default 0,
  flg_is_staging int(2) NOT NULL default 0,
  is_http_only int(2) NOT NULL default 0,
  is_secure int(2) NOT NULL default 0,
  flg_is_base64 int(2) NOT NULL DEFAULT '0',
  cookie_same_site_attribute int(2) NOT NULL default 1,
  flg_check_signatures int(2) NOT NULL default 0,
  flg_mask_value int(2) NOT NULL default 0,
  flg_enforced_as_param tinyint(1) unsigned NOT NULL default 0,
  flg_conviction tinyint(1) unsigned NOT NULL default 0,
  flg_detect_base64 int(2) NOT NULL DEFAULT '0',
  UNIQUE (policy_name_crc, cookie_name_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE  
) ENGINE=InnoDB COMMENT='Contains all cookies not to be checked by core enforcer';


-- ACTIVE_POLICY: DCC.ACCOUNTS_OBJECTS_HEADER_WEB_PROFILES
CREATE TABLE ACCOUNTS_OBJECTS_HEADER_WEB_PROFILES (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  object_crc  bigint(20) unsigned NOT NULL default '0',
  content_profile_id int(8) unsigned NOT NULL default '0',
  type_id  int(8) unsigned NOT NULL default '0',
  header_order int(10) NOT NULL default '0',
  header_name varchar(1024),
  header_value  blob NOT NULL,
  flg_in_classification int(2) NOT NULL default '0',
  PRIMARY KEY  (id),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS (policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;



CREATE TABLE APPLICATION_NAMES (
  app_id int(10) NOT NULL default '0',
  app_name char(40) NOT NULL default ''
) ENGINE=InnoDB COMMENT='A fixed pool describing supported applications';





-- ACTIVE_POLICY: DCC.ATTACK_TYPE_CODES
CREATE TABLE ATTACK_TYPE_CODES (
  attack_type_id bigint(20) unsigned NOT NULL default '0',
  attack_type_name varchar(128) default NULL,
  attack_type_backward_compatible_name varchar(128) default NULL,
  attack_type_code bigint(20) unsigned NOT NULL default '0',
  attack_type_bit_index bigint(20) unsigned NOT NULL default '0',
  PRIMARY KEY (attack_type_id)
) ENGINE=InnoDB;


CREATE TABLE BIG_IP_UNIT_INFO (
  unit_info_id tinyint NOT NULL default 1,
  unit_hostname varchar(128),
  mng_ip_addr varchar(128),
  mng_ip_addr2 varchar(128),
  software_version varchar(128),
  flg_is_asm_provisioned int(2) NOT NULL default '1',
  PRIMARY KEY  (unit_info_id)
) ENGINE=InnoDB;





-- ACTIVE_POLICY: DCC.BOT_ANOMALIES
CREATE TABLE BOT_ANOMALIES (
    bot_anomaly_id bigint(20) unsigned NOT NULL default '0',
    bot_anomaly_name blob NOT NULL,
    bot_class int(10) NOT NULL,
    PRIMARY KEY (bot_anomaly_id)
) ENGINE=InnoDB;



-- ACTIVE_POLICY: DCC.BOT_SIGNATURES
CREATE TABLE BOT_SIGNATURES (
  bot_sig_id bigint(20) unsigned NOT NULL auto_increment,
  bot_sig_name varchar(255) NOT NULL,
  bot_sig_class int(8) NOT NULL,
  bot_sig_category varchar(255) NOT NULL,
  PRIMARY KEY (bot_sig_id)
) ENGINE=InnoDB;


CREATE TABLE BOT_SIGNATURE_HOSTNAMES (
  bot_sig_id int(10) NOT NULL default '0',
  hostname varchar(255) NOT NULL,
  PRIMARY KEY (bot_sig_id, hostname),
  FOREIGN KEY (bot_sig_id) REFERENCES BOT_SIGNATURES(bot_sig_id) ON DELETE CASCADE
) ENGINE=InnoDB;



-- ACTIVE_POLICY: DCC.CLIENT_SIDE_CAPTCHA
CREATE TABLE CLIENT_SIDE_CAPTCHA (
  dirname varchar(255) NOT NULL,
  is_active tinyint(1) NOT NULL,
  PRIMARY KEY (dirname)
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.CLIENT_SIDE_OBFUSCATED_JS
CREATE TABLE CLIENT_SIDE_OBFUSCATED_JS (
  dirname varchar(255) NOT NULL,
  datacrypt_key varchar(256) NOT NULL,
  generation_time int(4) NOT NULL,
  is_latest_update tinyint(1) NOT NULL,
  PRIMARY KEY (dirname)
) ENGINE=InnoDB;


CREATE TABLE CLUSTER_SYNC_FILES ( 
  sync_file_id bigint(10) unsigned NOT NULL auto_increment,
  sync_filename varchar(255) NOT NULL,
  create_datetime datetime,
  first_seen_datetime datetime,
  sync_type varchar(255) NOT NULL default 'full',
  policy_name_crc bigint(20) unsigned default '0',
  policy_id int(10),
  status varchar(255) NOT NULL default 'new',
  completed_datetime datetime,
  PRIMARY KEY (sync_file_id),
  UNIQUE (sync_filename)
) ENGINE=InnoDB;



CREATE TABLE CLUSTER_SYNC_FILE_STATUS ( 
  sync_file_id bigint(10) unsigned NOT NULL,
  status_filename varchar(255) NOT NULL,
  slot_number int(10) NOT NULL,
  status varchar(255) NOT NULL,
  status_datetime datetime NOT NULL,
  message blob,
  KEY (sync_file_id),
  FOREIGN KEY (sync_file_id) references CLUSTER_SYNC_FILES(sync_file_id) ON DELETE CASCADE
) ENGINE=InnoDB;



CREATE TABLE CMD_RESULTS (
  code int(10) NOT NULL default '0',
  description varchar(255) NOT NULL default ''
) ENGINE=InnoDB COMMENT='Obsolete';





-- CLUSTER_TABLE: DCC.CONF_PRIMARY_BLADE_RATE_LIMIT
CREATE TABLE CONF_PRIMARY_BLADE_RATE_LIMIT (
  primary_blade_slot char(20) NOT NULL default '',
  green_blade_count int(8) NOT NULL default '1',
  mysql_password char(100) NOT NULL default '',
  ip_address varchar(128) NOT NULL default '',
  PRIMARY KEY (primary_blade_slot)
) ENGINE=InnoDB;


CREATE TABLE CONFIG_TYPE_UPDATE_LOGGER_CFG  (
  last_update_time  int(4)
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.CONTENT_PROFILE_TEMPLATES
CREATE TABLE CONTENT_PROFILE_TEMPLATES (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  profile_templ_id int(10) NOT NULL auto_increment,
  profile_id bigint(20) unsigned NOT NULL default 0,
  defense_config_filename varchar(255) NOT NULL,
  schema_filename varchar(255) NOT NULL,
  json_schemas_md5 varchar(255) NOT NULL,
  request_xpath_filename varchar(255) NOT NULL,
  response_xpath_filename varchar(255) NOT NULL,
  flg_validation_soapaction_header int(2) NOT NULL default 0,
  content_type varchar(50) NOT NULL default '',
  flg_allow_soap_attachment int(2) NOT NULL default 0,
  flg_is_soap_traffic int(2) NOT NULL default 0,
  flg_has_disallowed_methods int(2) NOT NULL default 0,
  flg_is_wss_security int(2) NOT NULL default 0,
  flg_is_xml_security int(2) NOT NULL default 0,
  modify_time datetime,
  charset_templ_id int(10) NOT NULL default '0',
  flg_is_json_security int(2) NOT NULL default '0',
  flg_check_param_value_length int(2) NOT NULL default '1',
  max_param_value_length int(10) NOT NULL default '0',
  flg_use_xml_blocking_page int(2) NOT NULL default '0',
  flg_check_element_metachars int(2) NOT NULL default '0',
  flg_check_attribute_metachars int(2) NOT NULL default '0',
  flg_check_signatures int(2) NOT NULL default '0',
  flg_inspect_soap_attachments int(2) NOT NULL default 0,
  flg_is_gwt_security  int(2) NOT NULL default '0',
  flg_tolerate_parsing  int(2) NOT NULL default '0',
  flg_check_document_length int(2) NOT NULL default '0',
  max_document_length  int(10) NOT NULL default '0',
  profile_name varchar(255) NOT NULL,
  flg_is_plain_text_security int(2) NOT NULL default '0',
  flg_perform_percent_decoding int(2) NOT NULL default '0',
  flg_handle_json_parameters tinyint(2) NOT NULL default 0,
  flg_is_grpc_security int(2) NOT NULL default '0',
  flg_detect_string_base64 int(2) NOT NULL default 0,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  PRIMARY KEY (profile_templ_id)
) ENGINE=InnoDB;


-- CONFIG_SYNC: DCC.CREDENTIAL_STUFFING_UPDATE_FILE
CREATE TABLE CREDENTIAL_STUFFING_UPDATE_FILE (
  credential_filename varchar(255) NOT NULL default '',
  flg_credential_stuffing_subscription boolean NOT NULL default 1,
  PRIMARY KEY (credential_filename),
  UNIQUE KEY credential_filename (credential_filename)
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.DATA_PROTECTION
CREATE TABLE DATA_PROTECTION (
  conf_file  varchar(255) NOT NULL default '',
  key_gen_time int(4) NOT NULL default 0,
  grace_conf_file varchar(255) default '',
  grace_signing_end_time int(4) NOT NULL default 0,
  grace_accepting_end_time int(4) NOT NULL  default 0
) ENGINE=InnoDB;


CREATE TABLE DATABASE_PROTECTION_SETTINGS (   
   server_ip_addr varchar(128) NOT NULL DEFAULT '',
   server_host_name varchar(255) NOT NULL DEFAULT '',
   server_port varchar(128) NOT NULL DEFAULT '0',
   flg_is_request_hold_timeout_enabled int(2) NOT NULL DEFAULT '0',
   request_hold_timeout int(4) NOT NULL DEFAULT 5,
   flg_is_response_hold_timeout_enabled int(2) NOT NULL DEFAULT '0',
   response_hold_timeout int(4) NOT NULL DEFAULT 5
 ) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.DECEPTION_RESPONSES
CREATE TABLE DECEPTION_RESPONSES (
  deception_response_id bigint(20) unsigned NOT NULL auto_increment,
  response_code varchar(3) NOT NULL default '200',
  response_body blob,
  PRIMARY KEY (deception_response_id)
) ENGINE=InnoDB;


CREATE TABLE DECEPTION_RESPONSE_HEADERS (
  deception_response_id bigint(20) unsigned NOT NULL default '0',
  header_name blob NOT NULL,
  header_value blob NOT NULL,
  FOREIGN KEY (deception_response_id) REFERENCES DECEPTION_RESPONSES(deception_response_id) ON DELETE CASCADE
) ENGINE=InnoDB;


 -- ACTIVE_POLICY: DCC.DECEPTION_TRAPS
CREATE TABLE DECEPTION_TRAPS (
  deception_trap_id bigint(20) unsigned NOT NULL auto_increment,
  deception_trap_name varchar(254) NOT NULL,
  deception_trap_display_name varchar(254) NOT NULL,
  attack_type_id bigint(20) unsigned,
  risk tinyint(1) NOT NULL default 1,
  score int(10) NOT NULL default 0,
  PRIMARY KEY (deception_trap_id)
) ENGINE=InnoDB;


 -- ACTIVE_POLICY: DCC.DECEPTION_TRAP_INJECTIONS
CREATE TABLE DECEPTION_TRAP_INJECTIONS (
  deception_trap_injection_id bigint(20) unsigned NOT NULL auto_increment,
  deception_trap_id bigint(20) unsigned NOT NULL,
  injection_type tinyint (3) NOT NULL default '1',
  injection_value blob,
  injection_condition blob,
  tag_name blob,
  tag_injection_location tinyint(3),
  PRIMARY KEY (deception_trap_injection_id),
  FOREIGN KEY (deception_trap_id) REFERENCES DECEPTION_TRAPS(deception_trap_id) ON DELETE CASCADE
) ENGINE=InnoDB;


 -- ACTIVE_POLICY: DCC.DECEPTION_TRAP_INJECTION_HEADERS
CREATE TABLE DECEPTION_TRAP_INJECTION_HEADERS (
  injection_header_id bigint(20) unsigned NOT NULL auto_increment,
  deception_trap_id bigint(20) unsigned NOT NULL,
  header_name blob NOT NULL,
  header_value blob NOT NULL,
  PRIMARY KEY (injection_header_id),
  FOREIGN KEY (deception_trap_id) REFERENCES DECEPTION_TRAPS(deception_trap_id) ON DELETE CASCADE
) ENGINE=InnoDB;



 -- ACTIVE_POLICY: DCC.DECEPTION_TRAP_CONDITIONS
CREATE TABLE DECEPTION_TRAP_CONDITIONS (
  deception_trap_condition_id bigint(20) unsigned NOT NULL auto_increment,
  deception_trap_id bigint(20) unsigned NOT NULL,
  condition_source tinyint(8) NOT NULL default '1',
  condition_operator tinyint(3) NOT NULL default '1',
  condition_value varchar(254) NOT NULL,
  last_updated int(10) NOT NULL default '0',
  PRIMARY KEY (deception_trap_condition_id),
  FOREIGN KEY (deception_trap_id) REFERENCES DECEPTION_TRAPS(deception_trap_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.DECEPTION_TRAPS_ENTITIES
CREATE TABLE DECEPTION_TRAPS_ENTITIES (
  deception_trap_entity_id bigint(20) unsigned NOT NULL auto_increment,
  entity_key bigint(20) NOT NULL default '0',
  entity_type tinyint(8) NOT NULL default '1',
  deception_trap_id bigint(20) unsigned NOT NULL,
  PRIMARY KEY (deception_trap_entity_id),
  FOREIGN KEY (deception_trap_id) REFERENCES DECEPTION_TRAPS(deception_trap_id) ON DELETE CASCADE
) ENGINE=InnoDB;


CREATE TABLE DEFAULT_CHARSETS (
  charset_id int(10) NOT NULL default '0',
  charset mediumtext NOT NULL,
  description varchar(255) NOT NULL default '',
  charset_type int(10) NOT NULL default '0',
  encoding_id int(10) NOT NULL default '0',
  section_type int(10) NOT NULL default '0',
  rest_uuid char(22) NOT NULL default '',
  PRIMARY KEY  (charset_id)
) ENGINE=InnoDB;







CREATE TABLE DUMP_BD_CONFIG_TABLES  (
  last_update_time  int(4)
) ENGINE=InnoDB;


CREATE TABLE ENCODINGS (
  encoding_id int(10) NOT NULL auto_increment,
  encoding varchar(255) NOT NULL default '',
  encoding_type int(2) NOT NULL default '1',
  display_priority int(10) NOT NULL default '0',
  icontrol_name varchar(255) NOT NULL default '',
  PRIMARY KEY  (encoding_id),
  UNIQUE KEY encoding (encoding)
) ENGINE=InnoDB;





-- ACTIVE_POLICY: DCC.ENFORCER_ACCOUNTS
CREATE TABLE ENFORCER_ACCOUNTS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  policy_name varchar(255) BINARY NOT NULL default '',
  policy_apply_date int unsigned NOT NULL default 0,
  lang_set_id int(10) NOT NULL default '3',
  flg_encoding_selected int(2) NOT NULL default '0',
  flg_use_dynamic_session_in_url int(2) NOT NULL default '0',
  dynamic_session_pattern varchar(255) NOT NULL default '',
  flg_enable_account int(2) NOT NULL default '1',
  flg_use_violation_asm_irule int(2) NOT NULL default '0',
  dynamic_session_description blob,
  domain_name_changed_time int(10) NOT NULL default 0,
  http_protocol_checks_mask bigint(20) unsigned NOT NULL default '0', -- will be removed after BD change
  http_protocol_checks_learn_mask bigint(20) unsigned NOT NULL default '0',
  http_protocol_checks_alarm_mask bigint(20) unsigned NOT NULL default '0',
  http_protocol_checks_reject_mask bigint(20) unsigned NOT NULL default '0',
  max_headers int(10) unsigned NOT NULL default '0',   
  mandatory_headers_mask bigint(20) unsigned NOT NULL default '0',
  negsig_excluded_headers_mask bigint(20) unsigned NOT NULL default '0',
  flg_migrated int(2) NOT NULL default '0',
  wss_sub_violations_mask int(4) NOT NULL default '0',
  flg_is_whitehat int(2) NOT NULL default '0',
  whitehat_attacks_bitmap int NOT NULL default '0',
  policy_template_system_id int(4) NOT NULL default '0',
  flg_virus_check_file_upload int(2) NOT NULL default '0',
  max_params int(10) unsigned NOT NULL default '0',   
  flg_is_protocol_free int(2) NOT NULL default '0',
  flg_is_module_provisioned int(2) NOT NULL default '1',
  encoding_type int(2) NOT NULL default '1',
  flg_is_trust_xff int(2) NOT NULL default '0',
  flg_ajax_enabled int(2) NOT NULL default '0',
  path_parameter_handling int(2) NOT NULL default '1',
  flg_mask_sensitive int(2) NOT NULL default '1',
  redirect_action int(2) NOT NULL default '0',
  obj_methods_templ_id int(10) NOT NULL DEFAULT '0',
  flg_persistent_bf_obj tinyint(1) NOT NULL default '0',
  flg_has_deep_object_params int(2) NOT NULL default '0',
  flg_has_openapi_array_params int(2) NOT NULL default '0',
  PRIMARY KEY  (policy_name_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  UNIQUE KEY policy_name (policy_name)
) ENGINE=InnoDB;



CREATE TABLE FACILITY_NAMES (
  facility_id int(10) NOT NULL default '0',
  facility_name varchar(100) NOT NULL default '',
  UNIQUE KEY facility_id (facility_id)
) ENGINE=InnoDB COMMENT='names of facilities for syslog';





CREATE TABLE FILE_REFERENCES_FOR_DELETION (
  id int(8) unsigned NOT NULL auto_increment, 
  filename char(255) NOT NULL default '',
  dir char(255) NOT NULL default '',
  delete_time int(10) NOT NULL,
  PRIMARY KEY (id),
  UNIQUE KEY filename (filename)
) ENGINE=InnoDB COMMENT='';



-- CONFIG_SYNC: DCC.FILTER_CUSTOM_DATA
CREATE TABLE FILTER_CUSTOM_DATA (
  filter_id int(10) NOT NULL default '0',
  filter_item varchar(255) NOT NULL default '',
  item_value text NOT NULL default ''
) ENGINE=InnoDB COMMENT='Intermediate table for GUI filter management';


-- CONFIG_SYNC: DCC.FILTERS
CREATE TABLE FILTERS (
  page_id int(10) NOT NULL default '0',
  filter_id int(10) NOT NULL auto_increment,
  filter_name varchar(255) NOT NULL default '',
  filter_type int(2) NOT NULL default '0',
  PRIMARY KEY  (filter_id)
) ENGINE=InnoDB COMMENT='Intermediate table for GUI filter management';





CREATE TABLE GLOBAL_CONFIGURATION (
  idx int(10) unsigned NOT NULL auto_increment,
  field_name varchar(40) NOT NULL default '',
  field_display_name varchar(40) NOT NULL default '',
  factory_value varchar(40) NOT NULL default '',
  current_value varchar(40) NOT NULL default '',
  help_text text NOT NULL,
  apply_to int(4) NOT NULL default '0',
  PRIMARY KEY  (idx)
) ENGINE=InnoDB COMMENT='Obsolete';





-- ACTIVE_POLICY: DCC.GLOBAL_PARAM_REG_EXPS
CREATE TABLE GLOBAL_PARAM_REG_EXPS (
  app_id int(10) NOT NULL default '0',
  reg_exp_crc bigint(20) unsigned NOT NULL default '0',
  reg_exp mediumtext NOT NULL default '',
  PRIMARY KEY  (reg_exp_crc)
) ENGINE=InnoDB COMMENT='regular expressions for allowed values of parameters';


-- ACTIVE_POLICY: DCC.GRPC_VALIDATION_FILES
CREATE TABLE GRPC_VALIDATION_FILES (
  id int(10) unsigned NOT NULL auto_increment,
  file_id int(10) NOT NULL default 0,
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  profile_templ_id int(10) NOT NULL default 0,
  schema_filename varchar(255) NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  FOREIGN KEY (profile_templ_id) REFERENCES CONTENT_PROFILE_TEMPLATES(profile_templ_id) ON DELETE CASCADE,
  UNIQUE KEY (profile_templ_id, file_id),
  PRIMARY KEY (id)
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.HSL_PROFILES
CREATE TABLE HSL_PROFILES (
  hsl_profile_id int(10) NOT NULL auto_increment,
  hsl_profile_name varchar(128) NOT NULL default '',
  hsl_profile_type_id int NOT NULL,
  reject_mask int NOT NULL default 0,
  alarm_mask int NOT NULL default 0,
  allowed_command_mask int NOT NULL default 0,
  UNIQUE (hsl_profile_name),
  PRIMARY KEY (hsl_profile_id)
) ENGINE=InnoDB COMMENT='Contains security profiles pool data';


-- CONFIG_SYNC: DCC.HSL_DATA_PROFILES
CREATE TABLE HSL_DATA_PROFILES (
  hsl_profile_id int(10) NOT NULL default '0',   
  data_profile_name varchar(128) NOT NULL default '',
  flg_is_enabled int(2) NOT NULL default '1',  
  FOREIGN KEY (hsl_profile_id) references HSL_PROFILES(hsl_profile_id) ON DELETE CASCADE,
  PRIMARY KEY (data_profile_name)
  ) ENGINE=InnoDB COMMENT='Contain security and data profile ids';


-- ACTIVE_POLICY: DCC.HSL_PROFILES_FTP_CONFIG
CREATE TABLE HSL_PROFILES_FTP_CONFIG (
  hsl_profile_id int(10) NOT NULL default '0',
  flg_username_retries int NOT NULL default 1,   
  username_retries_limit int(10) NOT NULL default 5,
  flg_hostip_retries int NOT NULL default 0,
  hostip_retries_limit int(10) NOT NULL default 5,
  reenable_login_after_timeout int(10) NOT NULL default 15,
  command_length_restriction int(10) NOT NULL default 255, 
  FOREIGN KEY (hsl_profile_id) references HSL_PROFILES (hsl_profile_id) ON DELETE CASCADE,
  PRIMARY KEY (hsl_profile_id)
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.HSL_PROFILES_SMTP_ADDRESS_CONFIG
CREATE TABLE HSL_PROFILES_SMTP_ADDRESS_CONFIG (
  hsl_profile_id int(10) NOT NULL default '0',
  address_type int(10) NOT NULL default '0',   
  address varchar(128) NOT NULL default '',
  route_domain int(2) NOT NULL default '0',
  FOREIGN KEY (hsl_profile_id) references HSL_PROFILES (hsl_profile_id) ON DELETE CASCADE,
  KEY (hsl_profile_id)
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.HSL_PROFILES_SMTP_CONFIG
CREATE TABLE HSL_PROFILES_SMTP_CONFIG (
  hsl_profile_id int(10) NOT NULL default 0,
  flg_skip_first_message int NOT NULL default 1,   
  sender_rate_limit int(10) NOT NULL default 2,
  receiver_rate_limit int(10) NOT NULL default 2,
  auto_reject_first_message_timeout int(10) NOT NULL default 30,
  directory_attack_timeout int(10) NOT NULL default 10,
  directory_attack_count int(10) NOT NULL default 20,
  hold_period int(10) NOT NULL default 60,
  FOREIGN KEY (hsl_profile_id) references HSL_PROFILES (hsl_profile_id) ON DELETE CASCADE,
  PRIMARY KEY (hsl_profile_id)
) ENGINE=InnoDB;



-- CONFIG_SYNC: DCC.HSL_VIRTUAL_SERVERS
CREATE TABLE HSL_VIRTUAL_SERVERS (
  virtual_server_name varchar(128) NOT NULL default '',  
  data_profile_name varchar(128) NOT NULL default '',
  FOREIGN KEY (data_profile_name) references HSL_DATA_PROFILES (data_profile_name) ON DELETE CASCADE,
  PRIMARY KEY (virtual_server_name)
  ) ENGINE=InnoDB;





CREATE TABLE HTTP_LICENSE_TYPE (
  flg_license_type int(2) NOT NULL default '0'
) ENGINE=InnoDB;





CREATE TABLE INSTALL_UCS_INFO (
  last_load_time int(20) NOT NULL default '0'
) ENGINE=InnoDB;





CREATE TABLE INTERNAL_CONFIG_FILES (
  file_id int(10) unsigned NOT NULL auto_increment,
  file_name varchar(255) NOT NULL default '',
  file_name_display varchar(255) NOT NULL default '',
  PRIMARY KEY  (file_id)
) ENGINE=InnoDB COMMENT='A list of internal configuration files';





-- CONFIG_SYNC: DCC.INTERNAL_CONFIG_ITEMS
CREATE TABLE INTERNAL_CONFIG_ITEMS (
  item_id int(10) unsigned NOT NULL auto_increment,
  rest_uuid char(22) NOT NULL default '',
  section_id int(10) unsigned NOT NULL default '0',
  field_name varchar(255) NOT NULL default '',
  factory_value text NOT NULL,
  current_value text NOT NULL,
  internal_remark varchar(255) default '',
  help_text text,
  value_type int(11) NOT NULL default '0',
  value_min int(11) NOT NULL default '0',
  value_max int(11) NOT NULL default '0',
  item_order int(10) unsigned NOT NULL default '0',
  flg_is_used_in_afw int(2) NOT NULL default '1',
  flg_is_used_in_full int(2) NOT NULL default '1',
  units varchar(256) default '',
  flg_is_factory_setting int(2) NOT NULL default '0',
  last_updated int(10) NOT NULL default '0',
  PRIMARY KEY  (item_id),
  KEY section_id (section_id),
  KEY field_name (field_name),
  KEY rest_uuid (rest_uuid),
  UNIQUE (section_id, field_name)
) ENGINE=InnoDB COMMENT='A list of internal configuration items';





CREATE TABLE INTERNAL_CONFIG_SECTIONS (
  section_id int(10) unsigned NOT NULL auto_increment,
  file_id int(10) unsigned NOT NULL default '0',
  section_name varchar(255) default NULL,
  section_order int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (section_id),
  KEY file_id (file_id)
) ENGINE=InnoDB COMMENT='A list of internal configuration sections';





-- ACTIVE_POLICY: DCC.INTERNAL_PARAMETERS
CREATE TABLE INTERNAL_PARAMETERS (
  raw_parameters_ini blob NOT NULL default ''
) ENGINE=InnoDB COMMENT='';


-- ACTIVE_POLICY: DCC.JSON_VALIDATION_FILES
CREATE TABLE JSON_VALIDATION_FILES (
  id int(10) unsigned NOT NULL auto_increment,
  file_id int(10) NOT NULL default 0,
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  profile_templ_id int(10) NOT NULL default 0,
  schema_filename varchar(255) NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  FOREIGN KEY (profile_templ_id) REFERENCES CONTENT_PROFILE_TEMPLATES(profile_templ_id) ON DELETE CASCADE,
  UNIQUE KEY (profile_templ_id, file_id),
  PRIMARY KEY (id)
) ENGINE=InnoDB;


CREATE TABLE LANG_CHAR_SETS (
  lang_code int(10) NOT NULL default '0',
  lang_char_set varchar(255) NOT NULL default '',
  lang_name varchar(40) NOT NULL default '',
  lang_encoding varchar(255) NOT NULL default '',
  default_lang_char_set varchar(255) NOT NULL default '',
  UNIQUE KEY lang_code (lang_code)
) ENGINE=InnoDB COMMENT='Contains charset per language';





CREATE TABLE LANGUAGE_ENCODINGS (
  lang_set_id int(10) NOT NULL auto_increment,
  lang_id int(10) NOT NULL default '0',
  encoding_id int(10) NOT NULL default '0',
  convert_order int(10) NOT NULL default '0',
  flg_visible int(2) NOT NULL default '1',
  icontrol_name varchar(50) NOT NULL default '',
  PRIMARY KEY  (lang_set_id),
  UNIQUE KEY lang_id (lang_id,encoding_id)
) ENGINE=InnoDB;





CREATE TABLE LANGUAGES (
  lang_id int(10) NOT NULL auto_increment,
  lang_name varchar(255) NOT NULL default '',
  PRIMARY KEY  (lang_id),
  UNIQUE KEY lang_name (lang_name)
) ENGINE=InnoDB;





CREATE TABLE LICENSE_STATE ( 
  state int(4),
  is_waf_licensed tinyint(2) NOT NULL default 0,
  last_updated int(10) NOT NULL default 0
) ENGINE=InnoDB;





CREATE TABLE LOCAL_FILTER (
  log_profile_name varchar(128) NOT NULL default '',
  log_profile_name_crc bigint(20) unsigned NOT NULL default '0',
  entity int(4) NOT NULL,
  logic_relation int (4) NOT NULL,
  request_type int(4) NOT NULL,
  protocols int(4) NOT NULL,
  respones_code varchar(255),
  http_methods varchar(255),
  login_results int(4) NOT NULL,
  apply_pattern_pair1_to int(4),
  pair1_pattern1 varchar(255),
  pair1_pattern2 varchar(255),
  apply_pattern_pair2_to int(4),
  pair2_pattern1 varchar(255),
  pair2_pattern2 varchar(255),
  lrn_mask bigint(20) unsigned NOT NULL default '0',
  flg_log_challenge_failure_requests int(2) NOT NULL default '0',
  PRIMARY KEY (log_profile_name_crc, entity)
) ENGINE=InnoDB;


CREATE TABLE LOG_APPIQ_CONFIG (
  log_profile_name varchar(128) NOT NULL default '',
  log_profile_name_crc bigint(20) unsigned NOT NULL default '0',
  response_logging int(2) NOT NULL default '0',
  storage_format varchar(1024) NOT NULL,
  storage_format_entities_bitmap varbinary(255) default '',
  PRIMARY KEY (log_profile_name_crc)
) ENGINE=InnoDB;


CREATE TABLE LOG_APPIQ_FILTER (
  log_profile_name varchar(128) NOT NULL default '',
  log_profile_name_crc bigint(20) unsigned NOT NULL default '0',
  logic_relation int (4) NOT NULL,
  request_type int(4) NOT NULL,
  start_time int(4),
  end_time int(4),
  protocols int (4) NOT NULL,
  respones_code varchar(255),
  http_methods varchar(255),
  login_results int(4) NOT NULL,
  apply_pattern_to int(4),
  pattern1 varchar(255),
  PRIMARY KEY (log_profile_name_crc)
) ENGINE=InnoDB;


CREATE TABLE LOG_LOCAL_STORAGE_CONFIGURATION (
  log_profile_name varchar(128) NOT NULL default '',
  log_profile_name_crc bigint(20) unsigned NOT NULL default '0',
  guaranteed_logging tinyint(1) NOT NULL,
  response_logging int(2) NOT NULL default '0',
  response_guaranteed_logging tinyint(1) NOT NULL default '0',
  PRIMARY KEY (log_profile_name_crc)
) ENGINE=InnoDB;


CREATE TABLE METHOD_POOL (
  method_code int(10) NOT NULL auto_increment,
  method_name varchar(255) NOT NULL default '',
  PRIMARY KEY  (method_code)
) ENGINE=InnoDB COMMENT='List of available request methods';





-- ACTIVE_POLICY: DCC.NEGSIG_COLLECTIONS
CREATE TABLE NEGSIG_COLLECTIONS (
  collection_id int(10) NOT NULL auto_increment,
  apply_to varchar(255) NOT NULL,
  md5_sum varchar(32) NOT NULL,
  filename varchar(255) NOT NULL,
  modify_time datetime,
  PRIMARY KEY (collection_id),  
  UNIQUE (apply_to, md5_sum)  
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.NEGSIG_SET_COMBINATIONS
CREATE TABLE NEGSIG_SET_COMBINATIONS (
  negsig_set_combination_id bigint(20) unsigned NOT NULL auto_increment,
  sets_json blob default '',
  sets_json_md5 varchar(32) NOT NULL,
  max_last_enforcement_change int(10) NOT NULL default 0,
  request_collection_id int(10) NOT NULL,
  response_collection_id int(10) NOT NULL,
  threat_campaigns_enabled boolean NOT NULL default 0,
  bot_signatures_enabled boolean NOT NULL default 0,
  UNIQUE(sets_json_md5),
  PRIMARY KEY (negsig_set_combination_id),
  FOREIGN KEY (request_collection_id) REFERENCES NEGSIG_COLLECTIONS(collection_id) ON DELETE CASCADE,
  FOREIGN KEY (response_collection_id) REFERENCES NEGSIG_COLLECTIONS(collection_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.NEGSIG_SIGNATURES_NAMES
CREATE TABLE NEGSIG_SIGNATURES_NAMES ( 
    sig_id bigint(20) unsigned NOT NULL auto_increment, 
    sig_name varchar(255) NOT NULL, 
    sig_name_len int(8) NOT NULL default '0',
    attack_type_code bigint(20) unsigned NOT NULL default '0',
    accuracy tinyint(2) NOT NULL default '0',
    risk tinyint(2) NOT NULL default '0',
    flg_has_cve tinyint(1) NOT NULL default '0',
    sig_cves blob NOT NULL default '',
    flg_conviction tinyint(1) unsigned NOT NULL default 0,
PRIMARY KEY (sig_id)
) ENGINE=InnoDB;


CREATE TABLE NEW_EVENT_CATEGORIES (
  id int(10) NOT NULL default '0',
  name varchar(100) NOT NULL default '',
  UNIQUE KEY id (id)
) ENGINE=InnoDB COMMENT='Contain data about event categories';





CREATE TABLE NEW_EVENT_SYSTEM (
  idx bigint(20) unsigned NOT NULL auto_increment,
  f_time int(20) NOT NULL default '0',
  l_time int(20) NOT NULL default '0',
  counter int(10) NOT NULL default '0',
  mac_ID varchar(40) NOT NULL default '',
  event_crc bigint(20) unsigned NOT NULL default '0',
  type int(10) NOT NULL default '0',
  code int(20) NOT NULL default '0',
  state int(10) NOT NULL default '0',
  result int(10) NOT NULL default '0',
  result_description varchar(255) NOT NULL default '',
  alert_status int(4) NOT NULL default '0',
  UNIQUE KEY sys_event_ID (idx),
  KEY event_crc (event_crc),
  KEY mac_ID (mac_ID),
  KEY alert_status (alert_status)
) ENGINE=InnoDB COMMENT='Accumulate system events';


CREATE TABLE NEW_EVENTS_TIME_WINDOW (
  event_type int(2) NOT NULL default '0',
  event_time_window bigint(20) NOT NULL default '0',
  UNIQUE KEY event_type (event_type)
) ENGINE=InnoDB COMMENT='Contain event consolidation times data';





CREATE TABLE NON_POLICY_TABLE_CHECKSUMS (
  table_name varchar(255) NOT NULL,
  checksum_value varchar(255) NOT NULL
) ENGINE=InnoDB;



-- CONFIG_SYNC: DCC.PARSER_STATUS_CODE_SEVERITIES
CREATE TABLE PARSER_STATUS_CODE_SEVERITIES (
  viol_index int(10) NOT NULL default '0',
  severity_id int(10) NOT NULL default '0',
  PRIMARY KEY  (viol_index)
) ENGINE=InnoDB COMMENT='Severities for syslog messages';


CREATE TABLE PARSER_STATUS_CODES (
  enum_id int(4) unsigned NOT NULL default '0',
  attack_type_id bigint(20) unsigned default NULL,
  flg_reject int(2) NOT NULL default '0',
  flg_enable_reject int(2) NOT NULL default '1',
  flg_alarm int(2) NOT NULL default '0',
  flg_enable_alarm int(2) NOT NULL default '1',
  description varchar(80) NOT NULL default '',
  icontrol_name varchar(50) NOT NULL default '',
  flg_disp_graph int(2) NOT NULL default '1',
  flg_disp_plc int(2) NOT NULL default '1',
  event_category_id int(10) NOT NULL default '0',
  group_id int(10) NOT NULL default '0',
  flg_learn int(2) NOT NULL default '0',
  flg_enable_learn int(2) NOT NULL default '1',
  flg_log_only int(2) NOT NULL default '0',
  flg_pb_handled int(2) NOT NULL default '0',
  violation_description_id int(10) unsigned default NULL,
  viol_index int(10) NOT NULL,
  viol_name varchar(255) NOT NULL default '',
  description_text mediumblob,
  description_risk mediumblob,
  description_examples mediumblob,
  bd_icontrol_name varchar(255) NOT NULL default '',
  attack_type_code bigint(20) unsigned NOT NULL default '0',
  viol_name_crc int(32) unsigned NOT NULL default '0',
  flg_is_user_defined int(2) NOT NULL default '0',
  severity_id int(10) NOT NULL default '0',
  PRIMARY KEY  (viol_index)
) ENGINE=InnoDB COMMENT='Contains the supported enforcer violation properties';


CREATE TABLE PLUGIN_USAGE (
  plugin_state int(2) NOT NULL default 0
) ENGINE=InnoDB;


-- CONFIG_SYNC: DCC.PROTECTION_LEVEL
CREATE TABLE PROTECTION_LEVEL (
    viol_set_low varbinary(16) NOT NULL default '',
    viol_set_medium varbinary(16) NOT NULL default '',
    viol_set_high varbinary(16) NOT NULL default '',
    http_protocol_checks_low_mask bigint(20) unsigned NOT NULL default '0', 
    http_protocol_checks_medium_mask bigint(20) unsigned NOT NULL default '0',
    http_protocol_checks_high_mask bigint(20) unsigned NOT NULL default '0', 
    norm_low_mask bigint(20) unsigned NOT NULL default '0', 
    norm_medium_mask bigint(20) unsigned NOT NULL default '0', 
    norm_high_mask bigint(20) unsigned NOT NULL default '0' 
) ENGINE=InnoDB;


CREATE TABLE REMOTE_FILTER (
  log_profile_name varchar(128) NOT NULL default '',
  log_profile_name_crc bigint(20) unsigned NOT NULL default '0',
  logic_relation int (4) NOT NULL,
  request_type int(4) NOT NULL,
  start_time int(4),
  end_time int(4),
  protocols int (4) NOT NULL,
  respones_code varchar(255),
  http_methods varchar(255),
  login_results int(4) NOT NULL,
  apply_pattern_to int(4),
  pattern1 varchar(255),
  flg_log_challenge_failure_requests int(2) NOT NULL default '0',
  PRIMARY KEY (log_profile_name_crc)
) ENGINE=InnoDB;


CREATE TABLE REMOTE_STORAGE_CONFIGURATION (
  log_profile_name varchar(128) NOT NULL default '',
  log_profile_name_crc bigint(20) unsigned NOT NULL default '0',
  entity int(4) NOT NULL,
  protocol int(4) NOT NULL,
  server_ip varchar(128) NOT NULL,
  route_domain int(2) NOT NULL default '0',
  ip_with_route_domain varchar(128) NOT NULL,
  server_port int(4) NOT NULL,
  facility int(10) NOT NULL,
  storage_format varchar(4096) NOT NULL,
  storage_format_fmt varchar(4096) NOT NULL,
  storage_format_entities_bitmap varbinary(255) default '',
  max_req_len int(4),
  max_hdrs_len int(4),
  max_qs_len int(4),
  max_log_length int(10) NOT NULL,
  severity_id int(10) NOT NULL,
  flg_log_anomaly_attacks int(2) NOT NULL default 0,
  flg_log_traffic int(2) NOT NULL default '1',
  response_logging int(2) NOT NULL default '1',
  flg_log_cloud_security int(2) NOT NULL default 0,
  dest_filename varchar(4096) NOT NULL default '',
  list_prefix varchar(255) NOT NULL default '',
  list_delimiter varchar(255) NOT NULL default ',',
  list_suffix varchar(255) NOT NULL default '',
  dest_type int(2) NOT NULL default '1',
  server_hostname varchar(4096) NOT NULL default '',
  PRIMARY KEY (log_profile_name_crc,server_ip,server_port)
) ENGINE=InnoDB;


CREATE TABLE REMOTE_STORAGE_FORMAT_ESCAPING (
  log_profile_name varchar(128) NOT NULL default '',
  log_profile_name_crc bigint(20) unsigned NOT NULL default '0',
  search_for char(8) NOT NULL,
  replace_with char(8) NOT NULL,
  PRIMARY KEY (log_profile_name_crc,search_for)
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.SERVER_TECHNOLOGIES_FINGERPRINTS
CREATE TABLE SERVER_TECHNOLOGIES_FINGERPRINTS (
  server_technology_fingerprint_id bigint(20) unsigned NOT NULL,
  server_technology_id bigint(20) unsigned NOT NULL,
  server_technology_name varchar(255) NOT NULL,
PRIMARY KEY (server_technology_fingerprint_id)
) ENGINE=InnoDB;



-- ACTIVE_POLICY: DCC.SERVER_TECHNOLOGIES_FINGERPRINTS_COLLECTIONS
CREATE TABLE SERVER_TECHNOLOGIES_FINGERPRINTS_COLLECTIONS (
  id bigint(20) unsigned NOT NULL auto_increment,
  fingerprints_collection_singleton_id int(10) NOT NULL default 1,
  request_server_technology_acy_collection longblob,
  response_server_technology_acy_collection longblob,
  request_md5sum  varchar(255) NOT NULL default '',
  response_md5sum  varchar(255) NOT NULL default '',
  request_mask int(10) NOT NULL,
  response_mask int(10) NOT NULL,
  UNIQUE(request_md5sum),
  UNIQUE(response_md5sum),
  PRIMARY KEY  (id)
) ENGINE=InnoDB;



CREATE TABLE SEVERITY_NAMES (
  severity_id int(10) NOT NULL default '0',
  severity_name varchar(100) NOT NULL default '',
  severity_desc varchar(100) NOT NULL default '',
  severity_target_bitmap int(10) NOT NULL default 0,
  UNIQUE KEY severity_id (severity_id)
) ENGINE=InnoDB COMMENT='names of severities for syslog';





-- TSCONFIG: DCC.SITE_UNITS
CREATE TABLE SITE_UNITS (
  idx int(10) NOT NULL auto_increment,
  site_id int(10) NOT NULL default '0',
  unit_id varchar(40) NOT NULL default '',
  mng_ip varchar(128) NOT NULL default '',
  flg_core_active int(2) NOT NULL default '0',
  version varchar(40) NOT NULL default '',
  PRIMARY KEY  (idx)
) ENGINE=InnoDB COMMENT='Contains the definitions of all units in ASM';


-- TSCONFIG: DCC.SITES
CREATE TABLE SITES (
  site_id int(10) NOT NULL default '0',
  name varchar(80) NOT NULL default '',
  topology_id int(10) NOT NULL default '0',
  magnifire_network varchar(40) NOT NULL default '',
  flg_network_protection int(2) NOT NULL default '0',
  flg_use_eth1 int(2) NOT NULL default '0',
  dms_ip varchar(128) NOT NULL default '',
  slot_ip varchar(128) NOT NULL default '',
  UNIQUE KEY site_id (site_id)
) ENGINE=InnoDB COMMENT='Contains A ASM based information';


CREATE TABLE SLOT_NAME (
  slot_name char(10) NOT NULL default '',
  slot_number int(4) NOT NULL default '0'
) ENGINE=InnoDB;


CREATE TABLE SUB_VIOLATIONS_CODES (
  attack_type_id bigint(20) unsigned NOT NULL default '0',
  description varchar(255) NOT NULL,
  parent_viol_index int(10) NOT NULL default '0',
  attack_type_code bigint(20) unsigned NOT NULL default '0',
  sub_violation_code int(20) unsigned NOT NULL,
  PRIMARY KEY (parent_viol_index, sub_violation_code)
) ENGINE=InnoDB;


CREATE TABLE TABLE_CHECKSUMS (
  table_name varchar(255) NOT NULL,
  policy_id int(10) NOT NULL,
  checksum_value varchar(255) NOT NULL,
  PRIMARY KEY (table_name, policy_id)
) ENGINE=InnoDB;



CREATE TABLE TABLE_CHECKSUMS_LAST_UPDATE (
  table_name varchar(255) NOT NULL,
  policy_id int(10) NOT NULL,
  max_last_update varchar(255) NOT NULL,
  row_count int(10) NOT NULL,
  PRIMARY KEY (table_name, policy_id)
) ENGINE=InnoDB;



-- ACTIVE_POLICY: DCC.THREAT_CAMPAIGNS
CREATE TABLE THREAT_CAMPAIGNS (
  threat_campaign_id bigint(20) unsigned NOT NULL,
  threat_campaign_name varchar(255) NOT NULL,
  threat_campaign_display_name varchar(255) NOT NULL,
  attack_type_id bigint(20) unsigned,
  PRIMARY KEY (threat_campaign_id),
  UNIQUE KEY (threat_campaign_name)
) ENGINE=InnoDB;


-- ACTIVE POLICY: DCC.USER_DEFINED_BROWSER_NAMES
CREATE TABLE USER_DEFINED_BROWSER_NAMES (
  sig_id bigint(20) unsigned NOT NULL auto_increment,
  browser_name varchar(255) NOT NULL,
  rule blob NOT NULL,
  browser_md5 varchar(32) NOT NULL,
  PRIMARY KEY (sig_id),
  UNIQUE (browser_md5)
) ENGINE=InnoDB;


CREATE TABLE VIOL_RATING (
  viol_rating_criteria int(10) unsigned NOT NULL,
  severity_none_score int(10) NOT NULL default '0',
  severity_low_score int(10) NOT NULL default '0',
  severity_low_med_score int(10) NOT NULL default '0',
  severity_med_score int(10) NOT NULL default '0',
  severity_med_high_score int(10) NOT NULL default '0',
  severity_high_score int(10) NOT NULL default '0',
  severity_crit_score int(10) NOT NULL default '0',
  severity_none_weight int(10) NOT NULL default '0',
  severity_low_weight int(10) NOT NULL default '0',
  severity_low_med_weight int(10) NOT NULL default '0',
  severity_med_weight int(10) NOT NULL default '0',
  severity_med_high_weight int(10) NOT NULL default '0',
  severity_high_weight int(10) NOT NULL default '0',
  severity_crit_weight int(10) NOT NULL default '0',
  PRIMARY KEY  (viol_rating_criteria)
) ENGINE=InnoDB;



CREATE TABLE VIRUS_DETECTION_SERVER (   
   icap_server_ip_addr varchar(128) default '',
   icap_server_port varchar(128) default 0,
   icap_server_host_name varchar(255) default '',
   flg_check_guaranteed int(2) NOT NULL default 0
 ) ENGINE=InnoDB;


CREATE TABLE VS_LOG_PROFILE (
  log_profile_name_crc bigint(20) unsigned NOT NULL default '0',
  vs_name_crc bigint(20) unsigned NOT NULL default '0',
  storage_type tinyint(5) unsigned NOT NULL default '0',
  PRIMARY KEY (log_profile_name_crc, vs_name_crc)
) ENGINE=InnoDB;


CREATE TABLE VS_RAMCACHE (
  vs_name varchar(128) NOT NULL default '',
  vs_name_crc bigint(20) unsigned NOT NULL default 0,
  ramcache_state int(2) NOT NULL default 0,
  PRIMARY KEY (vs_name_crc)
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.WH_PARAMETERS
CREATE TABLE WH_PARAMETERS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  param_crc bigint(20) unsigned NOT NULL default '0',
  attack_type_bitmap int NOT NULL default '0',
  PRIMARY KEY (param_crc),
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE
) ENGINE=InnoDB;


-- ACTIVE_POLICY: DCC.XML_SOAP_METHODS
CREATE TABLE  XML_SOAP_METHODS (
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  soap_method_crc bigint(20) unsigned NOT NULL default '0',
  allowed_soap_action varbinary(512) NOT NULL default '',
  flg_allowed int(2) NOT NULL default '1',
  profile_templ_id int(10) NOT NULL,
  FOREIGN KEY (policy_name_crc) REFERENCES ACCOUNTS(policy_name_crc) ON DELETE CASCADE,
  FOREIGN KEY (profile_templ_id) REFERENCES CONTENT_PROFILE_TEMPLATES(profile_templ_id) ON DELETE CASCADE,
  PRIMARY KEY (profile_templ_id, soap_method_crc)
) ENGINE=InnoDB COMMENT='per soap method enforcer configurations';



