CREATE TABLE ASM_IP_ADDRESS_LISTS (
  asm_ip_address_list_id int(10) NOT NULL auto_increment,
  ip_address_list_name varchar(128) NOT NULL default '',
  UNIQUE KEY (ip_address_list_name),
  PRIMARY KEY (asm_ip_address_list_id)
) ENGINE=InnoDB;


CREATE TABLE ASM_IP_ADDRESSES (
  asm_ip_address_id int(10) NOT NULL auto_increment,
  ip_address varchar(128) DEFAULT NULL,
  mask varchar(128) NOT NULL default '255.255.255.255',
  description text,
  flg_pb_trusted  int(1) NOT NULL default '0',
  flg_ignore_anomaly int(1) NOT NULL default '0',
  flg_never_log int(1) NOT NULL default '0',
  flg_never_block int(1) NOT NULL default '0',
  flg_never_learn  int(1) NOT NULL default '0',
  flg_ignore_ip_reputation int(1) NOT NULL default '0',
  ip_address_list_id int(10),
  PRIMARY KEY (asm_ip_address_id),
  FOREIGN KEY (ip_address_list_id) references ASM_IP_ADDRESS_LISTS (asm_ip_address_list_id) ON DELETE CASCADE
) ENGINE=InnoDB;


CREATE TABLE ASM_POLICIES (
  asm_policy_id int(10) NOT NULL auto_increment,
  http_class_name varchar(128) default '',
  device_id int(10) unsigned default 0,
  policy_name varchar(256) NOT NULL default '',
  description varchar(255) NOT NULL default '',
  policy_status varchar(128) NOT NULL default '',
  export_file_name varchar(256) NOT NULL default '',
  flg_transparent_mode int(2) NOT NULL default 0,
  PRIMARY KEY (asm_policy_id),
  UNIQUE KEY policy_name (policy_name)
) ENGINE=InnoDB;


CREATE TABLE DEPLOY_REQUESTS (
  deploy_request_id int(10) NOT NULL auto_increment,
  deploy_type int(10),
  policy_id int(10),
  ip_address_list_id int(10),
  logging_profile_name varchar(255),
  PRIMARY KEY (deploy_request_id),
  FOREIGN KEY (ip_address_list_id) references ASM_IP_ADDRESS_LISTS (asm_ip_address_list_id) ON DELETE CASCADE,
  FOREIGN KEY (policy_id) references ASM_POLICIES (asm_policy_id) ON DELETE CASCADE
) ENGINE=InnoDB;


CREATE TABLE DEPLOY_REQUEST_TARGETS (
  deploy_request_target_id int(10) NOT NULL auto_increment,
  deploy_request_id int(10) NOT NULL,
  device_id int(10) unsigned default 0,
  target_folder varchar(255),
  target_http_class_name varchar(255),
  target_virtual_server_name varchar(255),
  PRIMARY KEY (deploy_request_target_id),
  FOREIGN KEY (deploy_request_id) references DEPLOY_REQUESTS (deploy_request_id) ON DELETE CASCADE
) ENGINE=InnoDB;


CREATE TABLE DEPLOY_REQUEST_STATUS (
  deploy_request_status_id int(10) NOT NULL auto_increment,
  deploy_request_id int(10) NOT NULL,
  device_id int(10) unsigned default 0,
  deploy_status enum('pending','running','success','error') DEFAULT 'pending',
  last_action_message text,
  last_action_time int(10) NOT NULL default 0,
  deploy_start_time int(10) NOT NULL default 0,
  deploy_end_time int(10) NOT NULL default 0,
  PRIMARY KEY (deploy_request_status_id),
  UNIQUE (deploy_request_id, device_id),
  FOREIGN KEY (deploy_request_id) references DEPLOY_REQUESTS (deploy_request_id) ON DELETE CASCADE
) ENGINE=InnoDB;


CREATE TABLE LOGGING_PROFILES (
  logging_profile_id int(10) NOT NULL auto_increment,
  logging_profile_name varchar(128) default '',
  device_id int(10) unsigned default 0,
  PRIMARY KEY (logging_profile_id),
  UNIQUE KEY logging_profile_name (logging_profile_name)
) ENGINE=InnoDB;


