package F5::ASMConfig::Entity::Blocking;

use strict;
use warnings;

use base qw(F5::ASMConfig::Entity::Base F5::ASMConfig::Blocking);
use F5::Violation;
use F5::ASMConfig::Entity::Violation;

my %SUBVIOLATIONS = ( F5::Violation::VIOL_EVASION() => 'F5::ASMConfig::Entity::Normalization',
                      F5::Violation::VIOL_HTTP_PROTOCOL() => 'F5::ASMConfig::Entity::HttpCheck',
                      F5::Violation::VIOL_XML_WEB_SERVICES_SECURITY() => 'F5::ASMConfig::Entity::WssSubviolation',
                    );

our %DISABLE_LEARN = ( F5::Violation::VIOL_BLACKLISTED_IP() => 1,
                       F5::Violation::VIOL_WEBSOCKET_TEXT_NULL_VALUE() => 1,
                       F5::Violation::VIOL_MALICIOUS_IP() => 1,
                       F5::Violation::VIOL_BRUTE_FORCE() => 1,
                       F5::Violation::VIOL_ENCODING() => 1,
                       F5::Violation::VIOL_CSRF() => 1,
                       F5::Violation::VIOL_MALICIOUS_DEVICE() => 1,
                       F5::Violation::VIOL_BLOCKING_CONDITION() => 1,
                       F5::Violation::VIOL_THREAT_ANALYSIS() => 1,
                       F5::Violation::VIOL_JSON_SCHEMA() => 1,
                       F5::Violation::VIOL_LEAKED_CREDENTIALS() => 1,
                       F5::Violation::VIOL_CONVICTION() => 1,
                       F5::Violation::VIOL_HOSTNAME() => 1,
                       F5::Violation::VIOL_HOSTNAME_MISMATCH() => 1,
                       F5::Violation::VIOL_DATA_INTEGRITY() => 1,
                       F5::Violation::VIOL_SERVER_SIDE_HOST() => 1,
                       F5::Violation::VIOL_GRAPHQL_MALFORMED() => 1,
                       F5::Violation::VIOL_GRAPHQL_FORMAT() => 1,
                       F5::Violation::VIOL_GRAPHQL_INTROSPECTION_QUERY() => 1 );

sub before_store {
    my ($self, %params) = @_;
    my $dbh = $params{dbh} || $self->{dbh};
    my $policy = $params{policy} || $self->{policy};

    if ($self->has_value_changed(%params, check_fields => 'flg_learn') ){
        my $violation = $self->get_new_value(%params, field_name => 'violation');
        if ($DISABLE_LEARN{$violation->{viol_index}}) {
            $params{store_obj}->{flg_learn} = 0;
        }
        elsif ( $self->get_new_value(%params, field_name => 'flg_learn')) {
            $params{store_obj}->{flg_pb_enabled} = 1;
        }
        elsif( $violation->{viol_index} == F5::Violation::VIOL_SESSION_AWARENESS() ){
                $params{store_obj}->{flg_learn} = 1;
        }
    }
}

#----------------------------------------------------------------------

my %HIDE_LEARN_EARLIEST_VERSION = ( F5::Violation::VIOL_ATTACK_SIGNATURE() => '12.1.0',
                   F5::Violation::VIOL_WEBSOCKET_TEXT_NULL_VALUE() => '12.1.0',
                   F5::Violation::VIOL_BLACKLISTED_IP() => '13.0.0',
                   F5::Violation::VIOL_MALICIOUS_IP() => '13.0.0',
                   F5::Violation::VIOL_SESSION_AWARENESS() => '13.0.0',
                   F5::Violation::VIOL_BRUTE_FORCE() => '13.1.0',
                   F5::Violation::VIOL_ENCODING() => '14.0.0',
                   F5::Violation::VIOL_CSRF() => '13.1.0',
                   F5::Violation::VIOL_THREAT_CAMPAIGN() => '13.1.0',
                   F5::Violation::VIOL_PARAMETER_ARRAY_VALUE() => '15.0.0',
                   F5::Violation::VIOL_MANDATORY_PARAMETER() => '15.0.0',
                   F5::Violation::VIOL_PARAMETER_LOCATION() => '15.0.0',
                   F5::Violation::VIOL_MALICIOUS_DEVICE() => '15.0.0',
                   F5::Violation::VIOL_BLOCKING_CONDITION() => '15.0.0',
                   F5::Violation::VIOL_THREAT_ANALYSIS() => '15.0.0',
                   F5::Violation::VIOL_JSON_SCHEMA() => '15.0.0',
                   F5::Violation::VIOL_LEAKED_CREDENTIALS() => '15.0.0',
                   F5::Violation::VIOL_CONVICTION() => '15.0.0',
                   F5::Violation::VIOL_HOSTNAME() => '15.1.0',
                   F5::Violation::VIOL_HOSTNAME_MISMATCH() => '15.1.0',
                   F5::Violation::VIOL_MANDATORY_REQUEST_BODY() => '16.0.0',
                   F5::Violation::VIOL_RATING_NEED_EXAMINATION() => '16.0.0',
                   F5::Violation::VIOL_RATING_THREAT() => '16.0.0',
                   F5::Violation::VIOL_DATA_INTEGRITY() => '16.0.0',
                   F5::Violation::VIOL_FILE_UPLOAD_IN_BODY() => '16.0.0',
                   F5::Violation::VIOL_SERVER_SIDE_HOST() => '16.0.0',
                   F5::Violation::VIOL_GRAPHQL_MALFORMED() => '16.1.0',
                   F5::Violation::VIOL_GRAPHQL_FORMAT() => '16.1.0',
                   F5::Violation::VIOL_GRAPHQL_INTROSPECTION_QUERY() => '16.1.0',
                    );

my %HIDE_REJECT_AND_ALARM_EARLIEST_VERSION = ( F5::Violation::VIOL_ATTACK_SIGNATURE() => '12.1.0', );

sub map_fields_to_entity {
    my($class, %params) = @_;

    $class->SUPER::map_fields_to_entity(%params);
    my $ver = $params{ver} || $params{call_flags}->{rest_version};
    my $rec = $params{rec};
    my $viol_index = $rec->{violation}->{viol_index} || 0;

    $rec->{show_alarm} = $rec->{show_reject} = (!$HIDE_REJECT_AND_ALARM_EARLIEST_VERSION{$viol_index} 
                                               || ($ver && F5::BigipVersionUtils::compare_versions(version1 => $HIDE_REJECT_AND_ALARM_EARLIEST_VERSION{$viol_index},
                                                                                                   version2 => $ver) > 0)) ? 1 : 0;
 
    $rec->{show_learn} = (!$HIDE_LEARN_EARLIEST_VERSION{$viol_index}
                           || ($ver && F5::BigipVersionUtils::compare_versions(version1 => $HIDE_LEARN_EARLIEST_VERSION{$viol_index},
                                                                               version2 => $ver) > 0))
                         && ($viol_index < $F5::ASMConfig::Entity::Violation::MIN_USER_VIOL_INDEX || 
                             $viol_index > $F5::ASMConfig::Entity::Violation::MAX_USER_VIOL_INDEX) ? 1 : 0;
}

#----------------------------------------------------------------------


1;
