package F5::ASMConfig::Entity::GraphqlProfile;

use strict;
use warnings;

use Memoize;

use F5::ASMConfig::ASMConfig;
use F5::DbUtils;
use F5::ASMConfig::ContentProfileBase;
use F5::ASMConfig::Entity::GraphqlDefenseAttribute;
use base qw/F5::ASMConfig::ContentProfileBase F5::ASMConfig::GraphqlProfile/;

#----------------------------------------------------------------------

sub before_store {
    my($self, %params) = @_;
    my $store_obj = $params{store_obj};

    $self->populate_defense_attributes(store_obj => $store_obj);
    if ($params{validate_value}) {
        $self->validate_defense_attributes(defense_settings => $store_obj->{graphql_defense});
    }

    for my $graphql_defense (@{$store_obj->{graphql_defense}}) {
        if (defined $graphql_defense->{def_attrib_value} &&
            $graphql_defense->{value_type} eq F5::ASMConfig::DefenseAttributeValueType::DEFENSE_ATTRIBUTE_VALUE_TYPE_INTEGER) {
            $graphql_defense->{def_attrib_value} += 0;
        }
    }
}

#----------------------------------------------------------------------

sub after_nested_struct_store {
  my ($self, %params) = @_;
  my $dbh = $self->{dbh};
  my $store_obj = $params{store_obj};
  if ($params{store_mode} eq 'update') {
      $self->populate_defense_attributes(store_obj => $store_obj);
  }
}

#----------------------------------------------------------------------

sub after_nested_struct_load {
    my ($self, %params) = @_;
    $self->populate_defense_attributes();
    return;
}

#----------------------------------------------------------------------

sub populate_defense_attributes {
    my ($self, %params) = @_;
    my $store_obj = $params{store_obj} || $self;

    if (exists($store_obj->{graphql_defense})) {
        my $defense_attributes = $self->get_defense_attributes();
        for my $graphql_defense (@{$store_obj->{graphql_defense}}) {
            %$graphql_defense = ( %$graphql_defense, %{$defense_attributes->{$graphql_defense->{def_attrib_id}}} );
        }
    }
}

#----------------------------------------------------------------------

sub get_defense_attributes {
    my ($self, %params) = @_;
    my $dbh = $params{dbh} || $self->{dbh};

    my %retval = map {$_->{def_attrib_id} => $_} F5::ASMConfig::Entity::GraphqlDefenseAttribute->retrieve_all( dbh => $dbh, );

    return $self->install_accessor('get_defense_attributes', \%retval);
}

#----------------------------------------------------------------------

sub update_parent_staging {
    my ($self, %params) = @_;
    return $self->update_content_profile_staging(%params);
}

#----------------------------------------------------------------------

1;
