package F5::ASMConfig::Entity::PolicySignatureSet;

use strict;
use warnings;

use base qw/F5::ASMConfig::Entity::Base F5::ASMConfig::PolicySignatureSet/;

#----------------------------------------------------------------------

sub before_store {
    my($self, %params) = @_;

    my $store_obj = $params{store_obj};
    my $policy = $params{policy} || $self->{policy};
    my $dbh = $params{dbh} || $self->{dbh};

    if (!$policy->{policy_type}) {
        $policy = F5::ASMConfig::Cache::get_cached_policy(policy => { $policy },
                                                          dbh => $dbh,);
    }

    if ($policy->{policy_type} && $policy->{policy_type} == F5::ASMConfig::PolicyType::POLICY_TYPE_PARENT()
        && !$self->get_new_value(%params, field_name => 'flg_learn')) {
        $params{store_obj}->{flg_learn}  = 1;    	    	    	    	    		 
    }
    return {};
}

#----------------------------------------------------------------------

sub export_declarative {
    my ($class, %params) = @_;
    my $dbh = $params{dbh};

    my $rv = $class->SUPER::export_declarative(%params);

    my $sig_sets = $rv->{items};
    my @sig_set_names = map { $_->{name} } grep { !($_->{'$action'} && $_->{'$action'} eq 'delete') } @$sig_sets;

    my $set_name_filter = F5::ASMConfig::SearchFilter->new(field_name => 'set_name',
                                                           field_comparison => F5::ASMConfig::FieldComparison::FIELD_COMPARISON_IN(),
                                                           field_value_list => \@sig_set_names),
    my $user_defined_filter = F5::ASMConfig::SearchFilter->new(field_name => 'flg_is_user_defined',
                                                               field_comparison => F5::ASMConfig::FieldComparison::FIELD_COMPARISON_EQ(),
                                                               field_value => 1);

    my @user_defined_sets = F5::ASMConfig::Entity::SignatureSet->retrieve_all(%params,
                                                                              search_filters => [ $set_name_filter, $user_defined_filter ],
                                                                             );
    return $rv if !@user_defined_sets;

    my @signatures = F5::ASMConfig::Entity::Signature->retrieve_all(%params,
                                                                    selected_fields => [ qw(sig_name sig_tag) ],
                                                                    search_filters => [ $user_defined_filter ]);
    my %user_defined_signatures = map { $_->{sig_id} => $_ } @signatures;
    my %set_map = map { $_->{set_name} => $_ } @user_defined_sets;
    my $set_declarative_fields = F5::ASMConfig::Entity::SignatureSet->declarative_fields;
    for my $sig_set (@$sig_sets) {
        next if !$set_map{$sig_set->{name}};
        my @declarative_signatures;
        my $user_defined_set = $set_map{$sig_set->{name}};
        if ($user_defined_set->{flg_is_manual}) {
            delete $user_defined_set->{signature_set_filter};
            for my $sig_id (@{$set_map{$sig_set->{name}}->{sigs}}) {
                my $sig = $user_defined_signatures{$sig_id} || { sig_id => $sig_id };
                push ( @declarative_signatures,
                       F5::ASMConfig::Entity::Signature->new(dbh => $dbh,
                                                             object => $sig)->to_declarative(%params) );
            }
        }
        delete $user_defined_set->{sigs};
        $sig_set->{signatureSet} = $user_defined_set->to_declarative(%params);
        if (@declarative_signatures) {
            $sig_set->{signatureSet}->{signatures} = \@declarative_signatures;
        }
    }

    return { items => $sig_sets,
             warnings => $rv->{warnings} };
}

#----------------------------------------------------------------------

1;
