package F5::ASMConfig::Entity::SsrfHost;
use base qw(F5::ASMConfig::Entity::Base F5::ASMConfig::SsrfHost);


use strict;
use warnings;

#----------------------------------------------------------------------

sub before_store {
    my($self, %params) = @_;

    my $store_mode = $params{store_mode};
    my $store_obj = $params{store_obj};
    my $existing_obj = $params{existing_obj};

    my @fields = qw(
                   action_type
                  );

   my %field_values;

   for my $field (@fields) {
      $field_values{$field} = $self->get_new_value( store_obj => $store_obj,
                                                    existing_obj => $existing_obj,
                                                    field_name => $field, );
   }

   my $error_message;
   if ($field_values{action_type} == F5::ASMConfig::SsrfActionType::SSRF_ACTION_ALLOW()) {
      $error_message = '"allow" action is not supported';
   }
   elsif ($field_values{action_type} == F5::ASMConfig::SsrfActionType::SSRF_ACTION_RESOLVE()) {
      $error_message = '"resolve" action is not supported';
   }

   if ($error_message) {
          die { error_message => $error_message,
                display_message => $error_message,
                error_level     => 'info',
                error_code      => F5::ASMConfig::ErrorCode::ACTION_NOT_ALLOWED(),
          };
   }

   $store_obj->{is_wildcard} = 1; #treat everything as wildcard for now

   $self->adjust_wildcards(%params);
}

#----------------------------------------------------------------------

sub is_pure_wildcard {
    my ($self, %params) = @_;
    return ($self->get_new_value(%params, field_name => 'host') &&
            $self->get_new_value(%params, field_name => 'host') eq "*");
}

#----------------------------------------------------------------------

1;
