package F5::DeviceConfig;

use strict;
use warnings;

use Sys::Hostname;

#----------------------------------------------------------------------

sub new {
    my($class, %params) = @_;
    my $self = {};
    bless $self, $class;
    $self->init(%params);
    return $self;
}

#----------------------------------------------------------------------

sub init {
    my($self, %params) = @_;
    $self->{dbh} = $params{dbh};
    $self->{config}->{hostname} = hostname;
    $self->{logger} = $params{logger};
    return $self;
}

#----------------------------------------------------------------------

sub to_hash {
   my ($self, %params) = @_;
   return $self->{config};
}

#----------------------------------------------------------------------

sub apply {
   my ($self, %params) = @_;
   my $dbh = $params{dbh} || $self->{dbh};
   my $do_prepare_client_side_js = $params{do_prepare_client_side_js} || 1;
   my $config  = $self->{config};
   my $db_change_made = 0;
   # When more device config items are needed to be handled, a better dispatch methodology will be considered.
   if (defined($config->{hostname})) {
       my $rv = F5::DbUtils::update_row(dbh => $dbh,
                               table_name => 'DCC.BIG_IP_UNIT_INFO',
                               rec => {
                                        unit_hostname  => $config->{hostname},
                                      },
                              );
       $db_change_made ||= $rv;
   }

   if ($do_prepare_client_side_js) {
       my $base = F5::PrepareConf::Base->new(dbh => $dbh, logger => $self->{logger});
       my $rv = $base->prepare_client_side_js();
       $db_change_made ||= $rv;
   }

   return { db_change_made => $db_change_made };
}

#----------------------------------------------------------------------

1;
