package F5::Violation::Utils;

use strict;
use warnings;

use Bit::Vector;
use F5::Violation;

use constant MAX_VIOL_COUNT => 128;

#----------------------------------------------------------------------

sub get_viol_set {
    my(%params) = @_;

    my $viols = $params{viols};
    my $field_name = $params{field_name};

    my @indexes = grep { $viols->{$_}->{$field_name} } keys %$viols;
    my $vec = Bit::Vector->new(128);
    $vec->Index_List_Store(@indexes);
    # Bit::Vector indexes are from right-to-left -- we reverse to work from left-to-right
    $vec->Reverse($vec);
    return pack("H*", $vec->to_Hex);
}

#----------------------------------------------------------------------

# For upgrading from old 64-bit violation bitmask
sub get_viol_index_from_code {
    my($code) = @_;

    my $viol_index;
    if ($code eq '80') {
        # Special handling for MANDATORY_HEADER, which was moved to bit 64
        $viol_index = F5::Violation::VIOL_MANDATORY_HEADER();
    }
    elsif ($code eq '0' || ! $code) {
        return 0;
    }
    else {
        my $vec = Bit::Vector->new_Hex(64, $code);
        $vec->Reverse($vec);
        ($viol_index) = $vec->Index_List_Read;
        $viol_index = (7 - int($viol_index / 8)) * 8 + $viol_index % 8;
    }

    return $viol_index;
}

#----------------------------------------------------------------------

sub get_indexes_from_viol_set {
    my($bitstring) = @_;

    return unless ($bitstring);

    my $vec = Bit::Vector->new_Hex(128, unpack("H*", $bitstring));
    # Bit::Vector indexes are from right-to-left -- we reverse to work from left-to-right
    $vec->Reverse($vec);
    return grep { $_ != 0 } $vec->Index_List_Read;
}

#----------------------------------------------------------------------

sub get_viol_names_from_viol_set {
    my($bitstring) = @_;

    return map { $F5::Violation::viol_name{$_} } get_indexes_from_viol_set($bitstring);
}

#----------------------------------------------------------------------

sub has_violations {
    my($bitstring) = @_;
    #Count the number of set bits
    return (unpack("%32b*", $bitstring) > 0 ? 1 : 0);
}

#----------------------------------------------------------------------

sub split_bitmask_values {
    my ($bitmask) = @_;
    my @values;
    my $vec = Bit::Vector->new_Dec(128,$bitmask);
    for my $index (grep { $_ != 0 } $vec->Index_List_Read) {
        my $v = Bit::Vector->new(128);
        $v->Bit_On($index);
        push (@values, $v->to_Dec);
    }
    return @values;
}

#----------------------------------------------------------------------

1;
