CREATE TABLE ACTION_ITEMS (
  action_item_id int(8) unsigned NOT NULL auto_increment,
  action_item_type int(8) NOT NULL default 1,
  created_time int(11) NOT NULL default 0,
  next_display_time int(11) NOT NULL default 0,
  last_updated int(11) NOT NULL default 0,
  severity int(2) NOT NULL default 1,
  message varchar(255) NOT NULL default '',
  rest_uuid char(22) NOT NULL default '',
  KEY rest_uuid (rest_uuid),
  PRIMARY KEY (action_item_id),
  UNIQUE KEY (action_item_type)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.ASM_CONFIG_SETTINGS
CREATE TABLE ASM_CONFIG_SETTINGS (
  flg_recommend_sync int(1) NOT NULL default '1',
  flg_write_all_changes_to_syslog int(1) NOT NULL default '1'
) ENGINE=InnoDB;





CREATE TABLE BOT_ANOMALIES (
  bot_anomaly_id  bigint(20) unsigned NOT NULL auto_increment,
  bot_anomaly_name varchar(255) NOT NULL,
  bot_class int(10) NOT NULL default 0,
  description varchar(255) NOT NULL,
  has_score_threshold boolean NOT NULL default 0,
  score_threshold int(10) NOT NULL default 0,
  rest_uuid char(22) NOT NULL default '',
  PRIMARY KEY (bot_anomaly_id)
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.BOT_SIGNATURES
CREATE TABLE BOT_SIGNATURES (
  bot_signature_id bigint(20) unsigned NOT NULL auto_increment,
  name varchar(255) NOT NULL,
  description blob,
  rule blob,
  packed_rule_obj blob,
  risk tinyint(1) NOT NULL default '3',
  category varchar(255) NOT NULL,
  bot_class int(10) NOT NULL default 0,
  buffer_type_mask int(10) NOT NULL default 0,
  last_updated int(20),
  rest_uuid char(22) NOT NULL default '',
  KEY rest_uuid (rest_uuid),
  PRIMARY KEY (bot_signature_id),
  UNIQUE KEY (name)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.BOT_SIGNATURE_HOSTNAMES
CREATE TABLE BOT_SIGNATURE_HOSTNAMES (
  bot_signature_hostname_id bigint(20) unsigned NOT NULL auto_increment,
  bot_signature_id bigint(20) unsigned NOT NULL,
  hostname varchar(1024) NOT NULL,
  PRIMARY KEY (bot_signature_hostname_id),
  FOREIGN KEY (bot_signature_id) references BOT_SIGNATURES(bot_signature_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.CENTRAL_CONFIGURATION_ADDRESS
CREATE TABLE CENTRAL_CONFIGURATION_ADDRESS (
       central_configuration_address_id INT NOT NULL AUTO_INCREMENT ,
       ip_address varchar(128) NOT NULL default '',
       port int(4) NOT NULL,
       flg_is_connected int(2) NOT NULL default 0,
       rest_uuid char(22) NOT NULL default '',
       KEY rest_uuid (rest_uuid),
       UNIQUE (ip_address,port),
       PRIMARY KEY ( central_configuration_address_id )
) ENGINE=InnoDB;



CREATE TABLE CONFIG_SET (
  config_set longblob,
  last_updated int(10) NOT NULL default '0'
)ENGINE=InnoDB;






CREATE TABLE COUNTRY_CODES (
        country_code_id int(10) unsigned NOT NULL auto_increment,
        country_code char(5),
        country_name char(64),
  PRIMARY KEY  (country_code_id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;








-- CONFIG_SYNC: PLC.DATA_PROTECTION
CREATE TABLE DATA_PROTECTION (
  data_protection_id  bigint(20) unsigned NOT NULL auto_increment,
  secure_key blob NOT NULL default '',
  key_gen_time int(10) NOT NULL default 0,
  grace_signing_end_time int(10) NOT NULL default 0,
  grace_accepting_end_time int(10) NOT NULL default 0,
  PRIMARY KEY (data_protection_id)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.DATA_PROTECTION_CONFIGURATION
CREATE TABLE DATA_PROTECTION_CONFIGURATION (
  data_protection_configuration_id  bigint(20) unsigned NOT NULL auto_increment,
  data_protection_id bigint(20) unsigned NOT NULL,
  cookie_type int(4) NOT NULL default 0,
  scramble_algorithm int(4) NOT NULL default 0,
  hash_algorithm int(4) NOT NULL default 0,
  mac_algorithm int(4) NOT NULL default 0,
  PRIMARY KEY (data_protection_configuration_id),
  FOREIGN KEY (data_protection_id) references DATA_PROTECTION(data_protection_id) ON DELETE CASCADE,
  UNIQUE KEY cookie_type (cookie_type)
) ENGINE=InnoDB;


CREATE TABLE DATA_PROTECTION_CONFIGURATION_DEFAULTS (
  data_protection_configuration_default_id  bigint(20) unsigned NOT NULL auto_increment,
  security_level int(4) NOT NULL,
  cookie_type int(4) NOT NULL default 0,
  scramble_algorithm int(4) NOT NULL default 0,
  hash_algorithm int(4) NOT NULL default 0,
  mac_algorithm int(4) NOT NULL default 0,
  PRIMARY KEY (data_protection_configuration_default_id),
  UNIQUE KEY cookie_type (cookie_type, security_level)
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.DATABASE_PROTECTION_SETTINGS
CREATE TABLE DATABASE_PROTECTION_SETTINGS (   
   database_protection_settings_id int(2) NOT NULL default 1,
   hostname varchar(255) NOT NULL DEFAULT '',
   server_port varchar(128) NOT NULL DEFAULT '0',
   flg_is_request_hold_timeout_enabled int(2) NOT NULL DEFAULT '0',
   request_hold_timeout int(4) NOT NULL DEFAULT 5,
   flg_is_response_hold_timeout_enabled int(2) NOT NULL DEFAULT '0',
   response_hold_timeout int(4) NOT NULL DEFAULT 5,
   PRIMARY KEY (database_protection_settings_id)
 ) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.DECEPTION_RESPONSES
CREATE TABLE DECEPTION_RESPONSES (
  deception_response_id bigint(20) unsigned NOT NULL auto_increment,
  server_technology_id bigint(20) unsigned NOT NULL default '0',
  response_code varchar(3) NOT NULL default '200',
  response_headers blob,
  response_body blob,
  PRIMARY KEY (deception_response_id)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.DECEPTION_RESPONSES_SIGNATURES
CREATE TABLE DECEPTION_RESPONSES_SIGNATURES (
  id bigint(20) unsigned NOT NULL auto_increment,
  sig_id bigint(20) unsigned NOT NULL default '0',
  deception_response_id bigint(20) unsigned NOT NULL default '0',
  PRIMARY KEY (id),
  UNIQUE (sig_id, deception_response_id),
  FOREIGN KEY (deception_response_id) references DECEPTION_RESPONSES(deception_response_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.DECEPTION_TRAP_CONDITIONS
CREATE TABLE DECEPTION_TRAP_CONDITIONS (
  deception_trap_condition_id bigint(20) unsigned NOT NULL auto_increment,
  deception_trap_id bigint(20) unsigned NOT NULL,
  condition_source tinyint(8) NOT NULL default '1',
  condition_operator tinyint(3) NOT NULL default '1',
  condition_value varchar(254) NOT NULL,
  last_updated int(10) NOT NULL default '0',
  PRIMARY KEY (deception_trap_condition_id)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.DECEPTION_TRAP_INJECTION_HEADERS
CREATE TABLE DECEPTION_TRAP_INJECTION_HEADERS (
  injection_header_id bigint(20) unsigned NOT NULL auto_increment,
  deception_trap_id bigint(20) unsigned NOT NULL,
  header_name blob NOT NULL,
  header_value blob NOT NULL,
  PRIMARY KEY (injection_header_id),
  UNIQUE INDEX header_index (deception_trap_id, header_name(254))
) ENGINE=InnoDB;



-- CONFIG_SYNC: PLC.DECEPTION_TRAP_INJECTIONS
CREATE TABLE DECEPTION_TRAP_INJECTIONS (
  deception_trap_injection_id bigint(20) unsigned NOT NULL auto_increment,
  deception_trap_id bigint(20) unsigned NOT NULL,
  injection_type tinyint (3) NOT NULL default '1',
  injection_value blob,
  injection_condition blob,
  tag_name blob,
  tag_injection_location tinyint(3),
  PRIMARY KEY (deception_trap_injection_id),
  UNIQUE INDEX trap_index (deception_trap_id)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.DECEPTION_TRAP_VARIABLES
CREATE TABLE DECEPTION_TRAP_VARIABLES (
  variable_id bigint(20) unsigned NOT NULL auto_increment,
  var_name varchar(254) NOT NULL,
  var_value varchar(254) NOT NULL,
  PRIMARY KEY (variable_id)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.DECEPTION_TRAPS
CREATE TABLE DECEPTION_TRAPS (
  deception_trap_id bigint(20) unsigned NOT NULL auto_increment,
  deception_trap_name varchar(254) NOT NULL,
  deception_trap_display_name varchar(254) NOT NULL,
  attack_type_id bigint(20) unsigned NOT NULL default 1,
  risk tinyint(1) NOT NULL default 1,
  score int(10) NOT NULL default 0,
  PRIMARY KEY (deception_trap_id)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.DEVICE_GROUP_MEMBERS
CREATE TABLE DEVICE_GROUP_MEMBERS (
  host varchar(63) NOT NULL,
  known_time decimal(15,5) NOT NULL default 0,
  PRIMARY KEY  (host)
) ENGINE=InnoDB;



CREATE TABLE FACTORY_BROWSERS (
  factory_browser_id bigint(20) unsigned NOT NULL,
  browser_name varchar(255) NOT NULL,
  description varchar(255) NOT NULL,
  rest_uuid char(22) NOT NULL default '',
  KEY browser_name (browser_name),
  PRIMARY KEY (factory_browser_id)
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.GLOBAL_SCANNER_CONFIG
CREATE TABLE GLOBAL_SCANNER_CONFIG(
  global_scanner_config_id bigint(20) unsigned NOT NULL auto_increment,
  scanner_type varchar(128) NOT NULL default '',
  api_key blob,
  scanner_site_name varchar(128) NOT NULL default '',
  PRIMARY KEY (global_scanner_config_id),
  UNIQUE KEY (global_scanner_config_id, scanner_type)
) ENGINE=InnoDB;


CREATE TABLE GRAPHQL_DEFENSE_ATTRIBUTES (
  def_attrib_id int(10) NOT NULL,
  def_attrib_xpath varchar(255) NOT NULL,
  def_attrib_name varchar(255) NOT NULL,
  gui_display_order int(10) NOT NULL,
  value_type ENUM('integer', 'string', 'boolean') NOT NULL,
  max_value int(10),
  min_value int(10),
  units varchar(255),
  learning_factor float,
  PRIMARY KEY (def_attrib_id)
) ENGINE=InnoDB;





CREATE TABLE GRAPHQL_DEFENSE_ATTRIBUTES_DEFAULTS (
  def_attrib_id int(10) NOT NULL,
  def_attrib_value varchar(255) NOT NULL,
  flg_check_attrib int(2) NOT NULL default 1,
  PRIMARY KEY (def_attrib_id),
  FOREIGN KEY (def_attrib_id) references GRAPHQL_DEFENSE_ATTRIBUTES(def_attrib_id)
) ENGINE=InnoDB;





CREATE TABLE GRPC_DEFENSE_ATTRIBUTES (
  def_attrib_id int(10) NOT NULL,
  def_attrib_xpath varchar(255) NOT NULL,
  def_attrib_name varchar(255) NOT NULL,
  gui_display_order int(10) NOT NULL,
  value_type ENUM('integer', 'string', 'boolean') NOT NULL,
  max_value int(10),
  min_value int(10),
  units varchar(255),
  learning_factor float,
  PRIMARY KEY (def_attrib_id)
) ENGINE=InnoDB;





CREATE TABLE GRPC_DEFENSE_ATTRIBUTES_DEFAULTS (
  def_attrib_id int(10) NOT NULL,
  def_attrib_value varchar(255) NOT NULL,
  flg_check_attrib int(2) NOT NULL default 1,
  PRIMARY KEY (def_attrib_id),
  FOREIGN KEY (def_attrib_id) references GRPC_DEFENSE_ATTRIBUTES(def_attrib_id)
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.GUI_SETTINGS
CREATE TABLE GUI_SETTINGS (
  `license_type` enum('Full') NOT NULL default 'Full',
  `item_type` enum('number','list','checkbox','text') NOT NULL default 'number',
  `item` varchar(255) NOT NULL,
  `value` varchar(255) NOT NULL,
  `allowed_values` blob,
  `default_value` varchar(255) NOT NULL,
  `item_title` varchar(255) NOT NULL,
  `item_order` int(2) NOT NULL default '0',
  setting_group_name varchar(255) NOT NULL,
  PRIMARY KEY  (`license_type`,`item`)
) ENGINE=InnoDB;






CREATE TABLE GWT_DEFENSE_ATTRIBUTES (
  def_attrib_id int(10) NOT NULL,
  def_attrib_xpath varchar(255) NOT NULL,
  def_attrib_name varchar(255) NOT NULL,
  gui_display_order int(10) NOT NULL,
  value_type ENUM('integer', 'string', 'boolean') NOT NULL,
  max_value int(10),
  min_value int(10),
  units varchar(255),
  learning_factor float,
  PRIMARY KEY (def_attrib_id)
) ENGINE=InnoDB;





CREATE TABLE GWT_DEFENSE_ATTRIBUTES_DEFAULTS (
  def_attrib_id int(10) NOT NULL,
  def_attrib_value varchar(255) NOT NULL,
  flg_check_attrib int(2) NOT NULL default 1,
  PRIMARY KEY (def_attrib_id),
  FOREIGN KEY (def_attrib_id) references GWT_DEFENSE_ATTRIBUTES(def_attrib_id)
) ENGINE=InnoDB;





CREATE TABLE HSL_PROFILE_TYPES (
  hsl_profile_type_id int auto_increment NOT NULL,   
  hsl_profile_type_name varchar(255) NOT NULL default '',
  PRIMARY KEY (hsl_profile_type_id)
) ENGINE=InnoDB COMMENT='Contains violation description for different security profiles';





CREATE TABLE HSL_COMMAND_CODES (
  command_code int(10) NOT NULL default '0',   
  command_name varchar(100) NOT NULL default '',
  hsl_profile_type_id int NOT NULL,
  flg_is_enabled int(2) NOT NULL default '1',
  FOREIGN KEY (hsl_profile_type_id) references HSL_PROFILE_TYPES(hsl_profile_type_id) ON DELETE CASCADE,
  PRIMARY KEY (command_code, hsl_profile_type_id)
) ENGINE=InnoDB;






CREATE TABLE HSL_PROFILE_VIOLATION_CONFIG_DEFAULTS (
  violation_code int(10) NOT NULL default '0',   
  flg_alarm int(2) NOT NULL default '0',
  flg_reject int(2) NOT NULL default '0',
  hsl_profile_type_id int NOT NULL
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.HSL_PROFILES
CREATE TABLE HSL_PROFILES (
  hsl_profile_id int(10) NOT NULL auto_increment,
  hsl_profile_name varchar(100) NOT NULL default '',
  hsl_profile_type_id int NOT NULL,
  flg_is_enabled int(2) NOT NULL default '1',
  flg_default int(2) NOT NULL default '1', 
  UNIQUE (hsl_profile_name),
  FOREIGN KEY (hsl_profile_type_id) references HSL_PROFILE_TYPES(hsl_profile_type_id) ON DELETE CASCADE,
  PRIMARY KEY (hsl_profile_id)
) ENGINE=InnoDB COMMENT='Contains security profiles pool data';





-- CONFIG_SYNC: PLC.HSL_PROFILE_VIOLATION_CONFIG
CREATE TABLE HSL_PROFILE_VIOLATION_CONFIG (
  hsl_profile_id int(10) NOT NULL default '0',   
  violation_code int(10) NOT NULL default '0',   
  flg_alarm int(2) NOT NULL default '0',
  flg_reject int(2) NOT NULL default '0',
  FOREIGN KEY (hsl_profile_id) references HSL_PROFILES(hsl_profile_id) ON DELETE CASCADE
) ENGINE=InnoDB  COMMENT='Contains violation configuration for all avalable security profiles';



-- CONFIG_SYNC: PLC.HSL_PROFILE_COMMAND_CONFIG
CREATE TABLE HSL_PROFILE_COMMAND_CONFIG (
  hsl_profile_id int(10) NOT NULL default '0',
  command_code int(10) NOT NULL,
  flg_is_enabled int NOT NULL default 1,  
  FOREIGN KEY (hsl_profile_id) references HSL_PROFILES(hsl_profile_id) ON DELETE CASCADE,
  PRIMARY KEY (hsl_profile_id, command_code)
) ENGINE=InnoDB COMMENT='Contains violation configuration for all avalable security profiles';


-- CONFIG_SYNC: PLC.HSL_PROFILES_FTP_CONFIG
CREATE TABLE HSL_PROFILES_FTP_CONFIG (
  hsl_profile_id int(10) NOT NULL default '0',
  flg_username_retries int NOT NULL default 1,   
  username_retries_limit int(10) NOT NULL default 5,
  flg_hostip_retries int NOT NULL default 0,
  hostip_retries_limit int(10) NOT NULL default 5,
  reenable_login_after_timeout int(10) NOT NULL default 15,
  command_length_restriction int(10) NOT NULL default 255, 
  FOREIGN KEY (hsl_profile_id) references HSL_PROFILES (hsl_profile_id) ON DELETE CASCADE,
  PRIMARY KEY (hsl_profile_id)
) ENGINE=InnoDB;






-- CONFIG_SYNC: PLC.HSL_PROFILES_SMTP_ADDRESS_CONFIG
CREATE TABLE HSL_PROFILES_SMTP_ADDRESS_CONFIG (
  hsl_profile_id int(10) NOT NULL default '0',
  address_type int(10) NOT NULL default '0',   
  address varchar(128) NOT NULL default '',
  FOREIGN KEY (hsl_profile_id) references HSL_PROFILES (hsl_profile_id) ON DELETE CASCADE,
  KEY (hsl_profile_id)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.HSL_PROFILES_SMTP_CONFIG
CREATE TABLE HSL_PROFILES_SMTP_CONFIG (
  hsl_profile_id int(10) NOT NULL default 0,
  flg_skip_first_message int NOT NULL default 1,   
  sender_rate_limit int(10) NOT NULL default 100,
  receiver_rate_limit int(10) NOT NULL default 200,
  auto_reject_first_message_timeout int(10) NOT NULL default 40,
  directory_attack_timeout int(10) NOT NULL default 10,
  directory_attack_count int(10) NOT NULL default 20,
  hold_period int(10) NOT NULL default 60,
  FOREIGN KEY (hsl_profile_id) references HSL_PROFILES (hsl_profile_id) ON DELETE CASCADE,
  PRIMARY KEY (hsl_profile_id)
) ENGINE=InnoDB;






CREATE TABLE HSL_VIOLATION_CODES (
  violation_code int(20) NOT NULL default '0',   
  violation_name varchar(100) NOT NULL default '',
  hsl_profile_type_id int NOT NULL,
  FOREIGN KEY (hsl_profile_type_id) references HSL_PROFILE_TYPES(hsl_profile_type_id) ON DELETE CASCADE,
  PRIMARY KEY (violation_code, hsl_profile_type_id)
) ENGINE=InnoDB;






CREATE TABLE IP_REPUTATION_CATEGORIES (
  category_id int(10) unsigned NOT NULL,
  category_icontrol_name varchar(255) NOT NULL,
  category_bitmask_val int(10) unsigned NOT NULL,
  category_name varchar(255) NOT NULL default '',
  description text NOT NULL,
  flg_alarm int(2) NOT NULL default '0',
  flg_block int(2) NOT NULL default '0',
  flg_is_visible int(2) NOT NULL default '1'
 ) ENGINE=InnoDB COMMENT='Contain data about default values for ip reputation categories';





CREATE TABLE JSON_DEFENSE_ATTRIBUTES (
  def_attrib_id int(10) NOT NULL,
  def_attrib_xpath varchar(255) NOT NULL,
  def_attrib_name varchar(255) NOT NULL,
  gui_display_order int(10) NOT NULL,
  value_type ENUM('integer', 'string', 'boolean') NOT NULL,
  max_value int(10),
  min_value int(10),
  units varchar(255),
  learning_factor float,
  PRIMARY KEY (def_attrib_id)
) ENGINE=InnoDB;





CREATE TABLE JSON_DEFENSE_ATTRIBUTES_DEFAULTS (
  def_attrib_id int(10) NOT NULL,
  def_attrib_value varchar(255) NOT NULL,
  flg_check_attrib int(2) NOT NULL default 1,
  PRIMARY KEY (def_attrib_id),
  FOREIGN KEY (def_attrib_id) references JSON_DEFENSE_ATTRIBUTES(def_attrib_id)
) ENGINE=InnoDB;





CREATE TABLE MANDATORY_HEADERS_POOL (
  header_name varchar(255) NOT NULL default ''
) ENGINE=InnoDB;



CREATE TABLE METACHAR_DESCRIPTION (
        metachar_index int(10) unsigned NOT NULL default '0',
        charset_type int(10) unsigned NOT NULL default '0',
        metachar_description mediumblob,
        metachar_references blob,
        metachar_risk tinyint(1) default NULL,
        metachar_accuracy tinyint(1) default NULL,
  PRIMARY KEY  (metachar_index, charset_type)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;









CREATE TABLE METACHAR_LIST (
        metachar_index int(10) unsigned NOT NULL default '0',
        metachar_abbr varchar(3) NOT NULL default '',
        metachar_name varchar(255) NOT NULL,
  PRIMARY KEY  (metachar_index)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;







CREATE TABLE NEGSIG_ATTACK_TYPES (
  attack_type_id bigint(20) unsigned NOT NULL auto_increment,
  attack_type_name text NOT NULL,
  attack_type_display_name text NOT NULL,
  rest_uuid char(22) NOT NULL default '',
  KEY rest_uuid (rest_uuid),
  PRIMARY KEY (attack_type_id)
) ENGINE=InnoDB;





CREATE TABLE HTTP_CHECK_CODES (
  http_check_code int(8) unsigned NOT NULL,
  description varchar(255) NOT NULL,
  attack_type_id bigint(20) unsigned,
  description_text mediumblob,
  description_risk mediumblob,
  description_examples mediumblob,
  flg_allow_microservice_override int(2) NOT NULL default '1',
  rest_uuid char(22) NOT NULL default '',
  KEY rest_uuid (rest_uuid),
  FOREIGN KEY (attack_type_id) references NEGSIG_ATTACK_TYPES(attack_type_id),
  PRIMARY KEY  (http_check_code)
) ENGINE=InnoDB;






CREATE TABLE ATTACK_TYPE_DESCRIPTION (
 attack_type_description_id int(10) unsigned NOT NULL default '0',
 attack_type_id bigint(20) unsigned NOT NULL auto_increment,
 attack_type_description_text mediumblob,
 PRIMARY KEY  (attack_type_description_id),
 FOREIGN KEY (attack_type_id) references NEGSIG_ATTACK_TYPES(attack_type_id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;





-- CONFIG_SYNC: PLC.NEGSIG_PREVIOUS_ENFORCED_RULES
CREATE TABLE NEGSIG_PREVIOUS_ENFORCED_RULES (
  rule_id int(10) NOT NULL auto_increment,
  rule blob NOT NULL,
  rule_md5 varchar(32) NOT NULL,
  PRIMARY KEY (rule_id),  
  UNIQUE (rule_md5)  
) ENGINE=InnoDB;

-- CONFIG_SYNC: PLC.NEGSIG_REFERENCES
CREATE TABLE NEGSIG_REFERENCES (
  reference_type varchar(255) NOT NULL,
  url_template varchar(255) NOT NULL,
  PRIMARY KEY (reference_type)
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.NEGSIG_SETS
CREATE TABLE NEGSIG_SETS (
  set_id bigint(20) unsigned NOT NULL auto_increment,
  flg_is_user_defined tinyint(1) default 1,
  set_name varbinary(255) NOT NULL,
  flg_assign_to_policy_default tinyint(1) default 0,
  flg_learn_default tinyint(1) default 1,
  flg_alarm_default tinyint(1) default 1,
  flg_reject_default tinyint(1) default 1,
  flg_is_hidden tinyint(1) NOT NULL default '0',
  flg_is_manual tinyint(1) NOT NULL default '0',
  set_group_name varchar(255) NOT NULL default 'User-defined',
  rest_uuid char(22) default '',
  last_updated int(10) NOT NULL default 0,
  UNIQUE (set_name),
  KEY rest_uuid (rest_uuid),
  PRIMARY KEY (set_id)
) ENGINE=InnoDB;






-- CONFIG_SYNC: PLC.NEGSIG_SET_FILTERS
CREATE TABLE NEGSIG_SET_FILTERS (
  set_id bigint(20) unsigned NOT NULL,
  apply_to enum('Request','Response'),
  attack_type_id bigint(20) unsigned,
  risk_op enum('le','eq','ge'),
  risk_val tinyint(1),
  accuracy_op enum('le','eq','ge'),
  accuracy_val tinyint(1),
  last_update_op enum('le','ge'),
  last_update_val date,
  flg_is_user_defined tinyint(1), 
  flg_has_cve tinyint(1), 
  flg_is_hidden tinyint(1) default '0',
  sig_tag_op enum('untagged','eq'),
  sig_tag_val varchar(254) default '',
  sig_tag_policy_val varchar(254) default '',
  PRIMARY KEY (set_id),
  FOREIGN KEY (set_id) references NEGSIG_SETS(set_id) ON DELETE CASCADE,
  FOREIGN KEY (attack_type_id) references NEGSIG_ATTACK_TYPES(attack_type_id) ON DELETE CASCADE
) ENGINE=InnoDB;






-- CONFIG_SYNC: PLC.NEGSIG_SIGNATURES
CREATE TABLE NEGSIG_SIGNATURES (
  sig_id bigint(20) unsigned NOT NULL auto_increment,
  rev bigint(20) unsigned NOT NULL,
  flg_is_user_defined tinyint(1) default 1,
  sig_name varchar(254) NOT NULL,
  sig_tag varchar(254) NOT NULL default '',
  sig_tag_policy varchar(254) NOT NULL default '',
  rule blob NOT NULL,
  packed_rule_obj blob,
  last_update datetime,
  apply_to enum('Request','Response') default 'Request',
  attack_type_id bigint(20) unsigned,
  risk tinyint(1) default 1,
  accuracy tinyint(1) default 1,
  sig_desc mediumblob,
  last_enforcement_change int(10) NOT NULL default 0,
  threshold_in_seconds int(8) NOT NULL default 0,
  buffer_type_mask int(8) NOT NULL default 0,
  flg_has_valuecontent_http tinyint(1) NOT NULL default '0',
  flg_has_valuecontent_xml tinyint(1) NOT NULL default '0',
  flg_is_hidden tinyint(1) NOT NULL default '0',
  flg_has_valuecontent_json tinyint(1) NOT NULL default '0',
  flg_has_valuecontent_gwt tinyint(1) NOT NULL default '0',
  flg_has_headercontent tinyint(1) NOT NULL default '0',
  flg_has_uricontent tinyint(1) NOT NULL default '0',
  flg_has_requestcontent tinyint(1) NOT NULL default '0',
  rest_uuid char(22) default '',
  flg_has_valuecontent_plain_text tinyint(1) NOT NULL default '0',
  flg_has_responsecontent tinyint(1) NOT NULL default '0',
  flg_has_cve tinyint(1) NOT NULL default '0',
  PRIMARY KEY (sig_id),
  KEY rest_uuid (rest_uuid),
  KEY flg_has_valuecontent_http (flg_has_valuecontent_http),
  KEY flg_has_valuecontent_xml (flg_has_valuecontent_xml),
  KEY flg_has_valuecontent_json (flg_has_valuecontent_json),
  KEY flg_has_valuecontent_gwt (flg_has_valuecontent_gwt),
  KEY flg_has_valuecontent_plain_text (flg_has_valuecontent_plain_text),
  KEY flg_has_headercontent (flg_has_headercontent),
  KEY flg_has_uricontent (flg_has_uricontent),
  KEY flg_has_requestcontent (flg_has_requestcontent),
  KEY sig_tag (sig_tag),
  KEY sig_tag_policy (sig_tag_policy),
  UNIQUE KEY (sig_name, sig_tag, sig_tag_policy),
  FOREIGN KEY (attack_type_id) references NEGSIG_ATTACK_TYPES(attack_type_id) ON DELETE CASCADE
) ENGINE=InnoDB;

























































-- CONFIG_SYNC: PLC.NEGSIG_SIGNATURE_REFERENCES
CREATE TABLE NEGSIG_SIGNATURE_REFERENCES (
  sig_id bigint(20) unsigned NOT NULL,
  reference_type tinyint(1) NOT NULL,
  reference_val blob NOT NULL,
  KEY sig_id (sig_id),
  FOREIGN KEY (sig_id) references NEGSIG_SIGNATURES(sig_id) ON DELETE CASCADE
) ENGINE=InnoDB;









































































-- CONFIG_SYNC: PLC.NEGSIG_SET_SIGNATURES
CREATE TABLE NEGSIG_SET_SIGNATURES (
  set_id bigint(20) unsigned NOT NULL,
  sig_id bigint(20) unsigned NOT NULL,
  PRIMARY KEY (set_id,sig_id),
  FOREIGN KEY (set_id) references NEGSIG_SETS(set_id) ON DELETE CASCADE,
  FOREIGN KEY (sig_id) references NEGSIG_SIGNATURES(sig_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.NEGSIG_SYSTEM_GROUPS
CREATE TABLE NEGSIG_SYSTEM_GROUPS (
  system_group_id bigint(20) unsigned NOT NULL auto_increment,
  system_group text NOT NULL,
  system_group_display_name text NOT NULL,
  system_group_order int NOT NULL default '0',
  rest_uuid char(22) NOT NULL default '',
  KEY rest_uuid (rest_uuid),
  PRIMARY KEY (system_group_id)
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.NEGSIG_SYSTEMS
CREATE TABLE NEGSIG_SYSTEMS (
  system_id bigint(20) unsigned NOT NULL auto_increment,
  system_name text NOT NULL,
  system_display_name text NOT NULL,
  flg_is_hidden int(2) NOT NULL default '0',
  system_group varchar(255) NOT NULL default '',
  rest_uuid char(22) default '',
  KEY rest_uuid (rest_uuid),
  PRIMARY KEY (system_id)
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.NEGSIG_SIGNATURE_SYSTEMS
CREATE TABLE NEGSIG_SIGNATURE_SYSTEMS (
  sig_id bigint(20) unsigned NOT NULL,
  system_id bigint(20) unsigned NOT NULL,
  FOREIGN KEY (sig_id) references NEGSIG_SIGNATURES(sig_id) ON DELETE CASCADE,
  FOREIGN KEY (system_id) references NEGSIG_SYSTEMS(system_id) ON DELETE CASCADE,
  PRIMARY KEY (sig_id,system_id)
) ENGINE=InnoDB;






































































-- CONFIG_SYNC: PLC.NEGSIG_SET_FILTER_SYSTEMS
CREATE TABLE NEGSIG_SET_FILTER_SYSTEMS (
  set_id bigint(20) unsigned NOT NULL,
  system_id bigint(20) unsigned NOT NULL,
  PRIMARY KEY (set_id,system_id),
  FOREIGN KEY (set_id) references NEGSIG_SETS(set_id) ON DELETE CASCADE,
  FOREIGN KEY (system_id) references NEGSIG_SYSTEMS(system_id) ON DELETE CASCADE
) ENGINE=InnoDB;





CREATE TABLE NORMALIZATION_CODES (
  normalization_code int(8) unsigned NOT NULL,
  description varchar(255) NOT NULL,
  attack_type_id bigint(20) unsigned,
  api_name varchar(255) NOT NULL,
  description_text mediumblob,
  description_risk mediumblob,
  description_examples mediumblob,
  rest_uuid char(22) NOT NULL default '',
  KEY rest_uuid (rest_uuid),
  FOREIGN KEY (attack_type_id) references NEGSIG_ATTACK_TYPES(attack_type_id),
  PRIMARY KEY(normalization_code)
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.PARENT_POLICY_SETTINGS
CREATE TABLE PARENT_POLICY_SETTINGS (
  flg_is_parent_policy_mandatory BOOL NOT NULL DEFAULT 0
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.PL_ALLOWED_COOKIES
-- POLICY_IMPORT: PLC.PL_ALLOWED_COOKIES
CREATE TABLE PL_ALLOWED_COOKIES (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(11) NOT NULL default '0',
  cookie_name blob NOT NULL default '',
  flg_is_pattern int(2) NOT NULL default 0,
  pattern_order int(11),
  flg_is_staging int(2) NOT NULL default 0,    
  flg_tightening int(2) NOT NULL default 0,
  last_tightening_time int(10) NULL default NULL,
  cookie_enforcement_mode enum('allow', 'enforce') NOT NULL default 'allow', 
  staged_since int(10) default NULL,
  last_updated int(10) default NULL,
  created_by varchar(128) NOT NULL default 'GUI',
  is_http_only int(2) NOT NULL default 0,
  is_secure int(2) NOT NULL default 0,
  flg_is_base64 int(2) NOT NULL DEFAULT '0',
  flg_detect_base64 int(2) NOT NULL DEFAULT '0',
  cookie_same_site_attribute int(2) NOT NULL default 1,
  flg_check_signatures int(2) NOT NULL default 1,
  rest_uuid char(22) NOT NULL default '',
  is_inherited int(2) NOT NULL default 0,
  flg_mask_value int(2) NOT NULL default 0,
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY  (id),
  UNIQUE KEY policy_id (policy_id,cookie_name(500))
) ENGINE=InnoDB COMMENT=' Contain data about allowed cookies';


-- CONFIG_SYNC: PLC.PL_ALLOWED_METHODS
-- POLICY_IMPORT: PLC.PL_ALLOWED_METHODS
CREATE TABLE PL_ALLOWED_METHODS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(10) NOT NULL default '0',
  method_code int(10) NOT NULL default '0',
  act_as_method_code int(10) NOT NULL default '0',
  user_config_level enum('basic', 'advanced') NOT NULL default 'basic',
  rest_uuid char(22) NOT NULL default '',
  is_inherited int(2) NOT NULL default 0,
  last_updated int(10) NOT NULL default '0',
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY  (id),
  UNIQUE KEY policy_id (policy_id,method_code)
) ENGINE=InnoDB COMMENT='Contain data about allowed methods';


CREATE TABLE PL_ALLOWED_METHODS_DEFAULTS (
  id int(11) NOT NULL auto_increment,
  method_code int(10) NOT NULL default '0',
  act_as_method_code int(10) NOT NULL default '0',
  user_config_level enum('basic', 'advanced') NOT NULL default 'basic',
  rest_uuid char(22) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB COMMENT='Contain default allowed methods values';





CREATE TABLE PL_ALLOWED_RESPONSE_CODES_DEFAULTS (
   response_code int(10) NOT NULL default 0,
   is_inherited boolean default 0,
   PRIMARY KEY  (response_code),
   UNIQUE KEY response_code ( response_code)
) ENGINE=InnoDB;






CREATE TABLE PL_ALTERNATE_RESPONSE_DEFAULTS (
    cause enum('default', 'persistent flow','XML','Ajax','Ajax_login','Hijack','Mobile','Captcha','Captcha_fail','Failed_login_honeypot','Failed_login_honeypot_ajax', "Leaked_credentials", "Leaked_credentials_ajax",'graphql','grpc') NOT NULL,
    response_type enum ('default', 'redirect', 'custom', 'soap fault', 'erase cookies') NOT NULL,
    license_type enum ('ASM_ENABLED') NOT NULL,
    alternate_response_header blob,
    alternate_response_content blob,
    redirect_url blob,
    ajax_action_type enum('redirect ','alert_popup','custom'),
    ajax_redirect_url text,
    ajax_popup_message blob,
    flg_load_defaults int(2) NOT NULL default '0',
    ajax_custom_content text,
    rest_uuid char(22) NOT NULL default '',
    is_inherited int(2) NOT NULL default 0,
    last_updated int(10) NOT NULL default 0,
    grpc_status_message blob,
    grpc_status_code int(2) default 2,
    PRIMARY KEY (cause, license_type, response_type)
) ENGINE=InnoDB;





CREATE TABLE PL_BEHAVIORAL_ENFORCEMENT_DEFAULTS(
  flg_enabled int(2) NOT NULL default '0',
  flg_block_violations int(2) NOT NULL default '0',
  flg_block_cve_signatures int(2) NOT NULL default '0',
  flg_block_suspicious_transactions int(2) NOT NULL default '0',
  flg_block_likely_malicious_transactions int(2) NOT NULL default '0',
  flg_block_high_accuracy_signatures int(2) NOT NULL default '0'
) ENGINE=InnoDB;





CREATE TABLE PL_BEHAVIORAL_ENFORCEMENT_VIOLATIONS_DEFAULTS (
  viol_index int(10) NOT NULL,
  PRIMARY KEY (viol_index)
) ENGINE=InnoDB;





CREATE TABLE PL_BOT_CLASSES_DEFAULTS (
  bot_class int(10) NOT NULL default 0,
  action int(10) NOT NULL default 0
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.PL_CHARSETS
-- POLICY_IMPORT: PLC.PL_CHARSETS
CREATE TABLE PL_CHARSETS (
  id int(10) NOT NULL auto_increment,
  policy_id int(10) NOT NULL default '0',
  charset_type int(10) NOT NULL default '0',
  charset mediumtext NOT NULL default '',
  rest_uuid char(22) NOT NULL default '',
  last_updated int(10) NOT NULL default 0,
  section_type int(10),
  is_inherited int(2) NOT NULL default 0,
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY  (id),
  UNIQUE KEY policy_id (policy_id,charset_type)
) ENGINE=InnoDB COMMENT='Table contains current character sets per policy';


-- CLUSTER_TABLE: PLC.PL_CONFIG_LOG
-- POLICY_NONIMPORT: PLC.PL_CONFIG_LOG
CREATE TABLE PL_CONFIG_LOG (
  config_log_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int unsigned,
  log_note text,
  rule_number int(11),
  rule_is_trusted tinyint(2),
  event_type int(11),
  element_type int(11),
  element_id int(11),
  element_name text,
  element_kind varchar(255),
  element_rest_uuid char(22),
  event_time int(11),
  description text,
  rest_description text,
  rest_element_name text,
  rest_element_type int(11),
  rest_event_type int(11),
  user_name varchar(255),
  gui_user_name varchar(255),
  device_name varchar(255),
  is_policy_version_event tinyint(2) NOT NULL default 0,
  policy_version_time int(11),
  policy_version_device_name varchar(255),
  policy_version_policy_name varchar(255),
  policy_version_last_change blob,
  suggestion_rest_uuid char(22),
  rest_uuid char(22) NOT NULL default '',
  PRIMARY KEY (config_log_id),
  KEY rest_uuid (policy_id, rest_uuid),
  KEY rest_event_type (policy_id, rest_event_type),
  KEY policy_id (policy_id)
) ENGINE=InnoDB;



-- CONFIG_SYNC: PLC.PL_CONTENT_PROFILES
-- POLICY_IMPORT: PLC.PL_CONTENT_PROFILES
CREATE TABLE PL_CONTENT_PROFILES (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  profile_name varbinary(255) NOT NULL,
  description text,
  flg_validation_soapaction_header int(2) NOT NULL default 0,
  flg_allow_soap_attachment int(2) NOT NULL default 0,
  flg_follow_schema_links int(2) NOT NULL default 1,
  flg_is_wss_security int(2) NOT NULL default 0,
  content_profile_type tinyint NOT NULL default 1,
  flg_use_xml_blocking_page int(2) NOT NULL default 0,
  flg_check_element_metachars int(2) NOT NULL default 1,
  flg_check_attribute_metachars int(2) NOT NULL default 0,
  flg_check_signatures int(2) NOT NULL default 1,
  flg_check_param_value_length int(2) NOT NULL default 0,
  flg_inspect_soap_attachments int(2) NOT NULL DEFAULT '0',
  flg_associate_urls int(2) NOT NULL default 1,
  flg_detect_string_base64 int(2) NOT NULL default 0,
  last_updated int(10) default NULL,
  created_by enum('GUI', 'PolicyBuilder') NOT NULL default 'GUI',
  rest_uuid char(22) NOT NULL default '',
  collapse_type int(2) NOT NULL default 0,
  flg_handle_json_parameters tinyint(2) NOT NULL default 0,
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY (id),
  KEY rest_uuid (policy_id, rest_uuid),
  UNIQUE (policy_id, profile_name, content_profile_type)
) ENGINE=InnoDB COMMENT=' Contain basic config. & data about content profiles data';


-- CONFIG_SYNC: PLC.PL_CONTENT_PROFILE_VALUE_METACHARS
-- POLICY_IMPORT: PLC.PL_CONTENT_PROFILE_VALUE_METACHARS
CREATE TABLE PL_CONTENT_PROFILE_VALUE_METACHARS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  profile_id bigint(20) unsigned NOT NULL default '0',
  metachar int(8) unsigned NOT NULL default '0',
  flg_is_allowed int(2) NOT NULL default '1',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY (id),
  UNIQUE (profile_id, metachar),
  KEY policy_id (policy_id),
  FOREIGN KEY (profile_id) REFERENCES PL_CONTENT_PROFILES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_CONTENT_BASE64_ENC_DATA
-- POLICY_IMPORT: PLC.PL_CONTENT_BASE64_ENC_DATA
 CREATE TABLE PL_CONTENT_BASE64_ENC_DATA (
  id bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  policy_id int(8) NOT NULL DEFAULT '0',
  profile_id bigint(20) unsigned NOT NULL,
  namespace varbinary(512) NOT NULL DEFAULT '',
  base64_param_name varbinary(512) NOT NULL DEFAULT '',
  base64_param_type enum('Element','Attribute') DEFAULT NULL,
  PRIMARY KEY (id),
  KEY profile_id (profile_id),
  FOREIGN KEY (profile_id) REFERENCES PL_CONTENT_PROFILES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_CONTENT_SENSITIVE_PARAMS
-- POLICY_IMPORT: PLC.PL_CONTENT_SENSITIVE_PARAMS
CREATE TABLE PL_CONTENT_SENSITIVE_PARAMS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  profile_id bigint(20) unsigned NOT NULL,
  namespace varbinary(512) NOT NULL default '',
  sensitive_param_name varbinary(512) NOT NULL default '',
  sensitive_param_type ENUM('Element','Attribute'),
  PRIMARY KEY (id),
  FOREIGN KEY (profile_id) references PL_CONTENT_PROFILES(id) ON DELETE CASCADE
) ENGINE=InnoDB;



CREATE TABLE PL_CRAWLER_FILETYPES_POOL (
  id int(10) NOT NULL auto_increment,
  file_type varchar(20) binary NOT NULL default '',
  associate_with tinyint(4) NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB COMMENT='Contain policy builders default filetypes';





-- CONFIG_SYNC: PLC.PL_CRAWLER_NAVIGATION_PARAMS
-- POLICY_IMPORT: PLC.PL_CRAWLER_NAVIGATION_PARAMS
CREATE TABLE PL_CRAWLER_NAVIGATION_PARAMS (
  id bigint(10) NOT NULL auto_increment,
  policy_id int(10) NOT NULL default '0',
  object_path varchar(255) NOT NULL default '',
  param_name varchar(255) NOT NULL default '',
  rest_uuid char(22) NOT NULL default '',
  is_inherited int(2) NOT NULL default 0,
  last_updated int(10) NOT NULL default '0',
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY  (id),
  UNIQUE object_path (policy_id,object_path),
  KEY policy_id (policy_id,object_path(10))
) ENGINE=InnoDB COMMENT='Contain data about policy builder navigation params';


-- POLICY_NONIMPORT: PLC.PL_CRAWLER_USER_LOG
CREATE TABLE PL_CRAWLER_USER_LOG (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int unsigned NOT NULL default '0',
  action_name enum ('added','updated','removed','applied') NOT NULL,
  entity_type enum ('account','policy','filetype','object','flow','parameter','cookie','negsig','mask') NOT NULL,
  table_name text NOT NULL,
  entity_id int NOT NULL,
  entity_name text NOT NULL,
  event_time int(10) NOT NULL,
  event_reason enum('trusted-request','trusted-response','untrusted-requests') NOT NULL,
  description text NOT NULL,
  PRIMARY KEY (id),
  KEY policy_id (policy_id),
  KEY action_name (action_name),   
  KEY entity_type (entity_type)   
) ENGINE=InnoDB;


CREATE TABLE PL_DECEPTION_SETTINGS_DEFAULTS(
  flg_user_defined_responses int(2) NOT NULL default '0',
  server_technology_id bigint(20) unsigned NOT NULL default '0',
  flg_response_by_attack_type int(2) NOT NULL default '0'
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.PL_EXTRACT_ATTRIBUTES
-- POLICY_IMPORT: PLC.PL_EXTRACT_ATTRIBUTES
CREATE TABLE PL_EXTRACT_ATTRIBUTES (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  form_idx int(10) NOT NULL default '1',
  param_idx int(10) NOT NULL default '1',
  xpath blob NOT NULL default '',
  dynamic_param_type int(11) default '256', # Only search_within_form should be on by default
  regexp_prefix mediumtext NOT NULL default '',
  regexp_body mediumtext NOT NULL default '',
  regexp_suffix mediumtext NOT NULL default '',
  flg_check_dynamic_value int(2) NOT NULL default '1',
  regexp_num_occurrences int(10) NOT NULL default '0',
  rest_uuid char(22) NOT NULL default '',
  is_inherited int(2) NOT NULL default 0,
  last_updated int(10) default 0,
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY  (id),
  KEY policy_id (policy_id)
) ENGINE=InnoDB COMMENT='Complete config for all extract types';


-- CONFIG_SYNC: PLC.PL_FILETYPES
-- POLICY_IMPORT: PLC.PL_FILETYPES
CREATE TABLE PL_FILETYPES (
  id int(8) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  name varbinary(255) NOT NULL,
  uri_len int(8) NOT NULL default 100,
  req_len int(8) NOT NULL default 5000,
  flg_flow_check int(2) NOT NULL default '0',
  flg_is_referrer int(2) NOT NULL default '0',
  qs_len int(8) NOT NULL default 1000,
  pd_len int(8) NOT NULL default 1000,
  flg_filter_app_error int(2) NOT NULL default '0',
  flg_is_pattern int(2) NOT NULL default 0,
  pattern_order int(2),
  flg_tightening int(2) NOT NULL default 0,
  last_tightening_time int(10) NULL default NULL,
  expiration_datetime datetime,
  flg_is_allowed int(2) NOT NULL default '1', 	
  flg_is_staging int(4) NOT NULL default 0,
  staged_since int(10) default NULL,
  last_updated int(10) default NULL,
  flg_check_uri_len int(2) NOT NULL default 1,
  flg_check_req_len int(2) NOT NULL default 1,
  flg_check_qs_len int(2) NOT NULL default 1,
  flg_check_pd_len int(2) NOT NULL default 1,
  is_inherited int(2) NOT NULL default 0,
  created_by varchar(128) NOT NULL default 'GUI',
  rest_uuid char(22) NOT NULL default '',
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY  (id),
  UNIQUE policy_id (policy_id, name)
) ENGINE=InnoDB COMMENT=' Contain basic config. & data about object types';


-- CONFIG_SYNC: PLC.PL_GLOBAL_EXTRACTS
-- POLICY_IMPORT: PLC.PL_GLOBAL_EXTRACTS
CREATE TABLE PL_GLOBAL_EXTRACTS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  name varbinary(255) NOT NULL default '',
  flg_applies_to_all int(2) NOT NULL default '0',
  applies_to_regexp varchar(255) NOT NULL default '',
  extract_attrib_id bigint(20) unsigned NOT NULL,
  PRIMARY KEY  (id),
  KEY policy_id (policy_id),
  UNIQUE KEY (policy_id,name),
  FOREIGN KEY (extract_attrib_id) references PL_EXTRACT_ATTRIBUTES(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Basic data for global extracts';


-- CONFIG_SYNC: PLC.PL_GLOBAL_EXTRACT_OBJECT_TYPES
-- POLICY_IMPORT: PLC.PL_GLOBAL_EXTRACT_OBJECT_TYPES
CREATE TABLE PL_GLOBAL_EXTRACT_OBJECT_TYPES (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  global_extract_id bigint(20) unsigned NOT NULL,
  obj_type_id int(8) unsigned NOT NULL,
  PRIMARY KEY  (id),
  KEY policy_id (policy_id),
  UNIQUE KEY (global_extract_id, obj_type_id),
  FOREIGN KEY (global_extract_id) references PL_GLOBAL_EXTRACTS(id) ON DELETE CASCADE,
  FOREIGN KEY (obj_type_id) references PL_FILETYPES(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Object types to use for a global extract';


-- CONFIG_SYNC: PLC.PL_GRAPHQL_PROFILE_DEFENSE_ATTRIBUTES
-- POLICY_IMPORT: PLC.PL_GRAPHQL_PROFILE_DEFENSE_ATTRIBUTES
CREATE TABLE PL_GRAPHQL_PROFILE_DEFENSE_ATTRIBUTES (
 policy_id int(8) NOT NULL default '0',
 profile_id bigint(20) unsigned NOT NULL,
 def_attrib_id int(10) NOT NULL,
 def_attrib_value varchar(255) NOT NULL,
 flg_check_attrib int(2) NOT NULL default 1,
 PRIMARY KEY (profile_id, def_attrib_id),
 FOREIGN KEY (profile_id)  references PL_CONTENT_PROFILES(id) ON DELETE CASCADE,
 FOREIGN KEY (def_attrib_id) references GRAPHQL_DEFENSE_ATTRIBUTES(def_attrib_id)
) ENGINE=InnoDB;



-- CONFIG_SYNC: PLC.PL_GRPC_PROFILE_DEFENSE_ATTRIBUTES 
-- POLICY_IMPORT: PLC.PL_GRPC_PROFILE_DEFENSE_ATTRIBUTES 
CREATE TABLE PL_GRPC_PROFILE_DEFENSE_ATTRIBUTES ( 
 policy_id int(8) NOT NULL default '0',
 profile_id bigint(20) unsigned NOT NULL, 
 def_attrib_id int(10) NOT NULL, 
 def_attrib_value varchar(255) default '', 
 flg_check_attrib int(2) NOT NULL default 1,
 PRIMARY KEY (profile_id, def_attrib_id), 
 FOREIGN KEY (profile_id)  references PL_CONTENT_PROFILES(id) ON DELETE CASCADE, 
 FOREIGN KEY (def_attrib_id) references GRPC_DEFENSE_ATTRIBUTES(def_attrib_id) 
) ENGINE=InnoDB;



-- CONFIG_SYNC: PLC.PL_GRPC_PROFILE_IDL_FILES
-- POLICY_IMPORT: PLC.PL_GRPC_PROFILE_IDL_FILES
CREATE TABLE PL_GRPC_PROFILE_IDL_FILES (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  profile_id bigint(20) unsigned NOT NULL,
  flg_is_primary_enforced int(2) NOT NULL default 0,
  idl_file_id bigint(20) unsigned NOT NULL,
  import_url blob NULL default NULL,
  primary_idl_file_name varchar(63) default '',
  PRIMARY KEY (id),
  UNIQUE (profile_id, idl_file_id, import_url(500)),
  FOREIGN KEY (profile_id) references PL_CONTENT_PROFILES(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


-- CONFIG_SYNC: PLC.PL_GWT_PROFILE_DEFENSE_ATTRIBUTES
-- POLICY_IMPORT: PLC.PL_GWT_PROFILE_DEFENSE_ATTRIBUTES
CREATE TABLE PL_GWT_PROFILE_DEFENSE_ATTRIBUTES (
 policy_id int(8) NOT NULL default '0',
 profile_id bigint(20) unsigned NOT NULL,
 def_attrib_id int(10) NOT NULL,
 def_attrib_value varchar(255) default '',
 flg_check_attrib int(2) NOT NULL default 1,
 PRIMARY KEY (profile_id, def_attrib_id),
 FOREIGN KEY (profile_id)  references PL_CONTENT_PROFILES(id) ON DELETE CASCADE,
 FOREIGN KEY (def_attrib_id) references GWT_DEFENSE_ATTRIBUTES(def_attrib_id)
) ENGINE=InnoDB;


CREATE TABLE PL_HEADERS_DEFAULTS (
   header_name varchar(255) NOT NULL default '',
   flg_is_pattern int(2) NOT NULL default 0,
   pattern_order  int(10) NOT NULL default '0' ,
   flg_is_mandatory int(2) NOT NULL default 0,
   flg_check_signatures int(2) NOT NULL default 1,
   flg_is_base64 int(2) NOT NULL default 0,
   flg_detect_base64 int(2) NOT NULL default 0,
   flg_percent_normalization int(2) NOT NULL default 0,
   flg_uri_normalization int(2) NOT NULL default 0,
   flg_html_normalization int(2) NOT NULL default 0,
   flg_enable_normalization_violation int(2) NOT NULL default 0,
   flg_is_default int(2) NOT NULL default 1,
   flg_mask_value int(2) NOT NULL default 0,
   flg_allow_repeated int(2) NOT NULL default 1,
   rest_uuid char(22) NOT NULL default ''
) ENGINE=InnoDB;






-- CONFIG_SYNC: PLC.PL_HIDE_PARAM_VALUES
-- POLICY_IMPORT: PLC.PL_HIDE_PARAM_VALUES
CREATE TABLE PL_HIDE_PARAM_VALUES (
  id int(8) NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  param_name varchar(255) BINARY NOT NULL default '',
  rest_uuid char(22) NOT NULL default '',
  is_inherited int(2) NOT NULL default 0,
  last_updated int(10) NOT NULL default '0',
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY  (id),
  UNIQUE policy_id (policy_id,param_name)
) ENGINE=InnoDB COMMENT=' Contain data about sensitive params';


CREATE TABLE PL_HIDE_PARAM_VALUES_DEFAULTS (
  id int(8) NOT NULL auto_increment,
  param_name varchar(255) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB COMMENT='Contain sensitive params default values';





CREATE TABLE PL_HTTP_CHECKS_DEFAULTS (
  http_check_code int(8) unsigned NOT NULL,
  flg_is_enabled int(2) NOT NULL default '0',
  flg_pb_enabled int(2) NOT NULL default '1',
  max_headers int(8) NOT NULL default '20',
  max_params int(8) NOT NULL default '500',
  rest_uuid char(22) not null default '',
  PRIMARY KEY  (http_check_code),
  FOREIGN KEY (http_check_code) REFERENCES HTTP_CHECK_CODES (http_check_code) ON DELETE CASCADE
) ENGINE=InnoDB;






-- CONFIG_SYNC: PLC.PL_IDL_FILES
-- POLICY_IMPORT: PLC.PL_IDL_FILES
-- LARGE_RECORD_TABLE: PLC.PL_IDL_FILES
CREATE TABLE PL_IDL_FILES (
  idl_file_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  file_name varchar(255) NOT NULL,
  file_contents mediumblob,
  file_type tinyint(2) NOT NULL default 1,
  last_updated int (10) default NULL,
  rest_uuid char(22) NOT NULL default '',
  is_inherited int(2) NOT NULL default 0,
  UNIQUE KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY (idl_file_id),
  KEY (file_name)
) ENGINE=InnoDB COMMENT='';


CREATE TABLE PL_ILLEGAL_META_CHARS_POOL (
  id int(8) unsigned NOT NULL auto_increment,
  value varchar(10) NOT NULL default '',
  hex_value varchar(4) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB COMMENT='Contain illegal meta chars default values';





-- CONFIG_SYNC: PLC.PL_JSON_PROFILE_DEFENSE_ATTRIBUTES 
-- POLICY_IMPORT: PLC.PL_JSON_PROFILE_DEFENSE_ATTRIBUTES 
CREATE TABLE PL_JSON_PROFILE_DEFENSE_ATTRIBUTES ( 
 policy_id int(8) NOT NULL default '0',
 profile_id bigint(20) unsigned NOT NULL, 
 def_attrib_id int(10) NOT NULL, 
 def_attrib_value varchar(255) default '', 
 flg_check_attrib int(2) NOT NULL default 1,
 PRIMARY KEY (profile_id, def_attrib_id), 
 FOREIGN KEY (profile_id)  references PL_CONTENT_PROFILES(id) ON DELETE CASCADE, 
 FOREIGN KEY (def_attrib_id) references JSON_DEFENSE_ATTRIBUTES(def_attrib_id) 
) ENGINE=InnoDB;



-- CONFIG_SYNC: PLC.PL_JSON_PROFILE_VALIDATION_FILES
-- POLICY_IMPORT: PLC.PL_JSON_PROFILE_VALIDATION_FILES
CREATE TABLE PL_JSON_PROFILE_VALIDATION_FILES (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  profile_id bigint(20) unsigned NOT NULL,
  flg_is_primary_enforced int(2) NOT NULL default 0,
  json_validation_file_id bigint(20) unsigned NOT NULL,
  import_url blob NULL default NULL,
  PRIMARY KEY (id),
  UNIQUE (profile_id, json_validation_file_id, import_url(500)),
  FOREIGN KEY (profile_id) references PL_CONTENT_PROFILES(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


-- CONFIG_SYNC: PLC.PL_JSON_VALIDATION_FILES
-- POLICY_IMPORT: PLC.PL_JSON_VALIDATION_FILES
-- LARGE_RECORD_TABLE: PLC.PL_JSON_VALIDATION_FILES
CREATE TABLE PL_JSON_VALIDATION_FILES (
  json_validation_file_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  file_name varchar(255) NOT NULL,
  file_contents mediumblob,
  file_type tinyint(2) NOT NULL default 1,
  last_updated int (10) default NULL,
  rest_uuid char(22) NOT NULL default '',
  is_inherited int(2) NOT NULL default 0,
  UNIQUE KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY (json_validation_file_id),
  KEY (file_name)
) ENGINE=InnoDB COMMENT='';


-- CONFIG_SYNC: PLC.PL_MICROSERVICES
-- POLICY_IMPORT: PLC.PL_MICROSERVICES
CREATE TABLE PL_MICROSERVICES (
  microservice_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  microservice_uri blob NOT NULL,
  flg_is_pattern_uri int(2) NOT NULL default 1,
  flg_is_pattern int(2) NOT NULL default 1,
  pattern_order int(10) NOT NULL default '0',
  flg_wildcard_uri_includes_slash int(2) NOT NULL default '1',
  microservice_host_name varchar(254) NOT NULL default '',
  transparency_enforcement_mode tinyint(1) NOT NULL default 1,
  flg_is_pattern_host int(2) NOT NULL default 1,
  description blob,
  last_updated int(10) NOT NULL default 0,
  rest_uuid char(22) NOT NULL default '',
  is_inherited int(2) NOT NULL default 0,
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY (microservice_id),
  UNIQUE KEY (policy_id, microservice_host_name, microservice_uri(500))
);


CREATE TABLE PL_NORMALIZATION_DEFAULTS (
  normalization_code int(8) unsigned NOT NULL,
  flg_is_enabled int(2) NOT NULL default '0',
  flg_pb_enabled int(2) NOT NULL default '1',
  rest_uuid char(22) not null default '',
  max_decoding_passes int(8) NOT NULL default '2',
  PRIMARY KEY  (normalization_code),
  FOREIGN KEY (normalization_code) references NORMALIZATION_CODES(normalization_code) ON DELETE CASCADE
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.PL_OBJECTS
-- POLICY_IMPORT: PLC.PL_OBJECTS
CREATE TABLE PL_OBJECTS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  app_id int(2) NOT NULL default '0',
  uri blob NOT NULL,
  flg_is_referrer int(2) NOT NULL default '0',
  flg_check_flow int(2) NOT NULL default '0',
  flg_entry_point int(2) NOT NULL default '0',
  flg_cookie_change int(2) NOT NULL default '0',
  flg_parse_dynamic_params int(2) NOT NULL default '0',
  description blob,
  flg_is_pattern int(2) NOT NULL default 0,
  pattern_order int(2),
  flg_tightening int(2) NOT NULL default 0,
  last_tightening_time int(10) NULL default NULL,
  flg_check_obj_metachar int(2) NOT NULL default 1,
  user_config_level enum('basic', 'advanced') NOT NULL default 'basic',
  flg_is_staging int(4) NOT NULL default 0,
  staged_since int(10) default NULL,
  last_updated int(10) default NULL,
  flg_is_allowed int(2) NOT NULL default '1',
  created_by varchar(128) NOT NULL default 'GUI',
  flg_clickjacking_protection int(2) NOT NULL default 0,
  clickjacking_type int(2) default 0,
  clickjacking_from varchar(256),
  flg_wildcard_includes_slash int(2) NOT NULL default '1',
  flg_enable_cors_enforcement int(2) NOT NULL default 0,
  flg_allow_cors int(2) NOT NULL default 1,
  flg_check_credentials int(2) NOT NULL default 0,
  flg_allow_credentials int(2) NOT NULL default 0,
  flg_check_maximum_age int(2) NOT NULL default 0,
  maximum_age int(10) NOT NULL default '1800',
  allowed_origins_enforcement_mode int(2) NOT NULL default 1,
  flg_allowed_methods_check int(2) NOT NULL default 0,
  flg_allowed_headers_check int(2) NOT NULL default 0,
  flg_exposed_headers_check int(2) NOT NULL default 0,
  flg_check_obj_methods int(2) NOT NULL default 0,
  rest_uuid char(22) NOT NULL default '',
  flg_check_signatures tinyint(1) NOT NULL default 1,
  is_inherited int(2) NOT NULL default 0,
  flg_in_classification tinyint(2) NOT NULL default 0,
  method_name varchar(255) NOT NULL default '*',
  operation_id varchar(255),
  flg_mandatory_body tinyint(1) NOT NULL default 0,
  flg_disallow_file_upload_of_executables tinyint(1) NOT NULL default 0,
  PRIMARY KEY  (id),
  UNIQUE object (policy_id, app_id, uri(767), method_name),
  KEY rest_uuid (policy_id, rest_uuid),
  KEY (policy_id, uri(500), app_id, flg_is_pattern)
) ENGINE=InnoDB COMMENT=' Contain basic config. & data about objects' AUTO_INCREMENT=0;


/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;





-- CONFIG_SYNC: PLC.PL_OBJECT_METHOD_OVERRIDES
-- POLICY_IMPORT: PLC.PL_OBJECT_METHOD_OVERRIDES
CREATE TABLE PL_OBJECT_METHOD_OVERRIDES (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  obj_id bigint(20) unsigned NOT NULL default '0',
  method_name char(255) NOT NULL default '',  
  flg_is_allowed int(2) NOT NULL default '1',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY  (id),
  KEY policy_id (policy_id),
  UNIQUE obj_id (obj_id, method_name),
  FOREIGN KEY (obj_id) references PL_OBJECTS(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Contain data about object methods';



-- CONFIG_SYNC: PLC.PL_OBJECT_METACHARS
-- POLICY_IMPORT: PLC.PL_OBJECT_METACHARS
CREATE TABLE PL_OBJECT_METACHARS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  obj_id bigint(20) unsigned NOT NULL default '0',
  metachar int(8) unsigned NOT NULL default '0',
  flg_is_allowed int(2) NOT NULL default '1',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY  (id),
  KEY policy_id (policy_id),
  UNIQUE param_attrib_id (obj_id,metachar),
  FOREIGN KEY (obj_id) references PL_OBJECTS(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Contain data about object metachars';


-- CONFIG_SYNC: PLC.PL_OBJECT_EXTRACTS
-- POLICY_IMPORT: PLC.PL_OBJECT_EXTRACTS
CREATE TABLE PL_OBJECT_EXTRACTS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  name varbinary(255) NOT NULL default '',
  obj_id bigint(20) unsigned NOT NULL,
  extract_attrib_id bigint(20) unsigned NOT NULL,
  PRIMARY KEY  (id),
  KEY policy_id (policy_id),
  UNIQUE KEY (obj_id,name),
  FOREIGN KEY (extract_attrib_id) references PL_EXTRACT_ATTRIBUTES(id) ON DELETE CASCADE,
  FOREIGN KEY (obj_id) references PL_OBJECTS(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Basic data for object params';


-- CONFIG_SYNC: PLC.PL_OBJECT_EXPOSED_HEADERS
-- POLICY_IMPORT: PLC.PL_OBJECT_EXPOSED_HEADERS
CREATE TABLE PL_OBJECT_EXPOSED_HEADERS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL,
  obj_id bigint(20) unsigned NOT NULL,
  exposed_header_name varchar(255) NOT NULL default '',
  PRIMARY KEY (id),
  UNIQUE KEY (obj_id,exposed_header_name),
  FOREIGN KEY (obj_id) references PL_OBJECTS(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_OBJECT_CONTENT_PROFILES
-- POLICY_IMPORT: PLC.PL_OBJECT_CONTENT_PROFILES
CREATE TABLE PL_OBJECT_CONTENT_PROFILES (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL,
  obj_id bigint(20) unsigned NOT NULL,
  profile_id bigint(20) unsigned,
  header_name varchar(1024) NOT NULL default '*',
  header_value varchar(1024) NOT NULL default '*',
  header_order int(8) NOT NULL default '0',
  enforcement_type enum('http','xml','json','apply_value_signatures','disallow','dont_check','gwt','do_nothing','graphql', 'grpc') NOT NULL default 'http',
  PRIMARY KEY (id),
  FOREIGN KEY (obj_id) references PL_OBJECTS(id) ON DELETE CASCADE,
  FOREIGN KEY (profile_id) references PL_CONTENT_PROFILES(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT=' Contain basic config. & data about object flows';


-- CONFIG_SYNC: PLC.PL_OBJECT_ALLOWED_ORIGINS
-- POLICY_IMPORT: PLC.PL_OBJECT_ALLOWED_ORIGINS
CREATE TABLE PL_OBJECT_ALLOWED_ORIGINS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL,
  obj_id bigint(20) unsigned NOT NULL,
  origin_name varchar(255) NOT NULL default '',
  origin_port int(8) default 0,
  origin_protocol int(2) not NULL default 3,
  flg_include_sub_domains int(2) NOT NULL default 0,
  PRIMARY KEY (id),
  UNIQUE KEY (obj_id,origin_name,origin_port,origin_protocol),
  FOREIGN KEY (obj_id) references PL_OBJECTS(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_OBJECT_ALLOWED_METHODS
-- POLICY_IMPORT: PLC.PL_OBJECT_ALLOWED_METHODS
CREATE TABLE PL_OBJECT_ALLOWED_METHODS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL,
  obj_id bigint(20) unsigned NOT NULL,
  method_name varchar(255) NOT NULL default '',
  PRIMARY KEY (id),
  UNIQUE KEY (obj_id,method_name),
  FOREIGN KEY (obj_id) references PL_OBJECTS(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_OBJECT_ALLOWED_HEADERS
-- POLICY_IMPORT: PLC.PL_OBJECT_ALLOWED_HEADERS
CREATE TABLE PL_OBJECT_ALLOWED_HEADERS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL,
  obj_id bigint(20) unsigned NOT NULL,
  allowed_header_name varchar(255) NOT NULL default '',
  PRIMARY KEY (id),
  UNIQUE KEY (obj_id,allowed_header_name),
  FOREIGN KEY (obj_id) references PL_OBJECTS(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_LOGIN_OBJECTS
-- POLICY_IMPORT: PLC.PL_LOGIN_OBJECTS
CREATE TABLE PL_LOGIN_OBJECTS (
    id bigint(20) unsigned NOT NULL auto_increment,
    object_id bigint(20) unsigned NOT NULL,
    policy_id int(8) unsigned NOT NULL default '0',
    username_param varchar(255) NOT NULL default '',
    password_param varchar(255) NOT NULL default '',
    auth_type int(8) NOT NULL default '4', /* default is 'none' */
    resp_contains blob default '',
    resp_omits blob default '',
    resp_http_status blob default '',
    header_contains blob default '',
    header_omits blob default '',
    cookie_contains blob default '',
    param_contains blob default '',
    rest_uuid char(22) NOT NULL default '',
    is_inherited int(2) NOT NULL default 0,
    last_updated int(10) NOT NULL default '0',
    KEY rest_uuid (policy_id, rest_uuid),
    PRIMARY KEY (id),
    UNIQUE (object_id),
    FOREIGN KEY (object_id) REFERENCES PL_OBJECTS(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Pre-requisite objects';


-- CONFIG_SYNC: PLC.PL_LOGIN_BRUTE_FORCE_OBJECT_ATTRIBUTES 
-- POLICY_IMPORT: PLC.PL_LOGIN_BRUTE_FORCE_OBJECT_ATTRIBUTES
CREATE TABLE PL_LOGIN_BRUTE_FORCE_OBJECT_ATTRIBUTES (
   id bigint(20) unsigned NOT NULL auto_increment,
   object_id bigint(20) unsigned NOT NULL default '0',
   policy_id int(8) unsigned NOT NULL default '0',
   max_login_attempts int(8) NOT NULL default '20',
   session_expiration_period int(8) NOT NULL default '3600',
   measurement_period int(8) NOT NULL default '900',
   detection_threshold_abs int(8) NOT NULL default '100',
   max_prevention_time int(8) NOT NULL default '3600',
   flg_force_blocking int(2) NOT NULL default '0',
   rest_uuid char(22) NOT NULL default '',
   flg_is_default int(2) NOT NULL default '0',
   flg_enabled int(2) NOT NULL default '0',
   flg_identify_device int(2) NOT NULL default '0',
   is_inherited int(2) NOT NULL default '0',
   last_updated int(10) NOT NULL default '0',
   flg_detect_credentials_stuffing_attack tinyint(1) NOT NULL DEFAULT '1',
   detection_threshold_credentials_stuffing_matches_reached int(8) NOT NULL DEFAULT '100',
   detection_threshold_action int(2) NOT NULL DEFAULT '3',
   flg_detect_distributed_brute_force_attack tinyint(1) NOT NULL DEFAULT '1',
   flg_detect_login_attempts_from_the_same_user tinyint(1) NOT NULL DEFAULT '1',
   login_attempts_from_the_same_user_threshold int(8) NOT NULL DEFAULT '3',
   login_attempts_from_the_same_user_action int(2) NOT NULL DEFAULT '3',
   login_attempts_from_the_same_device_id_threshold int(8) NOT NULL DEFAULT '3',
   login_attempts_from_the_same_device_id_action int(2) NOT NULL DEFAULT '3',
   flg_detect_login_attempts_from_the_same_ip int(2) NOT NULL DEFAULT '1',
   login_attempts_from_the_same_ip_action int(2) NOT NULL DEFAULT '3',
   flg_captcha_bypass tinyint(1) NOT NULL DEFAULT '1',
   captcha_bypass_threshold int(8) NOT NULL DEFAULT '5',
   captcha_bypass_threshold_action int(2) NOT NULL DEFAULT '6',
   flg_client_side_integrity_bypass tinyint(1) NOT NULL DEFAULT '1',
   client_side_integrity_bypass_threshold int(8) NOT NULL DEFAULT '3',
   client_side_integrity_bypass_threshold_action int(2) NOT NULL DEFAULT '3',
   source_based_protection_detection_period int(8) NOT NULL DEFAULT '3600',
   flg_leaked_credentials_detection tinyint(1) NOT NULL DEFAULT '0',
   leaked_credentials_action int(2) NOT NULL DEFAULT '2',
   KEY rest_uuid (policy_id, rest_uuid),
   PRIMARY KEY  (id),
   UNIQUE KEY object_id ( object_id , policy_id ),
   FOREIGN KEY (object_id) REFERENCES PL_OBJECTS (id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_GLOBAL_EXTRACT_OBJECTS
-- POLICY_IMPORT: PLC.PL_GLOBAL_EXTRACT_OBJECTS
CREATE TABLE PL_GLOBAL_EXTRACT_OBJECTS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  global_extract_id bigint(20) unsigned NOT NULL,
  obj_id bigint(20) unsigned NOT NULL,
  PRIMARY KEY  (id),
  KEY policy_id (policy_id),
  UNIQUE KEY (global_extract_id, obj_id),
  FOREIGN KEY (global_extract_id) references PL_GLOBAL_EXTRACTS(id) ON DELETE CASCADE,
  FOREIGN KEY (obj_id) references PL_OBJECTS(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Object types to use for a global extract';


-- CONFIG_SYNC: PLC.PL_FLOWS
-- POLICY_IMPORT: PLC.PL_FLOWS
CREATE TABLE PL_FLOWS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  from_id bigint(20) unsigned NOT NULL default '0',
  to_id bigint(20) unsigned NOT NULL default '0',
  max_limit int(8) NOT NULL default '0',
  frame_index int(10) NOT NULL default '0',
  num_mandatory_params int(8) NOT NULL default '0',
  method int(2) NOT NULL default '0',
  flg_unicode_encoding int(2) NOT NULL default '0',
  flg_pd int(2) NOT NULL default '1',
  flg_qs int(2) NOT NULL default '1',
  flg_check_pd int(2) NOT NULL default '1',
  flg_check_qs int(2) NOT NULL default '1',
  last_updated int(10) NOT NULL default '0',
  rest_uuid char(22) NOT NULL default '',
  PRIMARY KEY  (id),
  KEY policy_id (policy_id),
  UNIQUE KEY flow (from_id,to_id,method),
  KEY rest_uuid (rest_uuid),
  FOREIGN KEY (from_id) references PL_OBJECTS(id) ON DELETE CASCADE,
  FOREIGN KEY (to_id) references PL_OBJECTS(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT=' Contain basic config. & data about object flows';


-- CONFIG_SYNC: PLC.PL_DYNAMIC_FLOWS
-- POLICY_IMPORT: PLC.PL_DYNAMIC_FLOWS
CREATE TABLE PL_DYNAMIC_FLOWS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  obj_id bigint(20) unsigned NOT NULL default '0',
  regexp_prefix mediumtext NOT NULL default '',
  regexp_body mediumtext NOT NULL default '',
  regexp_suffix mediumtext NOT NULL default '',
  PRIMARY KEY  (id),
  KEY policy_id (policy_id,obj_id),
  FOREIGN KEY (obj_id) references PL_OBJECTS(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_PARAM_ATTRIBUTES
-- POLICY_IMPORT: PLC.PL_PARAM_ATTRIBUTES
CREATE TABLE PL_PARAM_ATTRIBUTES (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  flg_mandatory int(2) NOT NULL default '0',
  flg_null_value int(2) NOT NULL default '1',
  key_type int(2) NOT NULL default '0',
  key_input_type int(10) NOT NULL default '4',
  key_ui_type int(10) NOT NULL default '32',
  max_len int(8) default '10',
  flg_check_min int(2) NOT NULL default '0',
  flg_check_max int(2) NOT NULL default '0',
  min_value double default NULL,
  max_value double default NULL,
  flg_regexpr int(2) NOT NULL default '0',
  regexpr_values mediumtext NOT NULL default '',
  flg_tightening int(2) NOT NULL default 0,
  last_tightening_time int(10) NULL default NULL,
  flg_check_param_name_metachar int(2) NOT NULL default 1,
  expiration_datetime datetime,
  flg_is_staging int(4) NOT NULL default 0,
  staged_since int(10) default NULL,
  last_updated int(10) default NULL,
  flg_is_sensitive int(2) NOT NULL default 0,
  created_by varchar(128) NOT NULL default 'GUI',
  flg_check_max_len int(2) NOT NULL default 0,
  flg_check_param_value_metachar int(2) NOT NULL default 1,
  flg_check_signatures int(2) NOT NULL default 1,
  flg_allow_repeated_parameter_name int(2) NOT NULL default 0,
  flg_in_classification int(2) NOT NULL default 0,
  flg_disallow_upload_of_exe int(2) NOT NULL default 1,
  flg_detect_base64 int(2) NOT NULL DEFAULT 0,
  flg_is_base64 int(2) NOT NULL DEFAULT '0',
  flg_is_ip_address int(2) NOT NULL DEFAULT '0',
  rest_uuid char(22) NOT NULL default '',
  is_inherited int(2) NOT NULL default 0,
  parameter_location tinyint(2) unsigned NOT NULL default 1,
  flg_check_min_items_in_array tinyint(2) unsigned NOT NULL default 0,
  flg_check_max_items_in_array tinyint(2) unsigned NOT NULL default 0,
  flg_check_array_unique_items tinyint(2) unsigned NOT NULL default 0,
  min_items_in_array int(10) unsigned NOT NULL default 1,
  max_items_in_array int(10) unsigned NOT NULL default 100,
  array_serialization_format tinyint(2) unsigned NOT NULL default 5,
  flg_exclusive_min tinyint(2) unsigned NOT NULL default 0,
  flg_exclusive_max tinyint(2) unsigned NOT NULL default 0,
  flg_check_multiple_of_value tinyint(2) NOT NULL default 0,
  multiple_of_value double NOT NULL default 5,
  min_len int(8) unsigned default 0,
  flg_check_min_len tinyint(2) unsigned NOT NULL default 0,
  flg_is_header tinyint(2) unsigned NOT NULL default 0,
  flg_is_cookie tinyint(2) unsigned NOT NULL default 0,
  object_serialization_style tinyint(2) unsigned NOT NULL default 1,
  flg_object_serialization_explode tinyint(2) unsigned NOT NULL default 0,
  PRIMARY KEY  (id),
  KEY rest_uuid (policy_id, rest_uuid),
  KEY policy_id (policy_id)
) ENGINE=InnoDB COMMENT='Complete config for all parameter types';


-- CONFIG_SYNC: PLC.PL_OBJECT_PARAMS
-- POLICY_IMPORT: PLC.PL_OBJECT_PARAMS
CREATE TABLE PL_OBJECT_PARAMS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  name varbinary(255) NOT NULL default '',
  obj_id bigint(20) unsigned NOT NULL,
  param_attrib_id bigint(20) unsigned NOT NULL,
  flg_is_pattern int(2) NOT NULL default 0,
  pattern_order int(2),
  PRIMARY KEY  (id),
  KEY policy_id (policy_id),
  KEY param_name (name),
  UNIQUE KEY (obj_id, name),
  FOREIGN KEY (param_attrib_id) references PL_PARAM_ATTRIBUTES(id) ON DELETE CASCADE,
  FOREIGN KEY (obj_id) references PL_OBJECTS(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Basic data for object params';


-- CONFIG_SYNC: PLC.PL_GLOBAL_PARAMS
-- POLICY_IMPORT: PLC.PL_GLOBAL_PARAMS
CREATE TABLE PL_GLOBAL_PARAMS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  name varbinary(255) NOT NULL default '',
  param_attrib_id bigint(20) unsigned NOT NULL,
  flg_is_pattern int(2) NOT NULL default 0,
  pattern_order int(2),
  PRIMARY KEY  (id),
  KEY policy_id (policy_id),
  KEY param_name (name),
  UNIQUE KEY (policy_id, name),
  UNIQUE KEY (param_attrib_id),
  FOREIGN KEY (param_attrib_id) references PL_PARAM_ATTRIBUTES(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Basic data for global params';


-- CONFIG_SYNC: PLC.PL_FLOW_PARAMS
-- POLICY_IMPORT: PLC.PL_FLOW_PARAMS
CREATE TABLE PL_FLOW_PARAMS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  name varbinary(255) NOT NULL default '',
  flow_id bigint(20) unsigned NOT NULL,
  param_attrib_id bigint(20) unsigned NOT NULL,
  flg_is_pattern int(2) NOT NULL default 0,
  pattern_order int(2),
  PRIMARY KEY  (id),
  KEY policy_id (policy_id),
  KEY param_name (name),
  UNIQUE KEY (flow_id, name),
  FOREIGN KEY (flow_id) references PL_FLOWS(id) ON DELETE CASCADE,
  FOREIGN KEY (param_attrib_id) references PL_PARAM_ATTRIBUTES(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Basic data for flow params';


-- CONFIG_SYNC: PLC.PL_DYNAMIC_PARAM_EXTRACTS
-- POLICY_IMPORT: PLC.PL_DYNAMIC_PARAM_EXTRACTS
CREATE TABLE PL_DYNAMIC_PARAM_EXTRACTS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  param_attrib_id bigint(20) unsigned NOT NULL,
  extract_attrib_id bigint(20) unsigned NOT NULL,
  PRIMARY KEY  (id),
  KEY policy_id (policy_id),
  FOREIGN KEY (param_attrib_id) references PL_PARAM_ATTRIBUTES(id) ON DELETE CASCADE,
  FOREIGN KEY (extract_attrib_id) references PL_EXTRACT_ATTRIBUTES(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Join table for linking dynamic params to extract attributes';


-- CONFIG_SYNC: PLC.PL_PARAM_CONTENT_PROFILES
-- POLICY_IMPORT: PLC.PL_PARAM_CONTENT_PROFILES
 CREATE TABLE PL_PARAM_CONTENT_PROFILES (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  profile_id bigint(20) unsigned NOT NULL,
  param_attrib_id bigint(20) unsigned NOT NULL,
  PRIMARY KEY  (id),
  UNIQUE KEY param_attrib_id (param_attrib_id),
  KEY profile_id (profile_id),
  FOREIGN KEY (param_attrib_id) REFERENCES PL_PARAM_ATTRIBUTES (id) ON DELETE CASCADE,
  FOREIGN KEY (profile_id) REFERENCES PL_CONTENT_PROFILES (id) ON DELETE CASCADE
) ENGINE=InnoDB;



-- CONFIG_SYNC: PLC.PL_PARAM_NAME_METACHARS
-- POLICY_IMPORT: PLC.PL_PARAM_NAME_METACHARS
CREATE TABLE PL_PARAM_NAME_METACHARS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  param_attrib_id bigint(20) unsigned NOT NULL default '0',
  metachar int(8) unsigned NOT NULL default '0',
  flg_is_allowed int(2) NOT NULL default '1',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY  (id),
  KEY policy_id (policy_id),
  UNIQUE param_attrib_id (param_attrib_id,metachar),
  FOREIGN KEY (param_attrib_id) references PL_PARAM_ATTRIBUTES(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Contain data about user-input parameters allowed metachars on parameter name';


-- CONFIG_SYNC: PLC.PL_PARAM_VALUE_METACHARS
-- POLICY_IMPORT: PLC.PL_PARAM_VALUE_METACHARS
CREATE TABLE PL_PARAM_VALUE_METACHARS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  param_attrib_id bigint(20) unsigned NOT NULL default '0',
  metachar int(8) unsigned NOT NULL default '0',
  flg_is_allowed int(2) NOT NULL default '1',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY  (id),
  KEY policy_id (policy_id),
  UNIQUE (param_attrib_id,metachar),
  FOREIGN KEY (param_attrib_id) references PL_PARAM_ATTRIBUTES(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Contain data about user-input parameters allowed metachars on parameter value';


-- CONFIG_SYNC: PLC.PL_POLICIES
CREATE TABLE PL_POLICIES (
  id int(8) unsigned NOT NULL auto_increment,
  account_id int(8) unsigned NOT NULL default '0',
  name varchar(255) binary NOT NULL default '',
  policy_name_crc bigint(20) unsigned NOT NULL default '0',
  description varchar(255) NOT NULL default '',
  application varchar(255) NOT NULL default '',
  creator_name varchar(255) NOT NULL default '',
  createdtime int(10) NOT NULL default '0',
  last_vs_assoc_update_time int(10) NOT NULL default '0',
  flg_disable_rejects int(2) NOT NULL default '1',
  flg_passive_mode int(2) NOT NULL default '0',
  user_config_level enum('basic', 'advanced') NOT NULL default 'basic',
  flg_is_case_insensitive int(2) NOT NULL default '0',
  flg_is_protocol_free int(2) NOT NULL default '0',
  flg_is_owa tinyint(1) NOT NULL DEFAULT 0,
  flg_is_candidate_for_sweep tinyint(1) NOT NULL DEFAULT 1,
  encoding varchar(255) NOT NULL DEFAULT 'utf-8',
  flg_encoding_selected int(2) NOT NULL default '0',
  rest_uuid char(22) NOT NULL default '',
  has_been_applied int(2) NOT NULL default '0',
  policy_type tinyint(2) NOT NULL default '1',
  flg_managed_by_bewaf int(2) NOT NULL default '0',
  PRIMARY KEY  (id),
  UNIQUE KEY name (name),
  KEY rest_uuid (rest_uuid)
) ENGINE=InnoDB COMMENT='Structure=Update,Data=KeepCurr';


-- CONFIG_SYNC: PLC.PL_PARAM_NEGSIG_SIGNATURES
-- POLICY_IMPORT: PLC.PL_PARAM_NEGSIG_SIGNATURES
CREATE TABLE PL_PARAM_NEGSIG_SIGNATURES (
  policy_id int(8) unsigned NOT NULL default '0',
  param_attrib_id bigint(20) unsigned NOT NULL default '0',
  sig_id bigint(20) unsigned NOT NULL,
  flg_is_enabled tinyint(1),
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY (param_attrib_id,sig_id),
  FOREIGN KEY (policy_id) REFERENCES PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (param_attrib_id) references PL_PARAM_ATTRIBUTES(id) ON DELETE CASCADE,
  FOREIGN KEY (sig_id) references NEGSIG_SIGNATURES(sig_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_OBJECT_POSITIONAL_PARAMETERS
-- POLICY_IMPORT: PLC.PL_OBJECT_POSITIONAL_PARAMETERS
CREATE TABLE PL_OBJECT_POSITIONAL_PARAMETERS (
  policy_id int(8) unsigned NOT NULL default '0',
  object_id bigint(20) unsigned NOT NULL default '0',
  param_attrib_id bigint(20) unsigned NOT NULL default '0',
  url_segment_index int(8) unsigned NOT NULL default '0',
  PRIMARY KEY (object_id,param_attrib_id,url_segment_index),
  FOREIGN KEY (policy_id) REFERENCES PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (object_id) references PL_OBJECTS(id) ON DELETE CASCADE,
  FOREIGN KEY (param_attrib_id) references PL_GLOBAL_PARAMS(param_attrib_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_OBJECT_NEGSIG_SIGNATURES
-- POLICY_IMPORT: PLC.PL_OBJECT_NEGSIG_SIGNATURES
CREATE TABLE PL_OBJECT_NEGSIG_SIGNATURES (
  policy_id int(8) unsigned NOT NULL default '0',
  obj_id bigint(20) unsigned NOT NULL,
  sig_id bigint(20) unsigned NOT NULL,
  flg_is_enabled tinyint(1) NOT NULL default '0',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY (obj_id,sig_id),
  FOREIGN KEY (policy_id) REFERENCES PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (obj_id) references PL_OBJECTS(id) ON DELETE CASCADE,
  FOREIGN KEY (sig_id) references NEGSIG_SIGNATURES(sig_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_NORMALIZATION
-- POLICY_IMPORT: PLC.PL_NORMALIZATION
CREATE TABLE PL_NORMALIZATION (
  policy_id int(8) unsigned NOT NULL default '0',
  normalization_code int(8) unsigned NOT NULL,
  flg_is_enabled int(2) NOT NULL default '0',
  flg_pb_enabled int(2) NOT NULL default '1',
  max_decoding_passes int(8) NOT NULL default '2',
  rest_uuid char(22) NOT NULL default '',
  last_updated int(10) NOT NULL default 0,
  is_inherited int(2) NOT NULL default 0,
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY  (policy_id,normalization_code),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (normalization_code) references NORMALIZATION_CODES(normalization_code) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_NEGSIG_EXCLUDED_HEADERS
-- POLICY_IMPORT: PLC.PL_NEGSIG_EXCLUDED_HEADERS
CREATE TABLE PL_NEGSIG_EXCLUDED_HEADERS (
   header_id bigint(20) unsigned NOT NULL auto_increment,
   policy_id int(8) unsigned NOT NULL,
   header_name varchar(255) NOT NULL default '',
   PRIMARY KEY  (header_id),
   UNIQUE KEY header_name ( policy_id, header_name),
   FOREIGN KEY (policy_id) REFERENCES PL_POLICIES (id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_MICROSERVICE_NORMALIZATION_OVERRIDES
-- POLICY_IMPORT: PLC.PL_MICROSERVICE_NORMALIZATION_OVERRIDES
CREATE TABLE PL_MICROSERVICE_NORMALIZATION_OVERRIDES (
  microservice_normalization_override_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  microservice_id bigint(20) unsigned NOT NULL,
  normalization_code int(8) unsigned NOT NULL,
  flg_is_enabled int(2) NOT NULL default '0',
  flg_pb_enabled int(2) NOT NULL default '1',
  max_decoding_passes int(8) NOT NULL default '2',
  UNIQUE KEY (`policy_id`,`microservice_id`,`normalization_code`),
  PRIMARY KEY (microservice_normalization_override_id),
  FOREIGN KEY (microservice_id) references PL_MICROSERVICES(microservice_id) ON DELETE CASCADE,
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (normalization_code) references NORMALIZATION_CODES(normalization_code) ON DELETE CASCADE
) ENGINE=InnoDB;



-- CONFIG_SYNC: PLC.PL_MICROSERVICE_HTTP_CHECKS_OVERRIDES
-- POLICY_IMPORT: PLC.PL_MICROSERVICE_HTTP_CHECKS_OVERRIDES
CREATE TABLE PL_MICROSERVICE_HTTP_CHECKS_OVERRIDES (
   microservice_http_check_override_id bigint(20) unsigned NOT NULL auto_increment,
   policy_id int(8) unsigned NOT NULL default 0,
   microservice_id bigint(20) unsigned NOT NULL,
   http_check_code int(8) unsigned NOT NULL default 0,
   flg_is_enabled int(2) NOT NULL default 0,
   flg_pb_enabled int(2) NOT NULL default 1,
   max_headers int(8) NOT NULL default '20',
   max_params int(8) NOT NULL default '500',
   PRIMARY KEY (microservice_http_check_override_id),
   KEY http_check_code (http_check_code),
   UNIQUE KEY (`policy_id`,`microservice_id`,`http_check_code`),
   FOREIGN KEY (microservice_id) references PL_MICROSERVICES(microservice_id) ON DELETE CASCADE,
   FOREIGN KEY (policy_id) REFERENCES PL_POLICIES (id) ON DELETE CASCADE,
   FOREIGN KEY (http_check_code) REFERENCES HTTP_CHECK_CODES (http_check_code) ON DELETE CASCADE
) ENGINE=InnoDB;



-- CONFIG_SYNC: PLC.PL_LOGIN_OBJECTS_OMITS_RESPONSE_CODES
-- POLICY_IMPORT: PLC.PL_LOGIN_OBJECTS_OMITS_RESPONSE_CODES
CREATE TABLE PL_LOGIN_OBJECTS_OMITS_RESPONSE_CODES (
    id bigint(20) unsigned NOT NULL auto_increment,
    login_object_id bigint(20) unsigned NOT NULL,
    policy_id int(8) unsigned NOT NULL default '0',
    response_code char(3) default '',
    PRIMARY KEY (id),
    UNIQUE (login_object_id,response_code),
    FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE,
    FOREIGN KEY (login_object_id) REFERENCES PL_LOGIN_OBJECTS(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Pre-requisite objects response code omits';


-- CONFIG_SYNC: PLC.PL_IP_WHITELIST
-- POLICY_IMPORT: PLC.PL_IP_WHITELIST
CREATE TABLE PL_IP_WHITELIST (
  whitelist_ip_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(10) unsigned NOT NULL default '0',
  ip_address varchar(128) NOT NULL,
  mask varchar(128) NOT NULL default '255.255.255.255',
  flg_pb_trusted  int(1) NOT NULL default '0',
  flg_ignore_anomaly int(1) NOT NULL default '0',
  flg_never_log int(1) NOT NULL default '0',
  block_ip int(3) NOT NULL default '1',
  flg_never_learn  int(1) NOT NULL default '0',
  flg_ignore_ip_reputation int(1) NOT NULL default '0',
  description text,
  flg_is_em_originated int(1) NOT NULL default 0,
  rest_uuid char(22) NOT NULL default '',
  last_updated int(10) NOT NULL default 0,
  is_inherited int(2) NOT NULL default 0,
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY  (whitelist_ip_id),
  UNIQUE (policy_id,ip_address,mask),
  FOREIGN KEY (policy_id) REFERENCES PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_IP_REPUTATION_CATEGORIES
-- POLICY_IMPORT: PLC.PL_IP_REPUTATION_CATEGORIES
CREATE TABLE PL_IP_REPUTATION_CATEGORIES (
  ip_reputation_category_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  category_id int(10) NOT NULL default '0',
  flg_alarm int(2) NOT NULL default '0',
  flg_block int(2) NOT NULL default '0',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY  (ip_reputation_category_id),
  FOREIGN KEY (policy_id) REFERENCES PL_POLICIES (id) ON DELETE CASCADE,
  UNIQUE KEY policy_id (policy_id,category_id)
) ENGINE=InnoDB COMMENT='Contain data about ip reputation categories';


-- CONFIG_SYNC: PLC.PL_IP_REPUTATION
-- POLICY_IMPORT: PLC.PL_IP_REPUTATION
CREATE TABLE PL_IP_REPUTATION (
  ip_reputation_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  flg_enabled int(2) NOT NULL default '0',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY  (ip_reputation_id),
  UNIQUE KEY (policy_id),
  FOREIGN KEY (policy_id) REFERENCES PL_POLICIES (id) ON DELETE CASCADE
)ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_HTTP_CHECKS
-- POLICY_IMPORT: PLC.PL_HTTP_CHECKS
CREATE TABLE PL_HTTP_CHECKS (
   policy_id int(8) unsigned NOT NULL default 0,
   http_check_code int(8) unsigned NOT NULL default 0,
   flg_is_enabled int(2) NOT NULL default 0,
   flg_pb_enabled int(2) NOT NULL default 1,
   max_headers int(8) NOT NULL default '20',
   max_params int(8) NOT NULL default '500',
   rest_uuid char(22) NOT NULL default '',
   last_updated int(10) NOT NULL default 0,
   is_inherited int(2) NOT NULL default 0,
   KEY rest_uuid (policy_id, rest_uuid),
   PRIMARY KEY  (policy_id,http_check_code),
   KEY http_check_code (http_check_code),
   FOREIGN KEY (policy_id) REFERENCES PL_POLICIES (id) ON DELETE CASCADE,
   FOREIGN KEY (http_check_code) REFERENCES HTTP_CHECK_CODES (http_check_code) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_HEADERS
-- POLICY_IMPORT: PLC.PL_HEADERS
CREATE TABLE PL_HEADERS (
   header_id bigint(20) unsigned NOT NULL auto_increment,
   policy_id int(8) unsigned NOT NULL,
   header_name varchar(255) NOT NULL default '',
   flg_is_pattern int(2) NOT NULL default 0,
   pattern_order  int(10) NOT NULL default '0' ,
   flg_is_mandatory int(2) NOT NULL default 0,
   flg_check_signatures int(2) NOT NULL default 1,
   flg_is_base64 int(2) NOT NULL default 0,
   flg_detect_base64 int(2) NOT NULL default 0,
   flg_percent_normalization int(2) NOT NULL default 0,
   flg_uri_normalization int(2) NOT NULL default 0,
   flg_html_normalization int(2) NOT NULL default 0,
   flg_enable_normalization_violation int(2) NOT NULL default 0,
   flg_is_default int(2) NOT NULL default 0,
   rest_uuid char(22) NOT NULL default '',
   is_inherited int(2) NOT NULL default 0,
   last_updated int(10) NOT NULL default '0',
   flg_mask_value int(2) NOT NULL default 0,
   flg_allow_repeated int(2) NOT NULL default 1,
   KEY rest_uuid (policy_id, rest_uuid),
   PRIMARY KEY  (header_id),
   UNIQUE KEY header_name ( policy_id, header_name),
   FOREIGN KEY (policy_id) REFERENCES PL_POLICIES (id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_HEADER_NEGSIG_SIGNATURES
-- POLICY_IMPORT: PLC.PL_HEADER_NEGSIG_SIGNATURES
CREATE TABLE PL_HEADER_NEGSIG_SIGNATURES (
  policy_id int(8) unsigned NOT NULL default '0',
  header_id bigint(20) unsigned NOT NULL,
  sig_id bigint(20) unsigned NOT NULL,
  flg_is_enabled tinyint(1) NOT NULL default '0',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY (header_id,sig_id),
  FOREIGN KEY (policy_id) REFERENCES PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (header_id) references PL_HEADERS(header_id) ON DELETE CASCADE,
  FOREIGN KEY (sig_id) references NEGSIG_SIGNATURES(sig_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_GEOLOCATION_ENFORCEMENT_LIST
-- POLICY_IMPORT: PLC.PL_GEOLOCATION_ENFORCEMENT_LIST
CREATE TABLE PL_GEOLOCATION_ENFORCEMENT_LIST (
  geolocation_enforcement_list_id int(8) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  country_code varchar(3) NOT NULL default '',
  rest_uuid char(22) NOT NULL default '',
  is_inherited int(2) NOT NULL default 0,
  last_updated int(10) default NULL,
  UNIQUE KEY (policy_id, country_code),
  KEY rest_uuid (rest_uuid),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE,
  PRIMARY KEY (geolocation_enforcement_list_id)
) ENGINE=InnoDB COMMENT='Contains a list of countries to disallow';


-- CONFIG_SYNC: PLC.PL_GEOLOCATION_ENFORCEMENT
-- POLICY_IMPORT: PLC.PL_GEOLOCATION_ENFORCEMENT
CREATE TABLE PL_GEOLOCATION_ENFORCEMENT (
  geolocation_enforcement_id int(8) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  geolocation_enforcement_mode enum('disallow', 'allow') NOT NULL DEFAULT 'disallow',
  PRIMARY KEY (geolocation_enforcement_id),
  UNIQUE KEY (policy_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_DISABLED_ACTION_ITEMS
-- POLICY_IMPORT: PLC.PL_DISABLED_ACTION_ITEMS
CREATE TABLE PL_DISABLED_ACTION_ITEMS (
  disabled_action_item_id int(8) unsigned NOT NULL auto_increment,
  policy_id int(8) UNSIGNED NOT NULL default '0',
  action_item_type  int(8) NOT NULL default 1,
  last_updated int(11) NOT NULL default 0,
  rest_uuid char(22) NOT NULL default '',
  KEY rest_uuid (rest_uuid),
  PRIMARY KEY (disabled_action_item_id),
  UNIQUE KEY (policy_id, action_item_type),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


CREATE TABLE PL_DIFFS (
  diff_id bigint(20) unsigned NOT NULL auto_increment,
  rest_uuid char(22) NOT NULL default '',
  first_policy_id int(8) unsigned NOT NULL default '0',
  second_policy_id int(8) unsigned NOT NULL default '0',
  gui_user_name varchar(255) NOT NULL default '',
  created_time int(10) NOT NULL default '0',
  last_updated int(10) NOT NULL default '0',
  PRIMARY KEY  (diff_id),
  KEY rest_uuid (rest_uuid),
  UNIQUE KEY uniq_key (first_policy_id,second_policy_id,created_time),
  FOREIGN KEY (first_policy_id) references PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (second_policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


CREATE TABLE PL_DIFF_ITEMS (
  diff_item_id bigint(20) unsigned NOT NULL auto_increment,
  diff_id bigint(20) unsigned NOT NULL,
  diff_type smallint NOT NULL,
  element_type smallint NOT NULL,
  element_kind varchar(255),
  element_name text NOT NULL,
  first_element_id bigint(20) unsigned,
  second_element_id bigint(20) unsigned,
  first_element_timestamp int(10) NOT NULL default '0',
  second_element_timestamp int(10) NOT NULL default '0',
  can_be_merged_first_to_second smallint NOT NULL,
  can_be_merged_second_to_first smallint NOT NULL,
  rest_uuid char(22) NOT NULL default '',
  PRIMARY KEY  (diff_item_id),
  KEY rest_uuid (rest_uuid),
  FOREIGN KEY (diff_id) references PL_DIFFS(diff_id) ON DELETE CASCADE
) ENGINE=InnoDB;


CREATE TABLE PL_DIFF_ITEM_DETAILS (
  diff_item_detail_id bigint(20) unsigned NOT NULL auto_increment,
  diff_item_id bigint(20) unsigned NOT NULL,
  field_name text NOT NULL,
  field_display_name varchar(255) NOT NULL DEFAULT "",
  first_diff_display text,
  second_diff_display text,
  can_be_merged_first_to_second smallint NOT NULL,
  can_be_merged_second_to_first smallint NOT NULL,
  first_element mediumblob,
  second_element mediumblob,
  detail_id_by_item bigint(20) unsigned NOT NULL,
  PRIMARY KEY  (diff_item_detail_id),
  FOREIGN KEY (diff_item_id) references PL_DIFF_ITEMS(diff_item_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- POLICY_IMPORT: PLC.PL_DECEPTION_SETTINGS
-- CONFIG_SYNC: PLC.PL_DECEPTION_SETTINGS
CREATE TABLE PL_DECEPTION_SETTINGS(
  deception_settings_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  flg_user_defined_responses int(2) NOT NULL default '0',
  server_technology_id bigint(20) unsigned NOT NULL default '0',
  flg_response_by_attack_type int(2) NOT NULL default '0',
  PRIMARY KEY (deception_settings_id),
  UNIQUE (policy_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- POLICY_IMPORT: PLC.PL_DECEPTION_RESPONSES
-- CONFIG_SYNC: PLC.PL_DECEPTION_RESPONSES
CREATE TABLE PL_DECEPTION_RESPONSES (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  response_code varchar(3) NOT NULL default '',
  response_headers blob,
  response_body blob,
  rest_uuid char(22) NOT NULL default '',
  last_updated int(10) NOT NULL default 0,
  PRIMARY KEY (id),
  KEY rest_uuid (policy_id, rest_uuid),
  UNIQUE (policy_id, response_code),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- POLICY_IMPORT: PLC.PL_DECEPTION_RESPONSE_CODES
-- CONFIG_SYNC: PLC.PL_DECEPTION_RESPONSE_CODES
CREATE TABLE PL_DECEPTION_RESPONSE_CODES (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  response_code varchar(3) NOT NULL default '',
  PRIMARY KEY (id),
  UNIQUE (policy_id, response_code),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_DATABASE_PROTECTION
-- POLICY_IMPORT: PLC.PL_DATABASE_PROTECTION
CREATE TABLE PL_DATABASE_PROTECTION (
  database_protection_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL DEFAULT '0',
  flg_is_enabled int(2) NOT NULL DEFAULT '0',
  user_source int(2) NOT NULL DEFAULT 1,
  PRIMARY KEY  (database_protection_id),
  UNIQUE (policy_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;



-- CONFIG_SYNC: PLC.PL_COOKIE_NEGSIG_SIGNATURES
-- POLICY_IMPORT: PLC.PL_COOKIE_NEGSIG_SIGNATURES
CREATE TABLE PL_COOKIE_NEGSIG_SIGNATURES (
  policy_id int(8) unsigned NOT NULL default '0',
  cookie_id bigint(20) unsigned NOT NULL,
  sig_id bigint(20) unsigned NOT NULL,
  flg_is_enabled tinyint(1),
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY (cookie_id,sig_id),
  FOREIGN KEY (policy_id) REFERENCES PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (cookie_id) references PL_ALLOWED_COOKIES(id) ON DELETE CASCADE,
  FOREIGN KEY (sig_id) references NEGSIG_SIGNATURES(sig_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_CONTENT_PROFILE_NEGSIG_SIGNATURES
-- POLICY_IMPORT: PLC.PL_CONTENT_PROFILE_NEGSIG_SIGNATURES
CREATE TABLE PL_CONTENT_PROFILE_NEGSIG_SIGNATURES (
  policy_id int(8) unsigned NOT NULL default '0',
  profile_id bigint(20) unsigned NOT NULL default '0',
  sig_id bigint(20) unsigned NOT NULL,
  flg_is_enabled tinyint(1),
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY (profile_id,sig_id),
  FOREIGN KEY (policy_id) REFERENCES PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (profile_id) references PL_CONTENT_PROFILES(id) ON DELETE CASCADE,
  FOREIGN KEY (sig_id) references NEGSIG_SIGNATURES(sig_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_BROWSER_DEFINITIONS
-- POLICY_IMPORT: PLC.PL_BROWSER_DEFINITIONS
CREATE TABLE PL_BROWSER_DEFINITIONS (
  browser_definition_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  browser_name varchar(255) NOT NULL,
  match_regex mediumtext default NULL,
  match_string mediumtext default NULL,
  rule blob default NULL,
  browser_md5 varchar(32) default NULL,
  last_updated int(20),
  is_inherited int(2) NOT NULL default 0, 
  rest_uuid char(22) NOT NULL default '',
  PRIMARY KEY (browser_definition_id),
  KEY rest_uuid (rest_uuid),
  UNIQUE (policy_id, browser_name),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


CREATE TABLE PL_BROWSERS (
  policy_browser_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  browser_definition_id bigint(20) NOT NULL default '',
  min_version int(11) default NULL, 
  max_version int(11) default NULL,
  action int(10) NOT NULL default 0,
  is_inherited tinyint(1) NOT NULL default 0,
  last_updated int(20),
  rest_uuid char(22) NOT NULL default '',
  PRIMARY KEY (policy_browser_id),
  KEY rest_uuid (rest_uuid),
  UNIQUE (policy_id,browser_definition_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (browser_definition_id) references PL_BROWSER_DEFINITIONS(browser_definition_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_BOT_SIGNATURES
-- POLICY_IMPORT: PLC.PL_BOT_SIGNATURES
CREATE TABLE PL_BOT_SIGNATURES (
  policy_bot_signature_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  bot_signature_id bigint(20) unsigned NOT NULL,
  action int(10) NOT NULL default 0,
  is_inherited tinyint(1) NOT NULL default 0,
  last_updated int(20),
  rest_uuid char(22) NOT NULL default '',
  PRIMARY KEY (policy_bot_signature_id),
  KEY rest_uuid (rest_uuid),
  UNIQUE (policy_id,bot_signature_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (bot_signature_id) references BOT_SIGNATURES(bot_signature_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_BOT_DEFENSE
-- POLICY_IMPORT: PLC.PL_BOT_DEFENSE
CREATE TABLE PL_BOT_DEFENSE (
  bot_defense_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  flg_enabled int(2) NOT NULL default 0,
  last_updated int(10) NOT NULL default '0',
  PRIMARY KEY (bot_defense_id),
  UNIQUE KEY (policy_id), 
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_BOT_CLASSES
-- POLICY_IMPORT: PLC.PL_BOT_CLASSES
CREATE TABLE PL_BOT_CLASSES (
  policy_bot_class_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  bot_class int(10) NOT NULL default 0,
  action int(10) NOT NULL default 0,
  last_updated int(10) NOT NULL default '0',
  rest_uuid char(22) default '',
  PRIMARY KEY (policy_bot_class_id),
  UNIQUE KEY (policy_id, bot_class),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


CREATE TABLE PL_BOT_ANOMALIES (
  policy_bot_anomaly_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  bot_anomaly_id bigint(20) unsigned NOT NULL,
  score_threshold int(10) NOT NULL default 0,
  action int(10) NOT NULL default 0,
  is_inherited tinyint(1) NOT NULL default 0,
  last_updated int(20),
  rest_uuid char(22) NOT NULL default '',
  PRIMARY KEY (policy_bot_anomaly_id),
  KEY rest_uuid (rest_uuid),
  UNIQUE (policy_id,bot_anomaly_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (bot_anomaly_id) references BOT_ANOMALIES(bot_anomaly_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- POLICY_IMPORT: PLC.PL_BEHAVIORAL_ENFORCEMENT_VIOLATIONS
-- CONFIG_SYNC: PLC.PL_BEHAVIORAL_ENFORCEMENT_VIOLATIONS
CREATE TABLE PL_BEHAVIORAL_ENFORCEMENT_VIOLATIONS(
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  viol_index int(10) NOT NULL default 0,
  PRIMARY KEY (id),
  UNIQUE KEY (policy_id,viol_index),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- POLICY_IMPORT: PLC.PL_BEHAVIORAL_ENFORCEMENT
-- CONFIG_SYNC: PLC.PL_BEHAVIORAL_ENFORCEMENT
CREATE TABLE PL_BEHAVIORAL_ENFORCEMENT(
  behavioral_enforcement_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  flg_enabled int(2) NOT NULL default '0',
  flg_block_violations int(2) NOT NULL default '0',
  flg_block_cve_signatures int(2) NOT NULL default '0',
  flg_block_suspicious_transactions int(2) NOT NULL default '0',
  flg_block_likely_malicious_transactions int(2) NOT NULL default '0',
  flg_block_high_accuracy_signatures int(2) NOT NULL default '0',
  PRIMARY KEY (behavioral_enforcement_id),
  UNIQUE (policy_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_ALTERNATE_RESPONSES
-- POLICY_IMPORT: PLC.PL_ALTERNATE_RESPONSES
CREATE TABLE PL_ALTERNATE_RESPONSES (
    id bigint(20) unsigned NOT NULL auto_increment,
    policy_id int(8) unsigned NOT NULL,
    cause enum('default', 'persistent flow','XML','Ajax','Ajax_login','Hijack','Mobile','Captcha','Captcha_fail','Failed_login_honeypot','Failed_login_honeypot_ajax', "Leaked_credentials", "Leaked_credentials_ajax",'graphql', 'grpc') NOT NULL default 'default',
    response_type enum ('default', 'redirect', 'custom', 'soap fault','erase cookies') NOT NULL,
    alternate_response_header blob,
    alternate_response_content blob,
    redirect_url blob,
    ajax_action_type enum('redirect','alert_popup','custom')  default 'redirect',
    ajax_redirect_url blob,
    ajax_popup_message blob,
    ajax_custom_content blob,
    rest_uuid char(22) NOT NULL default '',
    last_updated int(10) NOT NULL default 0,
    is_inherited int(2) NOT NULL default 0,
    grpc_status_message blob,
    grpc_status_code int(2) default 2,
    KEY rest_uuid (policy_id, rest_uuid),
    PRIMARY KEY (id),
    UNIQUE (policy_id, cause),
    FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Alternate response per criterium';


-- CONFIG_SYNC: PLC.PL_ALTERNATE_RESPONSE_SETTINGS
-- POLICY_IMPORT: PLC.PL_ALTERNATE_RESPONSE_SETTINGS
CREATE TABLE PL_ALTERNATE_RESPONSE_SETTINGS(
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL,
  flg_ajax_enabled int(2) unsigned NOT NULL default '0',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY  (id),
  UNIQUE (policy_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_ALLOWED_RESPONSE_CODES
-- POLICY_IMPORT: PLC.PL_ALLOWED_RESPONSE_CODES
CREATE TABLE PL_ALLOWED_RESPONSE_CODES (
   id bigint(20) unsigned NOT NULL auto_increment,
   policy_id int(8) unsigned NOT NULL default 0,
   response_code int(10) NOT NULL default 0,
   is_inherited int(2) NOT NULL default 0,
   PRIMARY KEY  (id),
   UNIQUE KEY response_code ( policy_id, response_code),
   KEY policy_id (policy_id, response_code),
   FOREIGN KEY (policy_id) REFERENCES PL_POLICIES (id) ON DELETE CASCADE
) ENGINE=InnoDB;



CREATE TABLE PL_POLICY_ACTION_ITEMS (
  policy_action_item_id int(8) unsigned NOT NULL auto_increment,
  policy_id int(8) UNSIGNED NOT NULL default '0',
  action_item_type int(8) NOT NULL default 1,
  created_time int(11) NOT NULL default 0,
  next_display_time int(11) NOT NULL default 0,
  last_updated int(11) NOT NULL default 0,
  severity int(2) NOT NULL default 1,
  message varchar(255) NOT NULL default '',
  rest_uuid char(22) NOT NULL default '',
  KEY rest_uuid (rest_uuid),
  PRIMARY KEY (policy_action_item_id),
  UNIQUE KEY (policy_id, action_item_type),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_ANTIVIRUS
-- POLICY_IMPORT: PLC.PL_POLICY_ANTIVIRUS
CREATE TABLE PL_POLICY_ANTIVIRUS (
  policy_id int(8) unsigned NOT NULL default '0',
  flg_inspect_http_uploads int(2) NOT NULL DEFAULT '0',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY (policy_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_BUILDER_CONFIG
-- POLICY_IMPORT: PLC.PL_POLICY_BUILDER_CONFIG
-- POLICY_BUILDER: PLC.PL_POLICY_BUILDER_CONFIG
CREATE TABLE PL_POLICY_BUILDER_CONFIG (
       pbconfig_id INT NOT NULL AUTO_INCREMENT ,
       policy_id int(8) unsigned NOT NULL default '0',
       flg_learning BOOL NOT NULL DEFAULT 1,
       flg_enabled BOOL NOT NULL DEFAULT 0,
       flg_signatures BOOL NOT NULL DEFAULT 1,
       flg_client_side_pb BOOL NOT NULL DEFAULT 0,
       rule_sitechanges_time_untrusted int(8) NOT NULL DEFAULT 900,
       rule_sitechanges_time_trusted int(8) NOT NULL DEFAULT 0,
       rule_sitechanges_time_untrusted_max int(8) NOT NULL DEFAULT 604800,
       rule_sitechanges_time_trusted_max int(8) NOT NULL DEFAULT 604800,
       rule_loosen_time_untrusted int(8) NOT NULL DEFAULT 3600,
       rule_loosen_time_trusted int(8) NOT NULL DEFAULT 0,
       rule_loosen_time_untrusted_max int(8) NOT NULL DEFAULT 604800,
       rule_loosen_time_trusted_max int(8) NOT NULL DEFAULT 604800,
       rule_tighten_requests int(8) NOT NULL DEFAULT 15000,
       rule_tighten_time int(8) NOT NULL DEFAULT 86400,
       rule_tighten_loosen_score int(8) NOT NULL DEFAULT 50,
       trusted_ips ENUM( 'all', 'list' ) NULL DEFAULT 'list',
       flg_track_site_changes_untrusted BOOL NOT NULL DEFAULT 1,
       flg_track_site_changes_trusted BOOL NOT NULL DEFAULT 1,
       rule_sitechanges_sources_untrusted int(8) NOT NULL DEFAULT 10,
       rule_sitechanges_sources_trusted int(8) NOT NULL DEFAULT 1,
       rule_loosen_sources_untrusted int(8) NOT NULL DEFAULT 20,
       rule_loosen_sources_trusted int(8) NOT NULL DEFAULT 1,
       flg_learn_from_responses BOOL NOT NULL DEFAULT 1,
       flg_learn_inactive_entities BOOL NOT NULL DEFAULT 1,
       inactive_entity_inactivity_duration_in_seconds int(8) NOT NULL DEFAULT 7776000,
       learning_progress int(3) NOT NULL DEFAULT 0,
       flg_full_policy_inspection bool NOT NULL DEFAULT 1,
       is_inherited bool NOT NULL DEFAULT 0,
       auto_apply_frequency int(3) NOT NULL DEFAULT 2,
       auto_apply_start_time char(5) NOT NULL default '00:00',
       auto_apply_end_time char(5) NOT NULL default '23:59',
       flg_auto_apply_at_all_times bool NOT NULL DEFAULT 1,
       flg_auto_apply_on_all_days bool NOT NULL DEFAULT 1,
       flg_auto_apply_on_sundays BOOL NOT NULL DEFAULT 0,
       flg_auto_apply_on_mondays BOOL NOT NULL DEFAULT 0,
       flg_auto_apply_on_tuesdays BOOL NOT NULL DEFAULT 0,
       flg_auto_apply_on_wednesdays BOOL NOT NULL DEFAULT 0,
       flg_auto_apply_on_thursdays BOOL NOT NULL DEFAULT 0,
       flg_auto_apply_on_fridays BOOL NOT NULL DEFAULT 0,
       flg_auto_apply_on_saturdays BOOL NOT NULL DEFAULT 0,
       flg_learn_only_from_non_bot_traffic BOOL NOT NULL DEFAULT 0,
       flg_fully_automatic BOOL NOT NULL DEFAULT 0,
       PRIMARY KEY ( pbconfig_id ) ,
       UNIQUE ( policy_id ),
       FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_BUILDER_CONFIG_CENTRAL_CONFIGURATION
-- POLICY_IMPORT: PLC.PL_POLICY_BUILDER_CONFIG_CENTRAL_CONFIGURATION
-- POLICY_BUILDER: PLC.PL_POLICY_BUILDER_CONFIG_CENTRAL_CONFIGURATION
CREATE TABLE PL_POLICY_BUILDER_CONFIG_CENTRAL_CONFIGURATION (
   pbconfig_central_configuration_id INT NOT NULL AUTO_INCREMENT ,
   policy_id int(8) unsigned NOT NULL default '0',
   building_mode int(2) NOT NULL default 1,
   event_correlation_mode int(2) NOT NULL default 1,
   is_inherited int(2) NOT NULL default 0,
   PRIMARY KEY ( pbconfig_central_configuration_id ) ,
   UNIQUE ( policy_id ),
   FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;



-- CONFIG_SYNC: PLC.PL_POLICY_BUILDER_CONFIG_CENTRAL_CONFIGURATION_ADDRESSES
-- POLICY_IMPORT: PLC.PL_POLICY_BUILDER_CONFIG_CENTRAL_CONFIGURATION_ADDRESSES
-- POLICY_BUILDER: PLC.PL_POLICY_BUILDER_CONFIG_CENTRAL_CONFIGURATION_ADDRESSES
CREATE TABLE PL_POLICY_BUILDER_CONFIG_CENTRAL_CONFIGURATION_ADDRESSES (
       pbconfig_central_configuration_address_id INT NOT NULL AUTO_INCREMENT ,
       policy_id int(8) unsigned NOT NULL default '0',
       ip_order int(2) NOT NULL default 1,
       ip_address varchar(128) NOT NULL default '',
       port int(4) NOT NULL,
       verify_certificate int(2) NOT NULL default 0,
       host_name varchar(255) default '',
       UNIQUE (policy_id,ip_address,port),
       PRIMARY KEY ( pbconfig_central_configuration_address_id ) ,
       FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;



-- CONFIG_SYNC: PLC.PL_POLICY_BUILDER_CONFIG_COOKIE
-- POLICY_IMPORT: PLC.PL_POLICY_BUILDER_CONFIG_COOKIE
-- POLICY_BUILDER: PLC.PL_POLICY_BUILDER_CONFIG_COOKIE
CREATE TABLE PL_POLICY_BUILDER_CONFIG_COOKIE (
       pbconfig_cookie_id INT NOT NULL AUTO_INCREMENT ,
       policy_id int(8) unsigned NOT NULL default '0',
       flg_cookies int(2) NOT NULL DEFAULT 2,
       flg_enforce_unmodified_cookies int(2) NOT NULL DEFAULT 1,
       max_cookies int(8) NOT NULL DEFAULT 100,
       collapse_cookies bool NOT NULL DEFAULT 1,
       collapse_cookies_occurrences int(8) NOT NULL DEFAULT 10,
       is_inherited int(2) NOT NULL default 0,
       PRIMARY KEY ( pbconfig_cookie_id ) ,
       UNIQUE ( policy_id ),
       FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_BUILDER_CONFIG_FILETYPE
-- POLICY_IMPORT: PLC.PL_POLICY_BUILDER_CONFIG_FILETYPE
-- POLICY_BUILDER: PLC.PL_POLICY_BUILDER_CONFIG_FILETYPE
CREATE TABLE PL_POLICY_BUILDER_CONFIG_FILETYPE (
       pbconfig_filetype_id INT NOT NULL AUTO_INCREMENT ,
       policy_id int(8) unsigned NOT NULL default '0',
       flg_filetypes int(2) NOT NULL DEFAULT 2,
       max_filetypes int(8) NOT NULL DEFAULT 100,
       is_inherited int(2) NOT NULL default 0,
       PRIMARY KEY ( pbconfig_filetype_id ) ,
       UNIQUE ( policy_id ),
       FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_BUILDER_CONFIG_HEADER
-- POLICY_IMPORT: PLC.PL_POLICY_BUILDER_CONFIG_HEADER
-- POLICY_BUILDER: PLC.PL_POLICY_BUILDER_CONFIG_HEADER
CREATE TABLE PL_POLICY_BUILDER_CONFIG_HEADER (
       pbconfig_header_id INT NOT NULL AUTO_INCREMENT ,
       policy_id int(8) unsigned NOT NULL default '0',
       flg_valid_host_names BOOL NOT NULL DEFAULT 1,
       is_inherited int(2) NOT NULL default 0,
       max_hosts int(8) unsigned NOT NULL default 10000,
       PRIMARY KEY ( pbconfig_header_id ) ,
       UNIQUE ( policy_id ),
       FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_BUILDER_CONFIG_PARAMETER
-- POLICY_IMPORT: PLC.PL_POLICY_BUILDER_CONFIG_PARAMETER
-- POLICY_BUILDER: PLC.PL_POLICY_BUILDER_CONFIG_PARAMETER
CREATE TABLE PL_POLICY_BUILDER_CONFIG_PARAMETER (
       pbconfig_parameter_id INT NOT NULL AUTO_INCREMENT ,
       policy_id int(8) unsigned NOT NULL default '0',
       flg_parameters int(2) NOT NULL DEFAULT 2,
       flg_parameters_integer_value BOOL NOT NULL DEFAULT 1,
       max_params int(8) NOT NULL DEFAULT 10000,
       level_parameters ENUM( 'global', 'url' ) NOT NULL DEFAULT 'global',
       flg_dynamic_parameters_hidden bool NOT NULL DEFAULT 0,
       dynamic_parameters_value int(8) NOT NULL DEFAULT 10,
       flg_dynamic_parameters_statistics_forms bool NOT NULL DEFAULT 0,
       flg_dynamic_parameters_statistics_links bool NOT NULL DEFAULT 0,
       collapse_parameters bool NOT NULL DEFAULT 1,
       collapse_parameters_occurrences int(8) NOT NULL DEFAULT 10,
       flg_classify_parameters bool NOT NULL DEFAULT 0,
       is_inherited int(2) NOT NULL default 0,
       PRIMARY KEY ( pbconfig_parameter_id ) ,
       UNIQUE ( policy_id ),
       FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_BUILDER_CONFIG_REDIRECTION_PROTECTION
-- POLICY_IMPORT: PLC.PL_POLICY_BUILDER_CONFIG_REDIRECTION_PROTECTION
-- POLICY_BUILDER: PLC.PL_POLICY_BUILDER_CONFIG_REDIRECTION_PROTECTION
CREATE TABLE PL_POLICY_BUILDER_CONFIG_REDIRECTION_PROTECTION (
       pbconfig_redirection_protection_id INT NOT NULL AUTO_INCREMENT ,
       policy_id int(8) unsigned NOT NULL default '0',
       tighten_redirection_domains tinyint(1) unsigned NOT NULL DEFAULT 1,
       max_redirection_domains int(8) NOT NULL DEFAULT 100,
       is_inherited int(2) NOT NULL default 0,
       PRIMARY KEY ( pbconfig_redirection_protection_id ) ,
       UNIQUE ( policy_id ),
       FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_BUILDER_CONFIG_SERVER_TECHNOLOGIES
-- POLICY_IMPORT: PLC.PL_POLICY_BUILDER_CONFIG_SERVER_TECHNOLOGIES
-- POLICY_BUILDER: PLC.PL_POLICY_BUILDER_CONFIG_SERVER_TECHNOLOGIES
CREATE TABLE PL_POLICY_BUILDER_CONFIG_SERVER_TECHNOLOGIES (
       pbconfig_server_technologies_id INT NOT NULL AUTO_INCREMENT ,
       policy_id int(8) unsigned NOT NULL default '0',
       flg_server_technologies bool NOT NULL DEFAULT 0,
       is_inherited int(2) NOT NULL default 0,
       PRIMARY KEY ( pbconfig_server_technologies_id ) ,
       UNIQUE ( policy_id ),
       FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_BUILDER_CONFIG_SESSIONS_AND_LOGINS
-- POLICY_IMPORT: PLC.PL_POLICY_BUILDER_CONFIG_SESSIONS_AND_LOGINS
-- POLICY_BUILDER: PLC.PL_POLICY_BUILDER_CONFIG_SESSIONS_AND_LOGINS
CREATE TABLE PL_POLICY_BUILDER_CONFIG_SESSIONS_AND_LOGINS (
       pbconfig_sessions_and_logins_id INT NOT NULL AUTO_INCREMENT ,
       policy_id int(8) unsigned NOT NULL default '0',
       flg_learn_login_pages bool NOT NULL DEFAULT 1,
       is_inherited int(2) NOT NULL default 0,
       PRIMARY KEY ( pbconfig_sessions_and_logins_id ) ,
       UNIQUE ( policy_id ),
       FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_BUILDER_CONFIG_URL
-- POLICY_IMPORT: PLC.PL_POLICY_BUILDER_CONFIG_URL
-- POLICY_BUILDER: PLC.PL_POLICY_BUILDER_CONFIG_URL
CREATE TABLE PL_POLICY_BUILDER_CONFIG_URL (
       pbconfig_url_id INT NOT NULL AUTO_INCREMENT ,
       policy_id int(8) unsigned NOT NULL default '0',
       flg_urls int(2) NOT NULL DEFAULT 0,
       max_urls int(8) NOT NULL DEFAULT 10000,
       collapse_urls bool NOT NULL DEFAULT 1,
       collapse_urls_occurrences int(8) NOT NULL DEFAULT 500,
       collapse_urls_depth int(8) NOT NULL DEFAULT 2,
       flg_classify_urls bool NOT NULL DEFAULT 0,
       flg_set_method_override_on_url bool NOT NULL DEFAULT 0,
       flg_websocket_urls tinyint(1) NOT NULL DEFAULT 0,
       max_websocket_urls int(8) NOT NULL DEFAULT 10000,
       flg_classify_websocket_urls bool NOT NULL DEFAULT 0,
       is_inherited int(2) NOT NULL default 0,
       PRIMARY KEY ( pbconfig_url_id ) ,
       UNIQUE ( policy_id ),
       FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_BUILDER_FILETYPES
-- POLICY_IMPORT: PLC.PL_POLICY_BUILDER_FILETYPES
-- POLICY_BUILDER: PLC.PL_POLICY_BUILDER_FILETYPES
CREATE TABLE PL_POLICY_BUILDER_FILETYPES (
       id INT NOT NULL AUTO_INCREMENT ,
       policy_id int(8) unsigned NOT NULL default '0',
       filetype VARCHAR ( 64 ) NOT NULL ,
       PRIMARY KEY ( id ) ,
       FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- POLICY_BUILDER: PLC.PL_POLICY_BUILDER_FILETYPES_DEFAULTS
CREATE TABLE PL_POLICY_BUILDER_FILETYPES_DEFAULTS (
       filetype VARCHAR ( 64 ) NOT NULL ,
       PRIMARY KEY ( filetype ) 
) ENGINE=InnoDB;





-- POLICY_BUILDER: PLC.PL_POLICY_BUILDER_INTERNAL_INFO
CREATE TABLE PL_POLICY_BUILDER_INTERNAL_INFO(
  policy_builder_internal_info_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  internal_info_key VARCHAR(255) NOT NULL default '',
  internal_info_value blob default '',
  PRIMARY KEY (policy_builder_internal_info_id),
  UNIQUE (policy_id, internal_info_key),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_BUILDER_RESPONSE_CODES
-- POLICY_IMPORT: PLC.PL_POLICY_BUILDER_RESPONSE_CODES
-- POLICY_BUILDER: PLC.PL_POLICY_BUILDER_RESPONSE_CODES
CREATE TABLE PL_POLICY_BUILDER_RESPONSE_CODES (
       id INT NOT NULL AUTO_INCREMENT ,
       pbconfig_id int,
       policy_id int(8) unsigned NOT NULL default '0',
       response_code VARCHAR ( 3 ) NOT NULL ,
       PRIMARY KEY ( id ) ,
       FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE,
       FOREIGN KEY (pbconfig_id) references PL_POLICY_BUILDER_CONFIG(pbconfig_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- POLICY_BUILDER: PLC.PL_POLICY_BUILDER_RESPONSE_CODES_DEFAULTS
CREATE TABLE PL_POLICY_BUILDER_RESPONSE_CODES_DEFAULTS (
       response_code VARCHAR ( 3 ) NOT NULL ,
       PRIMARY KEY ( response_code ) 
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.PL_POLICY_CHANGES_LOG
-- POLICY_NONIMPORT: PLC.PL_POLICY_CHANGES_LOG
CREATE TABLE PL_POLICY_CHANGES_LOG (
  policy_changes_log_id bigint(10) auto_increment not null,
  policy_id int(11) NOT NULL default '0',
  modified_table varchar(255) NOT NULL default '',
  modify_action varchar(255) NOT NULL default '',
  user_name varchar(255) NOT NULL default '',
  update_time int(10) NOT NULL default '0',
  PRIMARY KEY  (policy_changes_log_id),
  KEY policy_id (policy_id)
) ENGINE=InnoDB COMMENT='Contain all policy changes before set it as active policy';


-- CONFIG_SYNC: PLC.PL_POLICY_COOKIE_SETTINGS
-- POLICY_IMPORT: PLC.PL_POLICY_COOKIE_SETTINGS
CREATE TABLE PL_POLICY_COOKIE_SETTINGS (
  policy_id int(8) unsigned NOT NULL default '0',
  cookie_len int(8) NOT NULL default '0',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY (policy_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_CSRF
-- POLICY_IMPORT: PLC.PL_POLICY_CSRF
CREATE TABLE PL_POLICY_CSRF(
  csrf_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  flg_is_enabled int(2) NOT NULL default 0,
  flg_is_ssl_only int(2) NOT NULL default '0',
  expiration_time_in_seconds int(8) NOT NULL default '0',
  enforcement_mode enum('enforcing', 'non-enforcing') NOT NULL default 'enforcing',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY (csrf_id),
  UNIQUE KEY (policy_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_CSRF_URLS
-- POLICY_IMPORT: PLC.PL_POLICY_CSRF_URLS
CREATE TABLE PL_POLICY_CSRF_URLS (
    csrf_url_id bigint(20) unsigned NOT NULL auto_increment,
    rest_uuid char(22) NOT NULL default '',
    policy_id int(8) unsigned NOT NULL default '0',
    target_pattern blob NOT NULL default '',
    created_by varchar(128) NOT NULL default 'GUI',
    csrf_url_method int(8)unsigned NOT NULL default '2',
    csrf_url_enforcement_action int(10) unsigned NOT NULL default '2',
    flg_is_pattern int(2) NOT NULL default 1,
    pattern_order int(10) NOT NULL default 0,
    required_parameters  int(10) unsigned NOT NULL default '1',
    last_updated int(10) NOT NULL default '0',
    is_inherited int(2) NOT NULL default 0,
    KEY rest_uuid (rest_uuid),
    UNIQUE (policy_id, target_pattern(255),csrf_url_method),
    PRIMARY KEY (csrf_url_id)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_CSRF_URLS_PARAMETERS
-- POLICY_IMPORT: PLC.PL_POLICY_CSRF_URLS_PARAMETERS
CREATE TABLE PL_POLICY_CSRF_URLS_PARAMETERS (
    policy_id int(8) unsigned NOT NULL default '0',
    csrf_url_id bigint(20) unsigned NOT NULL,
    param_name varbinary(255) NOT NULL default '',
    UNIQUE (csrf_url_id,param_name),
    FOREIGN KEY (csrf_url_id) REFERENCES PL_POLICY_CSRF_URLS(csrf_url_id) ON DELETE CASCADE
) ENGINE=InnoDB;



-- CONFIG_SYNC: PLC.PL_POLICY_CUSTOM_HEADERS
-- POLICY_IMPORT: PLC.PL_POLICY_CUSTOM_HEADERS
CREATE TABLE PL_POLICY_CUSTOM_HEADERS (
   custom_header_id bigint(20) unsigned NOT NULL auto_increment,
   policy_id int(8) unsigned NOT NULL,
   header_name varchar(255) NOT NULL default '',
   is_inherited int(2) NOT NULL default 0,
   PRIMARY KEY  (custom_header_id),
   UNIQUE KEY header_name ( policy_id, header_name),
   FOREIGN KEY (policy_id) REFERENCES PL_POLICIES (id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_EM_TRANSACTIONS
CREATE TABLE PL_POLICY_EM_TRANSACTIONS (
  em_transaction_id int(8) NOT NULL auto_increment,
  policy_id int(8) default NULL,
  PRIMARY KEY (em_transaction_id)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_ENFORCER_SETTINGS
-- POLICY_IMPORT: PLC.PL_POLICY_ENFORCER_SETTINGS
CREATE TABLE PL_POLICY_ENFORCER_SETTINGS (
  policy_id int(8) unsigned NOT NULL default '0',
  state_cookie_http_only_attribute int(2) NOT NULL default 0,
  state_cookie_secure_attribute int(2) NOT NULL default 1,
  state_cookie_same_site_attribute int(2) NOT NULL default 1,
  last_updated int(20),
  is_inherited int(2) NOT NULL default 0,
  rest_uuid char(22) NOT NULL default '',
  PRIMARY KEY (policy_id),
  KEY rest_uuid (rest_uuid),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_GENERAL
-- POLICY_IMPORT: PLC.PL_POLICY_GENERAL
CREATE TABLE PL_POLICY_GENERAL (
  policy_id int(8) unsigned NOT NULL default '0',
  flg_irules int(2) NOT NULL default '0',
  flg_use_dynamic_session_in_url int(2) NOT NULL default '0',
  dynamic_session_pattern varchar(255) NOT NULL default '',
  dynamic_session_description blob,
  path_parameter_handling int(2) NOT NULL default '1',
  flg_mask_sensitive int(2) NOT NULL default '1',
  quarantined_period int(8) NOT NULL default '7',
  flg_enable_correlation tinyint(2) NOT NULL default '1',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY (policy_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_GROUPS
CREATE TABLE PL_POLICY_GROUPS (
  id int(10) NOT NULL auto_increment,
  name varchar(255) NOT NULL default '',
  last_updated int(10) default NULL,
  rest_uuid char(22) NOT NULL default '',
  KEY rest_uuid (rest_uuid),
  UNIQUE (name),
  PRIMARY KEY (id)
) ENGINE=InnoDB COMMENT='';


-- CONFIG_SYNC: PLC.PL_POLICY_GROUPING
CREATE TABLE PL_POLICY_GROUPING (
  id int(10) NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL,
  group_id int(10) NOT NULL,
  PRIMARY KEY (id),
  FOREIGN KEY (policy_id) REFERENCES PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (group_id) REFERENCES PL_POLICY_GROUPS(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


-- CONFIG_SYNC: PLC.PL_POLICY_HEADER_SETTINGS
-- POLICY_IMPORT: PLC.PL_POLICY_HEADER_SETTINGS
CREATE TABLE PL_POLICY_HEADER_SETTINGS (
  policy_id int(8) unsigned NOT NULL default '0',
  http_len int(8) NOT NULL default '0',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY (policy_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_HISTORY
-- POLICY_NONIMPORT: PLC.PL_POLICY_HISTORY
CREATE TABLE PL_POLICY_HISTORY (
  policy_history_id bigint(20) unsigned NOT NULL auto_increment,
  revision int(10) NOT NULL default '0',
  policy_id int(10) NOT NULL default '0',
  from_date int(10) NOT NULL default '0',
  to_date int(10) NOT NULL default '0',
  validation_report mediumtext,
  username varchar(255) NOT NULL default '',
  policy_version_time int(11),
  policy_version_device_name varchar(255),
  policy_version_policy_name varchar(255),
  policy_version_last_change blob,
  rest_uuid char(22) NOT NULL default '',
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY  (policy_history_id)
) ENGINE=InnoDB COMMENT='Contain policy revision indexes and from and to active dates';


-- POLICY_NONIMPORT: PLC.PL_POLICY_LOCK
CREATE TABLE PL_POLICY_LOCK (
  policy_id int(8) NOT NULL default '0',
  user_name varchar(255) NOT NULL default '',
  last_activity int(10) unsigned NOT NULL default '0',
  UNIQUE KEY user_name (policy_id)
) ENGINE=InnoDB COMMENT='Contain data that serve "policy lock from user" mechanism';


-- CONFIG_SYNC: PLC.PL_POLICY_NEGSIG_ATTRIBUTES
-- POLICY_IMPORT: PLC.PL_POLICY_NEGSIG_ATTRIBUTES
CREATE TABLE PL_POLICY_NEGSIG_ATTRIBUTES (
  policy_id int(8) unsigned NOT NULL default '0',
  flg_quarantine_signatures int(2) NOT NULL default 1,
  place_sigs_in_staging  tinyint(1) default '1',
  is_inherited int(2) NOT NULL default 0,
  min_accuracy_for_auto_added_signatures tinyint(1) NOT NULL default 2,
  attack_signature_false_positive_mode int(10) unsigned NOT NULL default '1',
  PRIMARY KEY (policy_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_NEGSIG_REQUIREMENTS
-- POLICY_IMPORT: PLC.PL_POLICY_NEGSIG_REQUIREMENTS
CREATE TABLE PL_POLICY_NEGSIG_REQUIREMENTS (
  id int(8) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  sig_tag varchar(254) NOT NULL default '',
  min_revision_datetime int(10),
  max_revision_datetime int(10),
  rest_uuid char(22) NOT NULL default '',
  last_updated int(10) NOT NULL default 0,
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY (id),
  UNIQUE (policy_id, sig_tag),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_NEGSIG_SETS
-- POLICY_IMPORT: PLC.PL_POLICY_NEGSIG_SETS
CREATE TABLE PL_POLICY_NEGSIG_SETS (
  policy_id int(8) unsigned NOT NULL default '0',
  set_id bigint(20) unsigned NOT NULL,
  flg_learn tinyint(1) default 1,
  flg_alarm tinyint(1) default 1,
  flg_reject tinyint(1) default 1,
  rest_uuid char(22) default '',
  last_updated int(10) NOT NULL default 0,  
  is_inherited int(2) NOT NULL default 0,
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY (policy_id,set_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (set_id) references NEGSIG_SETS(set_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_NEGSIG_SIGNATURES
-- POLICY_IMPORT: PLC.PL_POLICY_NEGSIG_SIGNATURES
CREATE TABLE PL_POLICY_NEGSIG_SIGNATURES (
  policy_id int(8) unsigned NOT NULL default '0',
  sig_id bigint(20) unsigned NOT NULL,
  flg_disabled tinyint(1) NOT NULL default '0',
  flg_quarantined tinyint(1) NOT NULL default '1',
  rest_uuid char(22) default '',
  last_updated int(10) NOT NULL default 0,
  previous_enforced_rule blob NOT NULL default '',
  previous_enforced_rule_md5 varchar(32) NOT NULL default '',
  is_inherited int(2) NOT NULL default 0,
  KEY rest_uuid (policy_id, rest_uuid),
  KEY previous_enforced_rule_md5 (previous_enforced_rule_md5),
  PRIMARY KEY (policy_id,sig_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (sig_id) references NEGSIG_SIGNATURES(sig_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_OPEN_API_FILES
-- POLICY_IMPORT: PLC.PL_POLICY_OPEN_API_FILES
CREATE TABLE PL_POLICY_OPEN_API_FILES (
  id int(8) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  filename varchar(255) binary NOT NULL default '',
  upload_datetime int(10) NOT NULL default '0',
  rest_uuid char(22) NOT NULL default '',
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY (id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;

-- CONFIG_SYNC: PLC.PL_POLICY_PARENT
CREATE TABLE PL_POLICY_PARENT (
  policy_id int(8) unsigned NOT NULL default '0',
  parent_policy_id int(8) unsigned NOT NULL default '0',
  PRIMARY KEY  (policy_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


-- CONFIG_SYNC: PLC.PL_POLICY_PREREQUISITE_ATTRIBUTES 
-- POLICY_IMPORT: PLC.PL_POLICY_PREREQUISITE_ATTRIBUTES 
CREATE TABLE PL_POLICY_PREREQUISITE_ATTRIBUTES( 
  prerequisite_attribute_id bigint(20) unsigned NOT NULL auto_increment, 
  policy_id int(8) unsigned NOT NULL default '0',
  expiration_period int(2) NOT NULL default '0',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY (prerequisite_attribute_id),
  UNIQUE (policy_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE 
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_RESPONSE_SCRUBBING_URLS
-- POLICY_IMPORT: PLC.PL_POLICY_RESPONSE_SCRUBBING_URLS
CREATE TABLE PL_POLICY_RESPONSE_SCRUBBING_URLS (
    response_scrubbing_url_id bigint(20) unsigned NOT NULL auto_increment,
    policy_id int(8) unsigned NOT NULL default '0',
    target_pattern blob NOT NULL default '',
    UNIQUE (policy_id, target_pattern(255)),
    PRIMARY KEY (response_scrubbing_url_id)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_THREAT_CAMPAIGN_ATTRIBUTES
-- POLICY_IMPORT: PLC.PL_POLICY_THREAT_CAMPAIGN_ATTRIBUTES
CREATE TABLE PL_POLICY_THREAT_CAMPAIGN_ATTRIBUTES (
  policy_id int(8) unsigned NOT NULL default '0',
  flg_quarantine_threat_campaigns tinyint(1) NOT NULL default 0,
  threat_campaign_quarantined_period int(8) unsigned NOT NULL default 1,
  is_inherited tinyint(1) NOT NULL default 0,
  PRIMARY KEY (policy_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_POLICY_XFF
-- POLICY_IMPORT: PLC.PL_POLICY_XFF
CREATE TABLE PL_POLICY_XFF(
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  flg_is_trust_xff int(2) NOT NULL default '0',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY (id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_PREREQUISITE_OBJECT_TARGETS
-- POLICY_IMPORT: PLC.PL_PREREQUISITE_OBJECT_TARGETS
CREATE TABLE PL_PREREQUISITE_OBJECT_TARGETS (
    id bigint(20) unsigned NOT NULL auto_increment,
    policy_id int(8) unsigned NOT NULL default '0',
    target_pattern blob NOT NULL,
    PRIMARY KEY (id),
    UNIQUE  (policy_id, target_pattern(255))
) ENGINE=InnoDB COMMENT='Pre-requisite objects';


-- CONFIG_SYNC: PLC.PL_REDIRECTION_DOMAINS
-- POLICY_IMPORT: PLC.PL_REDIRECTION_DOMAINS
CREATE TABLE PL_REDIRECTION_DOMAINS (
  redirection_domain_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default 0,
  domain_name varchar(255) NOT NULL default '',
  flg_include_subdomains bool NOT NULL default FALSE,
  flg_is_pattern int(2) NOT NULL DEFAULT 0,
  pattern_order int(11) DEFAULT NULL,
  flg_tightening int(2) NOT NULL DEFAULT 0,
  last_tightening_time int(10) DEFAULT NULL,
  last_updated int(10) DEFAULT NULL,
  created_by varchar(128) NOT NULL DEFAULT 'GUI',
  rest_uuid char(22) NOT NULL default '',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY (redirection_domain_id),
  UNIQUE KEY (policy_id, domain_name),
  KEY rest_uuid (rest_uuid),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_REDIRECTION_PROTECTION
-- POLICY_IMPORT: PLC.PL_REDIRECTION_PROTECTION
CREATE TABLE PL_REDIRECTION_PROTECTION (
  policy_id int(8) unsigned NOT NULL default 0,
  flg_enabled bool NOT NULL default TRUE,
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY (policy_id),
  FOREIGN KEY (policy_id) REFERENCES PL_POLICIES (id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_REQUEST_LOGGERS
-- POLICY_IMPORT: PLC.PL_REQUEST_LOGGERS
CREATE TABLE PL_REQUEST_LOGGERS (
  request_logger_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  request_logger_name varchar(255) NOT NULL default '',
  destination varchar(255) NOT NULL default '',
  format_type int(10) NOT NULL default 0,
  format_string blob NOT NULL default '',
  last_updated int(20),
  rest_uuid char(22) NOT NULL default '',
  max_message_size int(10) NOT NULL default 65536,
  PRIMARY KEY (request_logger_id),
  KEY rest_uuid (rest_uuid),
  UNIQUE (policy_id,request_logger_name),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_REQUEST_LOGGERS_FILTERS
-- POLICY_IMPORT: PLC.PL_REQUEST_LOGGERS_FILTERS
CREATE TABLE PL_REQUEST_LOGGERS_FILTERS (
  request_logger_filter_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  request_logger_id bigint(20) unsigned NOT NULL,
  field_name varchar(255) NOT NULL default '',
  field_values mediumblob,
  PRIMARY KEY (request_logger_filter_id),
  FOREIGN KEY (policy_id) REFERENCES PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (request_logger_id) references PL_REQUEST_LOGGERS(request_logger_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_RESPONSE_SCRUBBING
-- POLICY_IMPORT: PLC.PL_RESPONSE_SCRUBBING
CREATE TABLE PL_RESPONSE_SCRUBBING (
  policy_id int(8) unsigned NOT NULL,
  flg_is_enabled int(2) NOT NULL default 0,
  flg_check_for_credit_card tinyint(1) NOT NULL default '0',
  ccn_exposed_len int(2) NOT NULL default '4',
  flg_check_for_ssn tinyint(1) NOT NULL default '0',
  ssn_exposed_len int(2) NOT NULL default '4',
  flg_mask_data tinyint(1) NOT NULL default '0',
  flg_check_custom_patterns tinyint(1) NOT NULL default '0',
  flg_check_exception_patterns tinyint(1) NOT NULL default '0',
  enforcement_mode enum("enforce_all_except_url_list","enforce_only_url_list") default "enforce_all_except_url_list",
  flg_check_file_content tinyint(1) NOT NULL default '0',  
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY  (policy_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_RESPONSE_SCRUBBING_EXCEPTIONS
-- POLICY_IMPORT: PLC.PL_RESPONSE_SCRUBBING_EXCEPTIONS
CREATE TABLE PL_RESPONSE_SCRUBBING_EXCEPTIONS (
  policy_id int(8) unsigned NOT NULL,
  pattern varbinary(255) NOT NULL default '',
  PRIMARY KEY  (policy_id,pattern),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;



-- CONFIG_SYNC: PLC.PL_RESPONSE_SCRUBBING_PATTERNS
-- POLICY_IMPORT: PLC.PL_RESPONSE_SCRUBBING_PATTERNS
CREATE TABLE PL_RESPONSE_SCRUBBING_PATTERNS (
  policy_id int(8) unsigned NOT NULL,
  pattern varbinary(255) NOT NULL default '0',
  PRIMARY KEY  (policy_id,pattern),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_REVOKE_OBJECTS
-- POLICY_IMPORT: PLC.PL_REVOKE_OBJECTS
CREATE TABLE PL_REVOKE_OBJECTS (
    id bigint(20) unsigned NOT NULL auto_increment,
    policy_id int(8) unsigned NOT NULL default '0',
    revoke_object_id bigint(20) unsigned NOT NULL,
    request_contains blob default '',
    request_omits blob default '',
    PRIMARY KEY  (id),
    UNIQUE  (policy_id, revoke_object_id),
    FOREIGN KEY  (revoke_object_id) REFERENCES PL_OBJECTS(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Join table which identifies revoke objects';


-- CONFIG_SYNC: PLC.PL_SCANNER_CONFIG
-- POLICY_IMPORT: PLC.PL_SCANNER_CONFIG
-- POLICY_EXPORT_FLAG: PLC.PL_SCANNER_CONFIG(include_scanner_tables)
CREATE TABLE PL_SCANNER_CONFIG(
  scanner_config_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  scanner_type varchar(128) NOT NULL default '',
  api_key blob default '',
  scanner_site_name varchar(128) NOT NULL default '',
  scanner_auth_data_1 varchar(128) NOT NULL default '',
  scanner_auth_data_2 varchar(128) NOT NULL default '',
  scan_requested_time int(8) NOT NULL default '0',
  flg_is_api_key_final int(2) NOT NULL default '0',
  flg_is_api_key_encrypted int(2) NOT NULL default '0',
  scan_load_time int(8) NOT NULL default '0',
  scan_status int(2) NOT NULL default '3',
  flg_bidir_enabled bool NOT NULL default FALSE,
  sync_frequency tinyint(1) unsigned NOT NULL default 1,
  sync_hour int(8) NOT NULL default 1,
  sync_weekday int(8) NOT NULL default 0,
  sync_day_of_month int(8) NOT NULL default 1,
  rule_loosen_time_untrusted int(8) NOT NULL default 3600,
  rule_loosen_time_trusted int(8) NOT NULL default 0,
  rule_loosen_time_untrusted_max int(8) NOT NULL default 604800,
  rule_loosen_time_trusted_max int(8) NOT NULL default 604800,
  rule_loosen_sources_untrusted int(8) NOT NULL default 20,
  rule_loosen_sources_trusted int(8) NOT NULL default 1,
  flg_all_trusted_ips bool NOT NULL default FALSE,
  flg_learn_from_responses bool NOT NULL default TRUE,
  last_scheduled_sync_time int(8) NOT NULL default '0',
  PRIMARY KEY (scanner_config_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE,
  UNIQUE (policy_id)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_SCANNER_CONFIG_RESPONSE_CODES
-- POLICY_IMPORT: PLC.PL_SCANNER_CONFIG_RESPONSE_CODES
-- POLICY_EXPORT_FLAG: PLC.PL_SCANNER_CONFIG_RESPONSE_CODES(include_scanner_tables)
CREATE TABLE PL_SCANNER_CONFIG_RESPONSE_CODES (
   scanner_config_id bigint(20) unsigned NOT NULL DEFAULT 0,
   policy_id int(8) unsigned NOT NULL DEFAULT 0,
   response_code varchar(3) NOT NULL DEFAULT '',
   UNIQUE KEY (scanner_config_id, response_code),
   FOREIGN KEY (scanner_config_id) REFERENCES PL_SCANNER_CONFIG(scanner_config_id) ON DELETE CASCADE,
   FOREIGN KEY (policy_id) REFERENCES PL_POLICIES (id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- SCANNER_CONFIG: PLC.PL_SCANNER_CONFIG_RESPONSE_CODES_DEFAULTS
CREATE TABLE PL_SCANNER_CONFIG_RESPONSE_CODES_DEFAULTS (
       response_code VARCHAR ( 3 ) NOT NULL ,
       PRIMARY KEY ( response_code ) 
) ENGINE=InnoDB;





-- POLICY_IMPORT: PLC.PL_SCANNER_SITE_MAP_TRANSMISSION
CREATE TABLE PL_SCANNER_SITE_MAP_TRANSMISSION (
  transmission_id int(8) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL DEFAULT 0,
  update_time int(10) unsigned NOT NULL DEFAULT 0,
  action tinyint(1) unsigned NOT NULL DEFAULT 1,
  status tinyint(1) unsigned NOT NULL DEFAULT 1,
  flg_update_incremental bool NOT NULL DEFAULT TRUE,
  sent_transaction_count int(8) NOT NULL DEFAULT 0,
  msg text NOT NULL DEFAULT '',
  urls_in_memory int(8) NOT NULL DEFAULT 0,
  urls_satisfied int(8) NOT NULL DEFAULT 0,
  urls_reported int(8) NOT NULL DEFAULT 0,
  params_in_memory int(8) NOT NULL DEFAULT 0,
  params_satisfied int(8) NOT NULL DEFAULT 0,
  params_reported int(8) NOT NULL DEFAULT 0,
  rest_uuid char(22) NOT NULL default '',
  PRIMARY KEY (transmission_id),
  KEY rest_uuid (policy_id, rest_uuid)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_SCANNER_VULNS
-- POLICY_IMPORT: PLC.PL_SCANNER_VULNS
-- POLICY_EXPORT_FLAG: PLC.PL_SCANNER_VULNS(include_scanner_tables)
CREATE TABLE PL_SCANNER_VULNS(
  vuln_id bigint(20) unsigned NOT NULL auto_increment,
  scanner_vuln_id varchar(128) NOT NULL default '',
  scanner_attack_vector_id bigint(20) unsigned NOT NULL,
  policy_id int(8) unsigned NOT NULL default '0',
  attack_type_id bigint(20) unsigned,
  asm_vuln_status enum('pending','handled','ignored','handled-staging') default 'pending',
  scanner_vuln_status enum('open','closed', 'mitigated') default 'open',
  threat enum ('urgent', 'critical', 'high', 'medium', 'low', 'info') default 'medium',
  severity enum ('urgent', 'critical', 'high', 'medium', 'low', 'info') default 'medium',
  score int(2) unsigned NOT NULL default '3',
  opened_time int(10) default NULL,
  closed_time int(10) default NULL,
  resolve_time int(10) default NULL,
  load_time int(10) default NULL,
  retest_status enum('none', 'retest_requested', 'manual_retest', 'retest_temporarily_unavailable', 'retest_refused') default 'none',
  flg_retest_local int (2) NOT NULL default '0',
  scanner_vuln_name varchar(128) NOT NULL default '',
  scanner_vuln_display_name varchar(255) NOT NULL default '',
  request_url blob default '',
  parameter varbinary(255) default '',
  attack_vector_status enum('open','closed','mitigated') default 'open',
  object_id bigint(20) unsigned,
  param_attrib_id bigint(20) unsigned,
  tested_time varchar(255) NOT NULL default '0', 
  flg_is_resolvable int (2) NOT NULL default '0',
  user_notes blob,
  cookie blob,
  cookie_id bigint(20) unsigned,
  valid_host_name_id bigint(20) unsigned,
  rest_uuid char(22) NOT NULL default '',
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY (vuln_id),
  FOREIGN KEY (attack_type_id) references NEGSIG_ATTACK_TYPES(attack_type_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


CREATE TABLE PL_SECTION_DEFAULTS (
    section_type int NOT NULL,
    parent_inheritance_status tinyint NOT NULL default 3, /* None */
    child_inheritance_status tinyint NOT NULL default 4, /* None */
    user_comment text NOT NULL default '',
    is_read tinyint NOT NULL default 0,
    rest_uuid char(22) NOT NULL default '',
    PRIMARY KEY (section_type)
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.PL_SECTIONS
-- POLICY_IMPORT: PLC.PL_SECTIONS
CREATE TABLE PL_SECTIONS (
    section_id bigint(20) unsigned NOT NULL auto_increment,
    policy_id int(8) unsigned NOT NULL,
    section_type int NOT NULL,
    parent_inheritance_status tinyint NOT NULL,
    child_inheritance_status tinyint NOT NULL,
    rest_uuid char(22) NOT NULL default '',
    last_updated int(10) NOT NULL default 0,
    user_comment text NOT NULL default '',
    is_read tinyint NOT NULL default 0,
    KEY rest_uuid (policy_id, rest_uuid),
    PRIMARY KEY (section_id),
    UNIQUE (policy_id, section_type),
    FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


CREATE TABLE PL_SECURITY_LEVEL_NAMES (
  security_level_id int(8) NOT NULL default '0',
  name varchar(255) NOT NULL default '',
  PRIMARY KEY  (security_level_id),
  UNIQUE KEY name (name)
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.PL_SESSION_AWARENESS_DATA_POINT
-- POLICY_IMPORT: PLC.PL_SESSION_AWARENESS_DATA_POINT
CREATE TABLE PL_SESSION_AWARENESS_DATA_POINT (
  data_point_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  data_point_action enum('track_all', 'block_illegal', 'block_all')  NOT NULL,
  data_point_scope enum('user', 'session', 'ip', 'device')  NOT NULL,
  data_point_value varbinary(255) NOT NULL default '',
  create_time int(10)  NOT NULL default '0',
  rest_uuid char(22) NOT NULL default '',
  is_inherited int(2) NOT NULL default 0,
  last_updated int(10) NOT NULL default '0',
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY  (data_point_id),
  UNIQUE (policy_id, data_point_action, data_point_scope, data_point_value),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_SESSION_AWARENESS_LOGIN_OBJECTS
-- POLICY_IMPORT: PLC.PL_SESSION_AWARENESS_LOGIN_OBJECTS
CREATE TABLE PL_SESSION_AWARENESS_LOGIN_OBJECTS (
    id bigint(20) unsigned NOT NULL auto_increment,
    policy_id int(8) NOT NULL default '0',
    object_id bigint(20) unsigned NOT NULL,
    PRIMARY KEY (id),
    UNIQUE (policy_id, object_id),
    FOREIGN KEY (object_id) REFERENCES PL_LOGIN_OBJECTS(object_id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Pre-requisite objects with session awareness';



-- CONFIG_SYNC: PLC.PL_SESSION_AWARENESS_SETTINGS
-- POLICY_IMPORT: PLC.PL_SESSION_AWARENESS_SETTINGS
CREATE TABLE PL_SESSION_AWARENESS_SETTINGS (
  session_awareness_settings_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  flg_session_awareness_on tinyint(1) NOT NULL default '0',
  sliding_window_lifetime int(4)  NOT NULL default '900',
  sid_track_all_threshold int(4)  NOT NULL default '5',
  sid_block_illegal_threshold int(4)  NOT NULL default '5',
  sid_block_all_threshold int(4)  NOT NULL default '20',
  ip_track_all_threshold int(4)  NOT NULL default '15',
  ip_block_illegal_threshold int(4)  NOT NULL default '15',
  ip_block_all_threshold int(4)  NOT NULL default '60',
  user_track_all_threshold int(4)  NOT NULL default '5',
  user_block_illegal_threshold int(4)  NOT NULL default '5',
  user_block_all_threshold int(4)  NOT NULL default '20',
  device_track_all_threshold int(4)  NOT NULL default '7',
  device_block_illegal_threshold int(4)  NOT NULL default '7',
  device_block_all_threshold int(4)  NOT NULL default '30',
  track_all_period int(4)  NOT NULL default '600',
  block_illegal_period int(4)  NOT NULL default '600',
  flg_sid_track_all_threshold_enabled tinyint(1) NOT NULL default '0',
  flg_sid_block_illegal_threshold_enabled tinyint(1) NOT NULL default '0',
  flg_sid_block_all_threshold_enabled tinyint(1) NOT NULL default '0',
  flg_ip_track_all_threshold_enabled tinyint(1) NOT NULL default '0',
  flg_ip_block_illegal_threshold_enabled tinyint(1) NOT NULL default '0',
  flg_ip_block_all_threshold_enabled tinyint(1) NOT NULL default '0',
  flg_user_track_all_threshold_enabled tinyint(1) NOT NULL default '0',
  flg_user_block_illegal_threshold_enabled tinyint(1)  NOT NULL default '0',
  flg_user_block_all_threshold_enabled tinyint(1) NOT NULL default '0',
  flg_violations_actions_enabled tinyint(1)  NOT NULL default '1',
  flg_device_track_all_threshold_enabled tinyint(1) NOT NULL default '0',
  flg_device_block_illegal_threshold_enabled tinyint(1)  NOT NULL default '0',
  flg_device_block_all_threshold_enabled tinyint(1) NOT NULL default '0',
  block_all_period int(4)  NOT NULL default '600',
  flg_check_block_all_period tinyint(1)  NOT NULL default '1',
  flg_block_only_authenticated tinyint(1)  NOT NULL default '0',
  flg_session_hijacking tinyint(1) NOT NULL default '0',
  application_username_type int(4) NOT NULL default '4',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY  (session_awareness_settings_id),
  UNIQUE KEY policy_id (policy_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


CREATE TABLE PL_SESSION_AWARENESS_VIOLATIONS_DEFAULTS (
  viol_index int(10) NOT NULL,
  PRIMARY KEY (viol_index)
) ENGINE=InnoDB;






-- CONFIG_SYNC: PLC.PL_SSRF_HOSTS
-- POLICY_IMPORT: PLC.PL_SSRF_HOSTS
CREATE TABLE PL_SSRF_HOSTS (
  ssrf_host_id int(8) unsigned NOT NULL auto_increment,
  policy_id int(10) unsigned NOT NULL default '0',
  host varchar(254) NOT NULL default '',
  rest_uuid char(22) NOT NULL default '',
  last_updated int(10) NOT NULL default 0,
  action_type int(10) NOT NULL default '1',
  pattern_order int(11) DEFAULT NULL,
  flg_is_pattern int(2) NOT NULL DEFAULT 1,
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY (ssrf_host_id),
  UNIQUE (policy_id, host),
  FOREIGN KEY (policy_id) REFERENCES PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_STATIC_PARAMS
-- POLICY_IMPORT: PLC.PL_STATIC_PARAMS
CREATE TABLE PL_STATIC_PARAMS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  param_attrib_id bigint(20) unsigned NOT NULL default '0',
  value varbinary(500) NOT NULL,
  PRIMARY KEY  (id),
  KEY policy_id (policy_id),
  KEY param_attrib_id (param_attrib_id,value(8)),
  FOREIGN KEY (param_attrib_id) references PL_PARAM_ATTRIBUTES(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Contain static parameters values';


-- CONFIG_SYNC: PLC.PL_SUGGESTIONS
-- POLICY_IMPORT: PLC.PL_SUGGESTIONS
-- EXPORT_WHERE_CLAUSE: PLC.PL_SUGGESTIONS "suggestion_status = 4"
CREATE TABLE PL_SUGGESTIONS (
  suggestion_id bigint(20) unsigned NOT NULL auto_increment,
  suggestion_key varbinary(127) NOT NULL,
  policy_id int(8) NOT NULL default 0,
  element_type smallint NOT NULL default 0,
  element_name blob,
  element_kind varchar(255),
  description blob,
  element mediumblob,
  matched_wildcard_element_name blob,
  matched_wildcard_element mediumblob,
  user_name varchar(255),
  suggestion_score smallint NOT NULL default 0,
  suggestion_status smallint NOT NULL default 1,
  suggestion_action smallint NOT NULL default 1,
  suggestion_reason smallint NOT NULL default 1,
  viol_index int(10),
  refinement_id int(10),
  is_acceptable_on_microservice tinyint(1) NOT NULL default 0,
  occurrence_count int(10) NOT NULL default 0,
  trusted_ip_count int(10) NOT NULL default 0,
  untrusted_ip_count int(10) NOT NULL default 0,
  trusted_session_count int(10) NOT NULL default 0,
  untrusted_session_count int(10) NOT NULL default 0,
  trusted_sources_count int(10) NOT NULL default 0,
  untrusted_sources_count int(10) NOT NULL default 0,
  user_comment blob,
  first_occurrence_time int(10) NOT NULL default 0,
  last_occurrence_time int(10) NOT NULL default 0,
  average_violation_rating double NOT NULL default 0,
  is_read tinyint(1) NOT NULL default 0,
  is_automatically_learnable tinyint(1) NOT NULL default 0,
  is_tightening_suggestion tinyint(1) NOT NULL default 0,
  sig_id bigint(20) unsigned NOT NULL default 0,
  metachar int(8) unsigned,
  element_rest_uuid char(22) NOT NULL default '',
  matched_wildcard_element_rest_uuid char(22) NOT NULL default '',
  inheritance_acceptability tinyint(1) NOT NULL default 1,
  suggesting_child_policy_count int(10) NOT NULL default 0,
  top_scoring_suggesting_child_policy_count int(10) NOT NULL default 0,
  section_type int(10) NOT NULL default 0,
  rest_uuid char(22) NOT NULL default '',
  KEY rest_uuid (policy_id, rest_uuid),
  KEY policy_status (policy_id, suggestion_status, sig_id),
  KEY suggestion_status (suggestion_status),
  KEY (policy_id, element_type, element_rest_uuid),
  KEY (policy_id, element_type, matched_wildcard_element_rest_uuid),
  KEY (policy_id, element_kind),
  KEY (policy_id, section_type),
  UNIQUE suggestion_key (policy_id, suggestion_key),
  PRIMARY KEY  (suggestion_id)
) ENGINE=InnoDB COMMENT='';


CREATE TABLE PL_SUGGESTION_VIOLATION_RATING_COUNTS (
  id bigint(20) unsigned NOT NULL auto_increment,
  suggestion_id bigint(20) unsigned NOT NULL,
  violation_rating int(2) unsigned NOT NULL,
  occurrence_count int(10) unsigned NOT NULL,
  PRIMARY KEY  (id),
  FOREIGN KEY (suggestion_id) references PL_SUGGESTIONS(suggestion_id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


CREATE TABLE PL_SUGGESTION_SUPPORT_IDS (
  id bigint(20) unsigned NOT NULL auto_increment,
  suggestion_id bigint(20) unsigned NOT NULL,
  support_id bigint(20) unsigned NOT NULL,
  PRIMARY KEY  (id),
  FOREIGN KEY (suggestion_id) references PL_SUGGESTIONS(suggestion_id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


CREATE TABLE PL_SUGGESTION_MICROSERVICE_OCCURRENCES (
  id bigint(20) unsigned NOT NULL auto_increment,
  suggestion_id bigint(20) unsigned NOT NULL,
  microservice_id bigint(20) unsigned NOT NULL,
  occurrence_count int(10) unsigned NOT NULL,
  PRIMARY KEY  (id),
  FOREIGN KEY (microservice_id) references PL_MICROSERVICES(microservice_id) ON DELETE CASCADE,
  FOREIGN KEY (suggestion_id) references PL_SUGGESTIONS(suggestion_id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';



CREATE TABLE PL_SUGGESTION_CHILD_POLICIES (
  id bigint(20) unsigned NOT NULL auto_increment,
  suggestion_id bigint(20) unsigned NOT NULL,
  child_policy_id int(8) NOT NULL default 0,
  PRIMARY KEY  (id),
  FOREIGN KEY (suggestion_id) references PL_SUGGESTIONS(suggestion_id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


CREATE TABLE PL_SUGGESTION_ACCEPTED_MICROSERVICES (
  id bigint(20) unsigned NOT NULL auto_increment,
  suggestion_id bigint(20) unsigned NOT NULL,
  microservice_id bigint(20) unsigned NOT NULL,
  PRIMARY KEY  (id),
  FOREIGN KEY (microservice_id) references PL_MICROSERVICES(microservice_id) ON DELETE CASCADE,
  FOREIGN KEY (suggestion_id) references PL_SUGGESTIONS(suggestion_id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';



-- CONFIG_SYNC: PLC.PL_THREAT_RATING_SETTINGS
-- POLICY_IMPORT: PLC.PL_THREAT_RATING_SETTINGS
CREATE TABLE PL_THREAT_RATING_SETTINGS (
  threat_rating_settings_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  aggregation_strategy int(4) NOT NULL default '1',
  flg_machine_learning_enabled tinyint(1) NOT NULL default '0',
  machine_learning_weight double NOT NULL default 0,
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY (threat_rating_settings_id),
  UNIQUE KEY policy_id (policy_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


CREATE TABLE PL_THREAT_RATING_SETTINGS_DEFAULTS (
  aggregation_strategy int(4) NOT NULL default '1',
  flg_machine_learning_enabled tinyint(1) NOT NULL default '0',
  machine_learning_weight double NOT NULL default 0
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.PL_VALID_HOST_NAMES
-- POLICY_IMPORT: PLC.PL_VALID_HOST_NAMES
CREATE TABLE PL_VALID_HOST_NAMES(
  valid_host_name_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  host_name varchar(254) NOT NULL default '',
  flg_include_subdomains int(2) NOT NULL default '0',
  created_by varchar(128) NOT NULL default 'GUI',
  rest_uuid char(22) NOT NULL default '',
  is_inherited int(2) NOT NULL default 0,
  last_updated int(10) NOT NULL default '0',
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY (valid_host_name_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE,
  UNIQUE KEY policy_id (policy_id, host_name)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_WA_WEB_APPLICATION
-- POLICY_IMPORT: PLC.PL_WA_WEB_APPLICATION
CREATE TABLE PL_WA_WEB_APPLICATION (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  wa_web_application char(100) NOT NULL default '',
  PRIMARY KEY  (id)
) ENGINE=InnoDB;


-- POLICY_IMPORT: PLC.PL_WEBHOOKS
-- CONFIG_SYNC: PLC.PL_WEBHOOKS
CREATE TABLE PL_WEBHOOKS (
  webhook_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  trigger_event  int(11) NOT NULL default '1',
  webhook_url varchar(512) NOT NULL default '',
  content_type varchar(256) NOT NULL default '',
  body varchar(1024) NOT NULL default '',
  rest_uuid varchar(22) NOT NULL default '',
  last_updated int(10) NOT NULL default 0,
  webhook_name varchar(256) NOT NULL default '',
  PRIMARY KEY (webhook_id),
  KEY rest_uuid (policy_id, rest_uuid),
  UNIQUE (policy_id, webhook_name),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
) ENGINE=InnoDB;

-- CONFIG_SYNC: PLC.PL_WEBSOCKET_URLS
-- POLICY_IMPORT: PLC.PL_WEBSOCKET_URLS
CREATE TABLE PL_WEBSOCKET_URLS (
  websocket_url_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default 0,
  protocol int(2) NOT NULL default 0,
  uri blob NOT NULL,
  description blob,
  flg_is_pattern tinyint(2) NOT NULL default 0,
  pattern_order int(2),
  flg_tightening tinyint(2) NOT NULL default 0,
  last_tightening_time int(10) NULL default NULL,
  flg_check_websocket_url_metachar tinyint(2) NOT NULL default 1,
  user_config_level enum('basic', 'advanced') NOT NULL default 'basic',
  flg_is_staging tinyint(4) NOT NULL default 0,
  staged_since int(10) default NULL,
  last_updated int(10) default NULL,
  flg_is_allowed tinyint(2) NOT NULL default 1,
  created_by varchar(128) NOT NULL default 'GUI',
  flg_wildcard_includes_slash tinyint(2) NOT NULL default 1,
  flg_enable_cors_enforcement tinyint(2) NOT NULL default 0,
  flg_allow_cors tinyint(2) NOT NULL default 1,
  allowed_origins_enforcement_mode tinyint(2) NOT NULL default 1,
  websocket_extension tinyint(2) NOT NULL default 3,
  flg_websocket_message_format_text tinyint(2) NOT NULL default 1,
  flg_websocket_message_format_json tinyint(2) NOT NULL default 0,
  flg_websocket_message_format_binary tinyint(2) NOT NULL default 0,
  message_max_binary_size int(10) NOT NULL default 10000,
  message_max_frame_size int(10) NOT NULL default 10000,
  message_max_frames int(10) NOT NULL default 100,
  websocket_json_profile_id bigint(20) unsigned,
  websocket_text_profile_id bigint(20) unsigned,
  flg_in_classification tinyint(2) NOT NULL default 0,
  rest_uuid char(22) NOT NULL default '',
  flg_check_payload tinyint(2) NOT NULL default 1,
  flg_check_message_max_binary_size tinyint(2) NOT NULL default 1,
  flg_check_message_max_frame_size tinyint(2) NOT NULL default 1,
  flg_check_message_max_frames tinyint(2) NOT NULL default 1,
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY  (websocket_url_id),
  UNIQUE websocket_url (policy_id, uri(500), protocol),
  KEY rest_uuid (policy_id, rest_uuid)
) ENGINE=InnoDB COMMENT=' Contain basic config. & data about WebSocket URLs' AUTO_INCREMENT=1;


-- CONFIG_SYNC: PLC.PL_WEBSOCKET_URL_METACHARS
-- POLICY_IMPORT: PLC.PL_WEBSOCKET_URL_METACHARS
CREATE TABLE PL_WEBSOCKET_URL_METACHARS (
  url_metachars_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  websocket_url_id bigint(20) unsigned NOT NULL default '0',
  metachar int(8) unsigned NOT NULL default '0',
  flg_is_allowed tinyint(2) NOT NULL default '1',
  is_inherited int(2) NOT NULL default 0,
  PRIMARY KEY (url_metachars_id),
  KEY policy_id (policy_id),
  UNIQUE param_attrib_id (websocket_url_id,metachar),
  FOREIGN KEY (websocket_url_id) references PL_WEBSOCKET_URLS(websocket_url_id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='Contain data about WebSocket URL metachars' AUTO_INCREMENT=1;


-- CONFIG_SYNC: PLC.PL_WEBSOCKET_URL_ALLOWED_ORIGINS
-- POLICY_IMPORT: PLC.PL_WEBSOCKET_URL_ALLOWED_ORIGINS
CREATE TABLE PL_WEBSOCKET_URL_ALLOWED_ORIGINS (
  allowed_origins_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL,
  websocket_url_id bigint(20) unsigned NOT NULL,
  origin_name varchar(255) NOT NULL default '',
  origin_port int(8) unsigned default 0,
  origin_protocol int(2) unsigned not NULL default 3,
  flg_include_sub_domains tinyint(2) NOT NULL default 0,
  PRIMARY KEY (allowed_origins_id),
  UNIQUE KEY (websocket_url_id,origin_name,origin_port,origin_protocol),
  FOREIGN KEY (websocket_url_id) references PL_WEBSOCKET_URLS(websocket_url_id) ON DELETE CASCADE
) ENGINE=InnoDB;


CREATE TABLE PL_XML_PROFILE_OBJECTS (
  policy_id int(8) NOT NULL default '0',
  profile_id bigint(20) unsigned NOT NULL,
  object_uri varbinary(512) NOT NULL default '',
  FOREIGN KEY (profile_id) references PL_CONTENT_PROFILES(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


-- CONFIG_SYNC: PLC.PL_XML_PROFILE_SOAP_METHODS
-- POLICY_IMPORT: PLC.PL_XML_PROFILE_SOAP_METHODS
CREATE TABLE PL_XML_PROFILE_SOAP_METHODS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  profile_id bigint(20) unsigned NOT NULL,
  soap_method varbinary(512) NOT NULL default '',
  namespace varbinary(512) NOT NULL default '',
  allowed_soap_action varbinary(512) NOT NULL default '',
  flg_allowed int(2) NOT NULL default '1',
  PRIMARY KEY (id),
  UNIQUE (profile_id, soap_method(480), namespace(480)),
  FOREIGN KEY (profile_id) references PL_CONTENT_PROFILES(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


-- CONFIG_SYNC: PLC.PL_XML_PROFILE_VALIDATION_FILES
-- POLICY_IMPORT: PLC.PL_XML_PROFILE_VALIDATION_FILES
CREATE TABLE PL_XML_PROFILE_VALIDATION_FILES (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  profile_id bigint(20) unsigned NOT NULL,
  flg_is_primary_enforced int(2) NOT NULL default 0,
  xml_validation_file_id bigint(20) unsigned NOT NULL,
  import_url blob NULL default NULL,
  PRIMARY KEY (id),
  UNIQUE (profile_id, xml_validation_file_id, import_url(500)),
  FOREIGN KEY (profile_id) references PL_CONTENT_PROFILES(id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


-- CONFIG_SYNC: PLC.PL_XML_ROLE_ACTOR
-- POLICY_IMPORT: PLC.PL_XML_ROLE_ACTOR
CREATE TABLE PL_XML_ROLE_ACTOR( 
 policy_id int(8) unsigned NOT NULL default '0',
 id bigint(20) unsigned NOT NULL auto_increment,
 profile_id bigint(20) unsigned NOT NULL,
 role_actor varbinary(1024) default NULL,
 apply_to enum('Request','Response'),
 PRIMARY KEY (id),
 FOREIGN KEY (profile_id) references PL_CONTENT_PROFILES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


CREATE TABLE PL_XML_SOAP_PREDEFINED_PREFIX_NAMESPACE_MAPPING(
user_prefix varbinary(512) NOT NULL default '',
user_namespace varbinary(1024) NOT NULL default ''
) ENGINE=InnoDB;





CREATE TABLE PL_XML_SOAP_PREDEFINED_ROLE_ACTOR(
 short_name varbinary(512) NOT NULL default ''
) ENGINE=InnoDB;





CREATE TABLE PL_XML_SOAP_PREDEFINED_SPECIFIC_ELEMENTS (
  ws_action ENUM('encrypt','decrypt'),
  xpath_name varbinary(1024)
)ENGINE=InnoDB;






-- CONFIG_SYNC: PLC.PL_XML_SOAP_PREFIX_NAMESPACE_MAPPING
-- POLICY_IMPORT: PLC.PL_XML_SOAP_PREFIX_NAMESPACE_MAPPING
CREATE TABLE PL_XML_SOAP_PREFIX_NAMESPACE_MAPPING(
 prefix_id int(20) unsigned NOT NULL auto_increment,
 policy_id int(8) unsigned NOT NULL default '0',
 profile_id bigint(20) unsigned NOT NULL,
 user_prefix varbinary(512) NOT NULL default '',
 user_namespace varbinary(1024) NOT NULL default '',
 PRIMARY KEY (prefix_id),
 UNIQUE (user_prefix,profile_id),
 FOREIGN KEY (profile_id) references PL_CONTENT_PROFILES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_XML_SOAP_SECURITY
-- POLICY_IMPORT: PLC.PL_XML_SOAP_SECURITY
CREATE TABLE PL_XML_SOAP_SECURITY (
  soap_security_id int(10) unsigned NOT NULL auto_increment,
  profile_id bigint(20) unsigned NOT NULL,
  policy_id int(8) unsigned NOT NULL default '0',
  flg_encrypt_whole_body_content int(2) NOT NULL default '1',
  flg_add_timestamp int(2) NOT NULL default '0', 
  flg_enforce_timestamp int(2) NOT NULL default '0', 
  flg_enable_response_elements int(2) NOT NULL default '1', 
  flg_enable_request_elements int(2) NOT NULL default '1', 
  flg_enable_response_role_actor int(2) NOT NULL default '0', 
  flg_enable_request_role_actor int(2) NOT NULL default '0',
  flg_verify_all int(2) NOT NULL default '0', 
  flg_decrypt_all int(2) NOT NULL default '1', 
  create_timestamp_interval bigint(20) NOT NULL default '300', 
  timestamp_maximal_interval bigint(20) NOT NULL default '10000000000',
  flg_verify_body int(2) NOT NULL default '0',
  canonicalization_algorithm ENUM('exc-c14n') default 'exc-c14n', 
  signature_algorithm ENUM('hmac_sha1','rsa_sha1') default 'rsa_sha1', 
  encryption_algorithm ENUM('aes256','aes128','tripledes') default 'aes256',
  key_transport_algorithm ENUM('rsa-1_5','rsa_oaep'),
  request_ws_action ENUM('verify') default 'verify',
  response_ws_action ENUM('encrypt','sign','sign_before_encrypt','encrypt_before_sign') default 'encrypt',
  PRIMARY KEY  (soap_security_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (profile_id) references PL_CONTENT_PROFILES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_XML_SOAP_SPECIFIC_ELEMENTS
-- POLICY_IMPORT: PLC.PL_XML_SOAP_SPECIFIC_ELEMENTS
CREATE TABLE PL_XML_SOAP_SPECIFIC_ELEMENTS (
xpath_id int(10) unsigned NOT NULL auto_increment,
profile_id bigint(20) unsigned NOT NULL,
policy_id int(8) unsigned NOT NULL default '0',
apply_to ENUM('Request','Response') default 'Response',
xpath_name varbinary(1024) default NULL,
encrypted_part ENUM( 'element','content'),
PRIMARY KEY (xpath_id),
FOREIGN KEY (profile_id) references PL_CONTENT_PROFILES(id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_XML_VALIDATION_FILES
-- POLICY_IMPORT: PLC.PL_XML_VALIDATION_FILES
-- LARGE_RECORD_TABLE: PLC.PL_XML_VALIDATION_FILES
CREATE TABLE PL_XML_VALIDATION_FILES (
  xml_validation_file_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  file_name varchar(255) NOT NULL,
  file_contents mediumblob,
  file_type tinyint(2) NOT NULL default 1,
  last_updated int (10) default NULL,
  rest_uuid char(22) NOT NULL default '',
  is_inherited int(2) NOT NULL default 0,
  UNIQUE KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY (xml_validation_file_id),
  KEY (file_name)
) ENGINE=InnoDB COMMENT='';


CREATE TABLE PLAIN_TEXT_DEFENSE_ATTRIBUTES (
  def_attrib_id int(10) NOT NULL,
  def_attrib_xpath varchar(255) NOT NULL,
  def_attrib_name varchar(255) NOT NULL,
  gui_display_order int(10) NOT NULL,
  value_type ENUM('integer', 'string', 'boolean') NOT NULL,
  max_value int(10),
  min_value int(10),
  units varchar(255),
  learning_factor float,
  PRIMARY KEY (def_attrib_id)
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.PL_PLAIN_TEXT_PROFILE_DEFENSE_ATTRIBUTES 
-- POLICY_IMPORT: PLC.PL_PLAIN_TEXT_PROFILE_DEFENSE_ATTRIBUTES 
CREATE TABLE PL_PLAIN_TEXT_PROFILE_DEFENSE_ATTRIBUTES ( 
 policy_id int(8) NOT NULL default '0',
 profile_id bigint(20) unsigned NOT NULL, 
 def_attrib_id int(10) NOT NULL, 
 def_attrib_value varchar(255) default '', 
 flg_check_attrib int(2) NOT NULL default 1,
 PRIMARY KEY (profile_id, def_attrib_id), 
 FOREIGN KEY (profile_id)  references PL_CONTENT_PROFILES(id) ON DELETE CASCADE, 
 FOREIGN KEY (def_attrib_id) references PLAIN_TEXT_DEFENSE_ATTRIBUTES(def_attrib_id) 
) ENGINE=InnoDB;



CREATE TABLE PLAIN_TEXT_DEFENSE_ATTRIBUTES_DEFAULTS (
  def_attrib_id int(10) NOT NULL,
  def_attrib_value varchar(255) NOT NULL,
  flg_check_attrib int(2) NOT NULL default 1,
  PRIMARY KEY (def_attrib_id),
  FOREIGN KEY (def_attrib_id) references PLAIN_TEXT_DEFENSE_ATTRIBUTES(def_attrib_id)
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.POLICY_BUILDING_DISALLOWED_FILETYPES
CREATE TABLE POLICY_BUILDING_DISALLOWED_FILETYPES (
  disallowed_filetype_id bigint(20) unsigned NOT NULL auto_increment,
  disallowed_filetype_name varbinary(255) NOT NULL,
  rest_uuid char(22) NOT NULL default '',
  flg_is_user_defined tinyint(1) NOT NULL default 1,
  flg_is_deleted tinyint(1) NOT NULL default 0,
  KEY rest_uuid (rest_uuid),
  PRIMARY KEY (disallowed_filetype_id),
  UNIQUE KEY (disallowed_filetype_name)
) ENGINE=InnoDB;





CREATE TABLE POLICY_TEMPLATES_SYSTEMS ( 
  policy_template_system_id int(8) unsigned NOT NULL default '0', 
  policy_template_system_name varchar(255) character set latin1 collate latin1_bin NOT NULL default '', 
  PRIMARY KEY (policy_template_system_id), 
  UNIQUE KEY name (policy_template_system_name) 
) ENGINE=InnoDB;






-- CONFIG_SYNC: PLC.POLICY_TEMPLATES
CREATE TABLE POLICY_TEMPLATES (
  id int(8) unsigned NOT NULL auto_increment,
  name varchar(255) character set latin1 collate latin1_bin NOT NULL default '',
  icontrol_name varchar(255) character set latin1 collate latin1_bin NOT NULL default '',
  icontrol_enum_order int (8) NOT NULL default 0,
  description text NOT NULL,
  policy_template_system_id int(8) unsigned default NULL,
  template_file varchar(255) NOT NULL default '',
  display_priority int(10) NOT NULL default '0',
  flg_is_visible tinyint(1) NOT NULL DEFAULT 1,
  rest_uuid char(22) NOT NULL default '',
  template_type tinyint(1) NOT NULL default 3,
  policy_type tinyint(1) NOT NULL default 1,
  last_updated int(10) DEFAULT NULL,
  template_defaults text,
  flg_is_deprecated tinyint(1) NOT NULL default 0,
  PRIMARY KEY (id),
  KEY rest_uuid (rest_uuid),
  FOREIGN KEY (policy_template_system_id) references POLICY_TEMPLATES_SYSTEMS(policy_template_system_id),
  UNIQUE KEY name (name)
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.PL_POLICY_TEMPLATES_SETTINGS
-- POLICY_IMPORT: PLC.PL_POLICY_TEMPLATES_SETTINGS
CREATE TABLE PL_POLICY_TEMPLATES_SETTINGS (
  policy_templates_setting_id int(8) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  policy_template_id int(8) unsigned NOT NULL,
  FOREIGN KEY (policy_template_id) references POLICY_TEMPLATES(id) ON DELETE CASCADE,
  UNIQUE KEY (policy_id),
  PRIMARY KEY (policy_templates_setting_id)
) ENGINE=InnoDB COMMENT='';


CREATE TABLE REFINEMENTS (
  refinement_id int(4) unsigned NOT NULL default '0',
  description varbinary(255) NOT NULL default '',
  name varbinary(255) NOT NULL default '',
  group_name varbinary(255) NOT NULL default '',
  default_learn tinyint NOT NULL default 1,
  description_text mediumblob,
  description_risk mediumblob,
  description_examples mediumblob,
  section_type int(10),
  rest_uuid char(22) default '',
  KEY rest_uuid (rest_uuid),
  UNIQUE (description),
  UNIQUE (name),
  PRIMARY KEY  (refinement_id)
) ENGINE=InnoDB COMMENT='Contains the supported Policy Refinement properties';






CREATE TABLE RESPONSE_SCRUBBING_FORMATS(
  format_id int(8) unsigned NOT NULL,
  format_name varchar(255) NOT NULL,
  format_type varchar(255) NOT NULL,
  rest_uuid char(22) NOT NULL default '',
  KEY rest_uuid (rest_uuid),
  PRIMARY KEY  (format_id)
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.PL_RESPONSE_SCRUBBING_FORMATS
-- POLICY_IMPORT: PLC.PL_RESPONSE_SCRUBBING_FORMATS
CREATE TABLE PL_RESPONSE_SCRUBBING_FORMATS(
  policy_id int(8) unsigned NOT NULL,
  format_id int(8) unsigned NOT NULL,
  PRIMARY KEY  (policy_id, format_id),
  FOREIGN KEY (format_id) references RESPONSE_SCRUBBING_FORMATS(format_id) ON DELETE CASCADE,
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE
 ) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.SAVED_FILTERS
CREATE TABLE SAVED_FILTERS (
  filter_id int(8) unsigned NOT NULL auto_increment,
  kind varchar(255) NOT NULL default '',
  filter_name varchar(255) NOT NULL default '',
  partition_id varchar(255) NOT NULL default '',
  rest_uuid char(22) NOT NULL default '',
  filter blob NOT NULL default '',
  order_by blob NOT NULL default '',
  gui_filter blob NOT NULL default '',
  gui_order_by blob NOT NULL default '',
  PRIMARY KEY (filter_id),
  KEY rest_uuid (rest_uuid),
  UNIQUE (filter_name, partition_id, kind)
) ENGINE=InnoDB COMMENT='List of saved filters';


CREATE TABLE SECTION_PROPERTIES (
    section_property_id bigint(20) unsigned NOT NULL auto_increment,
    section_type int NOT NULL,
    description text,
    full_description text,
    inheritance_exceptions text NOT NULL default '',
    api_name text,
    flg_is_inheritable BOOL NOT NULL DEFAULT 0,
    rest_uuid char(22) NOT NULL default '',
    PRIMARY KEY (section_property_id),
    UNIQUE (section_type),
    KEY rest_uuid (rest_uuid)
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.SERVER_TECHNOLOGIES
CREATE TABLE SERVER_TECHNOLOGIES (
  server_technology_id bigint(20) unsigned NOT NULL auto_increment,
  server_technology_name varchar(255) NOT NULL,
  server_technology_display_name varchar(255) NOT NULL,
  description blob NOT NULL,
  logo_filename blob NOT NULL,
  last_updated int(20),
  rest_uuid char(22) NOT NULL default '',
  flg_is_learnable int(2) NOT NULL default '0',
  flg_has_deception_responses int(2) NOT NULL default '0',
  KEY rest_uuid (rest_uuid),
  PRIMARY KEY (server_technology_id),
  UNIQUE KEY (server_technology_name)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_SERVER_TECHNOLOGIES
-- POLICY_IMPORT: PLC.PL_SERVER_TECHNOLOGIES
CREATE TABLE PL_SERVER_TECHNOLOGIES (
  policy_server_technology_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  server_technology_id bigint(20) unsigned NOT NULL,
  last_updated int(20),
  is_inherited int(2) NOT NULL default 0, 
  rest_uuid char(22) NOT NULL default '',
  PRIMARY KEY (policy_server_technology_id),
  KEY rest_uuid (rest_uuid),
  UNIQUE (policy_id,server_technology_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (server_technology_id) references SERVER_TECHNOLOGIES(server_technology_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.SERVER_TECHNOLOGIES_FINGERPRINTS
CREATE TABLE SERVER_TECHNOLOGIES_FINGERPRINTS (
  server_technology_fingerprint_id bigint(20) unsigned NOT NULL auto_increment,
  server_technology_id bigint(20) unsigned NOT NULL,
  fingerprint_index int(10) NOT NULL,
  rule blob NOT NULL,
  packed_rule_obj blob,
  apply_to int(4) NOT NULL default 1,
  comment blob NOT NULL,
  accuracy int(10) NOT NULL,
  PRIMARY KEY (server_technology_fingerprint_id),
  FOREIGN KEY (server_technology_id) references SERVER_TECHNOLOGIES(server_technology_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.SERVER_TECHNOLOGIES_IMPLIED
CREATE TABLE SERVER_TECHNOLOGIES_IMPLIED (
  server_technology_implied_id bigint(20) unsigned NOT NULL auto_increment,
  server_technology_id bigint(20) unsigned NOT NULL,
  implied_server_technology varchar(255) NOT NULL,
  PRIMARY KEY (server_technology_implied_id),
  FOREIGN KEY (server_technology_id) references SERVER_TECHNOLOGIES(server_technology_id) ON DELETE CASCADE,
  FOREIGN KEY (implied_server_technology) references SERVER_TECHNOLOGIES(server_technology_name) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.SERVER_TECHNOLOGIES_POLICY_ACTIONS
CREATE TABLE SERVER_TECHNOLOGIES_POLICY_ACTIONS (
  server_technology_policy_action_id bigint(20) unsigned NOT NULL auto_increment,
  server_technology_id bigint(20) unsigned NOT NULL,
  policy_action varchar(1024) NOT NULL,
  PRIMARY KEY (server_technology_policy_action_id),
  FOREIGN KEY (server_technology_id) references SERVER_TECHNOLOGIES(server_technology_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.SIGFILE_AUTO_UPDATE_HISTORY
CREATE TABLE SIGFILE_AUTO_UPDATE_HISTORY (
  sigfile_auto_update_id int(8) unsigned NOT NULL auto_increment,
  attempt_datetime timestamp,
  completed_successfully tinyint(2),
  msg blob,
  PRIMARY KEY(sigfile_auto_update_id)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.SIGFILE_FLAGS
CREATE TABLE SIGFILE_FLAGS (
  update_mode enum('auto-interval','auto-user','manual') NOT NULL default 'auto-user',
  auto_update_interval enum('daily', 'weekly', 'monthly') NOT NULL default 'daily'
) ENGINE=InnoDB;






-- CONFIG_SYNC: PLC.SIGFILE_STATUS
CREATE TABLE SIGFILE_STATUS (
  sigfile_status_id int(8) unsigned NOT NULL auto_increment,
  sigfile_timestamp datetime,
  load_datetime datetime,
  bigip_version varchar(255),
  updated_by varchar(255) default NULL,
  update_mode enum('Manual', 'Scheduled') default NULL,
  readme longblob,
  last_added_readme_file varchar(255),
  sigs_updated_count int(8) unsigned NOT NULL default '0',
  sigs_updated_minor_count int(8) unsigned NOT NULL default '0',
  sigs_updated_major_count int(8) unsigned NOT NULL default '0',
  sigs_added_count int(8) unsigned NOT NULL default '0',
  sigs_deleted_count int(8) unsigned NOT NULL default '0',
  rest_uuid char(22) NOT NULL default '',
  flg_is_user_defined boolean NOT NULL default 0,
  sig_tag varchar(255) NOT NULL default '',
  sig_tag_policy varchar(255) NOT NULL default '',
  sigs_count int(8) unsigned NOT NULL default '0',
  botsigs_updated_count int(8) unsigned NOT NULL default '0',
  botsigs_added_count int(8) unsigned NOT NULL default '0',
  botsigs_deleted_count int(8) unsigned NOT NULL default '0',
  negsig_version int(10) NOT NULL default '1',
  server_technologies_updated_count int(8) unsigned NOT NULL default '0',
  server_technologies_added_count int(8) unsigned NOT NULL default '0',
  server_technologies_deleted_count int(8) unsigned NOT NULL default '0',
  KEY rest_uuid (rest_uuid),
  PRIMARY KEY (sigfile_status_id)
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.SIGFILE_MODIFIED_SIGNATURES
CREATE TABLE SIGFILE_MODIFIED_SIGNATURES (
  negsig_signature_update_id int(8) unsigned NOT NULL auto_increment,
  sig_id bigint(20) unsigned NOT NULL,
  sig_name varchar(255) NOT NULL,
  sig_tag varchar(255) NOT NULL default '',
  sig_tag_policy varchar(255) NOT NULL default '',
  change_level enum('minor', 'major', 'added') default NULL,
  sigfile_status_id int(8) unsigned NOT NULL,
  PRIMARY KEY (negsig_signature_update_id),
  FOREIGN KEY (sigfile_status_id) references SIGFILE_STATUS(sigfile_status_id) ON DELETE CASCADE,
  FOREIGN KEY (sig_id) references NEGSIG_SIGNATURES(sig_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.SSL_CERTIFICATES
CREATE TABLE SSL_CERTIFICATES (
  ssl_cert_id int(10) unsigned NOT NULL auto_increment,
  key_name varchar(255) NOT NULL default '',
  key_file blob,
  flg_skip_validation int(2) NOT NULL default 0,
  cert_type ENUM('client','server') NOT NULL default 'client',
  expiration_date datetime,
  last_updated int(10) NOT NULL default '0',
  rest_uuid char(22) NOT NULL default '',
  PRIMARY KEY(ssl_cert_id),
  KEY rest_uuid (rest_uuid),
  UNIQUE(key_name)
)ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.SSL_CERTIFICATE_FILES_PATH
CREATE TABLE SSL_CERTIFICATE_FILES_PATH (
  path_id int(10) unsigned NOT NULL auto_increment,
  ssl_cert_id int(10) unsigned NOT NULL,
  key_file_path varchar(255) NOT NULL default '',
  PRIMARY KEY(path_id),
  UNIQUE(ssl_cert_id),
  FOREIGN KEY(ssl_cert_id) references SSL_CERTIFICATES(ssl_cert_id) ON DELETE CASCADE
)ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_XML_PROFILE_SERVER_CERTIFICATE
-- POLICY_IMPORT: PLC.PL_XML_PROFILE_SERVER_CERTIFICATE
CREATE TABLE PL_XML_PROFILE_SERVER_CERTIFICATE (
  xml_server_id  int(10) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  profile_id bigint(20) unsigned NOT NULL,
  ssl_cert_id int(10) unsigned NOT NULL,
  PRIMARY KEY(xml_server_id),
  FOREIGN KEY(ssl_cert_id) references SSL_CERTIFICATES(ssl_cert_id) ON DELETE CASCADE,
  FOREIGN KEY(profile_id) references PL_CONTENT_PROFILES(id) ON DELETE CASCADE
)ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_XML_PROFILE_CLIENT_CERTIFICATE 
-- POLICY_IMPORT: PLC.PL_XML_PROFILE_CLIENT_CERTIFICATE
CREATE TABLE PL_XML_PROFILE_CLIENT_CERTIFICATE (
  xml_client_id int(10) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  profile_id bigint(20) unsigned NOT NULL,
  ssl_cert_id int(10) unsigned NOT NULL,
  PRIMARY KEY(xml_client_id), 
  FOREIGN KEY(ssl_cert_id) references SSL_CERTIFICATES(ssl_cert_id) ON DELETE CASCADE,
  FOREIGN KEY(profile_id) references PL_CONTENT_PROFILES(id) ON DELETE CASCADE
)ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.TAGS
CREATE TABLE TAGS (
  tag_id int(8) unsigned NOT NULL auto_increment,
  tag_name varchar(255) NOT NULL default '',
  partition_id varchar(255) NOT NULL default '',
  rest_uuid char(22) NOT NULL default '',
  PRIMARY KEY (tag_id),
  KEY rest_uuid (rest_uuid),
  UNIQUE (tag_name, partition_id)
) ENGINE=InnoDB COMMENT='List of tags';


CREATE TABLE THIRD_PARTY_ATTACKS (
  attack_id int(10) NOT NULL,
  attack_name varchar(255) NOT NULL default '',
  PRIMARY KEY (attack_id)
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.THREAT_CAMPAIGN_FILE_AUTO_UPDATE_HISTORY
CREATE TABLE THREAT_CAMPAIGN_FILE_AUTO_UPDATE_HISTORY (
  threat_campaign_file_auto_update_id int(8) unsigned NOT NULL auto_increment,
  attempt_datetime timestamp,
  completed_successfully tinyint(2),
  msg blob,
  PRIMARY KEY(threat_campaign_file_auto_update_id)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.THREAT_CAMPAIGN_FILE_FLAGS
CREATE TABLE THREAT_CAMPAIGN_FILE_FLAGS (
  update_mode enum('auto-interval','auto-user','manual') NOT NULL default 'auto-interval'
) ENGINE=InnoDB;






-- CONFIG_SYNC: PLC.THREAT_CAMPAIGN_FILE_STATUS
CREATE TABLE THREAT_CAMPAIGN_FILE_STATUS (
  threat_campaign_file_status_id int(8) unsigned NOT NULL auto_increment,
  threat_campaign_file_timestamp datetime,
  load_datetime datetime,
  bigip_version varchar(255),
  updated_by varchar(255) default NULL,
  update_mode enum('Manual', 'Scheduled') default NULL,
  threat_campaigns_updated_count int(8) unsigned NOT NULL default '0',
  threat_campaigns_added_count int(8) unsigned NOT NULL default '0',
  threat_campaigns_deleted_count int(8) unsigned NOT NULL default '0',
  rest_uuid char(22) NOT NULL default '',
  threat_campaigns_count int(8) unsigned NOT NULL default '0',
  KEY rest_uuid (rest_uuid),
  PRIMARY KEY (threat_campaign_file_status_id)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.THREAT_CAMPAIGNS
CREATE TABLE THREAT_CAMPAIGNS (
  threat_campaign_id bigint(20) unsigned NOT NULL auto_increment,
  name varchar(255) NOT NULL,
  display_name varchar(255) NOT NULL,
  description blob,
  intent varchar(255),
  target_info varchar(255),
  prevention blob,
  collateral_damage blob,
  remediation varchar(255),
  threat_actor_name varchar(255),
  threat_actor_description blob,
  payload_analysis blob,
  payload_tactics blob,
  risk tinyint(1) NOT NULL default '3',
  attack_type_id bigint(20) unsigned,
  status tinyint(1) NOT NULL default '1',
  first_observed int(20),
  last_observed int(20),
  last_updated int(20),
  source_datetime int(20),
  rest_uuid char(22) NOT NULL default '',
  KEY rest_uuid (rest_uuid),
  PRIMARY KEY (threat_campaign_id),
  UNIQUE KEY (name)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.THREAT_CAMPAIGN_FILE_MODIFIED_THREAT_CAMPAIGNS
CREATE TABLE THREAT_CAMPAIGN_FILE_MODIFIED_THREAT_CAMPAIGNS (
  threat_campaign_update_id int(8) unsigned NOT NULL auto_increment,
  threat_campaign_id bigint(20) unsigned NOT NULL,
  threat_campaign_name varchar(255) NOT NULL,
  threat_campaign_display_name varchar(255) NOT NULL,
  change_level enum('updated', 'added') default NULL,
  threat_campaign_file_status_id int(8) unsigned NOT NULL,
  PRIMARY KEY (threat_campaign_update_id),
  FOREIGN KEY (threat_campaign_file_status_id) references THREAT_CAMPAIGN_FILE_STATUS(threat_campaign_file_status_id) ON DELETE CASCADE,
  FOREIGN KEY (threat_campaign_id) references THREAT_CAMPAIGNS(threat_campaign_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.PL_THREAT_CAMPAIGNS
-- POLICY_IMPORT: PLC.PL_THREAT_CAMPAIGNS
CREATE TABLE PL_THREAT_CAMPAIGNS (
  policy_threat_campaign_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) unsigned NOT NULL default '0',
  threat_campaign_id bigint(20) unsigned NOT NULL,
  flg_enabled tinyint(1) NOT NULL default 1,
  flg_is_staging tinyint(1) NOT NULL default 1,
  is_inherited tinyint(1) NOT NULL default 0,
  last_updated int(20),
  staged_since int(10) default NULL,
  rest_uuid char(22) NOT NULL default '',
  PRIMARY KEY (policy_threat_campaign_id),
  KEY rest_uuid (rest_uuid),
  UNIQUE (policy_id,threat_campaign_id),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (threat_campaign_id) references THREAT_CAMPAIGNS(threat_campaign_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.THREAT_CAMPAIGNS_MALWARES
CREATE TABLE THREAT_CAMPAIGNS_MALWARES (
  threat_campaign_id bigint(20) unsigned NOT NULL,
  type varchar(255) NOT NULL,
  family varchar(255),
  target_system varchar(255),
  programming_language varchar(255),
  analysis blob,
  KEY threat_campaign_id (threat_campaign_id),
  FOREIGN KEY (threat_campaign_id) references THREAT_CAMPAIGNS(threat_campaign_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.THREAT_CAMPAIGNS_MATCH_RULES
CREATE TABLE THREAT_CAMPAIGNS_MATCH_RULES (
  threat_campaign_match_rule_id mediumint(8) unsigned NOT NULL auto_increment,
  threat_campaign_id bigint(20) unsigned NOT NULL,
  match_rule_index int(10) NOT NULL,
  match_rule blob NOT NULL,
  packed_rule_obj blob,
  apply_to int(4) NOT NULL default 1,
  buffer_type_mask int(10) NOT NULL default 0,
  PRIMARY KEY (threat_campaign_match_rule_id),
  KEY threat_campaign_id (threat_campaign_id),
  UNIQUE KEY (threat_campaign_id, match_rule_index),
  FOREIGN KEY (threat_campaign_id) references THREAT_CAMPAIGNS(threat_campaign_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.THREAT_CAMPAIGNS_REFERENCES
CREATE TABLE THREAT_CAMPAIGNS_REFERENCES (
  threat_campaign_id bigint(20) unsigned NOT NULL,
  type tinyint(1) NOT NULL,
  value blob NOT NULL,
  flg_is_clickable tinyint(1) NOT NULL default 1,
  KEY threat_campaign_id (threat_campaign_id),
  FOREIGN KEY (threat_campaign_id) references THREAT_CAMPAIGNS(threat_campaign_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.THREAT_CAMPAIGNS_SYSTEMS
CREATE TABLE THREAT_CAMPAIGNS_SYSTEMS (
  threat_campaign_id bigint(20) unsigned NOT NULL,
  system_id bigint(20) unsigned NOT NULL,
  KEY threat_campaign_id (threat_campaign_id),
  FOREIGN KEY (threat_campaign_id) references THREAT_CAMPAIGNS(threat_campaign_id) ON DELETE CASCADE,
  FOREIGN KEY (system_id) references NEGSIG_SYSTEMS(system_id) ON DELETE CASCADE
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_API_PROTECTION_PROFILE_CONFIG
CREATE TABLE TSK_API_PROTECTION_PROFILE_CONFIG (
   task_id bigint(20) unsigned NOT NULL auto_increment,
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   execution_start_time int(10) default NULL,
   end_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   policy_name varchar(255) binary NOT NULL default '',
   target_policy_id bigint(20) unsigned,
   full_path varchar(255),
   result_policy_id bigint(20) unsigned,
   message text,
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_APPLY_POLICY
CREATE TABLE TSK_APPLY_POLICY (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL, 
   task_status tinyint NOT NULL default '1',
   policy_id bigint(20) unsigned NOT NULL,
   message text,
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)   
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_APPLY_SERVER_TECHNOLOGIES
CREATE TABLE TSK_APPLY_SERVER_TECHNOLOGIES (
   task_id bigint(20) unsigned NOT NULL auto_increment,
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   target_policy_id bigint(20) unsigned,
   message text,
   get_messages_only tinyint NOT NULL default 0,
   include_implied_server_technologies tinyint NOT NULL default 1,
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


CREATE TABLE TSK_APPLY_SERVER_TECHNOLOGIES_FILES (
  id bigint(20) unsigned NOT NULL auto_increment,
  task_id bigint(20) unsigned NOT NULL,
  server_technology_id bigint(20) unsigned NOT NULL,
  PRIMARY KEY (id),
  FOREIGN KEY (task_id) references TSK_APPLY_SERVER_TECHNOLOGIES(task_id) ON DELETE CASCADE
)  ENGINE=InnoDB COMMENT='';


-- TSK_TABLE: PLC.TSK_ASSOC_JSON_VALIDATION_FILES
CREATE TABLE TSK_ASSOC_JSON_VALIDATION_FILES (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   policy_id bigint(20) unsigned,
   json_profile_id bigint(20) unsigned,
   primary_json_validation_file_id bigint(20) unsigned,
   flg_follow_schema_links int(2) NOT NULL default 1,
   message text,
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


CREATE TABLE TSK_ASSOC_JSON_VALIDATION_FILES_PROFILE_MISSING_FILES (
  id bigint(20) unsigned NOT NULL auto_increment,
  task_id bigint(20) unsigned NOT NULL,
  missing_file varchar(512) NOT NULL default '',
  PRIMARY KEY (id),
  FOREIGN KEY (task_id) references TSK_ASSOC_JSON_VALIDATION_FILES(task_id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


CREATE TABLE TSK_ASSOC_JSON_VALIDATION_FILES_PROFILE_VALIDATION_FILES (
  id bigint(20) unsigned NOT NULL auto_increment,
  task_id bigint(20) unsigned NOT NULL,
  json_validation_file_id bigint(20) unsigned NOT NULL default '0',
  import_url blob NOT NULL default '',
  PRIMARY KEY (id),
  FOREIGN KEY (task_id) references TSK_ASSOC_JSON_VALIDATION_FILES(task_id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


-- TSK_TABLE: PLC.TSK_ASSOC_XML_VALIDATION_FILES
CREATE TABLE TSK_ASSOC_XML_VALIDATION_FILES (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   policy_id bigint(20) unsigned,
   xml_profile_id bigint(20) unsigned,
   primary_xml_validation_file_id bigint(20) unsigned,
   flg_follow_schema_links int(2) NOT NULL default 1,
   message text,
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


CREATE TABLE TSK_ASSOC_XML_VALIDATION_FILES_PROFILE_MISSING_FILES (
  id bigint(20) unsigned NOT NULL auto_increment,
  task_id bigint(20) unsigned NOT NULL,
  missing_file varchar(512) NOT NULL default '',
  PRIMARY KEY (id),
  FOREIGN KEY (task_id) references TSK_ASSOC_XML_VALIDATION_FILES(task_id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


CREATE TABLE TSK_ASSOC_XML_VALIDATION_FILES_PROFILE_VALIDATION_FILES (
  id bigint(20) unsigned NOT NULL auto_increment,
  task_id bigint(20) unsigned NOT NULL,
  xml_validation_file_id bigint(20) unsigned NOT NULL default '0',
  import_url blob NOT NULL default '',
  PRIMARY KEY (id),
  FOREIGN KEY (task_id) references TSK_ASSOC_XML_VALIDATION_FILES(task_id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


-- TSK_TABLE: PLC.TSK_BULK
CREATE TABLE TSK_BULK (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   is_transaction boolean NOT NULL default 1,
   timeout_seconds int(10) NOT NULL default 0,
   bulk_deploy_file varchar(255) default NULL,
   asm_bulk_deploy_file varchar(255) default NULL,
   flg_create_result_reference boolean NOT NULL default 0,
   result_file varchar(255) default NULL,
   file_size int,
   message text,
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


CREATE TABLE TSK_BULK_COMMANDS (
  id bigint(20) unsigned NOT NULL auto_increment,
  task_id bigint(20) unsigned NOT NULL,
  method char(8) NOT NULL,
  uri blob NOT NULL,
  body_blob longblob default NULL, 
  PRIMARY KEY (id),
  FOREIGN KEY (task_id) references TSK_BULK(task_id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


CREATE TABLE TSK_BULK_ERRORS (
  id bigint(20) unsigned NOT NULL auto_increment,
  task_id bigint(20) unsigned NOT NULL,
  error varchar(512) NOT NULL default '',
  PRIMARY KEY (id),
  FOREIGN KEY (task_id) references TSK_BULK(task_id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


-- TSK_TABLE: PLC.TSK_CHECK_SIGNATURES
CREATE TABLE TSK_CHECK_SIGNATURES (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',   
   message text,
   is_update_available bool,
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_CHECK_THREAT_CAMPAIGNS
CREATE TABLE TSK_CHECK_THREAT_CAMPAIGNS (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',   
   message text,
   is_update_available bool,
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_EXPORT_DATA_PROTECTION
CREATE TABLE TSK_EXPORT_DATA_PROTECTION (
   task_id bigint(20) unsigned NOT NULL auto_increment,
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   message text,
   flg_inline boolean NOT NULL default '0',
   filename varchar(255),
   file_size int,
   exported_data_protection longblob,
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_EXPORT_POLICY
CREATE TABLE TSK_EXPORT_POLICY (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   policy_id bigint(20) unsigned NOT NULL,
   policy_template_id bigint(20) unsigned,
   message text,
   flg_inline boolean NOT NULL default '0',
   flg_include_vulnerability boolean NOT NULL default '1',
   filename varchar(255),
   flg_minimal boolean NOT NULL default '0',
   file_size int,
   exported_policy longblob,
   flg_is_base64 boolean NOT NULL default '0',  
   file_format tinyint NOT NULL default '1',
   flg_export_suggestions boolean NOT NULL default '0',
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)   
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_EXPORT_POLICY_TEMPLATE
CREATE TABLE TSK_EXPORT_POLICY_TEMPLATE (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   policy_template_id bigint(20) unsigned NOT NULL,
   message text,
   flg_inline boolean NOT NULL default '0',
   filename varchar(255),
   file_size int,
   exported_policy_template longblob,
   flg_is_base64 boolean NOT NULL default '0',  
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)   
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_EXPORT_REQUESTS
CREATE TABLE TSK_EXPORT_REQUESTS (
   task_id bigint(20) unsigned NOT NULL auto_increment,
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   filename varchar(255),
   file_size int,
   exported_requests longblob,
   flg_inline tinyint(2) NOT NULL default '0',
   flg_is_base64 tinyint(2) NOT NULL default '0',
   filter text,
   order_by varchar(255),
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_EXPORT_SIGNATURES
CREATE TABLE TSK_EXPORT_SIGNATURES (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   message text,
   flg_inline boolean NOT NULL default '0',
   filename varchar(255),
   exported_signatures longblob,
   flg_is_base64 boolean NOT NULL default '0',
   pid int(8) NOT NULL default '0',
   file_size int,
   sig_filter text,
   file_format varchar(15),
   sig_tag varchar(50),
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)   
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_EXPORT_SUGGESTIONS
CREATE TABLE TSK_EXPORT_SUGGESTIONS (
   task_id bigint(20) unsigned NOT NULL auto_increment,
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   policy_id bigint(20) unsigned NOT NULL,
   filename varchar(255),
   file_size int,
   exported_suggestions longblob,
   message longblob,
   flg_inline tinyint(2) NOT NULL default '0',
   filter text,
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_EXPORT_TO_FILE
CREATE TABLE TSK_EXPORT_TO_FILE (
   task_id bigint(20) unsigned NOT NULL auto_increment,
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   filename varchar(255),
   file_size int,
   inline_result longblob,
   flg_inline tinyint(2) NOT NULL default '0',
   flg_is_base64 tinyint(2) NOT NULL default '0',
   filter text,
   order_by varchar(255),
   pid int(8) NOT NULL default '0',
   rest_path varchar(255),
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_IMPORT_CERTIFICATE
CREATE TABLE TSK_IMPORT_CERTIFICATE (
   task_id bigint(20) unsigned NOT NULL auto_increment, 
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   filename varchar(255),
   file_contents longblob,
   result_certificate_id bigint(20) unsigned,
   message text,
   flg_skip_validation BOOL NOT NULL DEFAULT 0,
   key_name varchar(255),
   cert_type enum('client','server'),
   target_certificate_id bigint(20) unsigned,
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_IMPORT_DATA_PROTECTION
CREATE TABLE TSK_IMPORT_DATA_PROTECTION (
   task_id bigint(20) unsigned NOT NULL auto_increment,
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   message text,
   result_data_protection_id int(8) unsigned,
   import_text text,
   filename varchar(255),
   file_contents longblob,
   grace_signing_interval int(10) NOT NULL default 0,
   grace_accepting_interval int(10) NOT NULL default 0,
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


CREATE TABLE TSK_IMPORT_DATA_PROTECTION_CONFIGURATION (
  import_data_protection_configuration_id  bigint(20) unsigned NOT NULL auto_increment,
  import_data_protection_task_id bigint(20) unsigned NOT NULL,
  cookie_type int(4) NOT NULL default 0,
  scramble_algorithm int(4) NOT NULL default 0,
  PRIMARY KEY (import_data_protection_configuration_id),
  FOREIGN KEY (import_data_protection_task_id) references TSK_IMPORT_DATA_PROTECTION(task_id) ON DELETE CASCADE,
  UNIQUE KEY cookie_type (cookie_type)
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_IMPORT_OPEN_API
CREATE TABLE TSK_IMPORT_OPEN_API (
   task_id bigint(20) unsigned NOT NULL auto_increment,
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   target_policy_id bigint(20) unsigned,
   filename varchar(255),
   file_contents longblob,
   policy_name varchar(255),
   full_path varchar(255),
   policy_template_id int(8) unsigned,
   message text,
   result_policy_id bigint(20) unsigned,
   encoding varchar(255),
   flg_is_base64 boolean NOT NULL default '0',
   policy_description varchar(255),
   api_type int(10) NOT NULL default 1,
   api_content_format tinyint(2),
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY (task_id)
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_IMPORT_POLICY
CREATE TABLE TSK_IMPORT_POLICY (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   target_policy_id bigint(20) unsigned,
   filename varchar(255),
   file_contents longblob,
   file_reference blob,
   policy_history_id bigint(20) unsigned,
   policy_template_id int(8) unsigned,
   policy_name varchar(255),
   full_path varchar(255),
   message text,
   result_policy_id bigint(20) unsigned,
   flg_is_base64 boolean NOT NULL default '0',
   encoding varchar(255),
   flg_encoding_selected boolean,
   policy_type tinyint(2),
   flg_allow_parent_policy boolean default NULL,
   parent_policy_id bigint(20) unsigned,
   source_policy_id bigint(20) unsigned,
   retain_inheritance_settings boolean NOT NULL default 0,
   policy_description varchar(255),
   get_policy_attributes_only boolean NOT NULL default 0,
   result_policy_attributes longblob,
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_IMPORT_POLICY_TEMPLATE
CREATE TABLE TSK_IMPORT_POLICY_TEMPLATE (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   policy_id bigint(20) unsigned NOT NULL,
   message text,
   target_policy_template_id int(8) unsigned,
   result_policy_template_id int(8) unsigned,
   template_name varchar(255),
   template_title varchar(255),
   description varchar(255),
   filename varchar(255),
   file_contents longblob,
   flg_is_base64 boolean NOT NULL default '0',
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)   
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_IMPORT_VULNERABILITIES
CREATE TABLE TSK_IMPORT_VULNERABILITIES (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   target_policy_id bigint(20) unsigned,
   filename varchar(255),
   file_contents longblob,
   message text,
   flg_is_base64 boolean NOT NULL default '0',
   vulnerability_count int default NULL,
   only_get_domain_names boolean NOT NULL default '0',
   import_all_domain_names boolean NOT NULL default '0',
   subscription_id varchar(255),
   scan_id varchar(255),
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


CREATE TABLE TSK_IMPORT_VULNERABILITIES_DOMAIN_NAMES (
  id bigint(20) unsigned NOT NULL auto_increment,
  task_id bigint(20) unsigned NOT NULL,
  domain_name VARCHAR(511) NULL default '',
  PRIMARY KEY (id),
  FOREIGN KEY (task_id) references TSK_IMPORT_VULNERABILITIES(task_id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


CREATE TABLE TSK_IMPORT_VULNERABILITIES_VULNERABLE_HOSTS (
  id bigint(20) unsigned NOT NULL auto_increment,
  task_id bigint(20) unsigned NOT NULL,
  domain_name VARCHAR(511) NULL default '',
  vulnerability_count int default '0',
  PRIMARY KEY (id),
  FOREIGN KEY (task_id) references TSK_IMPORT_VULNERABILITIES(task_id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


-- TSK_TABLE: PLC.TSK_INIT_VULN_ASSESSMENT
CREATE TABLE TSK_INIT_VULN_ASSESSMENT (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   target_policy_id bigint(20) unsigned,
   message text,
   subscription_id varchar(255),
   scan_id varchar(255),
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_POLICY_DIFF
CREATE TABLE TSK_POLICY_DIFF (
   task_id bigint(20) unsigned NOT NULL auto_increment,
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   message text,
   pid int(8) NOT NULL default '0',
   first_policy_id bigint(20) unsigned,
   second_policy_id bigint(20) unsigned,
   result_diff_id bigint(20) unsigned,
   force_diff tinyint(2) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_POLICY_MERGE
CREATE TABLE TSK_POLICY_MERGE (
   task_id bigint(20) unsigned NOT NULL auto_increment,
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   message text,
   pid int(8) NOT NULL default '0',
   diff_id bigint(20) unsigned,
   add_missing_entities_to_first tinyint(2) NOT NULL default '0',
   add_missing_entities_to_second tinyint(2) NOT NULL default '0',
   handle_common_entities int(8)unsigned NOT NULL default '0',
   item_filter text,
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_RESOLVE_VULNERABILITIES
CREATE TABLE TSK_RESOLVE_VULNERABILITIES (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   policy_id bigint(20) unsigned,
   get_pre_resolve_messages tinyint NOT NULL default 0,
   stage_vulnerabilities tinyint NOT NULL default 0,
   message text,
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


CREATE TABLE TSK_RESOLVE_VULNERABILITIES_VULNS (
  id bigint(20) unsigned NOT NULL auto_increment,
  task_id bigint(20) unsigned NOT NULL,
  vuln_id bigint(20) unsigned NOT NULL default '0',
  PRIMARY KEY (id),
  FOREIGN KEY (task_id) references TSK_RESOLVE_VULNERABILITIES(task_id) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='';


-- TSK_TABLE: PLC.TSK_TERMINATE_VULN_ASSESSMENT
CREATE TABLE TSK_TERMINATE_VULN_ASSESSMENT (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   target_policy_id bigint(20) unsigned,
   message text,
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_UPDATE_ENFORCER
CREATE TABLE TSK_UPDATE_ENFORCER (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   message text,
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)   
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_UPDATE_SIGNATURES
CREATE TABLE TSK_UPDATE_SIGNATURES (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   filename varchar(255),
   file_contents longblob,
   flg_user_defined tinyint NOT NULL default '0',
   message text,
   sigfile_status_id int(8) unsigned,
   flg_is_base64 boolean NOT NULL default '0',
   flg_allow_older_timestamp boolean NOT NULL default '0',
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_UPDATE_THREAT_CAMPAIGNS
CREATE TABLE TSK_UPDATE_THREAT_CAMPAIGNS (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   filename varchar(255),
   file_contents longblob,
   message text,
   threat_campaign_file_status_id int(8) unsigned,
   flg_is_base64 boolean NOT NULL default '0',
   flg_allow_older_timestamp boolean NOT NULL default '0',
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


-- TSK_TABLE: PLC.TSK_VULN_SUBSCRIPTION
CREATE TABLE TSK_VULN_SUBSCRIPTION (
   task_id bigint(20) unsigned NOT NULL auto_increment,   
   rest_uuid char(22) NOT NULL default '',
   username varchar(255) NOT NULL default '',
   last_updated int(10) NOT NULL default '0',
   start_time decimal(16,6) NOT NULL default '0',
   end_time int(10) default NULL,
   execution_start_time int(10) default NULL,
   task_status tinyint NOT NULL default '1',
   target_policy_id bigint(20) unsigned,
   message text,
   subscriptions blob,
   pid int(8) NOT NULL default '0',
   KEY rest_uuid (rest_uuid),
   PRIMARY KEY  (task_id)
) ENGINE=InnoDB;


-- CONFIG_SYNC: PLC.VIOLATIONS
CREATE TABLE VIOLATIONS (
  enum_id int(4) unsigned NOT NULL default '0',
  attack_type_id bigint(20) unsigned default NULL,
  flg_reject int(2) NOT NULL default '0',
  flg_enable_reject int(2) NOT NULL default '1',
  flg_alarm int(2) NOT NULL default '0',
  flg_enable_alarm int(2) NOT NULL default '1',
  description varbinary(80) NOT NULL default '',
  icontrol_name varbinary(50) NOT NULL default '',
  flg_disp_graph int(2) NOT NULL default '1',
  flg_disp_plc int(2) NOT NULL default '1',
  event_category_id int(10) NOT NULL default '0',
  group_id int(10) NOT NULL default '0',
  flg_learn int(2) NOT NULL default '0',
  flg_enable_learn int(2) NOT NULL default '1',
  flg_log_only int(2) NOT NULL default '0',
  flg_pb_handled int(2) NOT NULL default '0',
  violation_description_id int(10) unsigned default NULL,
  viol_index int(10) NOT NULL,
  viol_name varbinary(255) NOT NULL default '',
  description_text mediumblob,
  description_risk mediumblob,
  description_examples mediumblob,
  bd_icontrol_name varbinary(255) NOT NULL default '',
  attack_type_code bigint(20) unsigned NOT NULL default '0',
  viol_name_crc int(32) unsigned NOT NULL default '0',
  flg_is_user_defined int(2) NOT NULL default '0',
  flg_is_deleted int(2) NOT NULL default '0',
  delete_time int(11) NOT NULL default 0,
  created_time int(11) NOT NULL default 0,
  section_type int(10) default NULL,
  rest_uuid char(22) default '',
  last_updated int(10) NOT NULL default 0,
  flg_exclude_session_awareness tinyint(2) NOT NULL default '0',
  feature_flag char(64) default '',
  KEY rest_uuid (rest_uuid),
  UNIQUE (viol_name),
  UNIQUE (description),
  UNIQUE (icontrol_name),
  PRIMARY KEY  (viol_index)
) ENGINE=InnoDB COMMENT='Contains the supported enforcer violation properties';







-- CONFIG_SYNC: PLC.PL_SESSION_AWARENESS_VIOLATIONS
-- POLICY_IMPORT: PLC.PL_SESSION_AWARENESS_VIOLATIONS
CREATE TABLE PL_SESSION_AWARENESS_VIOLATIONS (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  viol_index int(10) NOT NULL,
  PRIMARY KEY (id),
  UNIQUE (policy_id, viol_index),
  FOREIGN KEY (viol_index) REFERENCES VIOLATIONS (viol_index)ON DELETE CASCADE
) ENGINE=InnoDB;



-- CONFIG_SYNC: PLC.PL_SECURITY_LEVEL_DEFAULTS
CREATE TABLE PL_SECURITY_LEVEL_DEFAULTS (
  security_level_id int(8) NOT NULL default '0',
  flg_alarm int(2) NOT NULL default '0',
  flg_reject int(2) NOT NULL default '0',
  flg_learn int(2) NOT NULL default '0',
  viol_index int(10) NOT NULL default 0,
  UNIQUE (security_level_id, viol_index),
  FOREIGN KEY (viol_index) references VIOLATIONS(viol_index) ON DELETE CASCADE
) ENGINE=InnoDB;






-- CONFIG_SYNC: PLC.PL_MICROSERVICE_BLOCKING_OVERRIDES
-- POLICY_IMPORT: PLC.PL_MICROSERVICE_BLOCKING_OVERRIDES
CREATE TABLE PL_MICROSERVICE_BLOCKING_OVERRIDES (
  microservice_blocking_override_id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  microservice_id bigint(20) unsigned NOT NULL,
  flg_alarm int(2) NOT NULL default '0',
  flg_reject int(2) NOT NULL default '0',
  flg_learn int(2) NOT NULL default '0',
  viol_index int(10) NOT NULL default 0,
  PRIMARY KEY (microservice_blocking_override_id),
  FOREIGN KEY (viol_index) references VIOLATIONS(viol_index) ON DELETE CASCADE,
  FOREIGN KEY (microservice_id) references PL_MICROSERVICES(microservice_id) ON DELETE CASCADE,
  UNIQUE KEY policy_id (policy_id,microservice_id,viol_index)
) ENGINE=InnoDB COMMENT='Contain data about override blocking policy violations';


-- CONFIG_SYNC: PLC.PL_BLOCKING
-- POLICY_IMPORT: PLC.PL_BLOCKING
CREATE TABLE PL_BLOCKING (
  id bigint(20) unsigned NOT NULL auto_increment,
  policy_id int(8) NOT NULL default '0',
  flg_alarm int(2) NOT NULL default '0',
  flg_reject int(2) NOT NULL default '0',
  flg_learn int(2) NOT NULL default '0',
  flg_pb_enabled int(2) NOT NULL default '1',
  viol_index int(10) NOT NULL default 0,
  rest_uuid char(22) NOT NULL default '',
  is_inherited int(2) NOT NULL default 0,
  last_updated int(10) NOT NULL default 0,
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY  (id),
  FOREIGN KEY (viol_index) references VIOLATIONS(viol_index) ON DELETE CASCADE,
  UNIQUE KEY policy_id (policy_id,viol_index)
) ENGINE=InnoDB COMMENT='Contain data about blocking policy violations';


-- CONFIG_SYNC: PLC.VIOLATIONS_PROPERTIES
CREATE TABLE VIOLATIONS_PROPERTIES (
  viol_index int(10) NOT NULL default '0',
  severity_id int(10) NOT NULL default '0',
  FOREIGN KEY (viol_index) references VIOLATIONS(viol_index) ON DELETE CASCADE
) ENGINE=InnoDB COMMENT='User defined properties for violations';



CREATE TABLE VIOLATIONS_PROPERTIES_DEFAULTS (
  viol_index int(10) NOT NULL default '0',
  severity_id int(10) NOT NULL default '0',
  PRIMARY KEY  (viol_index)
) ENGINE=InnoDB COMMENT='Default properties for violations';







-- CONFIG_SYNC: PLC.VIRUS_DETECTION_SERVER
CREATE TABLE VIRUS_DETECTION_SERVER (   
   virus_detection_server_id int(2) NOT NULL default 1,
   icap_server_port varchar(128) default 0,
   hostname varchar(255) default '',
   flg_check_guaranteed int(2) NOT NULL default 0,
   PRIMARY KEY (virus_detection_server_id)
 ) ENGINE=InnoDB;






CREATE TABLE XML_DEFENSE_ATTRIBUTES (
  def_attrib_id int(10) NOT NULL,
  def_attrib_xpath varchar(255) NOT NULL,
  def_attrib_name varchar(255) NOT NULL,
  gui_display_order int(10) NOT NULL,
  value_type ENUM('integer', 'string', 'boolean') NOT NULL,
  min_value int(10),
  max_value int(10),
  units varchar(255),
  learning_factor float,
  PRIMARY KEY (def_attrib_id),
  UNIQUE (def_attrib_xpath)
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.PL_XML_PROFILE_DEFENSE_ATTRIBUTES
-- POLICY_IMPORT: PLC.PL_XML_PROFILE_DEFENSE_ATTRIBUTES
CREATE TABLE PL_XML_PROFILE_DEFENSE_ATTRIBUTES (
  policy_id int(8) NOT NULL default '0',
  profile_id bigint(20) unsigned NOT NULL,
  def_attrib_id int(10) NOT NULL,
  def_attrib_value varchar(255) default '',
  flg_check_attrib int(2) NOT NULL default 1,
  created_by enum('GUI', 'PolicyBuilder') NOT NULL default 'GUI',
  PRIMARY KEY (profile_id, def_attrib_id),
  FOREIGN KEY (profile_id) references PL_CONTENT_PROFILES(id) ON DELETE CASCADE,
  FOREIGN KEY (def_attrib_id) references XML_DEFENSE_ATTRIBUTES(def_attrib_id)
) ENGINE=InnoDB;



CREATE TABLE XML_DEFENSE_ATTRIBUTES_DEFAULTS (
  def_attrib_id int(10) NOT NULL,
  defense_level ENUM('HIGH', 'MEDIUM', 'LOW') NOT NULL,
  def_attrib_value varchar(255) NOT NULL,
  flg_check_attrib int(2) NOT NULL default 1,
  PRIMARY KEY (def_attrib_id, defense_level),
  FOREIGN KEY (def_attrib_id) references XML_DEFENSE_ATTRIBUTES(def_attrib_id)
) ENGINE=InnoDB;





CREATE TABLE XML_WS_SUBVIOLATIONS_CODES (
  subviolation_code int(8) unsigned NOT NULL,
  subviolation_name varchar(255) NOT NULL,
  subviolation_description varchar(255) NOT NULL,
  description_text mediumblob,
  description_risk mediumblob,
  description_examples mediumblob,
  rest_uuid char(22) NOT NULL default '',
  KEY rest_uuid (rest_uuid),
  PRIMARY KEY(subviolation_code)
) ENGINE=InnoDB;





CREATE TABLE PL_XML_WS_SUBVIOLATIONS_DEFAULTS (
  subviolation_code int(8) unsigned NOT NULL,
  flg_is_enabled int(2) NOT NULL default '0',
  flg_pb_enabled int(2) NOT NULL default '1',
  rest_uuid char(22) not null default '',
  PRIMARY KEY (subviolation_code),
  FOREIGN KEY (subviolation_code) references XML_WS_SUBVIOLATIONS_CODES(subviolation_code) ON DELETE CASCADE
) ENGINE=InnoDB;





-- CONFIG_SYNC: PLC.PL_XML_WS_SUBVIOLATIONS
-- POLICY_IMPORT: PLC.PL_XML_WS_SUBVIOLATIONS
CREATE TABLE PL_XML_WS_SUBVIOLATIONS (
  policy_id int(8) unsigned NOT NULL default '0',
  subviolation_code int(8) unsigned NOT NULL,
  flg_is_enabled int(2) NOT NULL default '0',
  flg_pb_enabled int(2) NOT NULL default '1',
  rest_uuid char(22) NOT NULL default '',
  last_updated int(10) NOT NULL default 0,
  is_inherited int(2) NOT NULL default 0,
  KEY rest_uuid (policy_id, rest_uuid),
  PRIMARY KEY (policy_id,subviolation_code),
  FOREIGN KEY (policy_id) references PL_POLICIES(id) ON DELETE CASCADE,
  FOREIGN KEY (subviolation_code) references XML_WS_SUBVIOLATIONS_CODES(subviolation_code) ON DELETE CASCADE
) ENGINE=InnoDB;


